#!/usr/bin/env python3
#
# Write a matrix element file using stored data.  This demonstrates
# using the Python interface to create a file and provides an
# example file for testing without running Gaussian.  The name of the
# file to create is taken from the sixth command-line argument if it
# exists (so that this script can be run as an External command from
# Gaussian) or from the first argument if the sixth is not present.
#
import numpy as np
import qcmatrixio as qcio
import sys
import QCOpMat as qco
import QCMatEl as qcm

dellist = ["ALPHA FOCK MATRIX", "BETA FOCK MATRIX", "REGULAR 2E INTEGRALS", "RAFFENETTI 2E INTEGRALS",
           "AA MO 2E INTEGRALS", "AB MO 2E INTEGRALS", "BA MO 2E INTEGRALS", "BB MO 2E INTEGRALS"]

def main():
  if len(sys.argv) >= 7: fname = sys.argv[6]
  else: fname = fname = sys.argv[1]

# create an empty object
  mel = qcm.MatEl(debug=True)

# load the header information, which gives the basic information about
# the molecule.
  mel.load_head(title="data from wrmat.py.1.0",natoms=3,nbasis=20,nbsuse=20,
    icharg=1,multip=2,ne=17,iopcl=1,nfc=2,nfv=0,itran=4,ian=[8,9,1],
    c=[9.5021380072e-02,1.3081104173e+00,-4.9303806576e-32,
       9.5021380072e-02,-1.3753006795e+00,4.9303806576e-32,
       -1.6153634612e+00,1.9128227772e+00,-4.9303806576e-32],
    atmwgt=[1.5994914640e+01,1.8998403250e+01,1.0078250370e+00])

# set some standard  information about the basis, number of electrons, etc.
  mel.nshlao = 8
  mel.nprmao = 15,
  mel.nbondtot = 4
  mel.ibfatm = np.array([1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,3,3],dtype="int32")
  mel.ibftyp = np.array([1,1,1001,1002,1003,1,1001,1002,1003,1,1,1001,1002,1003,
                         1,1001,1002,1003,1,1],dtype="int32")

# set some standard scalar result values such as the nuclear repulsion
# and ScF energies
  mel.set_scalars(virial=2.0041175143,S4SD=1.641414,ESCF=-173.371408,
                  ENucRep=33.669583,ETotal=-173.371408,S2SCF=0.988710,
                  S2A=0.752852,JobStatus=1.000000)

# some derived scalars which are used later
  nae = int(int(mel.ne+mel.multip-1)/2)
  nbe = int(int(mel.ne-mel.multip+1)/2)
  noa = int(nae-mel.nfc)
  nob = int(nbe-mel.nfc)
  nrorb = int(mel.nbsuse-mel.nfc-mel.nfv)

#
# loop over the list of operator matrices to include.  The get_arr
# subroutine holds the static values to be stored in each matrix.
  for name in qcm.mat_names_arr:
    asym,n,dimens,arr = get_arr(name,mel.natoms,mel.nbasis,mel.nbsuse,noa,nob,nrorb)
    if arr is not None:
      myobj = qco.OpMat(name,arr,asym=asym,nelem=n,dimens=dimens)
      mel.addobj(myobj)
  if len(sys.argv) > 2 and sys.argv[2] == "upd":
    for x in dellist:  mel.delobj(x)
    status, itemp, otemp = mel.update (dofock="density",model="b3lyp")
    if status: print ("new file",mel)
    else: print ("failed files",itemp,otemp)
  else:
    mel.write(fname)

def get_arr(name,natoms,nbasis,nbsuse,noa,nob,nrorb):
  asym = False
  n = 1
  dimens = None
  norbtt = int((nrorb*(nrorb+1))/2)
  if name == "IAn":
    arr = np.array([8, 9, 1], dtype=np.int32)
  elif name == "IAtTyp":
    arr = np.array([0, 0, 0], dtype=np.int32)
  elif name == "AtmChg":
    arr = np.array([  8.,   9.,   1.])
  elif name == "C":
    arr = np.array([  9.50213801e-02,   1.30811042e+00,  -4.93038066e-32,
         9.50213801e-02,  -1.37530068e+00,   4.93038066e-32,
        -1.61536346e+00,   1.91282278e+00,  -4.93038066e-32])
  elif name == "IBfAtm":
    arr = np.array([1, 1, 1, 1, 1, 1, 1, 1, 1, 2, 2, 2, 2, 2, 2, 2, 2, 2, 3, 3], dtype=np.int32)
  elif name == "IBfTyp":
    arr = np.array([   1,    1, 1001, 1002, 1003,    1, 1001, 1002, 1003,    1,    1,
       1001, 1002, 1003,    1, 1001, 1002, 1003,    1,    1], dtype=np.int32)
  elif name == "AtmWgt":
    arr = np.array([ 15.99491464,  18.99840325,   1.00782504])
  elif name == "SHELL TO ATOM MAP":
    arr = np.array([1, 1, 1, 2, 2, 2, 3, 3], dtype=np.int32)
  elif name == "SHELL TYPES":
    arr = np.array([ 0, -1, -1,  0, -1, -1,  0,  0], dtype=np.int32)
  elif name == "NUMBER OF PRIMITIVES PER SHELL":
    arr = np.array([3, 2, 1, 3, 2, 1, 2, 1], dtype=np.int32)
  elif name == "PRIMITIVE EXPONENTS":
    arr = np.array([  3.22037000e+02,   4.84308000e+01,   1.04206000e+01,
         7.40294000e+00,   1.57620000e+00,   3.73684000e-01,
         4.13801000e+02,   6.22446000e+01,   1.34340000e+01,
         9.77759000e+00,   2.08617000e+00,   4.82383000e-01,
         5.44717800e+00,   8.24547240e-01,   1.83191580e-01])
  elif name == "CONTRACTION COEFFICIENTS":
    arr = np.array([ 0.05923939,  0.35149996,  0.70765792, -0.40445358,  1.22156176,
        1.        ,  0.0585483 ,  0.34930802,  0.70963204, -0.40732628,
        1.22313783,  1.        ,  0.15628498,  0.90469088,  1.        ])
  elif name == "P(S=P) CONTRACTION COEFFICIENTS":
    arr = np.array([  0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.44586107e-01,   8.53955373e-01,   1.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.46680003e-01,   8.52321011e-01,   1.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00])
  elif name == "COORDINATES OF EACH SHELL":
    arr = np.array([  9.50213801e-02,   1.30811042e+00,  -1.61237057e-32,
         9.50213801e-02,   1.30811042e+00,  -1.61237057e-32,
         9.50213801e-02,   1.30811042e+00,  -1.61237057e-32,
         9.50213801e-02,  -1.37530068e+00,   1.69518897e-32,
         9.50213801e-02,  -1.37530068e+00,   1.69518897e-32,
         9.50213801e-02,  -1.37530068e+00,   1.69518897e-32,
        -1.61536346e+00,   1.91282278e+00,  -2.35773611e-32,
        -1.61536346e+00,   1.91282278e+00,  -2.35773611e-32])
  elif name == "BONDS PER ATOM":
    arr = np.array([2, 1, 1], dtype=np.int32)
  elif name == "BONDED ATOMS":
    arr = np.array([2, 3, 1, 1], dtype=np.int32)
  elif name == "BOND TYPES":
    arr = np.array([  1.,   1.,   1.,   1.])
  elif name == "INTEGER ISO":
    arr = np.array([16, 19,  1], dtype=np.int32)
  elif name == "INTEGER SPIN":
    arr = np.array([0, 1, 1], dtype=np.int32)
  elif name == "REAL ZEFFECTIVE":
    arr = np.array([-5.6 , -6.75, -1.  ])
  elif name == "REAL GFACTOR":
    arr = np.array([  0.00000000e+00,   2.62886700e+00,   2.79284600e+00])
  elif name == "REAL ZNUCLEAR":
    arr = np.array([ 8.,  9.,  1.])
  elif name == "NUCLEAR GRADIENT":
    dimens = (3,natoms)
    arr = np.array([  0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00])
  elif name == "ELECTRIC DIPOLE MOMENT":
    arr = np.array([ -9.62682187e-01,   1.05599433e+00,  -1.48639931e-32])
  elif name == "OVERLAP":
    dimens = (-nbasis,nbasis)
    arr = np.array([  1.00000000e+00,   2.09214610e-01,   1.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.00000000e+00,
         1.83087458e-01,   7.40016111e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.98766677e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.98766677e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.98766677e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.00000000e+00,
         2.20578657e-19,   1.73219761e-05,   1.63397857e-20,
        -7.34758923e-05,   0.00000000e+00,   1.10852772e-02,
         7.89220318e-18,  -3.54892458e-02,   0.00000000e+00,
         1.00000000e+00,   2.10498623e-06,   2.27297067e-03,
         1.35435233e-18,  -6.09018061e-03,   0.00000000e+00,
         6.88915074e-02,   4.20342181e-17,  -1.89017270e-01,
         0.00000000e+00,   2.14713614e-01,   1.00000000e+00,
        -2.11612519e-21,  -1.18732376e-18,   1.11159631e-03,
         3.20582195e-18,   0.00000000e+00,  -1.44443643e-17,
         3.95965624e-02,   4.04105828e-17,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.00000000e+00,
         9.51568090e-06,   5.33909530e-03,   3.20582195e-18,
        -1.33041759e-02,   0.00000000e+00,   6.49526608e-02,
         4.04105828e-17,  -1.42119630e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.11159631e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.95965624e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.00000000e+00,
         7.77963861e-03,   6.15075623e-02,   1.69788199e-17,
        -7.63494678e-02,   0.00000000e+00,   2.16879410e-01,
         8.91607077e-17,  -4.00933200e-01,   0.00000000e+00,
         1.83583301e-01,   7.32193301e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.00000000e+00,
        -6.19306522e-18,  -3.82991348e-17,   4.09659288e-02,
         4.88568615e-17,   0.00000000e+00,  -7.84747176e-17,
         2.15123974e-01,   1.45071953e-16,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.88369759e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.00000000e+00,   2.78486513e-02,   1.72221543e-01,
         4.88568615e-17,  -1.78731047e-01,   0.00000000e+00,
         3.52880999e-01,   1.45071953e-16,  -4.37227986e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.88369759e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.09659288e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.15123974e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.88369759e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.00000000e+00,
         2.24764242e-02,   1.59991223e-01,  -1.91997741e-01,
         6.78814524e-02,   0.00000000e+00,   3.63096001e-01,
        -5.31271766e-01,   1.87832934e-01,   0.00000000e+00,
         5.24337855e-06,   2.77953189e-04,  -2.77300155e-04,
         5.33094730e-04,   0.00000000e+00,   1.32565178e-02,
        -1.99687649e-02,   3.83888834e-02,   0.00000000e+00,
         1.00000000e+00,   6.06624228e-02,   3.01602454e-01,
        -1.11416601e-01,   3.93917172e-02,   0.00000000e+00,
         6.07803764e-01,  -4.18106391e-01,   1.47822932e-01,
         0.00000000e+00,   7.60668011e-03,   4.38608073e-02,
        -1.40952370e-02,   2.70973398e-02,   0.00000000e+00,
         1.36260075e-01,  -8.91040078e-02,   1.71297693e-01,
         0.00000000e+00,   6.45898123e-01,   1.00000000e+00])
  elif name == "CORE HAMILTONIAN ALPHA":
    dimens = (-nbasis,nbasis)
    arr = np.array([ -3.56790698e+01,  -8.29147193e+00,  -1.29766201e+01,
         1.85919943e-02,   1.21823588e-01,  -1.15107245e+01,
         7.45434844e-02,   4.88505970e-01,   2.04220435e-02,
        -1.16410408e+01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.14529622e+01,
        -6.93999784e+00,  -1.01432777e+01,   1.16317846e-01,
         4.68771709e-01,   0.00000000e+00,  -1.11304389e+01,
         2.63052943e-03,   7.36915588e-02,  -5.59906079e+00,
         1.88333920e-02,   0.00000000e+00,   1.92653977e-01,
        -7.92735723e+00,   1.05469497e-02,   2.97135097e-01,
         1.88333920e-02,  -5.72330152e+00,   0.00000000e+00,
         9.40834152e-01,   6.06606988e-02,  -8.65945398e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.54579192e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.75578287e+00,
        -1.05517229e-16,  -1.03659960e-03,   3.95536196e-08,
         4.26754622e-03,   0.00000000e+00,  -5.27053741e-01,
         1.54872542e-05,   1.67642528e+00,   0.00000000e+00,
        -4.34698870e+01,  -1.29959245e-04,  -5.01580904e-02,
         4.60064157e-05,   1.24963407e-01,   0.00000000e+00,
        -1.14031229e+00,   8.43253226e-04,   3.07983760e+00,
         0.00000000e+00,  -1.04934934e+01,  -1.48801457e+01,
         3.50518086e-08,   5.27688494e-05,  -2.17104075e-02,
        -1.31198872e-04,   0.00000000e+00,   1.46105846e-03,
        -5.46933971e-01,  -3.81049254e-03,   0.00000000e+00,
         1.96234221e-03,   1.24150973e-02,  -1.29333372e+01,
        -5.61725263e-04,  -1.07616343e-01,   1.18175486e-04,
         2.45679388e-01,   0.00000000e+00,  -9.57940641e-01,
         9.82834398e-04,   2.04309153e+00,   0.00000000e+00,
        -6.86721671e-02,  -4.34466339e-01,   2.35375558e-03,
        -1.30578346e+01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.17017216e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.46772234e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.29321128e+01,
        -3.04207400e-01,  -9.06261875e-01,   5.45962652e-03,
         1.02988686e+00,   0.00000000e+00,  -2.63117754e+00,
         1.30713996e-02,   4.78867740e+00,   0.00000000e+00,
        -8.55567152e+00,  -1.16361208e+01,   1.18105629e-02,
        -4.13310642e-01,   0.00000000e+00,  -1.25018350e+01,
         1.18807372e-04,   3.98248161e-03,  -5.12376535e-01,
        -3.12141324e-03,   0.00000000e+00,   1.48513467e-02,
        -1.95869084e+00,  -1.85554213e-02,   0.00000000e+00,
         2.72818541e-04,   7.41492401e-03,  -6.19376074e+00,
         2.19198381e-03,   0.00000000e+00,   2.41834685e-02,
        -8.47689038e+00,  -1.07796864e+00,  -2.46947093e+00,
         1.72291362e-02,   2.30443064e+00,   0.00000000e+00,
        -4.02640928e+00,   3.01677215e-02,   4.55167579e+00,
         0.00000000e+00,  -9.54728506e-03,  -2.59485260e-01,
         2.19198381e-03,  -6.30970147e+00,   0.00000000e+00,
        -8.43864571e-01,   1.25007757e-02,  -9.12765003e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.10328213e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.95149997e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.19262054e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.47038784e+00,
        -8.74134417e-01,  -2.16484778e+00,   2.23181916e+00,
        -7.26213758e-01,   0.00000000e+00,  -3.46471238e+00,
         4.20486564e+00,  -1.36872594e+00,   0.00000000e+00,
        -2.83031196e-04,  -5.76726063e-03,   5.15716332e-03,
        -1.02641312e-02,   0.00000000e+00,  -1.64038710e-01,
         2.07707353e-01,  -4.57583894e-01,   0.00000000e+00,
        -7.00601862e+00,  -2.31654274e+00,  -4.11610358e+00,
         1.33244538e+00,  -2.64520276e-01,   0.00000000e+00,
        -5.93442795e+00,   3.16383158e+00,  -4.96535422e-01,
         0.00000000e+00,  -3.60060727e-01,  -7.16196961e-01,
         1.93544441e-01,  -4.05774318e-01,   0.00000000e+00,
        -1.54945237e+00,   7.65526106e-01,  -1.85809776e+00,
         0.00000000e+00,  -4.87914923e+00,  -6.71149812e+00])
  elif name == "CORE HAMILTONIAN BETA":
    dimens = (-nbasis,nbasis)
    arr = np.array([ -3.56790698e+01,  -8.29147193e+00,  -1.29766201e+01,
         1.85919943e-02,   1.21823588e-01,  -1.15107245e+01,
         7.45434844e-02,   4.88505970e-01,   2.04220435e-02,
        -1.16410408e+01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.14529622e+01,
        -6.93999784e+00,  -1.01432777e+01,   1.16317846e-01,
         4.68771709e-01,   0.00000000e+00,  -1.11304389e+01,
         2.63052943e-03,   7.36915588e-02,  -5.59906079e+00,
         1.88333920e-02,   0.00000000e+00,   1.92653977e-01,
        -7.92735723e+00,   1.05469497e-02,   2.97135097e-01,
         1.88333920e-02,  -5.72330152e+00,   0.00000000e+00,
         9.40834152e-01,   6.06606988e-02,  -8.65945398e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.54579192e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.75578287e+00,
        -1.05517229e-16,  -1.03659960e-03,   3.95536196e-08,
         4.26754622e-03,   0.00000000e+00,  -5.27053741e-01,
         1.54872542e-05,   1.67642528e+00,   0.00000000e+00,
        -4.34698870e+01,  -1.29959245e-04,  -5.01580904e-02,
         4.60064157e-05,   1.24963407e-01,   0.00000000e+00,
        -1.14031229e+00,   8.43253226e-04,   3.07983760e+00,
         0.00000000e+00,  -1.04934934e+01,  -1.48801457e+01,
         3.50518086e-08,   5.27688494e-05,  -2.17104075e-02,
        -1.31198872e-04,   0.00000000e+00,   1.46105846e-03,
        -5.46933971e-01,  -3.81049254e-03,   0.00000000e+00,
         1.96234221e-03,   1.24150973e-02,  -1.29333372e+01,
        -5.61725263e-04,  -1.07616343e-01,   1.18175486e-04,
         2.45679388e-01,   0.00000000e+00,  -9.57940641e-01,
         9.82834398e-04,   2.04309153e+00,   0.00000000e+00,
        -6.86721671e-02,  -4.34466339e-01,   2.35375558e-03,
        -1.30578346e+01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.17017216e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.46772234e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.29321128e+01,
        -3.04207400e-01,  -9.06261875e-01,   5.45962652e-03,
         1.02988686e+00,   0.00000000e+00,  -2.63117754e+00,
         1.30713996e-02,   4.78867740e+00,   0.00000000e+00,
        -8.55567152e+00,  -1.16361208e+01,   1.18105629e-02,
        -4.13310642e-01,   0.00000000e+00,  -1.25018350e+01,
         1.18807372e-04,   3.98248161e-03,  -5.12376535e-01,
        -3.12141324e-03,   0.00000000e+00,   1.48513467e-02,
        -1.95869084e+00,  -1.85554213e-02,   0.00000000e+00,
         2.72818541e-04,   7.41492401e-03,  -6.19376074e+00,
         2.19198381e-03,   0.00000000e+00,   2.41834685e-02,
        -8.47689038e+00,  -1.07796864e+00,  -2.46947093e+00,
         1.72291362e-02,   2.30443064e+00,   0.00000000e+00,
        -4.02640928e+00,   3.01677215e-02,   4.55167579e+00,
         0.00000000e+00,  -9.54728506e-03,  -2.59485260e-01,
         2.19198381e-03,  -6.30970147e+00,   0.00000000e+00,
        -8.43864571e-01,   1.25007757e-02,  -9.12765003e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.10328213e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.95149997e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.19262054e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.47038784e+00,
        -8.74134417e-01,  -2.16484778e+00,   2.23181916e+00,
        -7.26213758e-01,   0.00000000e+00,  -3.46471238e+00,
         4.20486564e+00,  -1.36872594e+00,   0.00000000e+00,
        -2.83031196e-04,  -5.76726063e-03,   5.15716332e-03,
        -1.02641312e-02,   0.00000000e+00,  -1.64038710e-01,
         2.07707353e-01,  -4.57583894e-01,   0.00000000e+00,
        -7.00601862e+00,  -2.31654274e+00,  -4.11610358e+00,
         1.33244538e+00,  -2.64520276e-01,   0.00000000e+00,
        -5.93442795e+00,   3.16383158e+00,  -4.96535422e-01,
         0.00000000e+00,  -3.60060727e-01,  -7.16196961e-01,
         1.93544441e-01,  -4.05774318e-01,   0.00000000e+00,
        -1.54945237e+00,   7.65526106e-01,  -1.85809776e+00,
         0.00000000e+00,  -4.87914923e+00,  -6.71149812e+00])
  elif name == "KINETIC ENERGY":
    dimens = (-nbasis,nbasis)
    arr = np.array([  3.04699437e+01,  -2.85420502e+00,   2.78788218e+00,
         0.00000000e+00,   0.00000000e+00,   5.35130578e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.35130578e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.35130578e+00,
         1.98957852e-01,   6.52394769e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.60526000e-01,
         0.00000000e+00,   0.00000000e+00,   7.61164019e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.34210000e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.61164019e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.34210000e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.61164019e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.34210000e-01,
        -1.05517229e-16,  -4.29111247e-04,  -3.58843070e-19,
         1.61362672e-03,   0.00000000e+00,  -9.10281008e-03,
        -7.25779917e-19,   3.26364911e-03,   0.00000000e+00,
         3.89907656e+01,  -8.14394600e-05,  -1.99706174e-02,
        -9.48748357e-18,   4.26628191e-02,   0.00000000e+00,
        -3.21013927e-02,   6.81921090e-18,  -3.06642703e-02,
         0.00000000e+00,  -3.75452332e+00,   3.70045130e+00,
         7.45984883e-20,   8.45317735e-18,  -7.99899361e-03,
        -1.74297248e-17,   0.00000000e+00,  -1.87591401e-18,
         5.14247249e-03,   3.09777997e-17,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.10468099e+00,
        -3.35450574e-04,  -3.80118051e-02,  -1.74297248e-17,
         7.03780800e-02,   0.00000000e+00,   8.43551185e-03,
         3.09777997e-17,  -1.34156875e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.10468099e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.99899361e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.14247249e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.10468099e+00,
        -1.32358949e-02,  -4.88840398e-02,  -2.35450054e-18,
         1.05875947e-02,   0.00000000e+00,  -1.48175381e-03,
         3.69393101e-17,  -1.66106754e-01,   0.00000000e+00,
         2.57509662e-01,   8.37738364e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.23574500e-01,
         4.80227312e-18,   2.22536496e-18,  -5.68086016e-03,
         2.94569085e-17,   0.00000000e+00,  -3.25121009e-17,
         8.91259319e-02,   1.21197868e-16,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.66459373e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.20595750e+00,  -2.15946102e-02,  -1.00069046e-02,
         2.94569085e-17,  -1.38141143e-01,   0.00000000e+00,
         1.46198712e-01,   1.21197868e-16,  -4.55870294e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.66459373e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.20595750e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.68086016e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.91259319e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.66459373e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.20595750e+00,
        -3.59446648e-02,  -4.77572123e-02,  -1.16013691e-01,
         4.10170339e-02,   0.00000000e+00,   1.20510229e-01,
        -4.54931305e-01,   1.60842505e-01,   0.00000000e+00,
        -7.54723700e-05,  -2.14998220e-03,   1.85292806e-03,
        -3.56215518e-03,   0.00000000e+00,  -2.19798648e-02,
         2.11038298e-02,  -4.05709850e-02,   0.00000000e+00,
         1.54940495e+00,   1.98348804e-02,   9.46081984e-02,
        -7.18828196e-02,   2.54144146e-02,   0.00000000e+00,
         1.63693130e-01,  -2.15398222e-01,   7.61547716e-02,
         0.00000000e+00,  -2.71612930e-03,  -1.16560937e-02,
        -8.56095541e-04,   1.64579793e-03,   0.00000000e+00,
        -1.17190924e-02,  -1.59973035e-02,   3.07539612e-02,
         0.00000000e+00,   2.93150854e-01,   2.74787370e-01])
  elif name == "ORTHOGONAL BASIS":
    dimens = (nbasis,nbsuse)
    arr = np.array([  6.98690278e-02,   2.14515252e-01,  -9.42652391e-02,
        -6.57909202e-03,   0.00000000e+00,   2.87597176e-01,
        -1.74124322e-01,  -1.66345863e-02,   0.00000000e+00,
         2.09682624e-02,   6.30080836e-02,  -1.86307927e-02,
         5.24883077e-02,   0.00000000e+00,   9.84655237e-02,
        -4.54853325e-02,   1.30644861e-01,   0.00000000e+00,
         2.47952691e-01,   2.94725584e-01,  -1.31419530e-02,
        -3.50900086e-02,  -1.02493528e-01,   2.04289819e-01,
         0.00000000e+00,  -5.65671784e-02,  -1.59185099e-01,
         3.44511026e-01,   0.00000000e+00,  -9.56085711e-02,
        -2.42399896e-01,  -2.73600757e-02,  -1.26173751e-01,
         0.00000000e+00,  -2.85367389e-01,  -5.22982292e-02,
        -2.06795309e-01,   0.00000000e+00,   1.70285893e-01,
         9.60694854e-02,  -1.18599660e-01,  -2.40576962e-01,
        -2.16745646e-01,   4.07575707e-03,   0.00000000e+00,
        -2.11466847e-01,  -2.74755727e-01,  -4.52587733e-02,
         0.00000000e+00,   1.54025703e-01,   3.06901229e-01,
        -1.29232258e-01,  -1.54401463e-01,   0.00000000e+00,
         2.80624831e-01,  -1.77352474e-01,  -2.23099809e-01,
         0.00000000e+00,   9.38416498e-02,   1.70370921e-02,
        -8.62684375e-02,  -1.55036831e-01,  -1.90917083e-01,
        -2.37861308e-01,   0.00000000e+00,  -1.47532045e-01,
        -2.27255583e-01,  -2.29614020e-01,   0.00000000e+00,
        -1.33145088e-01,  -2.40451007e-01,  -1.90304736e-01,
         2.57226877e-01,   0.00000000e+00,  -2.15035591e-01,
        -2.30428991e-01,   2.85537748e-01,   0.00000000e+00,
         1.30435654e-02,  -3.45660019e-02,  -1.09371193e-01,
        -1.55465406e-01,  -2.30043143e-01,  -8.25451014e-02,
         0.00000000e+00,  -1.12652119e-01,  -1.77865624e-01,
        -7.50435664e-02,   0.00000000e+00,  -1.20621977e-02,
        -1.70276291e-02,   5.36312078e-01,   6.93650051e-02,
         0.00000000e+00,  -1.71760822e-02,   4.86897166e-01,
         5.17849891e-02,   0.00000000e+00,   1.42339686e-01,
         2.84958184e-02,  -2.86455052e-01,  -1.95872808e-01,
         1.23737236e-01,   4.93193050e-01,   0.00000000e+00,
        -5.03407428e-02,   6.59059040e-02,   2.30529187e-01,
         0.00000000e+00,   2.18713370e-01,   1.51888991e-01,
        -3.11440524e-02,   5.52745965e-01,   0.00000000e+00,
         2.97717281e-02,  -1.27132941e-02,   2.40068012e-01,
         0.00000000e+00,   4.97058797e-02,   5.35482166e-02,
         7.54529968e-01,   7.54621152e-02,  -3.96590570e-01,
         2.17259255e-01,   0.00000000e+00,  -8.42020955e-02,
        -1.07161987e-01,   4.38274008e-02,   0.00000000e+00,
         2.91964684e-01,   3.25582132e-02,   3.00398354e-02,
         2.05240302e-01,   0.00000000e+00,  -5.17949278e-02,
         1.31606155e-03,   3.24030704e-02,   0.00000000e+00,
        -1.90605089e-01,  -2.33350646e-01,  -1.51874026e-01,
         4.31057975e-02,   1.11960176e-01,  -2.85752706e-01,
         0.00000000e+00,   1.91792640e-02,   1.43391659e-02,
         9.43959400e-03,   0.00000000e+00,   9.22872139e-01,
        -2.39935637e-01,  -4.10669525e-03,  -1.43344876e-01,
         0.00000000e+00,  -2.41534814e-01,   9.10210642e-04,
         1.95438462e-02,   0.00000000e+00,   6.93207184e-02,
         4.91076744e-02,   5.63677822e-01,  -4.76560710e-01,
         6.34402651e-01,  -2.00957249e-01,   0.00000000e+00,
        -2.08923738e-01,  -5.81104562e-02,   4.02925593e-03,
         0.00000000e+00,  -3.36497261e-02,   2.82854775e-02,
         3.71222434e-02,   1.09219265e-01,   0.00000000e+00,
         6.66272073e-03,  -4.40634938e-03,  -3.17429309e-02,
         0.00000000e+00,   3.67872984e-01,   2.62339308e-01,
        -2.60703507e-02,   9.38819724e-02,   3.11055426e-01,
         3.72214096e-01,   0.00000000e+00,  -3.98538416e-02,
        -3.19115717e-01,  -2.60192110e-01,   0.00000000e+00,
         2.96173900e-02,  -9.93861339e-02,   8.35564272e-01,
        -2.48564159e-01,   0.00000000e+00,  -6.56282746e-03,
        -7.68466620e-01,   1.74758321e-01,   0.00000000e+00,
        -2.39687023e-01,   5.31971552e-03,  -8.90960784e-02,
         3.31368757e-01,   2.19204024e-03,  -6.55585690e-01,
         0.00000000e+00,  -1.82155194e-02,  -2.27424225e-02,
         4.73742561e-01,   0.00000000e+00,  -5.04184853e-02,
         1.88577776e-01,   3.74862798e-01,   7.11832633e-01,
         0.00000000e+00,   9.23391990e-03,  -3.77185717e-01,
        -5.94314810e-01,   0.00000000e+00,  -9.80878174e-02,
        -5.80534911e-02,  -9.57122482e-02,   6.69028308e-01,
         5.18020798e-01,   3.07900089e-01,   0.00000000e+00,
        -2.67194883e-01,  -6.14001635e-01,  -4.96959701e-01,
         0.00000000e+00,   2.84087420e-02,  -1.81914684e-01,
        -2.51912967e-01,   2.81192093e-01,   0.00000000e+00,
         6.51090558e-02,   3.32972517e-01,  -4.13176791e-01,
         0.00000000e+00,   3.50968140e-01,  -5.33388253e-01,
        -2.03356471e-02,   3.04547873e-01,   1.85068167e-01,
        -2.36188777e-01,   0.00000000e+00,  -2.07879680e-01,
        -2.49256895e-01,   4.49466068e-01,   0.00000000e+00,
        -9.74366314e-02,   9.77057519e-01,  -3.56639216e-03,
        -3.68992392e-01,   0.00000000e+00,  -6.75745649e-01,
         9.30804993e-03,   6.69920445e-01,   0.00000000e+00,
         2.91707265e-01,  -5.33599690e-01,   2.12489206e-02,
        -1.17006429e-01,  -3.58931647e-01,   8.91082211e-02,
         0.00000000e+00,   1.62796948e-01,   8.51290814e-01,
        -2.41867257e-01,   0.00000000e+00,   1.06165274e-02,
        -1.57932618e-01,   2.75135566e-01,   1.67271486e-02,
         0.00000000e+00,   1.19253648e-01,  -4.89561031e-01,
        -7.09349052e-02,   0.00000000e+00,   1.23251013e+00,
        -7.75694718e-01,  -1.38132218e-04,  -4.69383786e-01,
         3.04326503e-01,  -3.56064004e-01,   0.00000000e+00,
         7.73860666e-01,  -8.04529053e-01,   1.07964481e+00,
         0.00000000e+00,  -1.17831952e-02,  -7.77897999e-01,
        -3.38194056e-02,  -1.87137215e-01,   0.00000000e+00,
         1.17161972e+00,   9.11674479e-02,   5.91750971e-01,
         0.00000000e+00,  -9.15033831e-02,  -1.10281916e+00,
        -6.19713827e-02,  -1.20887005e+00,   1.73554693e-01,
         1.79018381e-01,   0.00000000e+00,   2.11861896e+00,
        -5.72401241e-01,  -7.39451050e-01,   0.00000000e+00,
         3.17272595e-02,   6.93627400e-01,  -2.57311725e-02,
         2.64545452e-01,   0.00000000e+00,  -1.21274924e+00,
         7.58786918e-02,  -9.33719816e-01,   0.00000000e+00,
        -3.03057156e-01,  -6.06763803e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.56533547e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.31351514e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.40590444e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.19397862e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.68393247e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.68433644e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.83219429e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.84700091e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.07175121e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.68826135e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.48618195e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.24084831e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.02340193e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.74549978e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.41542566e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.23404017e-01,   0.00000000e+00,
         0.00000000e+00])
  elif name == "DIPOLE INTEGRALS":
    dimens = (-nbasis,nbasis,3)
    arr = np.array([  9.50213801e-02,   1.98798610e-02,   9.50213801e-02,
         6.48996627e-02,   4.25302747e-01,   9.50213801e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.50213801e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.50213801e-02,
         1.73972230e-02,   7.03173521e-02,   4.07957746e-01,
         0.00000000e+00,   0.00000000e+00,   9.50213801e-02,
         9.18247227e-03,   2.58577094e-01,   4.73934980e-02,
         0.00000000e+00,   0.00000000e+00,   8.17933042e-01,
         9.50213801e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.73934980e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.50213801e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.73934980e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.50213801e-02,
         0.00000000e+00,   1.64595808e-06,   9.59275993e-07,
        -6.98178069e-06,   8.60570912e-38,   1.05333834e-03,
         4.38030991e-04,  -3.37223712e-03,   4.15660316e-35,
         9.50213801e-02,   2.00018697e-07,   2.15980810e-04,
         5.48596016e-04,  -5.78697367e-04,   7.13299576e-36,
         6.54616611e-03,   1.84476239e-02,  -1.79606819e-02,
         2.21382496e-34,   2.04023839e-02,   9.50213801e-02,
         1.65642044e-07,   6.32349033e-04,   1.05625415e-04,
        -1.70184687e-03,   2.09768822e-35,   3.23873367e-02,
         3.76252000e-03,  -9.06091209e-02,   1.11684364e-33,
         5.84153413e-02,   3.69574757e-01,   9.50213801e-02,
         9.04193131e-07,   5.07328203e-04,   1.28102300e-03,
        -1.26418115e-03,   1.68841695e-35,   6.17189147e-03,
         1.56447340e-02,  -1.35044033e-02,   2.12831262e-34,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.50213801e-02,  -1.11450408e-38,  -6.25330290e-36,
        -1.57898276e-35,   1.68841695e-35,   1.05625415e-04,
        -7.60744358e-35,  -1.92836234e-34,   2.12831262e-34,
         3.76252000e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.50213801e-02,
         7.39231998e-04,   5.84453346e-03,   2.94914966e-02,
        -7.25483180e-03,   8.94227059e-35,   2.06081809e-02,
         1.54868403e-01,  -3.80972259e-02,   4.69584565e-34,
         1.74443386e-02,   6.95740180e-02,   3.51578874e-01,
         0.00000000e+00,   0.00000000e+00,   9.50213801e-02,
         4.44076922e-04,   2.20349744e-02,   3.89263909e-03,
        -2.50661125e-02,   3.08963690e-34,   1.75957006e-01,
         2.04413769e-02,  -3.25282172e-01,   4.00941232e-33,
         8.12130938e-03,   2.20728737e-01,   4.64055685e-02,
         0.00000000e+00,   0.00000000e+00,   7.19903040e-01,
         9.50213801e-02,   2.64621728e-03,   1.63647287e-02,
         8.48623154e-02,  -1.69832707e-02,   2.57315455e-34,
         3.35312395e-02,   2.51983886e-01,  -4.15460066e-02,
         7.64053491e-34,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.64055685e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.50213801e-02,
        -3.26171462e-35,  -2.01710855e-34,  -1.04600880e-33,
         2.57315455e-34,   3.89263909e-03,  -4.13304437e-34,
        -3.10594120e-33,   7.64053491e-34,   2.04413769e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.64055685e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.50213801e-02,
        -3.92067973e-04,  -8.68717480e-02,   1.61791990e-01,
        -3.37811414e-02,   4.16384715e-34,  -4.00042848e-01,
         7.67244289e-01,  -2.08200578e-01,   2.56627026e-33,
         1.78581467e-08,  -1.09737492e-04,   2.05576980e-04,
        -2.06209595e-04,   2.54172949e-36,  -1.31159219e-02,
         2.67901589e-02,  -3.80735489e-02,   4.69292723e-34,
        -1.61536346e+00,   4.17244117e-03,  -3.02790607e-02,
         1.86340257e-01,  -3.02105672e-03,   3.72373990e-35,
        -2.84228680e-01,   8.62722249e-01,  -6.91267797e-02,
         8.52053343e-34,   5.66865740e-04,  -2.39965087e-03,
         2.30385944e-02,  -1.04930858e-03,   1.29337268e-35,
        -5.11986256e-02,   1.75669734e-01,  -6.43637282e-02,
         7.93344202e-34,  -1.04336023e+00,  -1.61536346e+00,
         1.30811042e+00,   2.73675811e-01,   1.30811042e+00,
         0.00000000e+00,   0.00000000e+00,   1.30811042e+00,
         6.48996627e-02,   4.25302747e-01,   0.00000000e+00,
         1.30811042e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.30811042e+00,
         2.39498611e-01,   9.68022783e-01,   0.00000000e+00,
         4.07957746e-01,   0.00000000e+00,   1.30811042e+00,
         0.00000000e+00,   0.00000000e+00,   6.52441886e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.30811042e+00,   9.18247227e-03,   2.58577094e-01,
         0.00000000e+00,   6.52441886e-01,   0.00000000e+00,
         8.17933042e-01,   0.00000000e+00,   1.30811042e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.52441886e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.30811042e+00,
         0.00000000e+00,  -1.92000021e-05,  -1.81317594e-20,
         8.24932217e-05,  -1.00498347e-36,  -1.45270602e-02,
        -1.03437562e-17,   4.69512920e-02,  -5.73320206e-34,
        -1.37530068e+00,   1.83224642e-06,  -4.91121331e-04,
        -2.85808493e-19,   1.83380467e-03,  -1.58414198e-35,
        -6.44857722e-02,  -3.91444887e-17,   1.94470510e-01,
        -2.16964958e-33,  -2.95295779e-01,  -1.37530068e+00,
        -1.84502588e-21,   2.68377833e-19,  -2.47756155e-04,
        -1.00254465e-18,   8.84592847e-51,   1.41583275e-17,
        -3.88124452e-02,  -4.31550990e-17,   4.89044173e-49,
         0.00000000e+00,   0.00000000e+00,  -1.37530068e+00,
         8.46225776e-06,  -5.74478347e-04,  -3.39205252e-19,
         2.55858725e-03,  -1.88010256e-35,  -3.12790887e-02,
        -1.95260533e-17,   6.46360225e-02,  -1.08226458e-33,
         5.84153413e-02,   3.69574757e-01,   0.00000000e+00,
        -1.37530068e+00,  -1.02263684e-37,   1.48752959e-35,
         8.84592847e-51,  -5.55677353e-35,  -2.47756155e-04,
         7.84749281e-34,   4.89044173e-49,  -2.39194445e-33,
        -3.88124452e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.37530068e+00,
         9.34898643e-03,   3.93914201e-02,   1.18212206e-17,
        -2.36655488e-02,   6.55211172e-34,  -4.42342961e-02,
        -1.81850418e-17,   2.36641946e-01,  -1.00793674e-33,
        -2.52482238e-01,  -1.00698594e+00,   0.00000000e+00,
         3.51578874e-01,   0.00000000e+00,  -1.37530068e+00,
        -7.44476262e-18,  -2.41560267e-17,   2.85218457e-02,
         1.53225143e-17,  -4.21479092e-49,   1.60055484e-17,
        -4.38762608e-02,  -8.56255090e-17,   3.64707518e-49,
         0.00000000e+00,   0.00000000e+00,  -6.71655262e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.37530068e+00,   3.39212955e-02,   1.30658530e-01,
         3.97687224e-17,  -6.54457464e-02,   2.20424879e-33,
         1.03984095e-01,   4.27486199e-17,   1.58778710e-02,
         2.36941466e-33,   8.12130938e-03,   2.20728737e-01,
         0.00000000e+00,  -6.71655262e-01,   0.00000000e+00,
         7.19903040e-01,   0.00000000e+00,  -1.37530068e+00,
        -4.12638577e-34,  -1.33888869e-33,  -4.21479092e-49,
         8.49276306e-34,   2.85218457e-02,   8.87134628e-34,
         3.64707518e-49,  -4.74593886e-33,  -4.38762608e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.71655262e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.37530068e+00,
         3.02953601e-02,   2.45374912e-01,  -2.91385576e-01,
         1.69264852e-01,  -1.26982396e-33,   6.28604424e-01,
        -9.21010854e-01,   5.03990637e-01,  -4.01365662e-33,
        -6.28772698e-06,  -1.20530057e-04,   1.24506100e-04,
        -1.41043494e-04,   2.95029448e-36,   9.40457584e-03,
        -1.42582577e-02,   3.43961602e-02,  -3.37863437e-34,
         1.91282278e+00,   7.99159285e-02,   4.15366950e-01,
        -1.52509329e-01,   2.31715608e-01,  -6.64617659e-34,
         9.15983697e-01,  -6.30102445e-01,   8.89977046e-01,
        -2.74591210e-33,  -1.01617023e-02,  -4.76963892e-02,
         1.57610538e-02,  -7.80700864e-03,   3.73473668e-34,
        -6.40808443e-02,   4.19041310e-02,   6.16311681e-02,
         9.92959590e-34,   1.23548864e+00,   1.91282278e+00,
        -1.61237057e-32,  -3.37331481e-33,  -1.61237057e-32,
         0.00000000e+00,   0.00000000e+00,  -1.61237057e-32,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.61237057e-32,   6.48996627e-02,   4.25302747e-01,
         0.00000000e+00,   0.00000000e+00,  -1.61237057e-32,
        -2.95204830e-33,  -1.19318020e-32,   0.00000000e+00,
         0.00000000e+00,   4.07957746e-01,  -1.61237057e-32,
         0.00000000e+00,   0.00000000e+00,  -8.04196714e-33,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.61237057e-32,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.04196714e-33,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.61237057e-32,
         9.18247227e-03,   2.58577094e-01,   0.00000000e+00,
         0.00000000e+00,  -8.04196714e-33,   8.17933042e-01,
         0.00000000e+00,   0.00000000e+00,  -1.61237057e-32,
         0.00000000e+00,   2.36658297e-37,   2.23491189e-52,
        -1.00498347e-36,   9.59275993e-07,   1.79059842e-34,
         1.27496639e-49,  -5.73320206e-34,   4.38030991e-04,
         1.69518897e-32,  -2.25841807e-38,   6.05353778e-36,
         3.52286166e-51,  -1.58414198e-35,   5.48596016e-04,
         7.94848510e-34,   4.82493075e-49,  -2.16964958e-33,
         1.84476239e-02,   3.63980150e-33,   1.69518897e-32,
         2.27416997e-53,  -3.30801219e-51,   3.05383039e-36,
         8.84592847e-51,  -2.84877674e-19,  -1.74514860e-49,
         4.78400322e-34,   4.89044173e-49,  -3.47912209e-18,
         0.00000000e+00,   0.00000000e+00,   1.69518897e-32,
        -1.02263684e-37,   1.48752959e-35,   8.84592847e-51,
        -3.67240774e-35,   1.28102300e-03,   7.84749281e-34,
         4.89044173e-49,  -1.72070790e-33,   1.56447340e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.69518897e-32,   1.65642044e-07,   6.32349033e-04,
         3.78461726e-19,  -1.70184687e-03,   8.24088498e-36,
         3.23873367e-02,   2.01499236e-17,  -9.06091209e-02,
         1.40240773e-33,   5.84153413e-02,   3.69574757e-01,
         0.00000000e+00,   0.00000000e+00,   1.69518897e-32,
        -1.15235155e-34,  -4.85536740e-34,  -1.45707793e-49,
         6.55211172e-34,   2.94914966e-02,   5.45229795e-34,
         2.24147946e-49,  -1.00793674e-33,   1.54868403e-01,
         3.11208386e-33,   1.24120601e-32,   0.00000000e+00,
         0.00000000e+00,   3.51578874e-01,   1.69518897e-32,
         9.17637841e-50,   2.97746018e-49,  -3.51558891e-34,
        -4.21479092e-49,  -1.88719320e-17,  -1.97283616e-49,
         5.40816669e-34,   3.64707518e-49,  -5.60369200e-17,
         0.00000000e+00,   0.00000000e+00,   8.27879028e-33,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.69518897e-32,  -4.12638577e-34,  -1.33888869e-33,
        -4.21479092e-49,   1.54372621e-33,   8.48623154e-02,
         8.87134628e-34,   3.64707518e-49,  -1.09918099e-33,
         2.51983886e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.27879028e-33,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.69518897e-32,
         4.44076922e-04,   2.20349744e-02,   5.57427604e-18,
        -2.50661125e-02,  -1.08860400e-33,   1.75957006e-01,
         7.23372089e-17,  -3.25282172e-01,   1.44428779e-33,
         8.12130938e-03,   2.20728737e-01,   0.00000000e+00,
         0.00000000e+00,   8.27879028e-33,   7.19903040e-01,
         0.00000000e+00,   0.00000000e+00,   1.69518897e-32,
        -3.73419143e-34,  -3.02447930e-33,   3.59160452e-33,
        -1.26982396e-33,   6.62444932e-02,  -7.74814773e-33,
         1.13523352e-32,  -4.01365662e-33,   1.78364126e-01,
         7.75022187e-38,   1.48564765e-36,  -1.53465617e-36,
         2.95029448e-36,   9.83128305e-05,  -1.15920347e-34,
         1.75746595e-34,  -3.37863437e-34,   6.98542170e-03,
        -2.35773611e-32,  -9.85039871e-34,  -5.11979294e-33,
         1.87982261e-33,  -6.64617659e-34,   1.77795418e-01,
        -1.12903708e-32,   7.76661226e-33,  -2.74591210e-33,
         6.67202190e-01,   1.25252652e-34,   5.87903387e-34,
        -1.94269987e-34,   3.73473668e-34,   2.24927750e-02,
         7.89857388e-34,  -5.16508292e-34,   9.92959590e-34,
         1.42189621e-01,  -1.52285733e-32,  -2.35773611e-32])
  elif name == "DIP VEL INTEGRALS":
    asym = True
    dimens = (-nbasis,nbasis,3)
    arr = np.array([ -0.00000000e+00,  -0.00000000e+00,  -0.00000000e+00,
        -1.66721759e+00,  -7.55381416e-01,  -0.00000000e+00,
        -0.00000000e+00,  -0.00000000e+00,   0.00000000e+00,
        -0.00000000e+00,  -0.00000000e+00,  -0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -0.00000000e+00,
        -0.00000000e+00,   0.00000000e+00,   3.04894565e-01,
         0.00000000e+00,   0.00000000e+00,  -0.00000000e+00,
        -2.16978935e-01,  -7.11486984e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.11296982e-01,
        -0.00000000e+00,  -0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -0.00000000e+00,   0.00000000e+00,  -0.00000000e+00,
        -0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -0.00000000e+00,
        -1.54492753e-33,  -2.93448755e-20,   2.73815266e-05,
         1.24538725e-19,  -1.53505830e-51,  -4.82447998e-18,
         1.32254226e-02,   1.54463248e-17,  -1.90390653e-49,
        -0.00000000e+00,  -4.38619978e-21,  -2.42405746e-18,
         2.26956675e-03,   6.49491247e-18,  -8.00559771e-50,
        -2.56953907e-17,   7.04391773e-02,   7.03496656e-17,
        -8.67126576e-49,  -0.00000000e+00,  -0.00000000e+00,
        -3.54611372e-06,  -1.98966729e-03,  -3.58404489e-18,
         5.37218178e-03,  -6.62172528e-35,  -2.42052591e-02,
        -4.51782243e-17,   6.77183575e-02,  -8.34693200e-34,
        -1.93560222e+00,  -8.62889141e-01,  -0.00000000e+00,
        -1.98408715e-20,  -5.72264089e-18,   5.37218178e-03,
         1.43254434e-17,  -1.91300311e-49,  -2.47028673e-17,
         6.77183575e-02,   5.41001442e-17,  -8.52457297e-49,
        -0.00000000e+00,  -0.00000000e+00,   0.00000000e+00,
        -0.00000000e+00,   2.44557622e-52,   7.05369948e-50,
        -6.62172528e-35,  -1.91300311e-49,  -1.19468163e-18,
         3.04486348e-49,  -8.34693200e-34,  -8.52457297e-49,
        -1.50594081e-17,  -0.00000000e+00,  -0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -0.00000000e+00,
        -4.30131898e-18,  -2.66002036e-17,   2.84523932e-02,
         3.39329457e-17,  -4.18255848e-49,  -5.45036715e-17,
         1.49411769e-01,   1.00757981e-16,  -1.24193800e-48,
        -0.00000000e+00,   0.00000000e+00,   3.39191344e-01,
         0.00000000e+00,   0.00000000e+00,  -0.00000000e+00,
        -1.03780786e-02,  -6.41800816e-02,  -5.46209951e-17,
         8.18722766e-02,  -1.00915372e-33,  -1.31504636e-01,
        -1.62187546e-16,   2.43105486e-01,  -2.99650647e-33,
        -2.47175985e-01,  -8.04120527e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.94537976e-01,
        -0.00000000e+00,  -1.53996812e-17,  -7.41218651e-17,
         8.18722766e-02,   7.96080419e-17,  -1.20566346e-48,
        -8.86820471e-17,   2.43105486e-01,   1.09879174e-16,
        -2.02073734e-48,  -0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -0.00000000e+00,   0.00000000e+00,  -0.00000000e+00,
         1.89815725e-49,   9.13622525e-49,  -1.00915372e-33,
        -1.20566346e-48,  -1.82069984e-17,   1.09309062e-48,
        -2.99650647e-33,  -2.02073734e-48,  -5.40625152e-17,
        -0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -0.00000000e+00,
         5.92363273e-02,   2.92160874e-01,  -2.63200062e-01,
         1.32743098e-01,  -1.63618501e-33,   3.24764827e-01,
        -1.67223614e-01,   1.68941582e-01,  -2.08236577e-33,
         1.39972176e-05,   5.59469095e-04,  -3.99681974e-04,
         1.08004840e-03,  -1.33126243e-35,   1.38690655e-02,
        -9.26252881e-03,   4.02513048e-02,  -4.96135637e-34,
        -0.00000000e+00,   3.74312800e-02,   1.67407252e-01,
         2.33091122e-03,   2.22068072e-02,  -2.73720031e-34,
         2.55587175e-01,   6.86339938e-02,   6.21609274e-02,
        -7.66192585e-34,   4.70964260e-03,   2.50794749e-02,
         9.88001973e-05,   1.56528940e-02,  -1.92936814e-34,
         6.18861172e-02,   1.16269407e-02,   7.77993780e-02,
        -9.58951372e-34,   0.00000000e+00,  -0.00000000e+00,
        -0.00000000e+00,  -0.00000000e+00,  -0.00000000e+00,
        -0.00000000e+00,  -0.00000000e+00,  -0.00000000e+00,
        -1.66721759e+00,  -7.55381416e-01,   0.00000000e+00,
        -0.00000000e+00,  -0.00000000e+00,  -0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -0.00000000e+00,
        -0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.04894565e-01,   0.00000000e+00,  -0.00000000e+00,
        -0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -0.00000000e+00,
        -0.00000000e+00,  -2.16978935e-01,  -7.11486984e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.11296982e-01,   0.00000000e+00,  -0.00000000e+00,
        -0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -0.00000000e+00,
         6.94714919e-18,   1.31956499e-04,   1.24538725e-19,
        -5.32637686e-04,   6.90276974e-36,   2.16944689e-02,
         1.54463248e-17,  -5.62328018e-02,   8.56138715e-34,
        -0.00000000e+00,   1.97236334e-05,   1.09003746e-02,
         6.49491247e-18,  -2.69364154e-02,   3.59991524e-34,
         1.15545687e-01,   7.03496656e-17,  -2.45905514e-01,
         3.89924936e-33,  -0.00000000e+00,  -0.00000000e+00,
        -1.98408715e-20,  -5.72264089e-18,   5.37218178e-03,
         1.43254434e-17,  -1.91300311e-49,  -2.47028673e-17,
         6.77183575e-02,   5.41001442e-17,  -8.52457297e-49,
        -0.00000000e+00,  -0.00000000e+00,  -0.00000000e+00,
         8.56732777e-05,   2.37436045e-02,   1.43254434e-17,
        -5.36735400e-02,   7.94011964e-34,   8.68773006e-02,
         5.41001442e-17,  -1.07837979e-01,   2.99859212e-33,
        -1.93560222e+00,  -8.62889141e-01,   0.00000000e+00,
        -0.00000000e+00,  -1.09971390e-36,  -3.17187063e-34,
        -1.91300311e-49,   7.94011964e-34,   5.37218178e-03,
        -1.36919826e-33,  -8.52457297e-49,   2.99859212e-33,
         6.77183575e-02,  -0.00000000e+00,  -0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -0.00000000e+00,
         1.93419459e-02,   1.19614402e-01,   3.39329457e-17,
        -1.24135499e-01,   1.88079099e-33,   2.45089255e-01,
         1.00757981e-16,  -3.03671440e-01,   5.58468173e-33,
        -0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.39191344e-01,   0.00000000e+00,  -0.00000000e+00,
        -1.53996812e-17,  -7.41218651e-17,   8.18722766e-02,
         7.96080419e-17,  -1.20566346e-48,  -8.86820471e-17,
         2.43105486e-01,   1.09879174e-16,  -2.02073734e-48,
        -0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -0.00000000e+00,
        -0.00000000e+00,   5.88704010e-02,   2.69127238e-01,
         7.96080419e-17,  -1.94232719e-01,   4.41241055e-33,
         2.67276148e-01,   1.09879174e-16,  -7.88794273e-03,
         6.09023933e-33,  -2.47175985e-01,  -8.04120527e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.94537976e-01,   0.00000000e+00,  -0.00000000e+00,
        -8.53553411e-34,  -4.10832991e-33,  -1.20566346e-48,
         4.41241055e-33,   8.18722766e-02,  -4.91535266e-33,
        -2.02073734e-48,   6.09023933e-33,   2.43105486e-01,
        -0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -0.00000000e+00,
        -2.09432044e-02,  -1.03294468e-01,   1.32743098e-01,
         6.53223453e-02,   5.78478758e-34,  -1.14821706e-01,
         1.68941582e-01,   2.50885469e-01,   7.36227477e-34,
        -2.69089028e-05,  -1.07554944e-03,   1.08004840e-03,
        -1.91420798e-03,   2.55928088e-35,  -2.66625373e-02,
         4.02513048e-02,  -6.57059698e-02,   9.53794249e-34,
        -0.00000000e+00,  -1.32339559e-02,  -5.91874017e-02,
         2.22068072e-02,   5.72899550e-02,   9.67746452e-35,
        -9.03637123e-02,   6.21609274e-02,   2.22474440e-01,
         2.70889986e-34,  -9.05403622e-03,  -4.82139502e-02,
         1.56528940e-02,  -2.18508782e-02,   3.70910715e-34,
        -1.18972753e-01,   7.77993780e-02,  -9.74692643e-02,
         1.84353277e-33,   0.00000000e+00,  -0.00000000e+00,
        -0.00000000e+00,  -0.00000000e+00,  -0.00000000e+00,
        -0.00000000e+00,  -0.00000000e+00,  -0.00000000e+00,
        -0.00000000e+00,  -0.00000000e+00,   0.00000000e+00,
        -0.00000000e+00,  -1.66721759e+00,  -7.55381416e-01,
         0.00000000e+00,   0.00000000e+00,  -0.00000000e+00,
        -0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.04894565e-01,  -0.00000000e+00,
        -0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -0.00000000e+00,
        -0.00000000e+00,  -0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -0.00000000e+00,   0.00000000e+00,  -0.00000000e+00,
        -2.16978935e-01,  -7.11486984e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.11296982e-01,
         0.00000000e+00,   0.00000000e+00,  -0.00000000e+00,
        -8.56302250e-50,  -1.62648943e-36,  -1.53505830e-51,
         6.90276974e-36,   2.73815266e-05,  -2.67404974e-34,
        -1.90390653e-49,   8.56138715e-34,   1.32254226e-02,
        -0.00000000e+00,  -2.43112552e-37,  -1.34357490e-34,
        -8.00559771e-50,   3.59991524e-34,   2.26956675e-03,
        -1.42421055e-33,  -8.67126576e-49,   3.89924936e-33,
         7.04391773e-02,  -0.00000000e+00,  -0.00000000e+00,
         2.44557622e-52,   7.05369948e-50,  -6.62172528e-35,
        -1.91300311e-49,  -1.19468163e-18,   3.04486348e-49,
        -8.34693200e-34,  -8.52457297e-49,  -1.50594081e-17,
        -0.00000000e+00,  -0.00000000e+00,  -0.00000000e+00,
        -1.09971390e-36,  -3.17187063e-34,  -1.91300311e-49,
         7.94011964e-34,   5.37218178e-03,  -1.36919826e-33,
        -8.52457297e-49,   2.99859212e-33,   6.77183575e-02,
        -0.00000000e+00,  -0.00000000e+00,   0.00000000e+00,
        -0.00000000e+00,  -3.54611372e-06,  -1.98966729e-03,
        -1.19468163e-18,   5.37218178e-03,  -1.98651758e-34,
        -2.42052591e-02,  -1.50594081e-17,   6.77183575e-02,
        -2.50407960e-33,  -1.93560222e+00,  -8.62889141e-01,
         0.00000000e+00,   0.00000000e+00,  -0.00000000e+00,
        -2.38407890e-34,  -1.47436133e-33,  -4.18255848e-49,
         1.88079099e-33,   2.84523932e-02,  -3.02095830e-33,
        -1.24193800e-48,   5.58468173e-33,   1.49411769e-01,
        -0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.39191344e-01,  -0.00000000e+00,
         1.89815725e-49,   9.13622525e-49,  -1.00915372e-33,
        -1.20566346e-48,  -1.82069984e-17,   1.09309062e-48,
        -2.99650647e-33,  -2.02073734e-48,  -5.40625152e-17,
        -0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -0.00000000e+00,
        -0.00000000e+00,  -8.53553411e-34,  -4.10832991e-33,
        -1.20566346e-48,   4.41241055e-33,   8.18722766e-02,
        -4.91535266e-33,  -2.02073734e-48,   6.09023933e-33,
         2.43105486e-01,  -0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -0.00000000e+00,   0.00000000e+00,  -0.00000000e+00,
        -1.03780786e-02,  -6.41800816e-02,  -1.82069984e-17,
         8.18722766e-02,  -3.02746117e-33,  -1.31504636e-01,
        -5.40625152e-17,   2.43105486e-01,  -8.98951940e-33,
        -2.47175985e-01,  -8.04120527e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.94537976e-01,
         0.00000000e+00,   0.00000000e+00,  -0.00000000e+00,
         2.58144924e-34,   1.27320261e-33,  -1.63618501e-33,
         5.78478758e-34,   1.12254118e-01,   1.41528679e-33,
        -2.08236577e-33,   7.36227477e-34,   3.10615338e-01,
         3.31677834e-37,   1.32571704e-35,  -1.33126243e-35,
         2.55928088e-35,   1.62127346e-04,   3.28641146e-34,
        -4.96135637e-34,   9.53794249e-34,   1.16750128e-02,
        -0.00000000e+00,   1.63121101e-34,   7.29541051e-34,
        -2.73720031e-34,   9.67746452e-35,   6.51412470e-02,
         1.11381875e-33,  -7.66192585e-34,   2.70889986e-34,
         2.44451647e-01,   1.11599613e-34,   5.94282819e-34,
        -1.92936814e-34,   3.70910715e-34,   8.24097398e-03,
         1.46645240e-33,  -9.58951372e-34,   1.84353277e-33,
         5.20958825e-02,   0.00000000e+00,  -0.00000000e+00])
  elif name == "R X DEL INTEGRALS":
    asym = True
    dimens = (-nbasis,nbasis,3)
    arr = np.array([  0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.68817259e-32,  -1.21795477e-32,  -0.00000000e+00,
         0.00000000e+00,  -2.18090470e+00,  -9.88122300e-01,
        -0.00000000e+00,  -1.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -0.00000000e+00,  -0.00000000e+00,
         4.91603024e-33,   3.98835756e-01,   0.00000000e+00,
         0.00000000e+00,  -0.00000000e+00,  -0.00000000e+00,
        -0.00000000e+00,  -0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.49850451e-33,  -1.14718068e-32,
        -0.00000000e+00,  -0.00000000e+00,   4.98766677e-01,
        -9.85637266e-33,  -0.00000000e+00,   0.00000000e+00,
        -2.83832406e-01,  -9.30703536e-01,  -0.00000000e+00,
        -4.98766677e-01,  -0.00000000e+00,  -7.99643950e-01,
        -0.00000000e+00,  -1.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -0.00000000e+00,  -0.00000000e+00,
        -4.64168618e-37,  -3.76578321e-05,  -0.00000000e+00,
        -0.00000000e+00,  -2.24195905e-34,  -1.81889327e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.84734452e-35,  -3.12133670e-03,
         0.00000000e+00,   0.00000000e+00,  -1.19407716e-33,
        -9.68750484e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.02521112e-50,   1.64304646e-18,  -3.79822710e-65,
         0.00000000e+00,   2.55285425e-49,   2.07112142e-17,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.71764941e-38,  -3.20808100e-35,  -1.92626951e-50,
        -4.44915458e-36,  -6.27676894e-03,  -3.90278475e-34,
        -2.42813465e-49,  -5.60832549e-35,  -5.35365407e-02,
         3.28121153e-32,   1.46276015e-32,  -0.00000000e+00,
         0.00000000e+00,  -4.63870829e-06,  -2.60270451e-03,
        -1.56277549e-18,   5.91581064e-03,   4.44915458e-36,
        -3.16631515e-02,  -1.96993686e-17,   4.89865265e-02,
         5.60832549e-35,   2.66203505e+00,   1.18673202e+00,
        -0.00000000e+00,  -1.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -0.00000000e+00,  -0.00000000e+00,
        -4.82321831e-34,  -3.91305958e-02,   0.00000000e+00,
         0.00000000e+00,  -2.53281183e-33,  -2.05486108e-01,
         0.00000000e+00,  -0.00000000e+00,  -0.00000000e+00,
        -5.74993424e-33,  -4.66490086e-01,   0.00000000e+00,
         0.00000000e+00,  -0.00000000e+00,  -0.00000000e+00,
         3.08643028e-49,   2.50400972e-17,   0.00000000e+00,
         0.00000000e+00,   9.16461793e-49,   7.43522139e-17,
         0.00000000e+00,  -0.00000000e+00,  -0.00000000e+00,
        -0.00000000e+00,  -0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.67333086e-34,  -1.03482075e-33,
        -2.93564284e-49,  -6.78053032e-35,  -7.16330688e-02,
        -2.12034205e-33,  -8.71688087e-49,  -2.01336055e-34,
        -1.19219167e-01,   4.19010003e-33,   1.36313625e-32,
        -0.00000000e+00,  -0.00000000e+00,   4.88369759e-01,
         1.17737311e-32,  -0.00000000e+00,   0.00000000e+00,
        -1.35756727e-02,  -8.39546333e-02,  -2.38167643e-17,
         6.61320491e-02,   6.78053032e-35,  -1.72022584e-01,
        -7.07197393e-17,   1.02884845e-01,   2.01336055e-34,
         3.39941300e-01,   1.10590751e+00,  -0.00000000e+00,
        -4.88369759e-01,  -0.00000000e+00,   9.55198550e-01,
        -0.00000000e+00,  -1.00000000e+00,   0.00000000e+00,
         8.55284707e-50,   6.84227766e-49,  -1.02634165e-48,
         2.64665586e-33,   2.14722233e-01,   2.39479718e-48,
        -1.36845553e-48,   7.32348998e-33,   5.94152094e-01,
        -0.00000000e+00,  -0.00000000e+00,  -0.00000000e+00,
         3.82253498e-36,   3.10120881e-04,  -0.00000000e+00,
        -4.27642354e-49,   2.75265992e-34,   2.23322304e-02,
         0.00000000e+00,   8.55284707e-50,   1.71056941e-49,
        -1.28292706e-49,   1.53585870e-33,   1.24603661e-01,
         6.84227766e-49,  -1.71056941e-49,   5.76352474e-33,
         4.67592678e-01,  -0.00000000e+00,  -0.00000000e+00,
        -0.00000000e+00,   1.94300419e-34,   1.57635227e-02,
        -0.00000000e+00,   1.71056941e-49,   1.22828343e-33,
         9.96501907e-02,  -0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.68817259e-32,   1.21795477e-32,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -0.00000000e+00,
         0.00000000e+00,   1.58421317e-01,   7.17773847e-02,
         1.00000000e+00,  -0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -0.00000000e+00,  -4.91603024e-33,
        -0.00000000e+00,  -2.89715023e-02,   0.00000000e+00,
         3.49850451e-33,   1.14718068e-32,  -0.00000000e+00,
        -0.00000000e+00,  -4.98766677e-01,   9.85637266e-33,
         0.00000000e+00,   0.00000000e+00,  -0.00000000e+00,
        -0.00000000e+00,  -0.00000000e+00,  -0.00000000e+00,
         0.00000000e+00,  -0.00000000e+00,   0.00000000e+00,
         2.06176379e-02,   6.76064752e-02,   4.98766677e-01,
        -0.00000000e+00,  -0.00000000e+00,   5.80862828e-02,
         1.00000000e+00,  -0.00000000e+00,   0.00000000e+00,
         8.13670216e-51,   1.54551270e-37,   4.64168618e-37,
        -6.55910707e-37,  -2.60183045e-06,   2.54091897e-35,
         2.24195905e-34,  -8.13514823e-35,  -1.25669791e-03,
         0.00000000e+00,   2.31008902e-38,   1.27668341e-35,
         3.84734452e-35,  -3.42068914e-35,  -2.15657365e-04,
         1.35330452e-34,   1.19407716e-33,  -3.70512056e-34,
        -6.69322784e-03,   0.00000000e+00,   0.00000000e+00,
         5.71764941e-38,   3.20808100e-35,   6.29205474e-36,
        -8.66194782e-35,  -1.11159631e-03,   3.90278475e-34,
         7.93136998e-35,  -1.09187087e-33,  -3.95965624e-02,
        -3.28121153e-32,  -1.46276015e-32,   0.00000000e+00,
         1.04496333e-37,   3.01395525e-35,   9.10686328e-35,
        -7.54481126e-35,  -5.10472126e-04,   1.30103108e-34,
         1.14795412e-33,  -2.84930361e-34,  -6.43469178e-03,
         0.00000000e+00,   0.00000000e+00,  -0.00000000e+00,
         0.00000000e+00,   3.36956619e-07,   1.89060932e-04,
         1.11159631e-03,  -5.10472126e-04,   1.88761642e-35,
         2.30001712e-03,   3.95965624e-02,  -6.43469178e-03,
         2.37941099e-34,   1.83923594e-01,   8.19929170e-02,
         1.00000000e+00,  -0.00000000e+00,   0.00000000e+00,
         2.26538467e-35,   1.40095849e-34,   4.82321831e-34,
        -1.78715355e-34,  -2.70358567e-03,   2.87055627e-34,
         2.53281183e-33,  -5.30664165e-34,  -1.41973125e-02,
         0.00000000e+00,  -0.00000000e+00,   5.74993424e-33,
        -0.00000000e+00,  -3.22304296e-02,   0.00000000e+00,
         1.67333086e-34,   1.03482075e-33,   9.58911793e-35,
        -1.32008450e-33,  -4.09659288e-02,   2.12034205e-33,
         2.84732180e-34,  -3.91976133e-33,  -2.15123974e-01,
        -4.19010003e-33,  -1.36313625e-32,  -0.00000000e+00,
        -0.00000000e+00,  -4.88369759e-01,  -1.17737311e-32,
         0.00000000e+00,   8.11058231e-35,   3.90379178e-34,
         1.38788980e-33,  -4.19273340e-34,  -7.77961671e-03,
         4.67063593e-34,   4.12109738e-33,  -5.78702947e-34,
        -2.31002188e-02,   0.00000000e+00,  -0.00000000e+00,
        -0.00000000e+00,  -0.00000000e+00,  -0.00000000e+00,
         0.00000000e+00,  -0.00000000e+00,   0.00000000e+00,
         9.86139351e-04,   6.09847993e-03,   4.09659288e-02,
        -7.77961671e-03,   2.87673538e-34,   1.24957520e-02,
         2.15123974e-01,  -2.31002188e-02,   8.54196540e-34,
         2.34870032e-02,   7.64086422e-02,   4.88369759e-01,
        -0.00000000e+00,  -0.00000000e+00,   6.59959570e-02,
         1.00000000e+00,  -0.00000000e+00,   0.00000000e+00,
        -9.79638399e-34,  -4.83169744e-33,   3.56252941e-33,
        -2.19527851e-33,   1.81331200e-01,  -5.37089501e-33,
         5.78913955e-34,  -2.79392170e-33,   5.01756668e-01,
         2.05762802e-37,   8.22434375e-36,  -1.20812807e-35,
         1.58769972e-35,   2.61894591e-04,   2.03878934e-34,
        -5.83053394e-34,   5.91704833e-34,   1.88593890e-02,
         0.00000000e+00,  -6.19030936e-34,  -2.76854727e-33,
        -4.97114073e-34,  -3.67251685e-34,   1.05226790e-01,
        -4.22684900e-33,  -2.85588796e-33,  -1.02800484e-33,
         3.94878258e-01,   6.92329925e-35,   3.68674918e-34,
        -3.13992528e-34,   2.30101684e-34,   1.33121682e-02,
         9.09742300e-34,  -1.82318759e-33,   1.14367145e-33,
         8.41537851e-02,  -0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.18090470e+00,   9.88122300e-01,   0.00000000e+00,
        -1.58421317e-01,  -7.17773847e-02,  -1.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -0.00000000e+00,  -0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -0.00000000e+00,  -3.98835756e-01,
         2.89715023e-02,  -0.00000000e+00,   0.00000000e+00,
         2.83832406e-01,   9.30703536e-01,  -0.00000000e+00,
         4.98766677e-01,  -0.00000000e+00,   7.99643950e-01,
         0.00000000e+00,  -2.06176379e-02,  -6.76064752e-02,
        -4.98766677e-01,  -0.00000000e+00,  -0.00000000e+00,
        -5.80862828e-02,  -1.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -0.00000000e+00,  -0.00000000e+00,
        -0.00000000e+00,  -0.00000000e+00,   0.00000000e+00,
        -0.00000000e+00,  -0.00000000e+00,   0.00000000e+00,
         6.60127704e-19,   1.25386886e-05,   3.76578321e-05,
        -5.06119680e-05,   6.55910707e-37,   2.06143837e-03,
         1.81889327e-02,  -5.34331843e-03,   8.13514823e-35,
         0.00000000e+00,   1.87416687e-06,   1.03576864e-03,
         3.12133670e-03,  -2.55953537e-03,   3.42068914e-35,
         1.09793106e-02,   9.68750484e-02,  -2.33662813e-02,
         3.70512056e-34,   0.00000000e+00,   0.00000000e+00,
         4.63870829e-06,   2.60270451e-03,   5.10472126e-04,
        -5.91581064e-03,   8.66194782e-35,   3.16631515e-02,
         6.43469178e-03,  -4.89865265e-02,   1.09187087e-33,
        -2.66203505e+00,  -1.18673202e+00,   0.00000000e+00,
         8.14079308e-06,   2.25615006e-03,   6.27676894e-03,
        -5.10013384e-03,   7.54481126e-35,   8.25520100e-03,
         5.35365407e-02,  -1.02469136e-02,   2.84930361e-34,
        -1.83923594e-01,  -8.19929170e-02,  -1.00000000e+00,
         0.00000000e+00,  -1.04496333e-37,  -3.01395525e-35,
        -9.10686328e-35,   7.54481126e-35,   5.10472126e-04,
        -1.30103108e-34,  -1.14795412e-33,   2.84930361e-34,
         6.43469178e-03,   0.00000000e+00,   0.00000000e+00,
        -0.00000000e+00,  -0.00000000e+00,   0.00000000e+00,
         1.83789839e-03,   1.13659256e-02,   3.91305958e-02,
        -1.17955265e-02,   1.78715355e-34,   2.32887192e-02,
         2.05486108e-01,  -2.88552793e-02,   5.30664165e-34,
         0.00000000e+00,  -0.00000000e+00,   4.66490086e-01,
         3.22304296e-02,  -0.00000000e+00,   0.00000000e+00,
         1.35756727e-02,   8.39546333e-02,   7.77961671e-03,
        -6.61320491e-02,   1.32008450e-33,   1.72022584e-01,
         2.31002188e-02,  -1.02884845e-01,   3.91976133e-33,
        -3.39941300e-01,  -1.10590751e+00,  -0.00000000e+00,
         4.88369759e-01,  -0.00000000e+00,  -9.55198550e-01,
         0.00000000e+00,   5.59394675e-03,   2.55728416e-02,
         7.16330688e-02,  -1.84562611e-02,   4.19273340e-34,
         2.53969484e-02,   1.19219167e-01,  -7.49523204e-04,
         5.78702947e-34,  -2.34870032e-02,  -7.64086422e-02,
        -4.88369759e-01,  -0.00000000e+00,  -0.00000000e+00,
        -6.59959570e-02,  -1.00000000e+00,   0.00000000e+00,
        -8.11058231e-35,  -3.90379178e-34,  -1.38788980e-33,
         4.19273340e-34,   7.77961671e-03,  -4.67063593e-34,
        -4.12109738e-33,   5.78702947e-34,   2.31002188e-02,
         0.00000000e+00,  -0.00000000e+00,  -0.00000000e+00,
        -0.00000000e+00,  -0.00000000e+00,   0.00000000e+00,
        -0.00000000e+00,  -0.00000000e+00,   0.00000000e+00,
        -7.94777091e-02,  -3.91993866e-01,   2.89026723e-01,
        -3.59433352e-01,   2.19527851e-33,  -4.35738770e-01,
         4.69670798e-02,  -7.28426525e-01,   2.79392170e-33,
         1.66934618e-05,   6.67238034e-04,  -9.80149931e-04,
         1.02620045e-03,  -1.58769972e-35,   1.65406242e-02,
        -4.73029110e-02,   2.91454101e-02,  -5.91704833e-34,
         0.00000000e+00,  -5.02217560e-02,  -2.24611239e-01,
        -4.03306850e-02,  -1.35021787e-01,   3.67251685e-34,
        -3.42922731e-01,  -2.31697157e-01,  -4.78279920e-01,
         1.02800484e-33,   5.61684765e-03,   2.99104628e-02,
        -2.54741003e-02,   5.35589816e-03,  -2.30101684e-34,
         7.38070638e-02,  -1.47914550e-01,   8.63186572e-03,
        -1.14367145e-33,  -0.00000000e+00,   0.00000000e+00])
  elif name == "ALPHA ORBITAL ENERGIES":
    arr = np.array([-26.65930922, -21.15347919,  -2.09261954,  -1.81331031,
        -1.23081655,  -1.22937771,  -1.14522379,  -1.0352292 ,
        -1.02850593,  -0.20232853,  -0.09195581,   0.77983496,
         1.15080117,   1.27645715,   1.3970014 ,   1.83889162,
         1.88956281,   2.08147685,   2.3897125 ,   3.35276033])
  elif name == "BETA ORBITAL ENERGIES":
    arr = np.array([-26.67313843, -21.091216  ,  -2.06318155,  -1.68236221,
        -1.20799551,  -1.10171511,  -1.07159153,  -1.00996223,
        -0.32945386,  -0.21829946,  -0.06918611,   0.78615949,
         1.34580144,   1.36106742,   1.46770424,   1.85339775,
         1.88386611,   1.99619424,   2.46228217,   3.35181457])
  elif name == "ALPHA MO COEFFICIENTS":
    dimens = (nbasis,nbsuse)
    arr = np.array([ -4.41711081e-04,  -2.44347872e-03,  -6.33515339e-05,
         4.13766377e-04,   0.00000000e+00,   6.73714544e-03,
        -2.71680115e-06,  -6.71549751e-03,   0.00000000e+00,
         9.82086290e-01,   9.40295141e-02,  -1.58956690e-04,
         2.41585209e-03,   0.00000000e+00,  -2.93686570e-02,
         1.73511359e-04,  -5.91926927e-03,   0.00000000e+00,
        -1.22557171e-03,   1.56973278e-03,   9.82850020e-01,
         9.69543394e-02,  -3.03611661e-03,  -1.62586826e-03,
         0.00000000e+00,  -3.64916646e-02,   5.91281358e-03,
         3.29554068e-03,   0.00000000e+00,  -2.58614044e-04,
        -1.97040315e-03,   9.70897912e-05,  -8.42298624e-05,
         0.00000000e+00,   6.43636635e-03,  -4.16741312e-04,
         4.93656894e-03,   0.00000000e+00,   2.38024420e-03,
         8.34150288e-03,  -1.74724757e-01,   1.95704803e-01,
        -4.90226244e-02,  -7.80228516e-02,   0.00000000e+00,
         5.02763270e-01,  -6.20012168e-02,  -4.74090958e-02,
         0.00000000e+00,  -1.65455338e-01,   1.71434803e-01,
        -8.25808266e-03,   5.62896785e-02,   0.00000000e+00,
         4.77132127e-01,  -6.96502961e-03,   5.43836912e-02,
         0.00000000e+00,   5.46595818e-02,  -2.75089723e-02,
         1.76129864e-01,  -1.89581192e-01,   8.11048399e-02,
        -8.45218881e-02,  -0.00000000e+00,  -5.75215883e-01,
         8.59155305e-02,  -3.21608122e-02,  -0.00000000e+00,
        -1.87494359e-01,   1.88222384e-01,  -3.72051491e-04,
        -1.55859274e-02,  -0.00000000e+00,   6.24960334e-01,
        -6.88507338e-03,   3.16054672e-02,   0.00000000e+00,
        -9.74526754e-02,   2.03130745e-02,  -5.94204379e-02,
         6.95175733e-02,   4.34127165e-01,  -1.65228939e-01,
         0.00000000e+00,   2.25622617e-01,   3.83007769e-01,
        -1.44251274e-01,   0.00000000e+00,   4.19532615e-02,
        -4.70325012e-02,   1.76048425e-01,   8.21768641e-02,
         0.00000000e+00,  -1.68169589e-01,   1.68905502e-01,
         8.12591370e-02,   0.00000000e+00,  -2.00878598e-01,
        -6.80557206e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.42352165e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.86403130e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.23578100e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.14470153e-01,   0.00000000e+00,   0.00000000e+00,
        -1.93456806e-02,   3.00785350e-02,   1.55648447e-01,
         4.64521493e-01,   0.00000000e+00,   5.49327183e-02,
         1.55159061e-01,   4.43745984e-01,   0.00000000e+00,
        -6.70684127e-02,   7.24782536e-02,   1.81064581e-01,
        -1.77393481e-01,   0.00000000e+00,   2.93215393e-01,
         1.84034590e-01,  -1.63269280e-01,   0.00000000e+00,
         3.15902659e-02,   1.65203530e-02,  -0.00000000e+00,
        -0.00000000e+00,  -0.00000000e+00,  -0.00000000e+00,
        -2.88372674e-01,  -0.00000000e+00,  -0.00000000e+00,
        -0.00000000e+00,  -2.49198545e-01,  -0.00000000e+00,
        -0.00000000e+00,  -0.00000000e+00,  -0.00000000e+00,
         5.32536981e-01,  -0.00000000e+00,  -0.00000000e+00,
         0.00000000e+00,   5.45753418e-01,   0.00000000e+00,
         0.00000000e+00,   2.64042482e-02,  -3.17944102e-02,
        -2.49360263e-01,  -1.27314187e-01,   0.00000000e+00,
        -1.01101736e-01,  -2.10967232e-01,  -1.29775793e-01,
         0.00000000e+00,   6.76817242e-03,  -4.69154494e-03,
         5.16267022e-01,   1.87525041e-02,   0.00000000e+00,
        -4.46736231e-02,   5.30053732e-01,   1.04520532e-02,
         0.00000000e+00,   1.04779434e-01,   2.01040033e-02,
         8.16849448e-02,  -8.92930868e-02,   5.76077529e-02,
         2.84371843e-01,   0.00000000e+00,  -5.01260695e-01,
         1.15280800e-01,   3.69434431e-01,   0.00000000e+00,
        -3.02415781e-02,   2.45281427e-02,   1.23098520e-02,
         4.72273500e-01,   0.00000000e+00,   1.92429262e-01,
         2.01309018e-02,   6.94553431e-01,   0.00000000e+00,
         6.42186487e-02,   3.51215792e-01,   5.82875535e-02,
        -3.30008498e-02,   2.38678412e-01,  -1.83766388e-01,
         0.00000000e+00,  -6.27632321e-01,   4.56110634e-01,
        -3.19961871e-01,   0.00000000e+00,   2.20449733e-02,
        -2.04037678e-02,  -7.49131899e-03,  -1.31358338e-01,
         0.00000000e+00,  -1.50652703e-01,  -5.42366439e-03,
        -2.23219939e-01,   0.00000000e+00,   1.78658500e-01,
         1.26073228e+00,   2.97563268e-02,  -4.55073871e-02,
         2.87766437e-01,  -1.46424984e-02,   0.00000000e+00,
         6.10881930e-02,   1.97280413e-01,  -1.49925487e-01,
         0.00000000e+00,  -9.90830236e-03,   3.76351258e-02,
        -1.08207936e-01,   4.55912176e-02,   0.00000000e+00,
         1.79080787e-03,   2.23544226e-03,  -1.04646371e-02,
         0.00000000e+00,   1.33433760e+00,  -9.18922048e-01,
        -0.00000000e+00,  -0.00000000e+00,  -0.00000000e+00,
        -0.00000000e+00,  -9.66280314e-01,  -0.00000000e+00,
        -0.00000000e+00,  -0.00000000e+00,   1.00625615e+00,
        -0.00000000e+00,  -0.00000000e+00,  -0.00000000e+00,
        -0.00000000e+00,  -1.78426912e-01,  -0.00000000e+00,
        -0.00000000e+00,   0.00000000e+00,   2.74352928e-02,
         0.00000000e+00,   0.00000000e+00,   4.05760895e-02,
        -1.23540672e-01,  -6.51709911e-01,  -6.94025084e-01,
         0.00000000e+00,  -1.30621911e-01,   7.82752280e-01,
         8.75915649e-01,   0.00000000e+00,  -2.98291780e-02,
         2.87520143e-02,  -1.93216620e-01,  -6.24934798e-02,
         0.00000000e+00,   2.79892382e-01,   7.32627307e-02,
         3.27728101e-01,   0.00000000e+00,   2.42893159e-01,
         4.43919789e-04,  -9.44504829e-03,   5.61405600e-02,
         6.72959865e-01,  -6.99067108e-01,   0.00000000e+00,
         6.07168162e-02,  -9.27721098e-01,   1.06163324e+00,
         0.00000000e+00,  -4.02338765e-02,   6.35018304e-02,
         2.10159028e-01,  -8.23493126e-02,   0.00000000e+00,
         3.24320856e-01,  -9.72611670e-02,   4.02664919e-01,
         0.00000000e+00,  -2.49168512e-01,  -3.95314457e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.69954367e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.14593316e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.77798531e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.02311673e+00,
         0.00000000e+00,   0.00000000e+00,  -2.08651892e-02,
         1.68864544e-01,   2.40499368e-01,  -2.01126201e-02,
         0.00000000e+00,  -1.16235074e-01,  -5.07454175e-01,
         8.57513137e-02,   0.00000000e+00,  -6.53633107e-03,
         2.97737110e-02,  -9.45307308e-01,  -1.68561316e-02,
         0.00000000e+00,   1.16435128e-02,   1.02392597e+00,
         4.90947948e-02,   0.00000000e+00,  -2.94566371e-01,
         8.89347422e-02,   3.89862083e-02,  -1.76717287e-01,
         6.15448310e-03,   1.99616071e-01,   0.00000000e+00,
        -9.85110026e-02,  -1.11545732e-02,   1.04990276e-01,
         0.00000000e+00,  -2.87223043e-02,   1.76843403e-01,
        -2.49706931e-03,  -1.01444929e+00,   0.00000000e+00,
        -6.26249895e-02,  -3.32796291e-03,   1.06808154e+00,
         0.00000000e+00,   5.35863357e-02,  -8.92830649e-02,
         7.95188215e-02,  -1.48489471e+00,   1.76690666e-01,
         1.02273220e-02,   0.00000000e+00,   1.74772396e+00,
        -4.92786821e-01,  -3.48731290e-02,   0.00000000e+00,
         6.75264735e-02,  -4.45210396e-01,  -8.37766436e-02,
         6.89239651e-02,   0.00000000e+00,   1.69605071e-01,
         1.26908583e-01,  -3.10170466e-01,   0.00000000e+00,
        -2.57936944e-01,  -4.99697890e-01,   7.91011645e-03,
         6.29369824e-01,  -2.45308924e-02,  -7.25331911e-02,
         0.00000000e+00,  -1.02595282e+00,   1.19592675e-01,
         5.77458860e-01,   0.00000000e+00,   9.64274843e-02,
        -1.45707470e+00,   1.24227811e-02,  -2.31135541e-01,
         0.00000000e+00,   1.60797412e+00,  -2.92466260e-02,
         6.36788162e-01,   0.00000000e+00,   1.86326149e-01,
         5.39419938e-03])
  elif name == "BETA MO COEFFICIENTS":
    dimens = (nbasis,nbsuse)
    arr = np.array([ -4.43711631e-04,  -2.52677957e-03,  -7.19705702e-05,
         4.26964937e-04,   0.00000000e+00,   6.91260035e-03,
        -1.88838031e-05,  -6.86872451e-03,   0.00000000e+00,
         9.81824339e-01,   9.49255766e-02,  -1.49860723e-04,
         2.41471461e-03,   0.00000000e+00,  -2.93867669e-02,
         1.75194584e-04,  -6.04663984e-03,   0.00000000e+00,
        -1.24524991e-03,   1.56182571e-03,   9.83910924e-01,
         9.34658235e-02,  -2.99633443e-03,  -1.53646876e-03,
         0.00000000e+00,  -3.69265788e-02,   6.09833010e-03,
         3.28810159e-03,   0.00000000e+00,  -2.84212027e-04,
        -1.97228622e-03,   9.54986025e-05,  -7.09780820e-05,
         0.00000000e+00,   6.54885302e-03,  -4.57983171e-04,
         5.01442710e-03,   0.00000000e+00,   2.73103842e-03,
         8.26368119e-03,  -8.78293261e-02,   9.05319065e-02,
        -1.81824272e-02,  -5.64921281e-02,   0.00000000e+00,
         2.36696243e-01,  -2.58316555e-02,  -3.22070032e-02,
         0.00000000e+00,  -2.29831592e-01,   2.37682967e-01,
        -3.84979779e-03,   5.59893231e-02,   0.00000000e+00,
         6.95728458e-01,  -7.53604306e-03,   7.19720933e-02,
         0.00000000e+00,   3.43943582e-02,  -1.05204762e-02,
        -2.10714916e-01,   2.14524808e-01,  -1.01420765e-01,
         4.96679573e-02,   0.00000000e+00,   6.69431696e-01,
        -1.01391724e-01,   1.36430137e-02,   0.00000000e+00,
         1.11074095e-01,  -1.14374062e-01,  -7.90863059e-03,
         9.38349249e-02,   0.00000000e+00,  -3.88481190e-01,
        -2.18469221e-03,   5.30243496e-02,   0.00000000e+00,
         1.61823934e-01,  -1.95783449e-03,  -3.53904524e-02,
         3.53030904e-02,   3.28168037e-01,  -1.50174067e-01,
         0.00000000e+00,   1.31605214e-01,   3.01276842e-01,
        -1.31434873e-01,   0.00000000e+00,   3.58890010e-02,
        -4.55779572e-02,   2.16653782e-01,   2.63172890e-01,
         0.00000000e+00,  -1.34597694e-01,   2.07086350e-01,
         2.66296150e-01,   0.00000000e+00,  -1.92308894e-01,
        -7.42166313e-02,  -4.89843724e-02,   6.28519044e-02,
         1.04518901e-01,   2.02337287e-01,   0.00000000e+00,
         1.83434642e-01,   1.24582325e-01,   2.05551470e-01,
         0.00000000e+00,  -2.58573345e-02,   3.62524001e-02,
         3.74245776e-01,  -3.00939272e-01,   0.00000000e+00,
         1.00159030e-01,   3.81616138e-01,  -3.11855606e-01,
         0.00000000e+00,   3.94596239e-02,   3.92760686e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.55784059e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.12813594e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.51608895e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.70324633e-01,
         0.00000000e+00,   0.00000000e+00,   7.25835599e-02,
        -8.31123794e-02,  -3.47055163e-01,  -1.07424656e-01,
         0.00000000e+00,  -2.92631770e-01,  -3.25439499e-01,
        -1.19383726e-01,   0.00000000e+00,   7.79351978e-04,
        -9.81844661e-04,   3.82043649e-01,   1.75035248e-01,
         0.00000000e+00,  -1.06409897e-02,   3.90138144e-01,
         1.77702927e-01,   0.00000000e+00,   1.43897260e-01,
         5.36519851e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.64364749e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.76725775e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.53382093e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.66068920e-01,   0.00000000e+00,   0.00000000e+00,
         8.69010407e-02,  -7.05245309e-02,   8.83159451e-02,
         4.21054185e-01,   0.00000000e+00,  -5.22590219e-01,
         1.65458273e-01,   6.20726627e-01,   0.00000000e+00,
        -5.75395342e-02,   5.46791763e-02,  -1.72718142e-02,
         3.61367389e-01,   0.00000000e+00,   3.29075206e-01,
        -1.77001917e-02,   5.14539559e-01,   0.00000000e+00,
         6.97620043e-02,   3.33082466e-01,   6.52118970e-02,
        -3.30602811e-02,   2.38580610e-01,  -2.00845611e-01,
         0.00000000e+00,  -6.75008582e-01,   4.73147779e-01,
        -3.81696891e-01,   0.00000000e+00,   2.62546385e-02,
        -2.53690095e-02,  -3.71497947e-03,  -9.09811905e-02,
         0.00000000e+00,  -1.73683877e-01,   2.50916240e-05,
        -1.60453185e-01,   0.00000000e+00,   1.50497315e-01,
         1.28637099e+00,   3.65749485e-02,  -4.87133212e-02,
         2.84548349e-01,  -2.26997306e-02,   0.00000000e+00,
         2.46863123e-02,   2.36657048e-01,  -1.48392410e-01,
         0.00000000e+00,  -1.09349579e-02,   3.95731323e-02,
        -1.13484637e-01,   5.00775856e-02,   0.00000000e+00,
         5.40814828e-03,   1.45411679e-03,  -1.40525903e-02,
         0.00000000e+00,   1.33571916e+00,  -8.95674534e-01,
         4.13490786e-02,  -1.38032702e-01,  -8.27182714e-01,
        -4.82962896e-01,   0.00000000e+00,  -1.42445394e-01,
         9.89077431e-01,   5.13383430e-01,   0.00000000e+00,
        -1.62147789e-02,   1.28623767e-02,  -2.60441237e-01,
        -6.57060930e-02,   0.00000000e+00,   1.62134604e-01,
         1.20649529e-01,   2.19906235e-01,   0.00000000e+00,
         2.76050042e-01,   1.26916954e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.03116522e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.00606430e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.24708738e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.51755559e-02,   0.00000000e+00,
         0.00000000e+00,   2.70623138e-03,   2.12577394e-03,
         4.60397155e-01,  -8.89556684e-01,   0.00000000e+00,
         3.38998715e-02,  -6.56183504e-01,   1.22537933e+00,
         0.00000000e+00,  -4.61422699e-02,   8.05527447e-02,
         1.57100292e-01,  -1.50680629e-01,   0.00000000e+00,
         3.62490905e-01,  -8.40913880e-02,   5.16506048e-01,
         0.00000000e+00,  -1.61453721e-01,  -3.75415139e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.35028471e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.58373673e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.71193326e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.01462176e+00,
         0.00000000e+00,   0.00000000e+00,  -1.69469723e-02,
         1.37843490e-01,   2.64571428e-01,   9.20925534e-03,
         0.00000000e+00,  -1.05324886e-01,  -5.36570048e-01,
         9.65420395e-02,   0.00000000e+00,  -9.16433173e-03,
         4.37618033e-02,  -9.32644576e-01,  -1.20778302e-01,
         0.00000000e+00,   8.28787424e-03,   1.01702874e+00,
         1.69872367e-01,   0.00000000e+00,  -2.94997816e-01,
         6.65573625e-02,   3.88241542e-02,  -1.06200752e-01,
        -3.30619933e-02,   2.69404937e-01,   0.00000000e+00,
        -2.07210926e-01,   8.53585507e-02,   4.28840178e-02,
         0.00000000e+00,  -2.95921526e-02,   1.90698068e-01,
         1.05461492e-01,  -9.72183249e-01,   0.00000000e+00,
        -8.37416213e-02,  -1.18324798e-01,   1.08359717e+00,
         0.00000000e+00,   1.09825230e-01,  -5.69156684e-02,
         8.59420794e-02,  -1.47757040e+00,   1.75288963e-01,
         3.24200424e-02,   0.00000000e+00,   1.68232056e+00,
        -4.71874718e-01,  -1.20068232e-02,   0.00000000e+00,
         6.89549417e-02,  -4.84859758e-01,  -6.79894799e-02,
         7.04510600e-03,   0.00000000e+00,   2.23106872e-01,
         1.09266100e-01,  -2.24689653e-01,   0.00000000e+00,
        -2.36296737e-01,  -4.94052744e-01,   4.83248361e-03,
         6.81653556e-01,  -2.94197117e-02,  -7.90239166e-02,
         0.00000000e+00,  -1.08257508e+00,   1.33341841e-01,
         5.84878365e-01,   0.00000000e+00,   9.34757258e-02,
        -1.44037403e+00,   1.65344615e-02,  -2.28123629e-01,
         0.00000000e+00,   1.60620293e+00,  -3.31472744e-02,
         6.45778077e-01,   0.00000000e+00,   1.94455297e-01,
         1.82103983e-02])
  elif name == "ALPHA DENSITY MATRIX":
    dimens = (-nbasis,nbasis)
    arr = np.array([  1.03214705e+00,   2.21551081e-02,   9.03958086e-02,
        -1.55248904e-02,   1.75252817e-02,   2.83863811e-01,
        -5.38261623e-03,   7.12935804e-03,   2.92934381e-02,
         2.72524052e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.77304670e-01,
        -2.42165516e-01,   2.24440315e-01,   6.05206540e-02,
         1.05631546e-02,   0.00000000e+00,   6.49165979e-01,
         4.46270293e-04,   1.01516816e-02,   2.53020864e-01,
         3.32160271e-02,   0.00000000e+00,   3.54599785e-02,
         2.26537049e-01,   2.42132533e-03,   4.60019890e-03,
         3.85120432e-02,   2.52895480e-01,   0.00000000e+00,
        -5.51263980e-04,   4.11761039e-02,   2.37898584e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.35663842e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.98687920e-01,
        -5.81887816e-03,   1.42419826e-03,  -1.07083367e-03,
        -9.78484716e-03,   0.00000000e+00,   3.63878425e-02,
        -1.62015177e-03,  -2.94134866e-02,   0.00000000e+00,
         1.03332721e+00,   2.48820800e-03,  -3.49398847e-03,
        -1.10548608e-03,   1.27935035e-02,   0.00000000e+00,
        -2.75278339e-02,  -2.48239847e-04,   2.47363789e-02,
         0.00000000e+00,   2.18242461e-02,   8.11501534e-02,
         1.14080755e-03,  -2.65599633e-04,  -2.37522830e-02,
        -1.00324791e-02,   0.00000000e+00,  -6.47108073e-03,
        -1.29130792e-02,  -1.16426299e-02,   0.00000000e+00,
         1.62429201e-05,   9.20267789e-04,   3.30377438e-01,
        -1.36202420e-02,   1.37376650e-02,  -6.35399329e-04,
        -1.01441933e-01,   0.00000000e+00,   4.41853478e-02,
        -4.83559875e-03,  -9.51892710e-02,   0.00000000e+00,
         1.14534495e-02,  -9.86641444e-03,  -8.43070750e-03,
         4.19904328e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.23110466e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.39583534e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.33582803e-01,
         3.61870251e-02,  -2.58587613e-02,   1.10507179e-02,
         7.96062682e-02,   0.00000000e+00,  -1.37354500e-01,
         1.46585995e-02,   1.17668188e-01,   0.00000000e+00,
        -2.51987928e-01,   2.26025138e-01,  -3.74600812e-03,
        -4.96263558e-02,   0.00000000e+00,   7.35386441e-01,
        -6.41777476e-06,   3.26007511e-04,  -3.04188877e-02,
        -8.77729412e-03,   0.00000000e+00,  -4.89591169e-03,
        -1.87393741e-02,  -1.09392703e-02,   0.00000000e+00,
         9.44548590e-04,   4.34849460e-04,   3.36766967e-01,
        -9.11087188e-03,   0.00000000e+00,  -5.75633020e-03,
         3.43450877e-01,  -4.74908637e-04,   5.55015323e-03,
         7.14057424e-03,  -9.75241451e-02,   0.00000000e+00,
         1.72504862e-02,   2.95788242e-03,  -8.90669644e-02,
         0.00000000e+00,  -6.30839015e-03,  -9.98528284e-04,
        -1.03201340e-02,   3.83904531e-02,   0.00000000e+00,
        -1.60993287e-02,  -1.13814041e-02,   3.73850494e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.10620202e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.16820038e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.38584707e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.43844240e-01,
        -1.02829630e-02,   1.30603026e-02,  -1.19008297e-01,
         3.84932174e-02,   0.00000000e+00,   2.92612424e-02,
        -1.05889157e-01,   2.99560836e-02,   0.00000000e+00,
        -1.81318147e-03,   2.15370261e-03,   2.40349838e-02,
        -1.55541044e-02,   0.00000000e+00,   3.59064615e-03,
         2.77119898e-02,  -2.04742241e-02,   0.00000000e+00,
         6.48207474e-02,   2.08371248e-02,  -1.33030611e-02,
        -2.90159839e-02,   1.67758251e-02,   0.00000000e+00,
        -4.22886753e-02,  -2.42437574e-02,   1.52067905e-02,
         0.00000000e+00,  -1.54471070e-03,   3.54242341e-03,
         1.60935650e-03,  -1.00081879e-02,   0.00000000e+00,
         1.49678451e-02,   2.25007262e-03,  -8.83943566e-03,
         0.00000000e+00,   1.28340448e-02,   6.55008341e-03])
  elif name == "BETA DENSITY MATRIX":
    dimens = (-nbasis,nbasis)
    arr = np.array([  1.02911600e+00,   2.84474869e-02,   7.50635016e-02,
        -2.19045832e-02,   2.33159054e-02,   2.49691503e-01,
        -1.94099526e-02,   2.17399767e-02,   5.14239840e-03,
         8.06934946e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.71209544e-03,
        -2.33066901e-01,   2.02066038e-01,   9.18325387e-02,
         6.87253632e-02,   0.00000000e+00,   6.42176816e-01,
        -1.07527206e-02,   2.19946952e-02,   2.35570733e-01,
         1.13378944e-02,   0.00000000e+00,   8.35218436e-02,
         2.23184105e-01,  -1.08903863e-02,   1.85371941e-02,
         1.89765868e-02,   7.66426701e-02,   0.00000000e+00,
         5.66841069e-02,   2.43308296e-02,   7.50604207e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.52627163e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.27269071e-02,
        -3.88125553e-03,   9.06750193e-05,   1.64843036e-03,
         8.21491857e-03,   0.00000000e+00,   2.65056852e-02,
         1.99218889e-03,  -7.95236458e-03,   0.00000000e+00,
         1.03109636e+00,   1.00807026e-03,  -2.69128581e-03,
        -3.55008406e-03,  -4.77906856e-03,   0.00000000e+00,
        -1.86389765e-02,  -3.45262511e-03,   3.68551777e-03,
         0.00000000e+00,   2.32958490e-02,   8.19819247e-02,
         3.82903845e-03,  -2.61777139e-03,  -2.15037946e-02,
         1.97165475e-03,   0.00000000e+00,  -2.08457849e-02,
        -1.15330162e-02,   2.85854892e-03,   0.00000000e+00,
        -1.74456682e-03,   3.29266020e-03,   3.33033511e-01,
        -6.62863528e-03,   1.01461796e-03,  -1.63705906e-02,
        -1.17717307e-01,   0.00000000e+00,   4.29921074e-03,
        -2.61280603e-02,  -1.17884842e-01,   0.00000000e+00,
         1.72882735e-02,  -2.02717260e-02,   1.03052334e-02,
         2.02407387e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.16897209e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.22289822e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.04272373e-01,
         2.62948322e-02,  -1.72390118e-02,  -3.27661891e-03,
        -1.69987634e-02,   0.00000000e+00,  -9.20575058e-02,
        -3.15267327e-03,   1.20650277e-02,   0.00000000e+00,
        -2.39333795e-01,   2.16768645e-01,   4.65664168e-03,
        -6.49979611e-02,   0.00000000e+00,   6.64123792e-01,
         2.96704913e-03,  -2.32339175e-03,  -2.71942802e-02,
         4.52371488e-03,   0.00000000e+00,  -2.01396849e-02,
        -1.66200329e-02,   4.85744285e-03,   0.00000000e+00,
        -4.69900418e-04,   2.48908984e-03,   3.36780289e-01,
         7.31767457e-03,   0.00000000e+00,   1.79502560e-03,
         3.40785210e-01,   6.19217170e-03,  -6.59418947e-03,
        -1.35786259e-02,  -1.23623001e-01,   0.00000000e+00,
        -2.18559410e-02,  -2.36590794e-02,  -1.21854390e-01,
         0.00000000e+00,   1.16935822e-03,  -1.31591657e-02,
         8.17865640e-03,   2.04026050e-01,   0.00000000e+00,
        -3.92843366e-02,   4.80427348e-03,   2.07799159e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.31042266e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.43403719e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.14596141e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.25270187e-01,
        -1.91143297e-02,   2.18188109e-02,  -1.25971416e-01,
         2.74955743e-02,   0.00000000e+00,   5.61821290e-02,
        -1.17131489e-01,   1.73256478e-02,   0.00000000e+00,
         1.03619586e-03,  -4.02832163e-04,   2.66664132e-02,
        -2.01910926e-02,   0.00000000e+00,  -1.05765796e-02,
         3.07594905e-02,  -2.68685918e-02,   0.00000000e+00,
         8.66251608e-02,   1.57950053e-02,  -7.43638048e-03,
        -4.22002358e-02,   6.66162106e-03,   0.00000000e+00,
        -2.88422587e-02,  -3.88102824e-02,   4.48537130e-03,
         0.00000000e+00,   1.00825854e-03,   1.32769605e-03,
         5.94451724e-03,  -1.20923508e-02,   0.00000000e+00,
         3.26127025e-03,   7.14132179e-03,  -1.22833344e-02,
         0.00000000e+00,   2.14898279e-02,   8.58731123e-03])
  elif name == "ALPHA SCF DENSITY MATRIX":
    dimens = (-nbasis,nbasis)
    arr = np.array([  1.03214705e+00,   2.21551081e-02,   9.03958086e-02,
        -1.55248904e-02,   1.75252817e-02,   2.83863811e-01,
        -5.38261623e-03,   7.12935804e-03,   2.92934381e-02,
         2.72524052e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.77304670e-01,
        -2.42165516e-01,   2.24440315e-01,   6.05206540e-02,
         1.05631546e-02,   0.00000000e+00,   6.49165979e-01,
         4.46270293e-04,   1.01516816e-02,   2.53020864e-01,
         3.32160271e-02,   0.00000000e+00,   3.54599785e-02,
         2.26537049e-01,   2.42132533e-03,   4.60019890e-03,
         3.85120432e-02,   2.52895480e-01,   0.00000000e+00,
        -5.51263980e-04,   4.11761039e-02,   2.37898584e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.35663842e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.98687920e-01,
        -5.81887816e-03,   1.42419826e-03,  -1.07083367e-03,
        -9.78484716e-03,   0.00000000e+00,   3.63878425e-02,
        -1.62015177e-03,  -2.94134866e-02,   0.00000000e+00,
         1.03332721e+00,   2.48820800e-03,  -3.49398847e-03,
        -1.10548608e-03,   1.27935035e-02,   0.00000000e+00,
        -2.75278339e-02,  -2.48239847e-04,   2.47363789e-02,
         0.00000000e+00,   2.18242461e-02,   8.11501534e-02,
         1.14080755e-03,  -2.65599633e-04,  -2.37522830e-02,
        -1.00324791e-02,   0.00000000e+00,  -6.47108073e-03,
        -1.29130792e-02,  -1.16426299e-02,   0.00000000e+00,
         1.62429201e-05,   9.20267789e-04,   3.30377438e-01,
        -1.36202420e-02,   1.37376650e-02,  -6.35399329e-04,
        -1.01441933e-01,   0.00000000e+00,   4.41853478e-02,
        -4.83559875e-03,  -9.51892710e-02,   0.00000000e+00,
         1.14534495e-02,  -9.86641444e-03,  -8.43070750e-03,
         4.19904328e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.23110466e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.39583534e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.33582803e-01,
         3.61870251e-02,  -2.58587613e-02,   1.10507179e-02,
         7.96062682e-02,   0.00000000e+00,  -1.37354500e-01,
         1.46585995e-02,   1.17668188e-01,   0.00000000e+00,
        -2.51987928e-01,   2.26025138e-01,  -3.74600812e-03,
        -4.96263558e-02,   0.00000000e+00,   7.35386441e-01,
        -6.41777476e-06,   3.26007511e-04,  -3.04188877e-02,
        -8.77729412e-03,   0.00000000e+00,  -4.89591169e-03,
        -1.87393741e-02,  -1.09392703e-02,   0.00000000e+00,
         9.44548590e-04,   4.34849460e-04,   3.36766967e-01,
        -9.11087188e-03,   0.00000000e+00,  -5.75633020e-03,
         3.43450877e-01,  -4.74908637e-04,   5.55015323e-03,
         7.14057424e-03,  -9.75241451e-02,   0.00000000e+00,
         1.72504862e-02,   2.95788242e-03,  -8.90669644e-02,
         0.00000000e+00,  -6.30839015e-03,  -9.98528284e-04,
        -1.03201340e-02,   3.83904531e-02,   0.00000000e+00,
        -1.60993287e-02,  -1.13814041e-02,   3.73850494e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.10620202e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.16820038e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.38584707e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.43844240e-01,
        -1.02829630e-02,   1.30603026e-02,  -1.19008297e-01,
         3.84932174e-02,   0.00000000e+00,   2.92612424e-02,
        -1.05889157e-01,   2.99560836e-02,   0.00000000e+00,
        -1.81318147e-03,   2.15370261e-03,   2.40349838e-02,
        -1.55541044e-02,   0.00000000e+00,   3.59064615e-03,
         2.77119898e-02,  -2.04742241e-02,   0.00000000e+00,
         6.48207474e-02,   2.08371248e-02,  -1.33030611e-02,
        -2.90159839e-02,   1.67758251e-02,   0.00000000e+00,
        -4.22886753e-02,  -2.42437574e-02,   1.52067905e-02,
         0.00000000e+00,  -1.54471070e-03,   3.54242341e-03,
         1.60935650e-03,  -1.00081879e-02,   0.00000000e+00,
         1.49678451e-02,   2.25007262e-03,  -8.83943566e-03,
         0.00000000e+00,   1.28340448e-02,   6.55008341e-03])
  elif name == "BETA SCF DENSITY MATRIX":
    dimens = (-nbasis,nbasis)
    arr = np.array([  1.02911600e+00,   2.84474869e-02,   7.50635016e-02,
        -2.19045832e-02,   2.33159054e-02,   2.49691503e-01,
        -1.94099526e-02,   2.17399767e-02,   5.14239840e-03,
         8.06934946e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.71209544e-03,
        -2.33066901e-01,   2.02066038e-01,   9.18325387e-02,
         6.87253632e-02,   0.00000000e+00,   6.42176816e-01,
        -1.07527206e-02,   2.19946952e-02,   2.35570733e-01,
         1.13378944e-02,   0.00000000e+00,   8.35218436e-02,
         2.23184105e-01,  -1.08903863e-02,   1.85371941e-02,
         1.89765868e-02,   7.66426701e-02,   0.00000000e+00,
         5.66841069e-02,   2.43308296e-02,   7.50604207e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.52627163e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.27269071e-02,
        -3.88125553e-03,   9.06750193e-05,   1.64843036e-03,
         8.21491857e-03,   0.00000000e+00,   2.65056852e-02,
         1.99218889e-03,  -7.95236458e-03,   0.00000000e+00,
         1.03109636e+00,   1.00807026e-03,  -2.69128581e-03,
        -3.55008406e-03,  -4.77906856e-03,   0.00000000e+00,
        -1.86389765e-02,  -3.45262511e-03,   3.68551777e-03,
         0.00000000e+00,   2.32958490e-02,   8.19819247e-02,
         3.82903845e-03,  -2.61777139e-03,  -2.15037946e-02,
         1.97165475e-03,   0.00000000e+00,  -2.08457849e-02,
        -1.15330162e-02,   2.85854892e-03,   0.00000000e+00,
        -1.74456682e-03,   3.29266020e-03,   3.33033511e-01,
        -6.62863528e-03,   1.01461796e-03,  -1.63705906e-02,
        -1.17717307e-01,   0.00000000e+00,   4.29921074e-03,
        -2.61280603e-02,  -1.17884842e-01,   0.00000000e+00,
         1.72882735e-02,  -2.02717260e-02,   1.03052334e-02,
         2.02407387e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.16897209e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.22289822e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.04272373e-01,
         2.62948322e-02,  -1.72390118e-02,  -3.27661891e-03,
        -1.69987634e-02,   0.00000000e+00,  -9.20575058e-02,
        -3.15267327e-03,   1.20650277e-02,   0.00000000e+00,
        -2.39333795e-01,   2.16768645e-01,   4.65664168e-03,
        -6.49979611e-02,   0.00000000e+00,   6.64123792e-01,
         2.96704913e-03,  -2.32339175e-03,  -2.71942802e-02,
         4.52371488e-03,   0.00000000e+00,  -2.01396849e-02,
        -1.66200329e-02,   4.85744285e-03,   0.00000000e+00,
        -4.69900418e-04,   2.48908984e-03,   3.36780289e-01,
         7.31767457e-03,   0.00000000e+00,   1.79502560e-03,
         3.40785210e-01,   6.19217170e-03,  -6.59418947e-03,
        -1.35786259e-02,  -1.23623001e-01,   0.00000000e+00,
        -2.18559410e-02,  -2.36590794e-02,  -1.21854390e-01,
         0.00000000e+00,   1.16935822e-03,  -1.31591657e-02,
         8.17865640e-03,   2.04026050e-01,   0.00000000e+00,
        -3.92843366e-02,   4.80427348e-03,   2.07799159e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.31042266e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.43403719e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.14596141e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.25270187e-01,
        -1.91143297e-02,   2.18188109e-02,  -1.25971416e-01,
         2.74955743e-02,   0.00000000e+00,   5.61821290e-02,
        -1.17131489e-01,   1.73256478e-02,   0.00000000e+00,
         1.03619586e-03,  -4.02832163e-04,   2.66664132e-02,
        -2.01910926e-02,   0.00000000e+00,  -1.05765796e-02,
         3.07594905e-02,  -2.68685918e-02,   0.00000000e+00,
         8.66251608e-02,   1.57950053e-02,  -7.43638048e-03,
        -4.22002358e-02,   6.66162106e-03,   0.00000000e+00,
        -2.88422587e-02,  -3.88102824e-02,   4.48537130e-03,
         0.00000000e+00,   1.00825854e-03,   1.32769605e-03,
         5.94451724e-03,  -1.20923508e-02,   0.00000000e+00,
         3.26127025e-03,   7.14132179e-03,  -1.22833344e-02,
         0.00000000e+00,   2.14898279e-02,   8.58731123e-03])
  elif name == "ALPHA FOCK MATRIX":
    dimens = (-nbasis,nbasis)
    arr = np.array([ -2.10347416e+01,  -5.87016505e+00,  -2.45027876e+00,
         2.78158046e-02,   7.30052087e-02,  -5.18283108e-01,
         1.55523145e-02,   3.79939001e-02,  -2.97250671e-02,
        -5.23854477e-01,  -3.72539481e-16,  -2.01821929e-16,
         2.35614863e-16,   3.67744272e-17,  -6.79718274e-01,
        -4.60976056e+00,  -3.00710804e+00,   8.79279133e-02,
         3.25111431e-02,  -2.24669104e-16,  -2.76993312e+00,
         5.02801920e-03,   5.18484184e-02,  -1.14734423e+00,
        -7.58737271e-04,   1.74966170e-16,   1.67788978e-01,
        -6.74277957e-01,   2.66362455e-03,   1.00777482e-02,
        -6.88391846e-04,  -1.12831794e+00,   7.11216973e-17,
         1.19900485e-01,   5.51975288e-02,  -8.29845056e-01,
        -2.10481338e-16,  -1.81770885e-16,   1.44433583e-16,
         3.72764796e-17,  -1.17902114e+00,  -1.78951763e-16,
         1.07148434e-16,   6.43593315e-17,  -5.58189493e-01,
         1.99151232e-05,  -2.23992331e-03,   5.26032995e-05,
         5.18280819e-03,   5.74565554e-17,  -3.64525106e-01,
         9.80284676e-06,   1.15251388e+00,   4.51818445e-17,
        -2.65073684e+01,  -7.86994574e-04,  -3.19225167e-02,
        -1.11346112e-03,   8.41241471e-02,  -6.46508220e-17,
        -4.04823787e-01,   2.51417872e-04,   1.01908810e+00,
        -7.48504537e-17,  -7.58233773e+00,  -2.63655486e+00,
        -1.51911480e-04,  -1.70421920e-04,  -6.95430327e-03,
         5.14967561e-03,   2.56113283e-17,   1.72421512e-03,
        -1.72951361e-01,  -3.68182012e-03,   3.77375621e-18,
         1.88480637e-03,   1.07798036e-02,  -3.20850221e-01,
        -4.01117914e-04,  -1.07882832e-01,  -9.10305963e-04,
         2.26228205e-01,  -5.14424095e-17,  -2.65579629e-01,
        -1.38488173e-03,   4.60708320e-01,  -2.62055599e-17,
        -2.44026335e-02,  -4.53562387e-02,   2.43457939e-02,
         2.84689129e-01,   1.17079469e-17,  -1.82212532e-16,
        -6.91509151e-17,   3.81988130e-17,  -2.83610249e-03,
        -2.02472239e-16,  -8.56170689e-17,   5.90786988e-17,
        -1.71980776e-01,  -1.02369504e-16,  -2.42557638e-16,
        -2.86301677e-16,   2.89109605e-16,  -3.32694431e-01,
        -2.07331457e-01,  -3.25877895e-01,   4.57489998e-03,
         2.97226800e-01,  -1.05916655e-16,  -6.36866933e-01,
         9.86848184e-03,   1.01013046e+00,  -1.09266511e-16,
        -5.82873071e+00,  -3.45360324e+00,   8.73362196e-03,
        -6.68291235e-02,  -2.65894429e-16,  -3.01636396e+00,
         2.89330042e-04,   7.56802125e-04,  -1.50350909e-01,
        -1.06600166e-03,   4.16268123e-17,   1.06464901e-02,
        -2.26494782e-01,  -1.44751577e-02,   1.62890615e-17,
         1.57041585e-04,   6.54407264e-03,  -1.24760127e+00,
         1.69489562e-02,  -1.92490564e-16,   1.64793265e-02,
        -3.66424520e-01,  -7.26382420e-01,  -8.32279057e-01,
         1.55771608e-02,   5.90498286e-01,  -1.10127559e-16,
        -8.05317501e-01,   2.22200018e-02,   4.19973492e-01,
        -7.77380061e-17,  -6.42812421e-03,  -1.21597683e-02,
         1.42040588e-02,  -8.78937002e-01,   9.75864507e-17,
        -1.88985343e-01,   1.86586520e-02,  -3.97056033e-01,
        -1.13304468e-17,  -1.95505729e-16,  -4.92881615e-17,
         4.19195616e-17,  -1.55505201e-01,  -2.10153694e-16,
        -6.59605994e-17,   4.75870029e-17,  -2.27220285e-01,
        -5.19748975e-17,  -1.81310538e-16,  -1.74950564e-16,
         1.76506743e-16,  -1.25179825e+00,  -1.96427809e-16,
        -1.44337114e-16,   5.46266506e-17,  -3.68898872e-01,
        -5.95944742e-01,  -8.27372959e-01,   7.12922983e-01,
        -2.38016953e-01,  -1.41360148e-16,  -8.86104887e-01,
         6.65986513e-01,  -2.26616095e-01,  -1.04264558e-16,
        -2.61994757e-04,  -1.57992297e-03,  -4.17505865e-03,
         2.11685091e-03,  -2.37907046e-17,  -6.15229122e-02,
         6.70923940e-02,  -1.55315466e-01,  -3.45777198e-17,
        -5.37892028e-01,  -1.54986950e+00,  -1.38591887e+00,
         4.33336342e-01,  -1.25034265e-01,  -1.61311545e-16,
        -1.41264930e+00,   4.71827424e-01,  -6.27711236e-02,
        -1.15607476e-16,  -2.47936991e-01,  -2.56839998e-01,
         6.48218186e-02,  -1.04256393e-01,  -7.69296696e-17,
        -3.68004012e-01,   1.01774389e-01,  -3.61258741e-01,
        -8.40620103e-17,  -8.89951788e-01,  -9.94157735e-01])
  elif name == "BETA FOCK MATRIX":
    dimens = (-nbasis,nbasis)
    arr = np.array([ -2.09820300e+01,  -5.80248921e+00,  -2.12979211e+00,
         2.91885571e-02,   3.72675948e-02,  -3.86003844e-01,
         1.97211853e-02,  -3.83207619e-02,   1.47688418e-02,
        -3.14928523e-02,  -3.79173648e-17,   1.49780218e-16,
         6.56018580e-17,  -1.86803721e-17,   2.38375767e-01,
        -4.56168219e+00,  -2.75305964e+00,   6.39631305e-02,
        -1.48287374e-02,   1.09064456e-16,  -2.55366772e+00,
         5.65214046e-03,   3.40285471e-02,  -1.08850079e+00,
         2.18209407e-02,   5.99016039e-17,   1.60101754e-01,
        -6.49332828e-01,   5.90562969e-03,  -3.22324921e-02,
         2.00423374e-02,  -8.57231643e-01,  -8.24913468e-18,
         1.10634599e-01,   6.82420870e-02,  -6.83082967e-01,
        -7.15956043e-17,   5.11431125e-17,   6.58722297e-17,
        -1.36366106e-17,  -6.00383261e-01,   6.96268821e-17,
         5.28848809e-17,  -1.32300463e-17,  -1.18230992e-01,
        -1.22595536e-05,  -1.89014245e-03,   2.84139760e-05,
         4.02331319e-03,   1.45658877e-17,  -3.66117347e-01,
        -1.31894705e-05,   1.15607370e+00,   3.57385301e-17,
        -2.65179382e+01,  -1.17368342e-03,  -4.19644382e-02,
         4.04827594e-03,   1.15190883e-01,  -3.58096458e-18,
        -4.23580525e-01,   3.02870421e-03,   1.06313782e+00,
         3.52415558e-18,  -7.60435590e+00,  -2.70451676e+00,
        -1.98860145e-04,   4.73940256e-03,  -8.56343080e-03,
        -3.82630161e-03,  -7.89392211e-18,   2.83334492e-03,
        -1.75073521e-01,  -2.97204606e-03,   1.47499574e-17,
         2.40629167e-03,   1.31719485e-03,  -3.41960988e-01,
        -1.44359257e-03,  -1.03388481e-01,   1.18014111e-02,
         2.51683087e-01,  -1.01643149e-17,  -3.01368557e-01,
         8.15062846e-03,   5.64026020e-01,  -3.29458256e-17,
        -2.55216738e-02,  -1.32440233e-02,  -1.94920982e-02,
        -1.87491458e-01,  -1.23534808e-16,  -8.03345061e-17,
         4.75804948e-17,   1.99565364e-17,  -5.98095263e-02,
        -9.58516168e-17,   7.20678538e-17,   2.91493021e-17,
        -2.26920827e-01,   3.67058715e-16,   2.39535775e-16,
         3.42624410e-16,  -3.59972990e-16,  -2.88317900e-01,
        -2.04799543e-01,  -3.07874085e-01,   4.33730314e-03,
         2.82099266e-01,   4.25148732e-18,  -6.32514689e-01,
         1.01144736e-02,   1.02549173e+00,   1.50163189e-17,
        -5.84412938e+00,  -3.51786117e+00,   4.51404775e-03,
        -3.71644506e-02,   1.90024933e-16,  -3.08024069e+00,
         2.55183910e-04,   1.97281842e-03,  -1.45782969e-01,
        -6.71724622e-03,  -1.95427211e-18,   1.01526235e-02,
        -2.25483949e-01,  -1.49721404e-02,   1.47134472e-17,
         4.42406189e-04,   2.18277852e-03,  -1.25859676e+00,
        -7.81320031e-03,   2.24075234e-16,   1.54638234e-02,
        -3.75766424e-01,  -7.18289205e-01,  -7.51170474e-01,
         1.20291698e-02,   4.97992267e-01,   1.97933343e-17,
        -7.67053133e-01,   2.36047062e-02,   4.29099296e-01,
         4.79329920e-18,  -5.90735286e-03,  -7.66666720e-03,
        -6.57082114e-03,  -1.19032696e+00,  -2.45810706e-16,
        -1.61501379e-01,   5.04274263e-03,  -5.96036941e-01,
        -1.25075850e-16,  -7.00039744e-17,   5.30286736e-17,
         6.24128389e-18,  -1.47761332e-01,  -7.40989391e-17,
         7.06536774e-17,   7.81177945e-19,  -2.31935947e-01,
         1.98507459e-16,   1.26303697e-16,   2.13459111e-16,
        -2.33883082e-16,  -1.23664155e+00,   1.44601837e-16,
         1.62938321e-16,  -1.75873973e-16,  -3.67647994e-01,
        -5.88522806e-01,  -7.95026939e-01,   7.00895157e-01,
        -2.16781442e-01,  -2.17211962e-17,  -8.67064082e-01,
         6.79980046e-01,  -2.15845623e-01,  -2.54918337e-17,
        -4.37088808e-04,  -4.14387363e-05,  -4.85037247e-03,
         2.76865834e-03,  -4.80151707e-17,  -6.04438319e-02,
         6.68783182e-02,  -1.54584819e-01,  -5.10871384e-17,
        -5.77733156e-01,  -1.53087817e+00,  -1.28269531e+00,
         4.17970502e-01,  -1.18825056e-01,   2.06799833e-17,
        -1.32411945e+00,   4.75251674e-01,  -4.81825075e-02,
         1.74021761e-17,  -2.49049579e-01,  -2.63280095e-01,
         6.42696893e-02,  -1.19591523e-01,  -6.85693201e-17,
        -3.67857677e-01,   1.01017594e-01,  -3.52563763e-01,
        -5.83626753e-17,  -9.01600401e-01,  -9.65461239e-01])
  elif name == "RAFFENETTI 2E INTEGRALS":
    n = 2
    dimens = (-nbasis,-nbasis,-nbasis,nbasis)
    nt = qco._lenarray(dimens)
    arr = np.array([  1.22671382e+00,   4.90685529e+00,   2.82870344e-01,
         1.13148138e+00,  -1.47842187e-01,   7.88779652e-01,
         1.42950113e+00,   1.97410904e-01,   1.50743551e-01,
         6.02974206e-01,   3.01797213e-01,   1.20718885e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.74339247e-01,   8.34811540e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.47094399e-02,
         3.98481766e-01,  -4.79481009e-02,   7.36333606e-01,
         1.56653217e+00,   1.37454550e-01,   2.71115264e-01,
         1.69822003e-01,   1.06426131e+00,   5.44541202e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.24940722e-01,   1.29976289e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.74339247e-01,   8.34811540e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.47094399e-02,
         3.98481766e-01,  -4.79481009e-02,   7.36333606e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.17663086e-01,   6.14035624e-01,
         1.56653217e+00,   1.37454550e-01,   2.71115264e-01,
         1.69822003e-01,   1.06426131e+00,   5.44541202e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.12053379e+00,   1.43383280e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.24940722e-01,   1.29976289e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.74339247e-01,   8.34811540e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.47094399e-02,
         3.98481766e-01,  -4.79481009e-02,   7.36333606e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.17663086e-01,   6.14035624e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.17663086e-01,   6.14035624e-01,
         1.56653217e+00,   1.37454550e-01,   2.71115264e-01,
         1.69822003e-01,   1.06426131e+00,   5.44541202e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.12053379e+00,   1.43383280e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.12053379e+00,   1.43383280e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.24940722e-01,   1.29976289e+00,
         3.23207269e-01,   1.29282908e+00,  -1.75957054e-01,
         1.07854840e+00,   1.66665543e-01,   4.00478817e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.54317377e-01,   1.11935836e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.54317377e-01,   1.11935836e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.54317377e-01,   1.11935836e-01,
        -8.44466093e-02,   5.30349001e-01,   9.38028333e-01,
         1.87360093e-01,   8.34832445e-02,   4.67024656e-01,
         4.11403545e-01,   1.64561418e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.24233795e-01,   3.77798664e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.24233795e-01,
         3.77798664e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.24233795e-01,   3.77798664e-01,   8.41532223e-02,
         3.72970281e-01,   1.06572148e-01,   7.08617794e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.85993956e-02,   3.38269254e-01,  -6.29963663e-02,
         1.00758279e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.45405947e-02,   4.92203576e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.85993956e-02,   3.38269254e-01,  -6.29963663e-02,
         1.00758279e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.45405947e-02,   4.92203576e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.85993956e-02,   3.38269254e-01,
        -6.29963663e-02,   1.00758279e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.45405947e-02,   4.92203576e-01,
         9.16276079e-01,   1.92562564e-01,   1.06876592e-01,
         3.54791585e-01,   5.66055799e-01,   1.13490639e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.78876254e-01,   2.74041197e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.78876254e-01,   2.74041197e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.78876254e-01,   2.74041197e-01,
         8.66928692e-02,   3.46771477e-01,   3.01096098e-01,
         1.20438439e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.72443695e-01,   6.89774779e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.32517253e-01,   5.60292654e-01,  -2.32802048e-02,
         1.37829734e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.36932869e-02,   1.23997084e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.09467150e-02,   3.25513191e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.68054587e-03,
         1.24550007e-01,  -4.43432778e-02,   5.94023483e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.91980121e-02,   4.66902104e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.14321287e-02,
         1.39100761e-01,  -6.26236027e-02,   3.41086386e-01,
         5.48958788e-01,   1.51118212e-02,   1.04464232e-01,
         3.56341846e-02,   4.37779593e-01,   2.08325186e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.61733345e-01,   1.04693338e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.54927477e-01,   5.48313703e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.54927477e-01,   5.48313703e-02,
         9.22403361e-02,   3.12501858e-02,   2.93511789e-01,
         2.00734263e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.28847146e-01,   2.04257045e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.67601093e-03,   4.48616162e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.65970660e-02,   4.96051004e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.23050029e-02,   3.16452182e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.65970660e-02,
         4.96051004e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.23050029e-02,   3.16452182e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.89551503e-03,   1.07358867e-01,   1.79010319e-02,
         4.21222869e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.83814601e-02,   4.82039930e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.72421086e-02,   1.22212550e-01,  -6.92275091e-02,
         5.26012892e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.87406158e-02,   3.44887390e-01,
         6.49731634e-01,   1.72633124e-03,   1.34086169e-01,
         6.68612315e-03,   6.14228791e-01,   9.05919752e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.49742170e-01,   4.63320206e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.12480236e-01,   2.72321706e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.12480236e-01,   2.72321706e-02,
         1.17246007e-01,   6.62205790e-03,   4.32599321e-01,
         1.24551428e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.17331084e-01,   2.29924926e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.62946132e-01,   6.51784528e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.40829017e-01,   5.63316070e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.32517253e-01,
         5.60292654e-01,  -2.32802048e-02,   1.37829734e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.36932869e-02,
         1.23997084e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.09467150e-02,   3.25513191e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.68054587e-03,   1.24550007e-01,  -4.43432778e-02,
         5.94023483e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.91980121e-02,   4.66902104e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.14321287e-02,
         1.39100761e-01,  -6.26236027e-02,   3.41086386e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.65970660e-02,   4.96051004e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.32763908e-02,   2.27569904e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.23050029e-02,   3.16452182e-01,   5.48958788e-01,
         1.51118212e-02,   1.04464232e-01,   3.56341846e-02,
         4.37779593e-01,   2.08325186e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.54927477e-01,   5.48313703e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.61733345e-01,
         1.04693338e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.54927477e-01,   5.48313703e-02,   9.22403361e-02,
         3.12501858e-02,   2.93511789e-01,   2.00734263e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.28847146e-01,   2.04257045e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.95238418e-01,   3.67580569e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.85801115e-01,
         3.20729193e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.67601093e-03,   4.48616162e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.65970660e-02,
         4.96051004e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.23050029e-02,   3.16452182e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.89551503e-03,   1.07358867e-01,   1.79010319e-02,
         4.21222869e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.83814601e-02,   4.82039930e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.72421086e-02,
         1.22212550e-01,  -6.92275091e-02,   5.26012892e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.87406158e-02,   3.44887390e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.13690329e-02,   2.18044018e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.14274915e-02,
         3.09855804e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.14274915e-02,
         3.09855804e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.88590469e-02,   2.64413665e-01,
         6.49731634e-01,   1.72633124e-03,   1.34086169e-01,
         6.68612315e-03,   6.14228791e-01,   9.05919752e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.12480236e-01,   2.72321706e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.49742170e-01,   4.63320206e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.12480236e-01,   2.72321706e-02,
         1.17246007e-01,   6.62205790e-03,   4.32599321e-01,
         1.24551428e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.17331084e-01,   2.29924926e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.85801115e-01,   3.20729193e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.77094222e-01,   6.89774779e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.62946132e-01,
         6.51784528e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.40829017e-01,   5.63316070e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.32517253e-01,
         5.60292654e-01,  -2.32802048e-02,   1.37829734e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.36932869e-02,
         1.23997084e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.09467150e-02,   3.25513191e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.68054587e-03,   1.24550007e-01,
        -4.43432778e-02,   5.94023483e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.91980121e-02,   4.66902104e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.14321287e-02,
         1.39100761e-01,  -6.26236027e-02,   3.41086386e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.65970660e-02,   4.96051004e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.32763908e-02,
         2.27569904e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.23050029e-02,   3.16452182e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.65970660e-02,
         4.96051004e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.32763908e-02,   2.27569904e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.23050029e-02,   3.16452182e-01,   5.48958788e-01,
         1.51118212e-02,   1.04464232e-01,   3.56341846e-02,
         4.37779593e-01,   2.08325186e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.54927477e-01,   5.48313703e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.54927477e-01,
         5.48313703e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.61733345e-01,   1.04693338e+00,   9.22403361e-02,
         3.12501858e-02,   2.93511789e-01,   2.00734263e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.28847146e-01,   2.04257045e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.95238418e-01,   3.67580569e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.85801115e-01,
         3.20729193e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.95238418e-01,   3.67580569e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.85801115e-01,   3.20729193e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.67601093e-03,   4.48616162e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.89551503e-03,
         1.07358867e-01,   1.79010319e-02,   4.21222869e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.83814601e-02,
         4.82039930e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.72421086e-02,   1.22212550e-01,  -6.92275091e-02,
         5.26012892e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.87406158e-02,   3.44887390e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.13690329e-02,   2.18044018e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.14274915e-02,
         3.09855804e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.14274915e-02,   3.09855804e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.88590469e-02,   2.64413665e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.13690329e-02,   2.18044018e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.14274915e-02,   3.09855804e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.14274915e-02,
         3.09855804e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.88590469e-02,   2.64413665e-01,
         6.49731634e-01,   1.72633124e-03,   1.34086169e-01,
         6.68612315e-03,   6.14228791e-01,   9.05919752e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.12480236e-01,   2.72321706e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.12480236e-01,   2.72321706e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.49742170e-01,   4.63320206e-01,
         1.17246007e-01,   6.62205790e-03,   4.32599321e-01,
         1.24551428e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.17331084e-01,   2.29924926e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.85801115e-01,   3.20729193e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.77094222e-01,   6.89774779e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.85801115e-01,
         3.20729193e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.77094222e-01,   6.89774779e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.62946132e-01,
         6.51784528e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.40829017e-01,   5.63316070e-01,
         0.00000000e+00,   0.00000000e+00,  -1.79289133e-06,
         7.17156532e-06,  -7.50198121e-07,   3.00079248e-06,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.23871057e-09,   8.95484230e-09,
         7.55991720e-06,  -3.02396688e-05,   1.62984061e-06,
        -6.51936244e-06,   0.00000000e+00,   0.00000000e+00,
        -4.04012933e-07,   1.61605173e-06,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.23871057e-09,   8.95484230e-09,
        -1.05838252e-03,   4.23353008e-03,  -2.21757342e-04,
         8.87029368e-04,   0.00000000e+00,   0.00000000e+00,
         2.76181475e-05,  -1.10472590e-04,   0.00000000e+00,
         0.00000000e+00,  -3.87553131e-04,   1.55021252e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.98711844e-07,   1.59484738e-06,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.12780438e-07,   4.51121751e-07,   3.37215453e-03,
        -1.34886181e-02,   7.05510813e-04,  -2.82204325e-03,
         0.00000000e+00,   0.00000000e+00,  -8.32098259e-05,
         3.32839304e-04,   0.00000000e+00,   0.00000000e+00,
         6.21110980e-04,  -2.48444392e-03,   0.00000000e+00,
         0.00000000e+00,  -2.35381646e-05,   9.41526585e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.98711844e-07,
         1.59484738e-06,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.12780438e-07,   4.51121751e-07,
        -4.65825010e-02,   1.86330004e-01,   7.17156532e-06,
         6.09863722e-20,   1.12529718e-06,   1.50039624e-06,
         3.58578245e-06,   1.43431298e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.99758221e-06,   5.86831107e-08,   1.38886321e-06,
        -6.32658052e-06,   6.61240908e-06,  -3.15030110e-05,
         0.00000000e+00,   0.00000000e+00,   4.84259507e-06,
         1.05903561e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.99758221e-06,   5.86831107e-08,  -2.20116062e-04,
         8.85716344e-04,  -1.05440224e-03,   4.23883709e-03,
         0.00000000e+00,   0.00000000e+00,   1.76300479e-04,
        -7.10048439e-04,   0.00000000e+00,   0.00000000e+00,
        -1.55929505e-03,   6.26575202e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.10161423e-07,   1.04650931e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.17707511e-06,
         1.27030739e-05,   7.05476718e-04,  -2.82201598e-03,
         3.37157855e-03,  -1.34893860e-02,   0.00000000e+00,
         0.00000000e+00,  -5.42033535e-04,   2.18364371e-03,
         0.00000000e+00,   0.00000000e+00,   2.59763387e-03,
        -1.03998614e-02,   0.00000000e+00,   0.00000000e+00,
        -6.54337445e-04,   2.65124984e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.10161423e-07,   1.04650931e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.17707511e-06,   1.27030739e-05,  -1.94914795e-02,
         7.79659182e-02,  -4.65825006e-02,   1.86330004e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.35806586e-09,   4.47742115e-09,  -1.73105708e-06,
         7.04159454e-06,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.38563033e-06,  -2.95870902e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.03837836e-03,   4.15362599e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.97919972e-07,   1.59421388e-06,  -3.45058698e-06,
         1.38736918e-05,   0.00000000e+00,   0.00000000e+00,
         4.51610560e-06,  -1.81064738e-05,   0.00000000e+00,
         0.00000000e+00,  -5.11459037e-04,   2.04605249e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.30909457e-03,  -1.32364203e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.62316565e-03,
        -6.49285980e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.57451938e-02,   1.82980775e-01,
        -3.02396688e-05,  -1.35525272e-20,  -6.27838504e-06,
        -1.92781920e-07,  -2.96079955e-05,  -2.52668736e-06,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.95703769e-05,  -2.22844245e-08,
         6.06019400e-07,   8.08025866e-07,   2.09883752e-06,
         1.27853622e-05,   0.00000000e+00,   0.00000000e+00,
        -1.57835450e-05,  -6.31341800e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.95703769e-05,  -2.22844245e-08,
         2.06975174e-05,  -1.04936086e-04,   1.49842930e-04,
        -6.88882401e-04,   0.00000000e+00,   0.00000000e+00,
        -1.09453967e-03,   4.39847277e-03,   0.00000000e+00,
         0.00000000e+00,   2.99677477e-04,  -1.31921268e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.35401523e-05,  -3.66146747e-06,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.51035652e-05,  -6.89615623e-06,  -8.30669192e-05,
         3.32724978e-04,  -5.42856662e-04,   2.18430221e-03,
         0.00000000e+00,   0.00000000e+00,   3.48600759e-03,
        -1.40093684e-02,   0.00000000e+00,   0.00000000e+00,
        -1.07869797e-03,   4.35395544e-03,   0.00000000e+00,
         0.00000000e+00,   3.56629294e-03,  -1.44080578e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.35401523e-05,
        -3.66146747e-06,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.51035652e-05,  -6.89615623e-06,
         2.25324297e-03,  -9.01297189e-03,   1.47660279e-02,
        -5.90641274e-02,   0.00000000e+00,   0.00000000e+00,
        -4.82571087e-02,   1.93028469e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.35806586e-09,   4.47742115e-09,
        -1.73105708e-06,   7.04159454e-06,   0.00000000e+00,
         0.00000000e+00,   7.38563033e-06,  -2.95870902e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.03837836e-03,   4.15362599e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.30909457e-03,  -1.32364203e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.97919972e-07,
         1.59421388e-06,  -3.45058698e-06,   1.38736918e-05,
         0.00000000e+00,   0.00000000e+00,   4.51610560e-06,
        -1.81064738e-05,   0.00000000e+00,   0.00000000e+00,
        -5.11459037e-04,   2.04605249e-03,   0.00000000e+00,
         0.00000000e+00,   1.62316565e-03,  -6.49285980e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.57451938e-02,   1.82980775e-01,
         4.23353008e-03,  -0.00000000e+00,   8.85388088e-04,
         1.31302367e-06,   4.23087655e-03,   1.06140543e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.15358378e-03,   5.62806396e-08,
        -1.03551960e-04,  -5.53650410e-06,  -6.81773444e-04,
        -2.35893012e-05,   0.00000000e+00,   0.00000000e+00,
         4.39085499e-03,   1.01570451e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.15358378e-03,   5.62806396e-08,
         5.81329696e-04,   7.75106261e-04,   2.34787127e-03,
         3.14001896e-03,   0.00000000e+00,   0.00000000e+00,
        -4.87173330e-04,  -6.89732029e-04,   0.00000000e+00,
         0.00000000e+00,   2.11298744e-03,   8.45194976e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.03351289e-03,   1.00749550e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.81154783e-03,   3.93230097e-05,   6.02552087e-04,
        -2.46959680e-03,   2.07794939e-03,  -9.98411384e-03,
         0.00000000e+00,   0.00000000e+00,   1.73719872e-03,
         2.10123809e-03,   0.00000000e+00,   0.00000000e+00,
         2.39512045e-03,  -1.47609462e-02,   0.00000000e+00,
         0.00000000e+00,   2.90370801e-03,   8.22076956e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.03351289e-03,
         1.00749550e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.81154783e-03,   3.93230097e-05,
        -1.70573434e-02,   6.82293736e-02,  -6.89431699e-02,
         2.75774886e-01,   0.00000000e+00,   0.00000000e+00,
         1.41619599e-02,  -5.66573472e-02,   0.00000000e+00,
         0.00000000e+00,  -4.63806669e-02,   1.86313577e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.59405550e-06,   6.33497831e-10,   9.58618944e-06,
         3.44427067e-06,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.44466135e-08,  -1.44660320e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.99000560e-04,   2.03608571e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.69170657e-07,   2.25560875e-07,   3.17544181e-06,
         1.27043805e-05,   0.00000000e+00,   0.00000000e+00,
         4.12084248e-06,  -3.02756824e-05,   0.00000000e+00,
         0.00000000e+00,  -9.40598516e-04,   3.84104008e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.61891718e-03,  -6.48946102e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.03404097e-03,
        -1.22052642e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.48855864e-02,   1.79542367e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.22617845e-02,   1.69052773e-01,  -1.34886181e-02,
        -0.00000000e+00,  -2.82200916e-03,  -2.72761762e-08,
        -1.34882341e-02,  -1.53591996e-06,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.32364046e-02,  -2.10256965e-08,   3.32696397e-04,
         1.14325326e-07,   2.17865075e-03,   7.09628325e-06,
         0.00000000e+00,   0.00000000e+00,  -1.39848667e-02,
        -3.26690455e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.32364046e-02,  -2.10256965e-08,  -2.46588503e-03,
        -1.48471142e-05,  -9.87667972e-03,  -4.20410550e-04,
         0.00000000e+00,   0.00000000e+00,   1.52337242e-03,
         2.27229913e-03,   0.00000000e+00,   0.00000000e+00,
        -1.28182721e-02,  -2.59023222e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.48853737e-03,  -3.49737579e-06,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.21793516e-02,
        -3.45501402e-05,   3.53072469e-05,   4.70763292e-05,
         9.92099936e-04,   1.33409993e-03,   0.00000000e+00,
         0.00000000e+00,  -5.39409131e-03,  -7.23975044e-03,
         0.00000000e+00,   0.00000000e+00,   1.84306349e-03,
         9.06928518e-03,   0.00000000e+00,   0.00000000e+00,
        -7.89454484e-03,  -3.15781794e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.48853737e-03,  -3.49737579e-06,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.21793516e-02,  -3.45501402e-05,   3.18805064e-04,
        -1.27522026e-03,   8.97613087e-03,  -3.59115175e-02,
         0.00000000e+00,   0.00000000e+00,  -4.96256612e-02,
         1.98532799e-01,   0.00000000e+00,   0.00000000e+00,
         2.70409628e-02,  -1.13235614e-01,   0.00000000e+00,
         0.00000000e+00,  -5.29345656e-02,   2.19874901e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.59405550e-06,
         6.33497831e-10,   9.58618944e-06,   3.44427067e-06,
         0.00000000e+00,   0.00000000e+00,  -3.44466135e-08,
        -1.44660320e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.99000560e-04,
         2.03608571e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.61891718e-03,  -6.48946102e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.69170657e-07,   2.25560875e-07,   3.17544181e-06,
         1.27043805e-05,   0.00000000e+00,   0.00000000e+00,
         4.12084248e-06,  -3.02756824e-05,   0.00000000e+00,
         0.00000000e+00,  -9.40598516e-04,   3.84104008e-03,
         0.00000000e+00,   0.00000000e+00,   3.03404097e-03,
        -1.22052642e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.48855864e-02,
         1.79542367e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.22617845e-02,   1.69052773e-01,
         3.72660008e-01,  -0.00000000e+00,   7.79659182e-02,
        -0.00000000e+00,   3.72660007e-01,   1.88053395e-09,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.65961550e-01,   2.89763769e-11,
        -9.01297189e-03,  -0.00000000e+00,  -5.90641214e-02,
        -7.99146516e-09,   0.00000000e+00,   0.00000000e+00,
         3.86056912e-01,   3.39974737e-08,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.65961550e-01,   2.89763769e-11,
         6.82293736e-02,  -0.00000000e+00,   2.75774059e-01,
         1.10335396e-06,   0.00000000e+00,   0.00000000e+00,
        -5.66537819e-02,  -4.75374883e-06,   0.00000000e+00,
         0.00000000e+00,   3.72033972e-01,   7.90909692e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.79542359e-01,   1.06091133e-08,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.38101320e-01,   5.63476014e-06,  -1.27522026e-03,
        -0.00000000e+00,  -3.59088947e-02,  -3.49700057e-06,
         0.00000000e+00,   0.00000000e+00,   1.98521491e-01,
         1.50772750e-05,   0.00000000e+00,   0.00000000e+00,
        -1.11333703e-01,  -2.53588153e-03,   0.00000000e+00,
         0.00000000e+00,   4.33647323e-01,   8.13663872e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.79542359e-01,
         1.06091133e-08,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.38101320e-01,   5.63476014e-06,
         0.00000000e+00,   0.00000000e+00,   2.67579468e-05,
         1.07031787e-04,   0.00000000e+00,   0.00000000e+00,
        -1.16427018e-04,  -4.65708072e-04,   0.00000000e+00,
         0.00000000e+00,   2.16953075e-02,   8.67812302e-02,
         0.00000000e+00,   0.00000000e+00,  -6.99664251e-02,
        -2.79865700e-01,   0.00000000e+00,   0.00000000e+00,
         1.38879378e+00,   5.55517511e+00,   2.29936202e-06,
         9.19744806e-06,  -3.71234251e-04,   1.48830012e-03,
        -1.52692345e-04,   6.22280716e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.26258142e-06,   2.01282467e-05,   9.41885507e-04,
        -3.76908506e-03,   2.11916289e-04,  -8.51203988e-04,
         0.00000000e+00,   0.00000000e+00,  -7.21122257e-05,
         3.01413424e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.26258142e-06,   2.01282467e-05,  -7.65990061e-03,
         3.06427190e-02,  -1.66882792e-03,   6.68300735e-03,
         0.00000000e+00,   0.00000000e+00,   3.92671662e-04,
        -1.57301381e-03,   0.00000000e+00,   0.00000000e+00,
        -2.80315894e-03,   1.12202690e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.48753154e-05,   1.03732709e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.90873788e-06,
         2.89505554e-05,   2.01614614e-02,  -8.06460383e-02,
         4.22000044e-03,  -1.68811852e-02,   0.00000000e+00,
         0.00000000e+00,  -5.60784748e-04,   2.24796264e-03,
         0.00000000e+00,   0.00000000e+00,   3.72224052e-03,
        -1.48901981e-02,   0.00000000e+00,   0.00000000e+00,
        -1.56097575e-04,   6.30080293e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.48753154e-05,   1.03732709e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.90873788e-06,   2.89505554e-05,  -2.00037943e-02,
         8.00151770e-02,  -4.18508600e-03,   1.67403441e-02,
         0.00000000e+00,   0.00000000e+00,   4.83801864e-04,
        -1.93520777e-03,   0.00000000e+00,   0.00000000e+00,
        -3.66243314e-03,   1.46497754e-02,   0.00000000e+00,
         0.00000000e+00,   6.84177080e-05,  -2.73807150e-04,
         0.00000000e+00,   0.00000000e+00,   9.37859912e-07,
         8.08916465e-20,  -4.65825010e-02,   1.86330004e-01,
         1.48703895e-03,   1.68156078e-06,   2.32635810e-04,
         3.14018192e-04,   7.39132295e-04,   2.95652918e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.37287195e-03,   1.25376548e-04,
         1.34479092e-04,  -7.89254230e-04,   6.42421390e-04,
        -4.14993419e-03,   0.00000000e+00,   0.00000000e+00,
         1.13474307e-03,   1.92319359e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.37287195e-03,   1.25376548e-04,
        -1.33085166e-03,   6.41262635e-03,  -6.84619880e-03,
         3.17176323e-02,   0.00000000e+00,   0.00000000e+00,
         1.77810763e-03,  -8.53185566e-03,   0.00000000e+00,
         0.00000000e+00,  -9.96934697e-03,   4.53062809e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.87129077e-04,   7.04053128e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.02656614e-04,   8.06465284e-04,   4.20926908e-03,
        -1.68726002e-02,   1.99926812e-02,  -8.08607504e-02,
         0.00000000e+00,   0.00000000e+00,  -2.95640355e-03,
         1.51274621e-02,   0.00000000e+00,   0.00000000e+00,
         1.53089913e-02,  -6.31271157e-02,   0.00000000e+00,
         0.00000000e+00,  -2.93821372e-03,   1.76273707e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.87129077e-04,
         7.04053128e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.02656614e-04,   8.06465284e-04,
        -4.18508602e-03,   1.67403441e-02,  -2.00037623e-02,
         8.00152194e-02,   0.00000000e+00,   0.00000000e+00,
         3.17032023e-03,  -1.26819937e-02,   0.00000000e+00,
         0.00000000e+00,  -1.47808900e-02,   5.92142674e-02,
         0.00000000e+00,   0.00000000e+00,   1.85698068e-03,
        -7.71520811e-03,   0.00000000e+00,   0.00000000e+00,
         1.93469339e-03,   1.82252296e-05,  -1.94914763e-02,
         7.79659225e-02,  -4.65794926e-02,   1.86333812e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.85572246e-06,   1.28336036e-05,  -3.04037817e-04,
         1.46690436e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.70156629e-04,  -3.61475637e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.42259469e-03,   2.99151389e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.44218846e-05,   1.03369964e-04,  -2.97797292e-04,
         1.33199422e-03,   0.00000000e+00,   0.00000000e+00,
         4.66450194e-04,  -1.96834054e-03,   0.00000000e+00,
         0.00000000e+00,  -3.71978246e-03,   1.51777747e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.96708264e-02,  -7.87858454e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.61267977e-03,
        -3.86806625e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.96442313e-02,   7.85769277e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.63738645e-03,   3.85502240e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.57449761e-02,   1.82981027e-01,  -3.76850642e-03,
        -7.71517389e-07,  -7.72439729e-04,  -6.37191735e-05,
        -3.55734096e-03,  -7.90124317e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.56445767e-03,  -6.70649247e-05,   1.12219751e-04,
         1.53947842e-04,   3.17312228e-04,   2.57713827e-03,
         0.00000000e+00,   0.00000000e+00,  -2.04184343e-03,
        -8.16737370e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.56445767e-03,  -6.70649247e-05,  -4.69039993e-04,
        -8.83644488e-04,  -1.22807770e-03,  -6.12690739e-03,
         0.00000000e+00,   0.00000000e+00,  -7.38426842e-03,
         3.30492132e-02,   0.00000000e+00,   0.00000000e+00,
        -7.58353432e-04,  -1.09858589e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.62929448e-03,  -2.91744804e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.75982846e-03,
        -4.85628555e-04,  -5.35656640e-04,   2.22786015e-03,
        -3.29781268e-03,   1.54005894e-02,   0.00000000e+00,
         0.00000000e+00,   1.95153212e-02,  -8.64799074e-02,
         0.00000000e+00,   0.00000000e+00,  -6.40488229e-03,
         3.05603707e-02,   0.00000000e+00,   0.00000000e+00,
         1.79424798e-02,  -8.72303082e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.62929448e-03,  -2.91744804e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.75982846e-03,  -4.85628555e-04,   4.83801961e-04,
        -1.93520785e-03,   3.17038929e-03,  -1.26820489e-02,
         0.00000000e+00,   0.00000000e+00,  -2.07225328e-02,
         8.28921883e-02,   0.00000000e+00,   0.00000000e+00,
         2.97796103e-03,  -1.21720344e-02,   0.00000000e+00,
         0.00000000e+00,  -1.04557666e-02,   4.26467494e-02,
         0.00000000e+00,   0.00000000e+00,  -5.53207498e-03,
        -7.83606056e-05,   2.25323484e-03,  -9.01298272e-03,
         1.47498961e-02,  -5.90844664e-02,   0.00000000e+00,
         0.00000000e+00,  -4.82352745e-02,   1.93055850e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.85572246e-06,
         1.28336036e-05,  -3.04037817e-04,   1.46690436e-03,
         0.00000000e+00,   0.00000000e+00,   8.70156629e-04,
        -3.61475637e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.42259469e-03,
         2.99151389e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.96708264e-02,  -7.87858454e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.44218846e-05,   1.03369964e-04,  -2.97797292e-04,
         1.33199422e-03,   0.00000000e+00,   0.00000000e+00,
         4.66450194e-04,  -1.96834054e-03,   0.00000000e+00,
         0.00000000e+00,  -3.71978246e-03,   1.51777747e-02,
         0.00000000e+00,   0.00000000e+00,   9.61267977e-03,
        -3.86806625e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.96442313e-02,
         7.85769277e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.63738645e-03,   3.85502240e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.57449761e-02,   1.82981027e-01,
         3.06415503e-02,   1.55828284e-06,   6.34214522e-03,
         2.74228838e-04,   3.00928184e-02,   2.16641853e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.98308538e-02,   1.12380062e-04,
        -7.10429471e-04,  -6.90532906e-04,  -4.99338591e-03,
        -3.11466083e-03,   0.00000000e+00,   0.00000000e+00,
         3.17321609e-02,   1.75606977e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.98308538e-02,   1.12380062e-04,
         4.20712380e-03,   5.61204283e-03,   1.66505495e-02,
         2.40103637e-02,   0.00000000e+00,   0.00000000e+00,
        -3.24349253e-03,  -8.99774757e-03,   0.00000000e+00,
         0.00000000e+00,   1.50768055e-02,   6.03072218e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.43631125e-02,   7.11458726e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.60337237e-02,   2.27969640e-03,   3.56645576e-03,
        -1.47655702e-02,   1.15524458e-02,  -6.01218793e-02,
         0.00000000e+00,   0.00000000e+00,   1.28596478e-02,
         1.51487466e-02,   0.00000000e+00,   0.00000000e+00,
         1.25939514e-02,  -8.94825259e-02,   0.00000000e+00,
         0.00000000e+00,   2.20680975e-02,   5.07538996e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.43631125e-02,
         7.11458726e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.60337237e-02,   2.27969640e-03,
        -3.66244652e-03,   1.46497861e-02,  -1.48069769e-02,
         5.92351369e-02,   0.00000000e+00,   0.00000000e+00,
         3.04973337e-03,  -1.22294522e-02,   0.00000000e+00,
         0.00000000e+00,  -1.91806593e-02,   8.09534384e-02,
         0.00000000e+00,   0.00000000e+00,   3.37425257e-03,
        -2.69563748e-02,   0.00000000e+00,   0.00000000e+00,
         9.00943732e-02,   1.30863384e-02,  -1.70572833e-02,
         6.82294537e-02,  -6.88150933e-02,   2.75938264e-01,
         0.00000000e+00,   0.00000000e+00,   1.38018622e-02,
        -5.71116831e-02,   0.00000000e+00,   0.00000000e+00,
        -4.42881215e-02,   1.88641233e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.01692485e-04,
         2.47846822e-06,   4.94265959e-04,   6.98343623e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.65856544e-04,  -1.72786562e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.01711208e-03,   1.46156384e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.05242330e-05,
         1.58041787e-05,   2.63562476e-05,   1.50750558e-03,
         0.00000000e+00,   0.00000000e+00,   5.38198191e-04,
        -3.12404987e-03,   0.00000000e+00,   0.00000000e+00,
        -5.79602580e-03,   2.77434960e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.38101923e-03,
        -3.84953340e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.70053896e-02,  -7.18367731e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.63755225e-03,   3.85503567e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.81378025e-02,
         7.26086940e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.48790292e-02,
         1.79550056e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.21279097e-02,   1.69185590e-01,
        -8.06459661e-02,  -9.62559121e-08,  -1.68700101e-02,
        -9.17682272e-06,  -8.05269907e-02,  -4.45012866e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.87473930e-02,  -5.12698840e-05,
         2.22102566e-03,   2.25143076e-05,   1.42306783e-02,
         1.37779666e-03,   0.00000000e+00,   0.00000000e+00,
        -8.33229240e-02,  -4.20931124e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.87473930e-02,  -5.12698840e-05,
        -1.47339498e-02,  -1.25245792e-04,  -5.86613888e-02,
        -3.95081161e-03,   0.00000000e+00,   0.00000000e+00,
         9.44302501e-03,   1.78820448e-02,   0.00000000e+00,
         0.00000000e+00,  -7.48175058e-02,  -1.95533602e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.83627732e-02,  -3.00300125e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.04060676e-02,  -1.90760736e-03,   2.35924485e-04,
         3.16462645e-04,   6.24310677e-03,   1.02823143e-02,
         0.00000000e+00,   0.00000000e+00,  -3.17450912e-02,
        -4.74802513e-02,   0.00000000e+00,   0.00000000e+00,
         1.03435693e-02,   6.01335222e-02,   0.00000000e+00,
         0.00000000e+00,  -4.60354757e-02,  -1.84141903e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.83627732e-02,
        -3.00300125e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.04060676e-02,  -1.90760736e-03,
         6.84603074e-05,  -2.73841229e-04,   1.94047823e-03,
        -7.78200616e-03,   0.00000000e+00,   0.00000000e+00,
        -1.06866176e-02,   4.28314301e-02,   0.00000000e+00,
         0.00000000e+00,   3.82722907e-03,  -2.73187560e-02,
         0.00000000e+00,   0.00000000e+00,  -1.61450417e-02,
         1.02833095e-01,   0.00000000e+00,   0.00000000e+00,
        -2.56511108e-01,  -4.20374488e-02,   3.18648526e-04,
        -1.27542897e-03,   8.64441132e-03,  -3.63358444e-02,
         0.00000000e+00,   0.00000000e+00,  -4.86902757e-02,
         1.99715909e-01,   0.00000000e+00,   0.00000000e+00,
         1.57265322e-02,  -1.25587229e-01,   0.00000000e+00,
         0.00000000e+00,  -3.75547652e-02,   2.36287024e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.01692485e-04,
         2.47846822e-06,   4.94265959e-04,   6.98343623e-04,
         0.00000000e+00,   0.00000000e+00,   1.65856544e-04,
        -1.72786562e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.01711208e-03,
         1.46156384e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.38101923e-03,  -3.84953340e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.05242330e-05,   1.58041787e-05,   2.63562476e-05,
         1.50750558e-03,   0.00000000e+00,   0.00000000e+00,
         5.38198191e-04,  -3.12404987e-03,   0.00000000e+00,
         0.00000000e+00,  -5.79602580e-03,   2.77434960e-02,
         0.00000000e+00,   0.00000000e+00,   1.70053896e-02,
        -7.18367731e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.63755225e-03,
         3.85503567e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.81378025e-02,   7.26086940e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.48790292e-02,   1.79550056e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.21279097e-02,   1.69185590e-01,   8.00151770e-02,
        -0.00000000e+00,   1.67403441e-02,   1.84524201e-11,
         8.00151556e-02,   8.51604279e-08,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.85769268e-02,   1.20921900e-09,  -1.93520775e-03,
        -7.77027826e-11,  -1.26817954e-02,  -3.01124767e-07,
         0.00000000e+00,   0.00000000e+00,   8.28914168e-02,
         1.02860333e-06,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.85769268e-02,   1.20921900e-09,   1.46497727e-02,
         1.07066243e-08,   5.92063390e-02,   2.44841723e-05,
         0.00000000e+00,   0.00000000e+00,  -1.21462354e-02,
        -7.26772457e-05,   0.00000000e+00,   0.00000000e+00,
         7.93668880e-02,   2.11540051e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.85501355e-02,   2.06474574e-07,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.25871374e-02,
         2.87420673e-05,  -2.73798630e-04,  -3.40794549e-08,
        -7.69097364e-03,  -7.68446571e-05,   0.00000000e+00,
         0.00000000e+00,   4.25687192e-02,   2.27160636e-04,
         0.00000000e+00,   0.00000000e+00,  -2.23620896e-02,
        -6.36730106e-03,   0.00000000e+00,   0.00000000e+00,
         8.84882471e-02,   1.91264644e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.85501355e-02,   2.06474574e-07,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.25871374e-02,   2.87420673e-05,  -2.34464978e-07,
         9.37859912e-07,  -4.77977963e-04,   1.94836231e-03,
         0.00000000e+00,   0.00000000e+00,   1.35853105e-03,
        -5.59084543e-03,   0.00000000e+00,   0.00000000e+00,
        -1.84341125e-02,   9.99091270e-02,   0.00000000e+00,
         0.00000000e+00,   5.09910742e-02,  -2.88039194e-01,
         0.00000000e+00,   0.00000000e+00,   3.29474654e-01,
         1.31789862e+00,   1.51028468e-07,   2.01371291e-07,
         3.04778754e-04,   4.43861658e-04,   0.00000000e+00,
         0.00000000e+00,  -8.62031105e-04,  -1.30899086e-03,
         0.00000000e+00,   0.00000000e+00,   1.00954473e-02,
         3.81328895e-02,   0.00000000e+00,   0.00000000e+00,
        -2.71752887e-02,  -1.15280534e-01,   0.00000000e+00,
         0.00000000e+00,  -1.68044965e-01,   9.08583081e-01,
         3.72660008e-01,   2.49011922e-11,   7.79659160e-02,
         8.70940325e-09,   3.72655743e-01,   1.58413805e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.65961212e-01,   1.12232784e-06,
        -9.01296647e-03,  -2.16730867e-08,  -5.90526357e-02,
        -4.24409287e-05,   0.00000000e+00,   0.00000000e+00,
         3.86025636e-01,   1.14751854e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.65961212e-01,   1.12232784e-06,
         6.82293335e-02,   1.60212141e-07,   2.75684055e-01,
         3.38945709e-04,   0.00000000e+00,   0.00000000e+00,
        -5.63975953e-02,  -9.52117061e-04,   0.00000000e+00,
         0.00000000e+00,   3.68665906e-01,   1.14887474e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.79537329e-01,   1.69696021e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.37865716e-01,   6.73950937e-04,  -1.27511589e-03,
        -4.17433299e-07,  -3.56765197e-02,  -8.79099551e-04,
         0.00000000e+00,   0.00000000e+00,   1.97857857e-01,
         2.47740316e-03,   0.00000000e+00,   0.00000000e+00,
        -1.02081816e-01,  -3.13405501e-02,   0.00000000e+00,
         0.00000000e+00,   4.08023076e-01,   8.60679634e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.79537329e-01,
         1.69696021e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.37865716e-01,   6.73950937e-04,
        -1.00685646e-07,   4.02742582e-07,  -1.79754595e-04,
         8.31488337e-04,   0.00000000e+00,   0.00000000e+00,
         4.74927368e-04,  -2.37855764e-03,   0.00000000e+00,
         0.00000000e+00,   8.68988495e-03,   3.92573394e-02,
         0.00000000e+00,   0.00000000e+00,  -3.12874008e-02,
        -1.11990845e-01,   0.00000000e+00,   0.00000000e+00,
         1.63986375e+00,   2.36403222e-01,   4.68929941e-07,
         1.87571976e-06,   9.49127754e-04,   3.79651101e-03,
         0.00000000e+00,   0.00000000e+00,  -2.69629566e-03,
        -1.07851826e-02,   0.00000000e+00,   0.00000000e+00,
         4.06652575e-02,   1.62661030e-01,   0.00000000e+00,
         0.00000000e+00,  -1.14786285e-01,  -4.59145140e-01,
         0.00000000e+00,   0.00000000e+00,   1.77582084e-01,
         7.10328338e-01,   3.46931898e-01,   1.38772759e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.71127245e-04,   6.84786401e-04,  -3.84864802e-05,
         1.54582167e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.26568987e-05,  -5.09667866e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.52396830e-05,   3.01377133e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.16376135e-03,   1.66550800e-02,  -8.71468133e-04,
         3.48608531e-03,   0.00000000e+00,   0.00000000e+00,
         1.09689602e-04,  -4.38864881e-04,   0.00000000e+00,
         0.00000000e+00,  -7.68503770e-04,   3.07423730e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.09689602e-04,  -4.38864881e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.07749155e-05,
        -1.23166973e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.90509849e-05,   1.96203940e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.94007993e-06,   2.77603482e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.10329946e-04,   1.24132005e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.39177773e-05,
         1.75673114e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.59512677e-02,   1.83805071e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.45017132e-05,
         1.43394354e-04,  -1.17041502e-04,   7.53586046e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.33304375e-05,  -3.25814918e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.48966742e-04,   1.65231866e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.69529923e-04,
         3.48453474e-03,  -4.13326740e-03,   1.66938816e-02,
         0.00000000e+00,   0.00000000e+00,   7.06551765e-04,
        -2.94342715e-03,   0.00000000e+00,   0.00000000e+00,
        -3.16781694e-03,   1.30136461e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.06551765e-04,
        -2.94342715e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.96232953e-04,  -3.44913289e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.21446418e-04,   1.28578864e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.95424711e-04,
         7.82538680e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.03380116e-03,
         8.13778924e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.24644071e-03,   5.02529505e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.92273530e-02,
         7.69094124e-02,  -4.59509786e-02,   1.83805403e-01,
         6.84682367e-04,   1.38711177e-07,   1.40358808e-04,
         1.15059369e-05,   6.46553532e-04,   1.42710019e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.31453421e-04,   1.32581368e-03,
        -1.90913455e-05,  -2.55681913e-05,  -1.12649771e-04,
        -2.01030751e-04,   0.00000000e+00,   0.00000000e+00,
         6.87215172e-04,   1.69630786e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.47824037e-04,   1.20662444e-05,
         8.13221055e-05,   1.76127702e-04,   1.97730562e-04,
         1.21496082e-03,   0.00000000e+00,   0.00000000e+00,
         2.16651032e-06,  -6.04661949e-04,   0.00000000e+00,
         0.00000000e+00,   8.92098842e-05,   2.19209072e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.85410368e-03,   1.66911014e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.47307808e-03,   1.60722875e-02,   1.05218455e-04,
        -4.35287962e-04,   6.25981773e-04,  -2.87897116e-03,
         0.00000000e+00,   0.00000000e+00,   8.49496192e-05,
         1.15241302e-03,   0.00000000e+00,   0.00000000e+00,
         5.73629741e-04,  -3.13854110e-03,   0.00000000e+00,
         0.00000000e+00,   1.81210502e-04,   2.00570423e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.96098808e-04,
         5.33876066e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.02019534e-04,   8.90687386e-05,
        -4.90509849e-05,   1.96203940e-04,  -3.21424692e-04,
         1.28577126e-03,   0.00000000e+00,   0.00000000e+00,
         1.09288821e-04,  -4.37459687e-04,   0.00000000e+00,
         0.00000000e+00,  -2.98283715e-04,   1.23339869e-03,
         0.00000000e+00,   0.00000000e+00,   7.14138449e-05,
        -4.13451057e-04,   0.00000000e+00,   0.00000000e+00,
         8.69059260e-04,   1.47499532e-06,  -3.10327653e-04,
         1.24131822e-03,  -2.03058537e-03,   8.13521661e-03,
         0.00000000e+00,   0.00000000e+00,   6.83660630e-04,
        -2.76915648e-03,   0.00000000e+00,   0.00000000e+00,
        -1.87962056e-03,   7.81583796e-03,   0.00000000e+00,
         0.00000000e+00,   4.67368737e-04,  -2.64704009e-03,
         0.00000000e+00,   0.00000000e+00,   1.81294734e-04,
         2.07019178e-05,   8.03076232e-04,   2.19615007e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.52154930e-02,   1.80865047e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.90913455e-05,  -2.55681913e-05,  -1.12649771e-04,
        -2.01030751e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.18794172e-04,   8.14438262e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.16651032e-06,  -6.04661949e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.05218455e-04,  -4.35287962e-04,   6.25981773e-04,
        -2.87897116e-03,   0.00000000e+00,   0.00000000e+00,
        -4.27640957e-03,   1.73785188e-02,   0.00000000e+00,
         0.00000000e+00,   5.73629741e-04,  -3.13854110e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.96091299e-04,   1.45724576e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.30835784e-03,
         9.90824488e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.09380923e-04,  -4.37533368e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.03485762e-04,  -4.16699699e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.92275906e-04,  -2.77604870e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.79510431e-04,
        -2.83566612e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.16164266e-03,  -8.64657130e-03,   1.41641945e-02,
        -5.66647857e-02,   0.00000000e+00,   0.00000000e+00,
        -4.74875870e-02,   1.89961310e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.58185308e-04,
         6.56873720e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.06526038e-03,   1.62794934e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.49421105e-05,   3.58220341e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.98754881e-03,
         7.99160939e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.51479622e-02,   1.80592036e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.44658444e-04,   1.25458631e-04,   1.00945197e-03,
         5.65583689e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.81163483e-04,  -2.97997954e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.62725878e-04,   1.73327792e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.37443126e-04,   3.04938878e-03,  -2.40722722e-03,
         1.24051743e-02,   0.00000000e+00,   0.00000000e+00,
         3.16974567e-04,  -2.93321696e-03,   0.00000000e+00,
         0.00000000e+00,  -2.64310463e-03,   1.84511629e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.16974567e-04,  -2.93321696e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.54656900e-04,
        -1.00271621e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.10765791e-04,   1.24338435e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.01735552e-04,   2.93999902e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.95406182e-03,   7.87539097e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.89934841e-03,
         1.80721120e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.68262010e-02,   6.73048073e-02,  -6.79959336e-02,
         2.72052812e-01,   0.00000000e+00,   0.00000000e+00,
         1.35476195e-02,  -5.43971261e-02,   0.00000000e+00,
         0.00000000e+00,  -4.54301957e-02,   1.84038131e-01,
         1.66550670e-02,   1.73058586e-08,   3.48406731e-03,
         1.65695647e-06,   1.66335771e-02,   8.04060203e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.62130939e-02,   6.37343318e-04,
        -4.34353806e-04,  -3.63015367e-06,  -2.81889962e-03,
        -1.23066038e-04,   0.00000000e+00,   0.00000000e+00,
         1.72761886e-02,   1.36440281e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.62725740e-02,   9.22594961e-06,
         3.04309332e-03,   2.49596226e-05,   1.21246645e-02,
         7.79660939e-04,   0.00000000e+00,   0.00000000e+00,
        -2.56537762e-03,  -6.27335207e-04,   0.00000000e+00,
         0.00000000e+00,   1.54966337e-02,   3.93937220e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.89085937e-03,   8.58113755e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.51963351e-03,   3.00785340e-02,  -4.61834081e-05,
        -6.16003145e-05,  -1.27691227e-03,  -1.79061672e-03,
         0.00000000e+00,   0.00000000e+00,   8.61250389e-03,
         1.17155549e-03,   0.00000000e+00,   0.00000000e+00,
        -3.34715238e-03,  -6.66571466e-03,   0.00000000e+00,
         0.00000000e+00,   1.66180533e-02,   8.42505054e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.93335304e-03,
         5.48879075e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.45997034e-02,   3.51650882e-04,
        -6.94008884e-06,   2.77603554e-05,  -1.94660055e-04,
         7.81926956e-04,   0.00000000e+00,   0.00000000e+00,
         9.99954353e-05,  -4.13907438e-04,   0.00000000e+00,
         0.00000000e+00,  -1.10442810e-04,   2.46696482e-03,
         0.00000000e+00,   0.00000000e+00,  -1.06193826e-03,
        -2.21285085e-03,   0.00000000e+00,   0.00000000e+00,
         4.48936194e-02,   9.20571039e-04,  -4.38653143e-05,
         1.75631144e-04,  -1.15773676e-03,   4.95433190e-03,
         0.00000000e+00,   0.00000000e+00,   4.34211025e-04,
        -2.63942659e-03,   0.00000000e+00,   0.00000000e+00,
        -1.10068830e-03,   1.58331839e-02,   0.00000000e+00,
         0.00000000e+00,  -4.21106464e-03,  -1.45546894e-02,
         0.00000000e+00,   0.00000000e+00,   8.91520350e-03,
         2.53720921e-03,   3.71603453e-02,   1.62510928e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.44190291e-02,   1.77833724e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.15108772e-02,   1.69285140e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.34353806e-04,
        -3.63015367e-06,  -2.81889962e-03,  -1.23066038e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.73874629e-04,   4.41273016e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.56537762e-03,  -6.27335207e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.61834081e-05,
        -6.16003145e-05,  -1.27691227e-03,  -1.79061672e-03,
         0.00000000e+00,   0.00000000e+00,  -1.26567192e-03,
         9.07409614e-03,   0.00000000e+00,   0.00000000e+00,
        -3.34715238e-03,  -6.66571466e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.81479945e-04,
         1.68548867e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.52168504e-03,   2.29368412e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.11059017e-04,  -4.45167194e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.31321444e-04,
        -3.72745861e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.64083346e-04,
        -2.80441178e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.43772867e-03,  -2.06737241e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.05843263e-04,
        -1.22338130e-03,   8.57887460e-03,  -3.44888760e-02,
         0.00000000e+00,   0.00000000e+00,  -4.86421773e-02,
         1.95092910e-01,   0.00000000e+00,   0.00000000e+00,
         2.42046294e-02,  -1.09893329e-01,   0.00000000e+00,
         0.00000000e+00,  -4.93856778e-02,   2.16195666e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.97400392e-05,   3.14058684e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.94482277e-03,
         7.95742856e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.76709028e-05,   5.68821088e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.54003495e-03,   1.48634416e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.43189700e-02,
         1.77282240e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.17661725e-02,   1.67256594e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.96203940e-04,   2.11436771e-14,   1.28576580e-03,
         1.88636726e-08,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.37437638e-04,  -7.85197832e-08,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.23078183e-03,   1.01462530e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.77603465e-05,   7.13218483e-12,   7.81459086e-04,
         1.03164271e-06,   0.00000000e+00,   0.00000000e+00,
        -4.12175628e-04,  -4.17058727e-06,   0.00000000e+00,
         0.00000000e+00,   2.29880997e-03,   5.39562598e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.05172850e-04,  -3.21817008e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.68338410e-03,
        -1.71569418e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.16803879e-04,   8.70165507e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.09357264e-02,   4.55840477e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.76119830e-05,   1.87827291e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.14288346e-04,
         1.02408027e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.47694114e-10,   8.63592152e-10,   1.10699843e-05,
         5.24110110e-05,   0.00000000e+00,   0.00000000e+00,
        -2.95233769e-05,  -2.00439220e-04,   0.00000000e+00,
         0.00000000e+00,  -1.49948261e-03,   2.40400030e-02,
         0.00000000e+00,   0.00000000e+00,   5.27032816e-03,
        -7.65232748e-02,   0.00000000e+00,   0.00000000e+00,
        -1.99600028e-01,   9.62844158e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.24131766e-03,
         1.96678367e-09,   8.13360422e-03,   3.86493275e-06,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.76482902e-03,  -1.03647607e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.77877082e-03,   8.91248540e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.75619899e-04,
         4.29729918e-08,   4.92176652e-03,   9.07292692e-05,
         0.00000000e+00,   0.00000000e+00,  -2.54625756e-03,
        -2.55051721e-04,   0.00000000e+00,   0.00000000e+00,
         1.43454325e-02,   3.47628728e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.55216777e-03,
        -2.31410886e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.04288772e-02,  -9.58043934e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.00966854e-05,   2.05815053e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.15755765e-03,
         1.13954181e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.32139368e-04,
         9.67787487e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.21161985e-03,   4.93486649e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.25819268e-07,
         9.25131716e-07,  -3.51821284e-04,   1.93014796e-03,
         0.00000000e+00,   0.00000000e+00,   9.65636953e-04,
        -5.51426527e-03,   0.00000000e+00,   0.00000000e+00,
        -7.84862084e-03,   9.60799594e-02,   0.00000000e+00,
         0.00000000e+00,   2.03997528e-02,  -2.74977305e-01,
         0.00000000e+00,   0.00000000e+00,  -1.70143836e-02,
         4.70410242e-01,  -5.52499155e-02,   8.47124816e-01,
         3.67610141e-01,   6.46371845e-13,   7.69094123e-02,
         1.49817436e-10,   3.67609689e-01,   1.48835117e-06,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.61727788e-01,   3.07509759e-06,
        -8.64657106e-03,  -3.24297200e-10,  -5.66617828e-02,
        -4.00382242e-06,   0.00000000e+00,   0.00000000e+00,
         3.79914398e-01,   1.09616169e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.61183932e-01,   1.87251263e-07,
         6.73048060e-02,   1.71889036e-09,   2.72026908e-01,
         3.45388463e-05,   0.00000000e+00,   0.00000000e+00,
        -5.43196331e-02,  -1.03323941e-04,   0.00000000e+00,
         0.00000000e+00,   3.66338251e-01,   2.31734823e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.77774621e-01,   7.88039740e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.36139056e-01,   3.24163066e-03,  -1.22337821e-03,
        -4.12283892e-09,  -3.44238594e-02,  -8.66887962e-05,
         0.00000000e+00,   0.00000000e+00,   1.94896335e-01,
         2.62100425e-04,   0.00000000e+00,   0.00000000e+00,
        -1.04990275e-01,  -6.53740581e-03,   0.00000000e+00,
         0.00000000e+00,   4.18401616e-01,   1.86529549e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.77279855e-01,
         3.17989305e-06,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.34369260e-01,   1.91904160e-04,
        -4.31796076e-10,   1.72718430e-09,   1.61519054e-05,
         4.83454741e-05,   0.00000000e+00,   0.00000000e+00,
        -8.09894469e-05,  -1.59266364e-04,   0.00000000e+00,
         0.00000000e+00,   1.72742258e-02,   9.02103627e-03,
         0.00000000e+00,   0.00000000e+00,  -5.57325390e-02,
        -2.77209811e-02,   0.00000000e+00,   0.00000000e+00,
         1.80235528e+00,   1.64444047e-01,   9.16936224e-07,
         1.09273223e-08,   1.73407440e-03,   2.61431410e-04,
         0.00000000e+00,   0.00000000e+00,  -4.89487122e-03,
        -8.25858729e-04,   0.00000000e+00,   0.00000000e+00,
         7.18229059e-02,   3.23427380e-02,   0.00000000e+00,
         0.00000000e+00,  -2.02460445e-01,  -9.66891469e-02,
         0.00000000e+00,   0.00000000e+00,   3.19527977e-01,
         2.01176354e-01,   1.22465577e+00,   6.26125154e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.21769720e-04,   1.68707888e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.16958001e-02,   8.67832004e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.74328671e-01,   1.49731468e+00,
         1.07410464e-05,   4.29641856e-05,  -9.33011373e-04,
         3.74756049e-03,  -3.78386331e-04,   1.56592610e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.81824265e-06,   5.79633697e-05,
         2.19816194e-03,  -8.79972449e-03,   4.98208667e-04,
        -2.00849988e-03,   0.00000000e+00,   0.00000000e+00,
        -1.72510633e-04,   7.48880708e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.81824265e-06,   5.79633697e-05,
        -8.64696086e-03,   3.46022989e-02,  -1.97216438e-03,
         7.92364506e-03,   0.00000000e+00,   0.00000000e+00,
         6.89623846e-04,  -2.76877630e-03,   0.00000000e+00,
         0.00000000e+00,  -3.15858496e-03,   1.26689771e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.17622850e-05,   1.46306099e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.03843814e-06,   4.02396904e-05,   1.87691942e-02,
        -7.50776537e-02,   3.93145285e-03,  -1.57309974e-02,
         0.00000000e+00,   0.00000000e+00,  -6.22949745e-04,
         2.51357024e-03,   0.00000000e+00,   0.00000000e+00,
         3.47604124e-03,  -1.39095491e-02,   0.00000000e+00,
         0.00000000e+00,  -1.67656794e-04,   6.96277443e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.17622850e-05,
         1.46306099e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.03843814e-06,   4.02396904e-05,
        -2.02811466e-03,   8.11245864e-03,  -4.24311135e-04,
         1.69724487e-03,   0.00000000e+00,   0.00000000e+00,
         9.81016219e-05,  -3.92407880e-04,   0.00000000e+00,
         0.00000000e+00,  -3.71274375e-04,   1.48528943e-03,
         0.00000000e+00,   0.00000000e+00,   1.37274366e-05,
        -5.55206965e-05,   0.00000000e+00,   0.00000000e+00,
         4.20415143e-06,   2.03287907e-20,  -1.28312180e-02,
         5.13248723e-02,  -2.68446170e-03,   1.07379243e-02,
         0.00000000e+00,   0.00000000e+00,   6.20617281e-04,
        -2.48266209e-03,   0.00000000e+00,   0.00000000e+00,
        -2.34890019e-03,   9.39703433e-03,   0.00000000e+00,
         0.00000000e+00,   8.69316954e-05,  -3.51463859e-04,
         0.00000000e+00,   0.00000000e+00,   8.96583214e-07,
         2.44213332e-08,   4.12689849e-06,   3.09011355e-07,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.15917554e-05,   3.66400946e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.27701582e-05,   5.18417774e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.12300473e-06,   3.86869933e-09,
        -4.78449674e-02,   1.91379870e-01,   3.74174237e-03,
         7.75750081e-06,   5.83948490e-04,   7.96058247e-04,
         1.85370665e-03,   7.41482661e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.41691866e-03,   3.52765397e-04,   2.92735649e-04,
        -1.84412146e-03,   1.40695920e-03,  -9.78328714e-03,
         0.00000000e+00,   0.00000000e+00,   2.89646437e-03,
         4.71197147e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.41691866e-03,   3.52765397e-04,  -1.12649691e-03,
         7.24711108e-03,  -6.61283277e-03,   3.72773371e-02,
         0.00000000e+00,   0.00000000e+00,   2.57037027e-03,
        -1.39454798e-02,   0.00000000e+00,   0.00000000e+00,
        -9.42964571e-03,   5.10648351e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.38653036e-03,   1.02273741e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.40457555e-03,
         1.10494492e-03,   3.90336093e-03,  -1.57085238e-02,
         1.83335237e-02,  -7.56226347e-02,   0.00000000e+00,
         0.00000000e+00,  -2.28941188e-03,   1.73969764e-02,
         0.00000000e+00,   0.00000000e+00,   1.38454482e-02,
        -5.99612471e-02,   0.00000000e+00,   0.00000000e+00,
        -1.29315777e-03,   1.92792029e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.38653036e-03,   1.02273741e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.40457555e-03,   1.10494492e-03,  -4.24311238e-04,
         1.69724495e-03,  -2.02804654e-03,   8.11254911e-03,
         0.00000000e+00,   0.00000000e+00,   6.42566045e-04,
        -2.57178383e-03,   0.00000000e+00,   0.00000000e+00,
        -1.45249140e-03,   6.00499587e-03,   0.00000000e+00,
         0.00000000e+00,   2.37309874e-04,  -1.56730569e-03,
         0.00000000e+00,   0.00000000e+00,   4.17971126e-03,
         7.10826760e-06,  -2.68447193e-03,   1.07379325e-02,
        -1.28170920e-02,   5.13426896e-02,   0.00000000e+00,
         0.00000000e+00,   4.02930920e-03,  -1.63140159e-02,
         0.00000000e+00,   0.00000000e+00,  -9.16977611e-03,
         3.81740506e-02,   0.00000000e+00,   0.00000000e+00,
         1.61443560e-03,  -1.03185681e-02,   0.00000000e+00,
         0.00000000e+00,   8.71893544e-04,   9.97096867e-05,
         3.86190616e-03,   1.05764832e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.93059078e-04,   2.40241726e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.87839282e-04,
         1.47067492e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.88979260e-03,   1.33682972e-04,  -2.00196951e-02,
         8.00789794e-02,  -4.78281280e-02,   1.91400991e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.85681137e-05,   4.16542846e-05,  -7.43990478e-04,
         3.68149271e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.00258230e-03,  -8.39664605e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.24021719e-03,   3.35815194e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.26744047e-05,   1.47035794e-04,  -5.45248903e-04,
         2.56816082e-03,   0.00000000e+00,   0.00000000e+00,
         1.01169932e-03,  -4.32879705e-03,   0.00000000e+00,
         0.00000000e+00,  -4.06052449e-03,   1.70161199e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.81143163e-02,  -7.27392651e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.73772345e-03,
        -3.55226206e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.91874951e-03,   7.67500231e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.07946828e-04,   3.63298741e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.21382875e-02,   4.85583885e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.73147611e-03,
         2.29945531e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.16021104e-05,   3.66409230e-04,  -6.00608146e-04,
         2.40845651e-03,   0.00000000e+00,   0.00000000e+00,
         2.72963731e-04,  -1.10767275e-03,   0.00000000e+00,
         0.00000000e+00,  -5.66829139e-04,   2.38615552e-03,
         0.00000000e+00,   0.00000000e+00,   2.30066494e-04,
        -1.21298672e-03,   0.00000000e+00,   0.00000000e+00,
         2.55508359e-05,   3.48120227e-05,   1.38116068e-04,
         2.59327275e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.68702792e-02,   1.87487409e-01,
        -8.79707072e-03,  -3.53836583e-06,  -1.79715241e-03,
        -1.72211019e-04,  -8.22499326e-03,  -2.07772517e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.25177723e-03,  -1.93158432e-04,
         2.77152879e-04,   3.89149898e-04,   7.48374990e-04,
         6.43044297e-03,   0.00000000e+00,   0.00000000e+00,
        -4.78539458e-03,  -1.91415783e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.25177723e-03,  -1.93158432e-04,
        -1.32036360e-03,  -1.16078634e-03,  -4.29498986e-03,
        -8.45319170e-03,   0.00000000e+00,   0.00000000e+00,
        -7.61577743e-03,   3.89316387e-02,   0.00000000e+00,
         0.00000000e+00,  -4.46785899e-03,  -1.42083142e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.79778363e-03,  -4.81210685e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.32836535e-03,  -7.26019786e-04,  -5.63612557e-04,
         2.46610049e-03,  -3.20453399e-03,   1.81290741e-02,
         0.00000000e+00,   0.00000000e+00,   1.62685110e-02,
        -8.46492943e-02,   0.00000000e+00,   0.00000000e+00,
        -5.78735831e-03,   3.43599821e-02,   0.00000000e+00,
         0.00000000e+00,   1.20983262e-02,  -8.30491056e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.79778363e-03,
        -4.81210685e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.32836535e-03,  -7.26019786e-04,
         9.81020569e-05,  -3.92408227e-04,   6.42736154e-04,
        -2.57191992e-03,   0.00000000e+00,   0.00000000e+00,
        -2.24607701e-03,   8.98838930e-03,   0.00000000e+00,
         0.00000000e+00,   4.88513252e-04,  -2.47353592e-03,
         0.00000000e+00,   0.00000000e+00,  -8.10860383e-04,
         4.88879500e-03,   0.00000000e+00,   0.00000000e+00,
        -1.11028167e-02,  -2.97097566e-05,   6.20645298e-04,
        -2.48268450e-03,   4.03224032e-03,  -1.63163608e-02,
         0.00000000e+00,   0.00000000e+00,  -1.41196112e-02,
         5.69792373e-02,   0.00000000e+00,   0.00000000e+00,
         3.05263196e-03,  -1.61355203e-02,   0.00000000e+00,
         0.00000000e+00,  -5.46173437e-03,   3.20058880e-02,
         0.00000000e+00,   0.00000000e+00,  -2.30474738e-03,
        -3.06175958e-04,  -1.01291138e-02,  -3.08323442e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.54165132e-04,  -1.09263387e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.03430677e-04,  -1.05894170e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.02253558e-02,  -4.19960840e-04,
         2.43635716e-03,  -9.74588811e-03,   1.58825443e-02,
        -6.39711702e-02,   0.00000000e+00,   0.00000000e+00,
        -4.96859647e-02,   1.99298697e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.85681137e-05,   4.16542846e-05,
        -7.43990478e-04,   3.68149271e-03,   0.00000000e+00,
         0.00000000e+00,   2.00258230e-03,  -8.39664605e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.24021719e-03,   3.35815194e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.81143163e-02,  -7.27392651e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.26744047e-05,
         1.47035794e-04,  -5.45248903e-04,   2.56816082e-03,
         0.00000000e+00,   0.00000000e+00,   1.01169932e-03,
        -4.32879705e-03,   0.00000000e+00,   0.00000000e+00,
        -4.06052449e-03,   1.70161199e-02,   0.00000000e+00,
         0.00000000e+00,   8.73772345e-03,  -3.55226206e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.91874951e-03,   7.67500231e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.07946828e-04,   3.63298741e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.21382875e-02,   4.85583885e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.73147611e-03,
         2.29945531e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.68702792e-02,   1.87487409e-01,
         3.45968781e-02,   7.22771376e-06,   7.06485726e-03,
         6.94027739e-04,   3.32175848e-02,   5.41300300e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.33487754e-02,   3.10325300e-04,
        -7.54933506e-04,  -1.61313041e-03,  -5.70612015e-03,
        -7.32428747e-03,   0.00000000e+00,   0.00000000e+00,
         3.57559403e-02,   4.23426449e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.33487754e-02,   3.10325300e-04,
         4.74870159e-03,   6.34314789e-03,   1.83151724e-02,
         2.88689806e-02,   0.00000000e+00,   0.00000000e+00,
        -3.32313344e-03,  -1.51240947e-02,   0.00000000e+00,
         0.00000000e+00,   1.67487832e-02,   6.69951328e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.58757324e-02,   1.06711441e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.78902304e-02,   2.89682378e-03,   3.27291238e-03,
        -1.37470460e-02,   9.66147107e-03,  -5.66140654e-02,
         0.00000000e+00,   0.00000000e+00,   1.46199250e-02,
         1.80341555e-02,   0.00000000e+00,   0.00000000e+00,
         9.52974263e-03,  -8.48173253e-02,   0.00000000e+00,
         0.00000000e+00,   2.55195684e-02,   5.14259377e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.58757324e-02,
         1.06711441e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.78902304e-02,   2.89682378e-03,
        -3.71334354e-04,   1.48533741e-03,  -1.51126983e-03,
         6.05201861e-03,   0.00000000e+00,   0.00000000e+00,
         6.41772785e-04,  -2.59614355e-03,   0.00000000e+00,
         0.00000000e+00,  -1.33226579e-03,   8.86937317e-03,
         0.00000000e+00,   0.00000000e+00,  -1.15155278e-03,
        -6.54916611e-03,   0.00000000e+00,   0.00000000e+00,
         7.36417471e-02,   1.51006893e-03,  -2.34923076e-03,
         9.39729878e-03,  -9.38217859e-03,   3.83439726e-02,
         0.00000000e+00,   0.00000000e+00,   3.57035175e-03,
        -1.65496961e-02,   0.00000000e+00,   0.00000000e+00,
        -8.20186574e-03,   5.56169287e-02,   0.00000000e+00,
         0.00000000e+00,  -5.09532598e-03,  -3.99326098e-02,
         0.00000000e+00,   0.00000000e+00,   1.46241531e-02,
         4.16193930e-03,   6.09563851e-02,   2.66576605e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.95817605e-04,   2.32934630e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.54753116e-03,   4.68635230e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.29576591e-02,   6.57618733e-03,
        -1.75193124e-02,   7.00789273e-02,  -7.04649350e-02,
         2.83680522e-01,   0.00000000e+00,   0.00000000e+00,
         1.44055137e-02,  -6.23737305e-02,   0.00000000e+00,
         0.00000000e+00,  -4.51333769e-02,   1.93518794e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.39996859e-04,   8.89878351e-06,   4.91194606e-04,
         1.73900601e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.86435811e-04,  -3.98858624e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.21039520e-03,   1.63360165e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.35845128e-05,   2.61413297e-05,  -2.55848599e-04,
         3.23328424e-03,   0.00000000e+00,   0.00000000e+00,
         1.35521015e-03,  -6.87288019e-03,   0.00000000e+00,
         0.00000000e+00,  -6.06730017e-03,   3.00628482e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.46262570e-03,  -3.53025424e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.47632039e-02,
        -6.38834803e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.08283550e-04,   3.63325679e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.46155646e-03,   5.88057543e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.73856768e-03,   2.30002263e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.04838365e-03,
         3.73895887e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.30070682e-05,   5.20313054e-05,  -3.95986364e-04,
         1.63719258e-03,   0.00000000e+00,   0.00000000e+00,
         3.33728999e-04,  -1.48866944e-03,   0.00000000e+00,
         0.00000000e+00,  -1.18563665e-03,   6.87288654e-03,
         0.00000000e+00,   0.00000000e+00,   1.17765676e-03,
        -1.02995422e-02,   0.00000000e+00,   0.00000000e+00,
         6.83420362e-04,   1.01538449e-03,   3.08874310e-03,
         6.48181176e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.58687278e-02,   1.83572068e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.27028249e-02,   1.71511369e-01,  -7.50773248e-02,
        -4.38499102e-07,  -1.57009607e-02,  -2.50665210e-05,
        -7.47644322e-02,  -1.14427003e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.26335152e-02,  -1.40999874e-04,   2.44606883e-03,
         5.83553834e-05,   1.52223502e-02,   3.38756676e-03,
         0.00000000e+00,   0.00000000e+00,  -7.73085754e-02,
        -9.78762509e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.26335152e-02,  -1.40999874e-04,  -1.37044012e-02,
        -1.65195153e-04,  -5.40599746e-02,  -5.63690882e-03,
         0.00000000e+00,   0.00000000e+00,   9.74874302e-03,
         2.19311011e-02,   0.00000000e+00,   0.00000000e+00,
        -6.73054422e-02,  -2.33491774e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.50331253e-02,  -5.05941584e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.20719810e-02,
        -2.41533238e-03,   2.59500899e-04,   3.54551289e-04,
         6.34804035e-03,   1.31662444e-02,   0.00000000e+00,
         0.00000000e+00,  -2.89774271e-02,  -5.01885030e-02,
         0.00000000e+00,   0.00000000e+00,   9.69071343e-03,
         6.40890216e-02,   0.00000000e+00,   0.00000000e+00,
        -4.22947065e-02,  -1.69178826e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.50331253e-02,  -5.05941584e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.20719810e-02,  -2.41533238e-03,   1.39183585e-05,
        -5.56734340e-05,   4.25299056e-04,  -1.71769704e-03,
         0.00000000e+00,   0.00000000e+00,  -1.30345878e-03,
         5.28287371e-03,   0.00000000e+00,   0.00000000e+00,
        -2.31712561e-04,  -7.28503829e-03,   0.00000000e+00,
         0.00000000e+00,   2.07994274e-03,   1.74902578e-02,
         0.00000000e+00,   0.00000000e+00,  -1.68415088e-01,
        -3.95300388e-03,   8.78462970e-05,  -3.52195540e-04,
         2.25455377e-03,  -1.08306627e-02,   0.00000000e+00,
         0.00000000e+00,  -7.05128377e-03,   3.32775275e-02,
         0.00000000e+00,   0.00000000e+00,  -2.59119666e-03,
        -4.19359133e-02,   0.00000000e+00,   0.00000000e+00,
         9.52600185e-03,   1.00183680e-01,   0.00000000e+00,
         0.00000000e+00,  -3.32229402e-02,  -1.02047009e-02,
        -1.37440489e-01,  -6.23815402e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.09375006e-05,  -1.09368353e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.81801420e-03,
        -5.50300541e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.42368673e-01,  -1.59111030e-02,   3.44046874e-04,
        -1.37980715e-03,   8.94118509e-03,  -3.97808639e-02,
         0.00000000e+00,   0.00000000e+00,  -4.93848791e-02,
         2.08077723e-01,   0.00000000e+00,   0.00000000e+00,
         1.77606973e-02,  -1.30906766e-01,   0.00000000e+00,
         0.00000000e+00,  -4.20976703e-02,   2.37957888e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.39996859e-04,
         8.89878351e-06,   4.91194606e-04,   1.73900601e-03,
         0.00000000e+00,   0.00000000e+00,   5.86435811e-04,
        -3.98858624e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.21039520e-03,
         1.63360165e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.46262570e-03,  -3.53025424e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.35845128e-05,   2.61413297e-05,  -2.55848599e-04,
         3.23328424e-03,   0.00000000e+00,   0.00000000e+00,
         1.35521015e-03,  -6.87288019e-03,   0.00000000e+00,
         0.00000000e+00,  -6.06730017e-03,   3.00628482e-02,
         0.00000000e+00,   0.00000000e+00,   1.47632039e-02,
        -6.38834803e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.08283550e-04,
         3.63325679e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.46155646e-03,   5.88057543e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.73856768e-03,   2.30002263e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.04838365e-03,   3.73895887e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.58687278e-02,
         1.83572068e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.27028249e-02,   1.71511369e-01,
         8.11245864e-03,  -0.00000000e+00,   1.69724485e-03,
         8.26218260e-11,   8.11241300e-03,   1.81480706e-07,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.67500070e-03,   2.14471250e-09,
        -3.92407793e-04,  -3.47943296e-10,  -2.57138407e-03,
        -6.23739751e-07,   0.00000000e+00,   0.00000000e+00,
         8.98685883e-03,   2.04063255e-06,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.67500070e-03,   2.14471250e-09,
         1.48527744e-03,   4.79825884e-08,   5.99063795e-03,
         5.04923848e-05,   0.00000000e+00,   0.00000000e+00,
        -2.43198936e-03,  -1.37133830e-04,   0.00000000e+00,
         0.00000000e+00,   7.54175692e-03,   1.77015500e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.63287410e-03,   3.30673078e-07,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.86769433e-03,   1.71747955e-05,  -5.54825121e-05,
        -1.52737494e-07,  -1.52352005e-03,  -1.58641752e-04,
         0.00000000e+00,   0.00000000e+00,   4.76438584e-03,
         4.28598014e-04,   0.00000000e+00,   0.00000000e+00,
        -3.28573986e-03,  -4.84181645e-03,   0.00000000e+00,
         0.00000000e+00,   7.81149705e-03,   1.29050144e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.63287410e-03,
         3.30673078e-07,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.86769433e-03,   1.71747955e-05,
        -1.05103786e-06,   4.20415143e-06,  -1.04270648e-03,
         4.18504246e-03,   0.00000000e+00,   0.00000000e+00,
         2.76641988e-03,  -1.11250990e-02,   0.00000000e+00,
         0.00000000e+00,  -1.79385402e-02,   7.47742988e-02,
         0.00000000e+00,   0.00000000e+00,   4.08684583e-02,
        -1.71379841e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.01250804e-07,
         9.02688547e-07,  -1.32670558e-04,   9.03360969e-04,
         0.00000000e+00,   0.00000000e+00,   3.22459761e-04,
        -2.40794167e-03,   0.00000000e+00,   0.00000000e+00,
        -1.17169082e-03,   1.67986144e-02,   0.00000000e+00,
         0.00000000e+00,   2.41871454e-03,  -3.87180247e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.55508359e-05,   3.48120227e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.83420362e-04,   1.01538449e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.14147590e-08,   1.08553012e-07,   1.34031693e-04,
         2.19946590e-04,   0.00000000e+00,   0.00000000e+00,
        -3.65880511e-04,  -6.62947765e-04,   0.00000000e+00,
         0.00000000e+00,  -3.78426427e-04,   2.57056002e-02,
         0.00000000e+00,   0.00000000e+00,   3.28522206e-03,
        -7.95109897e-02,   0.00000000e+00,   0.00000000e+00,
        -1.99600028e-01,   9.62844158e-01,   5.13248722e-02,
         1.12606147e-10,   1.07379055e-02,   3.05602372e-08,
         5.13148189e-02,   3.71608733e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.85564242e-02,   2.61916823e-06,  -2.48261774e-03,
        -7.40691619e-08,  -1.62431549e-02,  -9.60446810e-05,
         0.00000000e+00,   0.00000000e+00,   5.67914401e-02,
         2.50396297e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.85564242e-02,   2.61916823e-06,   9.39682731e-03,
         4.52327352e-07,   3.78258483e-02,   5.77551084e-04,
         0.00000000e+00,   0.00000000e+00,  -1.51813679e-02,
        -1.54832040e-03,   0.00000000e+00,   0.00000000e+00,
         4.70633790e-02,   1.14047329e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.29759014e-02,   2.86510729e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.69410684e-02,
         5.98027074e-04,  -3.50977056e-04,  -1.13685737e-06,
        -9.51087664e-03,  -1.41831833e-03,   0.00000000e+00,
         0.00000000e+00,   2.97858309e-02,   3.80783573e-03,
         0.00000000e+00,   0.00000000e+00,  -1.98190215e-02,
        -2.81536534e-02,   0.00000000e+00,   0.00000000e+00,
         4.83257973e-02,   6.91438437e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.29759014e-02,   2.86510729e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.69410684e-02,   5.98027074e-04,  -2.31777470e-07,
         9.27109881e-07,  -2.40957660e-04,   9.89990650e-04,
         0.00000000e+00,   0.00000000e+00,   6.38553955e-04,
        -2.66081702e-03,   0.00000000e+00,   0.00000000e+00,
        -3.53917365e-03,   1.86926007e-02,   0.00000000e+00,
         0.00000000e+00,   7.81481746e-03,  -4.30349070e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.35158574e-07,   4.35865701e-06,
        -6.34961439e-04,   4.65514240e-03,   0.00000000e+00,
         0.00000000e+00,   1.56876769e-03,  -1.24415396e-02,
         0.00000000e+00,   0.00000000e+00,  -6.90857739e-03,
         8.09496305e-02,   0.00000000e+00,   0.00000000e+00,
         1.48658908e-02,  -1.84226644e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.38116068e-04,   2.59327275e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.08874310e-03,
         6.48181176e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.71523470e-07,
         1.66102226e-06,   3.12728255e-04,   3.17830333e-03,
         0.00000000e+00,   0.00000000e+00,  -8.02571579e-04,
        -8.92404912e-03,   0.00000000e+00,   0.00000000e+00,
        -2.78196680e-03,   1.06712471e-01,   0.00000000e+00,
         0.00000000e+00,   1.16566836e-02,  -2.93570701e-01,
         0.00000000e+00,   0.00000000e+00,  -1.70143836e-02,
         4.70410242e-01,  -5.52499155e-02,   8.47124816e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.66398579e-04,   8.67811471e-09,   2.39864847e-03,
         9.05121821e-06,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.08294246e-03,  -2.29477914e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.27057938e-03,   1.16228711e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.17932581e-05,   1.91044366e-07,   1.40907783e-03,
         1.93141229e-04,   0.00000000e+00,   0.00000000e+00,
        -8.93852225e-04,  -5.06604464e-04,   0.00000000e+00,
         0.00000000e+00,   3.34084125e-03,   3.25170422e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.54087449e-04,  -2.65663567e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.20802805e-03,
        -7.59099434e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.65687396e-05,   6.85076831e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.90515234e-04,   1.87453297e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.50945548e-05,   4.05895772e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.81982301e-04,
         9.41839209e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.02954221e-06,   4.12590625e-06,  -9.30672221e-04,
         3.99005483e-03,   0.00000000e+00,   0.00000000e+00,
         2.42510119e-03,  -1.05403264e-02,   0.00000000e+00,
         0.00000000e+00,  -1.36843562e-02,   6.78897996e-02,
         0.00000000e+00,   0.00000000e+00,   3.06199486e-02,
        -1.54302000e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.48018820e-04,   1.01177573e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.92864449e-03,   4.30416597e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.35569294e-01,   7.07381308e-01,
         3.82759740e-01,   5.09977838e-10,   8.00789048e-02,
         9.94616754e-08,   3.82735623e-01,   8.84794935e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.74970098e-01,   6.29183393e-06,
        -9.74571581e-03,  -2.29735825e-07,  -6.38057978e-02,
        -2.20496511e-04,   0.00000000e+00,   0.00000000e+00,
         3.98181265e-01,   5.54837946e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.74970098e-01,   6.29183393e-06,
         7.00782981e-02,   8.38942383e-07,   2.82997729e-01,
         9.10390944e-04,   0.00000000e+00,   0.00000000e+00,
        -6.05918522e-02,  -2.37583784e-03,   0.00000000e+00,
         0.00000000e+00,   3.77298623e-01,   1.29852865e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.83535634e-01,   4.85784470e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.42497685e-01,   7.00069234e-04,  -1.37844978e-03,
        -1.80982752e-06,  -3.82748176e-02,  -2.00806176e-03,
         0.00000000e+00,   0.00000000e+00,   2.04125895e-01,
         5.26910312e-03,   0.00000000e+00,   0.00000000e+00,
        -1.08457775e-01,  -2.99319883e-02,   0.00000000e+00,
         0.00000000e+00,   4.23740371e-01,   6.95672069e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.83535634e-01,
         4.85784470e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.42497685e-01,   7.00069234e-04,
        -5.42765060e-08,   2.17106024e-07,  -6.35809208e-05,
         3.78036681e-04,   0.00000000e+00,   0.00000000e+00,
         1.34478413e-04,  -1.06323490e-03,   0.00000000e+00,
         0.00000000e+00,   1.66336398e-02,   1.20959473e-02,
         0.00000000e+00,   0.00000000e+00,  -5.46222017e-02,
        -3.31850507e-02,   0.00000000e+00,   0.00000000e+00,
         1.80235528e+00,   1.64444047e-01,   6.30853708e-07,
         1.37355807e-06,   1.51734720e-03,   2.21460818e-03,
         0.00000000e+00,   0.00000000e+00,  -4.37367333e-03,
        -6.06716772e-03,   0.00000000e+00,   0.00000000e+00,
         7.08682448e-02,   4.77923021e-02,   0.00000000e+00,
         0.00000000e+00,  -2.00966714e-01,  -1.23471983e-01,
         0.00000000e+00,   0.00000000e+00,   3.19527977e-01,
         2.01176354e-01,   1.22465577e+00,   6.26125154e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.54388060e-04,   2.09850223e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.87940040e-02,   5.66354086e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.29093452e+00,   1.65104131e-01,
         2.18225457e-06,   8.72901827e-06,   2.24758230e-03,
         8.99032918e-03,   0.00000000e+00,   0.00000000e+00,
        -5.95778133e-03,  -2.38311253e-02,   0.00000000e+00,
         0.00000000e+00,   3.62674628e-02,   1.45069851e-01,
         0.00000000e+00,   0.00000000e+00,  -8.19220036e-02,
        -3.27688014e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.74328671e-01,   1.49731468e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.71127245e-04,   6.84786401e-04,
        -3.84864802e-05,   1.54582167e-04,   0.00000000e+00,
         0.00000000e+00,   1.26568987e-05,  -5.09667866e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.52396830e-05,   3.01377133e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.09689602e-04,  -4.38864881e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.16376135e-03,
         1.66550800e-02,  -8.71468133e-04,   3.48608531e-03,
         0.00000000e+00,   0.00000000e+00,   1.09689602e-04,
        -4.38864881e-04,   0.00000000e+00,   0.00000000e+00,
        -7.68503770e-04,   3.07423730e-03,   0.00000000e+00,
         0.00000000e+00,   3.07749155e-05,  -1.23166973e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.90509849e-05,   1.96203940e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.94007993e-06,   2.77603482e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.10329946e-04,   1.24132005e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.39177773e-05,
         1.75673114e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.16021104e-05,   3.66409230e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.30070682e-05,   5.20313054e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.59512677e-02,   1.83805071e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.45017132e-05,
         1.43394354e-04,  -1.17041502e-04,   7.53586046e-04,
         0.00000000e+00,   0.00000000e+00,   4.33304375e-05,
        -3.25814918e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.48966742e-04,
         1.65231866e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.06551765e-04,  -2.94342715e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.69529923e-04,   3.48453474e-03,  -4.13326740e-03,
         1.66938816e-02,   0.00000000e+00,   0.00000000e+00,
         7.06551765e-04,  -2.94342715e-03,   0.00000000e+00,
         0.00000000e+00,  -3.16781694e-03,   1.30136461e-02,
         0.00000000e+00,   0.00000000e+00,   7.96232953e-04,
        -3.44913289e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.21446418e-04,
         1.28578864e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.95424711e-04,   7.82538680e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.03380116e-03,   8.13778924e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.24644071e-03,   5.02529505e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.00608146e-04,
         2.40845651e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.95986364e-04,   1.63719258e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.92273530e-02,
         7.69094124e-02,  -4.59509786e-02,   1.83805403e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.58185308e-04,   6.56873720e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.49421105e-05,
         3.58220341e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.06526038e-03,   1.62794934e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.98754881e-03,   7.99160939e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.83162147e-05,
         2.73639361e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.16746456e-05,   2.93058368e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.51479622e-02,   1.80592036e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.90913455e-05,  -2.55681913e-05,
        -1.12649771e-04,  -2.01030751e-04,   0.00000000e+00,
         0.00000000e+00,  -1.18794172e-04,   8.14438262e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.16651032e-06,  -6.04661949e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.96091299e-04,   1.45724576e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.05218455e-04,
        -4.35287962e-04,   6.25981773e-04,  -2.87897116e-03,
         0.00000000e+00,   0.00000000e+00,  -4.27640957e-03,
         1.73785188e-02,   0.00000000e+00,   0.00000000e+00,
         5.73629741e-04,  -3.13854110e-03,   0.00000000e+00,
         0.00000000e+00,  -2.30835784e-03,   9.90824488e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.09380923e-04,  -4.37533368e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.03485762e-04,  -4.16699699e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.92275906e-04,  -2.77604870e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.79510431e-04,
        -2.83566612e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.72963731e-04,  -1.10767275e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.33728999e-04,  -1.48866944e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.16164266e-03,  -8.64657130e-03,
         1.41641945e-02,  -5.66647857e-02,   0.00000000e+00,
         0.00000000e+00,  -4.74875870e-02,   1.89961310e-01,
         6.84682367e-04,   1.38711177e-07,   1.40358808e-04,
         1.15059369e-05,   6.46553532e-04,   1.42710019e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.47824037e-04,   1.20662444e-05,
        -1.90913455e-05,  -2.55681913e-05,  -1.12649771e-04,
        -2.01030751e-04,   0.00000000e+00,   0.00000000e+00,
         6.87215172e-04,   1.69630786e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.31453421e-04,   1.32581368e-03,
         8.13221055e-05,   1.76127702e-04,   1.97730562e-04,
         1.21496082e-03,   0.00000000e+00,   0.00000000e+00,
         2.16651032e-06,  -6.04661949e-04,   0.00000000e+00,
         0.00000000e+00,   8.92098842e-05,   2.19209072e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.96098808e-04,   5.33876066e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.02019534e-04,   8.90687386e-05,   1.05218455e-04,
        -4.35287962e-04,   6.25981773e-04,  -2.87897116e-03,
         0.00000000e+00,   0.00000000e+00,   8.49496192e-05,
         1.15241302e-03,   0.00000000e+00,   0.00000000e+00,
         5.73629741e-04,  -3.13854110e-03,   0.00000000e+00,
         0.00000000e+00,   1.81210502e-04,   2.00570423e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.85410368e-03,
         1.66911014e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.47307808e-03,   1.60722875e-02,
        -4.90509849e-05,   1.96203940e-04,  -3.21424692e-04,
         1.28577126e-03,   0.00000000e+00,   0.00000000e+00,
         1.09288821e-04,  -4.37459687e-04,   0.00000000e+00,
         0.00000000e+00,  -2.98283715e-04,   1.23339869e-03,
         0.00000000e+00,   0.00000000e+00,   7.14138449e-05,
        -4.13451057e-04,   0.00000000e+00,   0.00000000e+00,
         8.69059260e-04,   1.47499532e-06,  -3.10327653e-04,
         1.24131822e-03,  -2.03058537e-03,   8.13521661e-03,
         0.00000000e+00,   0.00000000e+00,   6.83660630e-04,
        -2.76915648e-03,   0.00000000e+00,   0.00000000e+00,
        -1.87962056e-03,   7.81583796e-03,   0.00000000e+00,
         0.00000000e+00,   4.67368737e-04,  -2.64704009e-03,
         0.00000000e+00,   0.00000000e+00,   1.81294734e-04,
         2.07019178e-05,   8.03076232e-04,   2.19615007e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.67453748e-05,   2.72382689e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.83844612e-05,   2.58426221e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.08861161e-04,   2.77426242e-05,
        -9.15917554e-05,   3.66400946e-04,  -5.93059078e-04,
         2.40241726e-03,   0.00000000e+00,   0.00000000e+00,
         2.54165132e-04,  -1.09263387e-03,   0.00000000e+00,
         0.00000000e+00,  -4.95817605e-04,   2.32934630e-03,
         0.00000000e+00,   0.00000000e+00,   8.09375006e-05,
        -1.09368353e-03,   0.00000000e+00,   0.00000000e+00,
         2.55508359e-05,   3.48120227e-05,   1.38116068e-04,
         2.59327275e-04,   0.00000000e+00,   0.00000000e+00,
         8.54388060e-04,   2.09850223e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.52154930e-02,   1.80865047e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.44658444e-04,
         1.25458631e-04,   1.00945197e-03,   5.65583689e-04,
         0.00000000e+00,   0.00000000e+00,  -3.81163483e-04,
        -2.97997954e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.62725878e-04,
         1.73327792e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.16974567e-04,  -2.93321696e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.37443126e-04,   3.04938878e-03,  -2.40722722e-03,
         1.24051743e-02,   0.00000000e+00,   0.00000000e+00,
         3.16974567e-04,  -2.93321696e-03,   0.00000000e+00,
         0.00000000e+00,  -2.64310463e-03,   1.84511629e-02,
         0.00000000e+00,   0.00000000e+00,   8.54656900e-04,
        -1.00271621e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.10765791e-04,
         1.24338435e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.01735552e-04,   2.93999902e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.95406182e-03,   7.87539097e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.89934841e-03,   1.80721120e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.66829139e-04,
         2.38615552e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.18563665e-03,   6.87288654e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.68262010e-02,
         6.73048073e-02,  -6.79959336e-02,   2.72052812e-01,
         0.00000000e+00,   0.00000000e+00,   1.35476195e-02,
        -5.43971261e-02,   0.00000000e+00,   0.00000000e+00,
        -4.54301957e-02,   1.84038131e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.97400392e-05,
         3.14058684e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.76709028e-05,   5.68821088e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.94482277e-03,   7.95742856e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.54003495e-03,
         1.48634416e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.16746456e-05,   2.93058368e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.77804135e-04,   2.69502486e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.43189700e-02,
         1.77282240e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.17661725e-02,   1.67256594e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.34353806e-04,
        -3.63015367e-06,  -2.81889962e-03,  -1.23066038e-04,
         0.00000000e+00,   0.00000000e+00,   9.73874629e-04,
         4.41273016e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.56537762e-03,
        -6.27335207e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.81479945e-04,   1.68548867e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.61834081e-05,  -6.16003145e-05,  -1.27691227e-03,
        -1.79061672e-03,   0.00000000e+00,   0.00000000e+00,
        -1.26567192e-03,   9.07409614e-03,   0.00000000e+00,
         0.00000000e+00,  -3.34715238e-03,  -6.66571466e-03,
         0.00000000e+00,   0.00000000e+00,  -1.52168504e-03,
         2.29368412e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.11059017e-04,
        -4.45167194e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.31321444e-04,  -3.72745861e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.64083346e-04,  -2.80441178e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.43772867e-03,  -2.06737241e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.30066494e-04,
        -1.21298672e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.17765676e-03,  -1.02995422e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.05843263e-04,
        -1.22338130e-03,   8.57887460e-03,  -3.44888760e-02,
         0.00000000e+00,   0.00000000e+00,  -4.86421773e-02,
         1.95092910e-01,   0.00000000e+00,   0.00000000e+00,
         2.42046294e-02,  -1.09893329e-01,   0.00000000e+00,
         0.00000000e+00,  -4.93856778e-02,   2.16195666e-01,
         1.66550670e-02,   1.73058586e-08,   3.48406731e-03,
         1.65695647e-06,   1.66335771e-02,   8.04060203e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.62725740e-02,   9.22594961e-06,
        -4.34353806e-04,  -3.63015367e-06,  -2.81889962e-03,
        -1.23066038e-04,   0.00000000e+00,   0.00000000e+00,
         1.72761886e-02,   1.36440281e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.62130939e-02,   6.37343318e-04,
         3.04309332e-03,   2.49596226e-05,   1.21246645e-02,
         7.79660939e-04,   0.00000000e+00,   0.00000000e+00,
        -2.56537762e-03,  -6.27335207e-04,   0.00000000e+00,
         0.00000000e+00,   1.54966337e-02,   3.93937220e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.93335304e-03,   5.48879075e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.45997034e-02,   3.51650882e-04,  -4.61834081e-05,
        -6.16003145e-05,  -1.27691227e-03,  -1.79061672e-03,
         0.00000000e+00,   0.00000000e+00,   8.61250389e-03,
         1.17155549e-03,   0.00000000e+00,   0.00000000e+00,
        -3.34715238e-03,  -6.66571466e-03,   0.00000000e+00,
         0.00000000e+00,   1.66180533e-02,   8.42505054e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.89085937e-03,
         8.58113755e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.51963351e-03,   3.00785340e-02,
        -6.94008884e-06,   2.77603554e-05,  -1.94660055e-04,
         7.81926956e-04,   0.00000000e+00,   0.00000000e+00,
         9.99954353e-05,  -4.13907438e-04,   0.00000000e+00,
         0.00000000e+00,  -1.10442810e-04,   2.46696482e-03,
         0.00000000e+00,   0.00000000e+00,  -1.06193826e-03,
        -2.21285085e-03,   0.00000000e+00,   0.00000000e+00,
         4.48936194e-02,   9.20571039e-04,  -4.38653143e-05,
         1.75631144e-04,  -1.15773676e-03,   4.95433190e-03,
         0.00000000e+00,   0.00000000e+00,   4.34211025e-04,
        -2.63942659e-03,   0.00000000e+00,   0.00000000e+00,
        -1.10068830e-03,   1.58331839e-02,   0.00000000e+00,
         0.00000000e+00,  -4.21106464e-03,  -1.45546894e-02,
         0.00000000e+00,   0.00000000e+00,   8.91520350e-03,
         2.53720921e-03,   3.71603453e-02,   1.62510928e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.83844612e-05,   2.58426221e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.08839472e-03,   1.36206577e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.83803657e-02,   4.00898760e-03,
        -1.27701582e-05,   5.18417774e-05,  -1.87839282e-04,
         1.47067492e-03,   0.00000000e+00,   0.00000000e+00,
        -2.03430677e-04,  -1.05894170e-03,   0.00000000e+00,
         0.00000000e+00,   1.54753116e-03,   4.68635230e-03,
         0.00000000e+00,   0.00000000e+00,  -4.81801420e-03,
        -5.50300541e-03,   0.00000000e+00,   0.00000000e+00,
         6.83420362e-04,   1.01538449e-03,   3.08874310e-03,
         6.48181176e-03,   0.00000000e+00,   0.00000000e+00,
         3.87940040e-02,   5.66354086e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.44190291e-02,   1.77833724e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.15108772e-02,   1.69285140e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.96203940e-04,   2.11436771e-14,
         1.28576580e-03,   1.88636726e-08,   0.00000000e+00,
         0.00000000e+00,  -4.37437638e-04,  -7.85197832e-08,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.23078183e-03,   1.01462530e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.05172850e-04,  -3.21817008e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.77603465e-05,
         7.13218483e-12,   7.81459086e-04,   1.03164271e-06,
         0.00000000e+00,   0.00000000e+00,  -4.12175628e-04,
        -4.17058727e-06,   0.00000000e+00,   0.00000000e+00,
         2.29880997e-03,   5.39562598e-04,   0.00000000e+00,
         0.00000000e+00,  -1.68338410e-03,  -1.71569418e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.16803879e-04,   8.70165507e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.09357264e-02,   4.55840477e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.76119830e-05,   1.87827291e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.14288346e-04,
         1.02408027e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.55508359e-05,   3.48120227e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.83420362e-04,   1.01538449e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.47694114e-10,   8.63592152e-10,
         1.10699843e-05,   5.24110110e-05,   0.00000000e+00,
         0.00000000e+00,  -2.95233769e-05,  -2.00439220e-04,
         0.00000000e+00,   0.00000000e+00,  -1.49948261e-03,
         2.40400030e-02,   0.00000000e+00,   0.00000000e+00,
         5.27032816e-03,  -7.65232748e-02,   0.00000000e+00,
         0.00000000e+00,  -1.99600028e-01,   9.62844158e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.24131766e-03,
         1.96678367e-09,   8.13360422e-03,   3.86493275e-06,
         0.00000000e+00,   0.00000000e+00,  -2.76482902e-03,
        -1.03647607e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.77877082e-03,
         8.91248540e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.55216777e-03,  -2.31410886e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.75619899e-04,   4.29729918e-08,   4.92176652e-03,
         9.07292692e-05,   0.00000000e+00,   0.00000000e+00,
        -2.54625756e-03,  -2.55051721e-04,   0.00000000e+00,
         0.00000000e+00,   1.43454325e-02,   3.47628728e-03,
         0.00000000e+00,   0.00000000e+00,  -1.04288772e-02,
        -9.58043934e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.00966854e-05,
         2.05815053e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.15755765e-03,   1.13954181e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.32139368e-04,   9.67787487e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.21161985e-03,   4.93486649e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.38116068e-04,
         2.59327275e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.08874310e-03,   6.48181176e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.25819268e-07,
         9.25131716e-07,  -3.51821284e-04,   1.93014796e-03,
         0.00000000e+00,   0.00000000e+00,   9.65636953e-04,
        -5.51426527e-03,   0.00000000e+00,   0.00000000e+00,
        -7.84862084e-03,   9.60799594e-02,   0.00000000e+00,
         0.00000000e+00,   2.03997528e-02,  -2.74977305e-01,
         0.00000000e+00,   0.00000000e+00,  -1.70143836e-02,
         4.70410242e-01,  -5.52499155e-02,   8.47124816e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.71928083e-04,   1.44392316e-06,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.47383264e-04,
         3.78120405e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.47383264e-04,   3.78120405e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.84897880e-04,   1.52486325e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.93545720e-04,
         8.29668129e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.34228280e-03,   4.13871064e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.93545720e-04,   8.29668129e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.34228280e-03,
         4.13871064e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.35569294e-01,   7.07381308e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.66398579e-04,   8.67811471e-09,
         2.39864847e-03,   9.05121821e-06,   0.00000000e+00,
         0.00000000e+00,  -1.08294246e-03,  -2.29477914e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.27057938e-03,   1.16228711e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.54087449e-04,  -2.65663567e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.17932581e-05,
         1.91044366e-07,   1.40907783e-03,   1.93141229e-04,
         0.00000000e+00,   0.00000000e+00,  -8.93852225e-04,
        -5.06604464e-04,   0.00000000e+00,   0.00000000e+00,
         3.34084125e-03,   3.25170422e-03,   0.00000000e+00,
         0.00000000e+00,  -2.20802805e-03,  -7.59099434e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.65687396e-05,   6.85076831e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.90515234e-04,   1.87453297e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.50945548e-05,   4.05895772e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.81982301e-04,
         9.41839209e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.48018820e-04,   1.01177573e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.92864449e-03,   4.30416597e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.02954221e-06,   4.12590625e-06,
        -9.30672221e-04,   3.99005483e-03,   0.00000000e+00,
         0.00000000e+00,   2.42510119e-03,  -1.05403264e-02,
         0.00000000e+00,   0.00000000e+00,  -1.36843562e-02,
         6.78897996e-02,   0.00000000e+00,   0.00000000e+00,
         3.06199486e-02,  -1.54302000e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.35569294e-01,   7.07381308e-01,
         3.67610141e-01,   6.46371845e-13,   7.69094123e-02,
         1.49817436e-10,   3.67609689e-01,   1.48835117e-06,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.61183932e-01,   1.87251263e-07,
        -8.64657106e-03,  -3.24297200e-10,  -5.66617828e-02,
        -4.00382242e-06,   0.00000000e+00,   0.00000000e+00,
         3.79914398e-01,   1.09616169e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.61727788e-01,   3.07509759e-06,
         6.73048060e-02,   1.71889036e-09,   2.72026908e-01,
         3.45388463e-05,   0.00000000e+00,   0.00000000e+00,
        -5.43196331e-02,  -1.03323941e-04,   0.00000000e+00,
         0.00000000e+00,   3.66338251e-01,   2.31734823e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.77279855e-01,   3.17989305e-06,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.34369260e-01,   1.91904160e-04,  -1.22337821e-03,
        -4.12283892e-09,  -3.44238594e-02,  -8.66887962e-05,
         0.00000000e+00,   0.00000000e+00,   1.94896335e-01,
         2.62100425e-04,   0.00000000e+00,   0.00000000e+00,
        -1.04990275e-01,  -6.53740581e-03,   0.00000000e+00,
         0.00000000e+00,   4.18401616e-01,   1.86529549e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.77774621e-01,
         7.88039740e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.36139056e-01,   3.24163066e-03,
        -4.31796076e-10,   1.72718430e-09,   1.61519054e-05,
         4.83454741e-05,   0.00000000e+00,   0.00000000e+00,
        -8.09894469e-05,  -1.59266364e-04,   0.00000000e+00,
         0.00000000e+00,   1.72742258e-02,   9.02103627e-03,
         0.00000000e+00,   0.00000000e+00,  -5.57325390e-02,
        -2.77209811e-02,   0.00000000e+00,   0.00000000e+00,
         1.80235528e+00,   1.64444047e-01,   9.16936224e-07,
         1.09273223e-08,   1.73407440e-03,   2.61431410e-04,
         0.00000000e+00,   0.00000000e+00,  -4.89487122e-03,
        -8.25858729e-04,   0.00000000e+00,   0.00000000e+00,
         7.18229059e-02,   3.23427380e-02,   0.00000000e+00,
         0.00000000e+00,  -2.02460445e-01,  -9.66891469e-02,
         0.00000000e+00,   0.00000000e+00,   3.19527977e-01,
         2.01176354e-01,   1.22465577e+00,   6.26125154e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.08861161e-04,   2.77426242e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.83803657e-02,   4.00898760e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.29093452e+00,   1.65104131e-01,
         4.12300473e-06,   3.86869933e-09,   3.88979260e-03,
         1.33682972e-04,   0.00000000e+00,   0.00000000e+00,
        -1.02253558e-02,  -4.19960840e-04,   0.00000000e+00,
         0.00000000e+00,   6.29576591e-02,   6.57618733e-03,
         0.00000000e+00,   0.00000000e+00,  -1.42368673e-01,
        -1.59111030e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.29093452e+00,   1.65104131e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.21769720e-04,   1.68707888e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.16958001e-02,   8.67832004e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.74328671e-01,   1.49731468e+00,
         1.32414750e-02,   5.29658998e-02,  -1.43713800e-02,
         7.31443690e-02,   4.17882232e-03,   2.84703428e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.04610118e-02,   5.60283791e-03,
         1.79918651e-02,  -7.45649536e-02,   3.53776165e-03,
        -1.81166821e-02,   0.00000000e+00,   0.00000000e+00,
         9.60893331e-03,   9.65581788e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.04610118e-02,   5.60283791e-03,
        -3.10443913e-02,   1.40124488e-01,  -2.68254354e-03,
         4.07781415e-02,   0.00000000e+00,   0.00000000e+00,
         3.79461917e-03,  -1.77692191e-02,   0.00000000e+00,
         0.00000000e+00,  -5.05146048e-03,   4.95894648e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.62279633e-03,   2.41819462e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.89989787e-03,   5.72799666e-04,   5.07086691e-02,
        -2.03133279e-01,   1.04141213e-02,  -4.28519411e-02,
         0.00000000e+00,   0.00000000e+00,   2.47840125e-03,
         7.16799329e-03,   0.00000000e+00,   0.00000000e+00,
         9.14611730e-03,  -3.77721909e-02,   0.00000000e+00,
         0.00000000e+00,   4.60774618e-03,   1.83554182e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.62279633e-03,
         2.41819462e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.89989787e-03,   5.72799666e-04,
        -1.71035386e-02,   6.84141542e-02,  -3.57825177e-03,
         1.43132406e-02,   0.00000000e+00,   0.00000000e+00,
         4.13411708e-04,  -1.65463113e-03,   0.00000000e+00,
         0.00000000e+00,  -3.09710789e-03,   1.25257736e-02,
         0.00000000e+00,   0.00000000e+00,  -5.08478913e-05,
        -2.34109144e-04,   0.00000000e+00,   0.00000000e+00,
         3.01928643e-03,  -0.00000000e+00,  -6.82147618e-02,
         2.72859197e-01,  -1.42591410e-02,   5.70863010e-02,
         0.00000000e+00,   0.00000000e+00,   1.61848174e-03,
        -6.59945656e-03,   0.00000000e+00,   0.00000000e+00,
        -1.22391075e-02,   4.99574392e-02,   0.00000000e+00,
         0.00000000e+00,  -4.23698110e-04,  -9.34243713e-04,
         0.00000000e+00,   0.00000000e+00,   6.48238857e-04,
         1.72175418e-07,   3.01894308e-03,   1.37338344e-06,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.89549136e-04,   1.18088235e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.36044766e-05,   1.67086599e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.97489028e-03,   1.03943542e-08,
        -1.22062893e-02,   4.88258486e-02,  -2.52252324e-03,
         1.02158452e-02,   0.00000000e+00,   0.00000000e+00,
         5.17098088e-04,  -2.36272476e-03,   0.00000000e+00,
         0.00000000e+00,  -1.95039301e-03,   8.94093415e-03,
         0.00000000e+00,   0.00000000e+00,  -5.33195305e-04,
        -3.36555410e-04,   0.00000000e+00,   0.00000000e+00,
         6.82672372e-05,   7.71811996e-07,   4.32318924e-04,
         3.22521048e-06,   0.00000000e+00,   0.00000000e+00,
         3.10774687e-03,   1.30658446e-06,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.89549136e-04,   1.18088235e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.36044766e-05,   1.67086599e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.97489028e-03,   1.03943542e-08,
        -4.65068067e-02,   1.86371042e-01,   6.72723006e-02,
         7.82942455e-03,   7.85227653e-03,   2.55315794e-02,
         3.06416018e-02,   1.22566407e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.42351037e-02,   2.12832382e-02,   1.21987377e-03,
        -1.62623718e-02,   7.12958689e-03,  -8.11825552e-02,
         0.00000000e+00,   0.00000000e+00,   5.29110681e-02,
         4.24495888e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.42351037e-02,   2.12832382e-02,   3.61475913e-03,
         3.57402993e-02,  -5.09916473e-04,   1.73583665e-01,
         0.00000000e+00,   0.00000000e+00,   8.20994101e-03,
        -7.33367090e-02,   0.00000000e+00,   0.00000000e+00,
        -3.51433879e-04,   1.89995188e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.16914832e-02,   1.64660597e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.33764699e-02,
         1.29525214e-02,   1.02974825e-02,  -4.27586301e-02,
         4.59136843e-02,  -2.07716538e-01,   0.00000000e+00,
         0.00000000e+00,   1.54943829e-02,   5.01307515e-02,
         0.00000000e+00,   0.00000000e+00,   3.15856535e-02,
        -1.62014882e-01,   0.00000000e+00,   0.00000000e+00,
         2.80981853e-02,   4.60908194e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.16914832e-02,   1.64660597e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.33764699e-02,   1.29525214e-02,  -3.57832474e-03,
         1.43132990e-02,  -1.71030838e-02,   6.84147605e-02,
         0.00000000e+00,   0.00000000e+00,   2.70846813e-03,
        -1.08440773e-02,   0.00000000e+00,   0.00000000e+00,
        -1.23095987e-02,   5.06306583e-02,   0.00000000e+00,
         0.00000000e+00,   5.42539594e-04,  -6.59903934e-03,
         0.00000000e+00,   0.00000000e+00,   3.03924713e-02,
         1.72087692e-05,  -1.42744564e-02,   5.70985533e-02,
        -6.81121648e-02,   2.72992048e-01,   0.00000000e+00,
         0.00000000e+00,   1.05144660e-02,  -4.34411997e-02,
         0.00000000e+00,   0.00000000e+00,  -4.79705324e-02,
         2.02366567e-01,   0.00000000e+00,   0.00000000e+00,
        -4.37484761e-05,  -2.71160957e-02,   0.00000000e+00,
         0.00000000e+00,   6.43254471e-03,   3.74198608e-04,
         2.96880381e-02,   2.72439518e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.87701539e-03,   7.74897730e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.90396526e-04,
         4.74217859e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.96145368e-02,   2.20607204e-04,  -2.56079947e-03,
         1.02464662e-02,  -1.19493749e-02,   4.91555815e-02,
         0.00000000e+00,   0.00000000e+00,   3.18243434e-03,
        -1.59560102e-02,   0.00000000e+00,   0.00000000e+00,
        -6.20708891e-03,   3.71759472e-02,   0.00000000e+00,
         0.00000000e+00,  -3.87208550e-03,  -1.12986187e-02,
         0.00000000e+00,   0.00000000e+00,   6.80897989e-04,
         7.71370646e-04,   4.62804990e-03,   3.42978213e-03,
         0.00000000e+00,   0.00000000e+00,   3.12580800e-02,
         1.93557371e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.87701539e-03,   7.74897730e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.90396526e-04,
         4.74217859e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.96145368e-02,   2.20607204e-04,  -1.90568971e-02,
         7.85034989e-02,  -4.49173890e-02,   1.88191814e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.64366102e-04,   1.46631402e-02,  -6.90776398e-03,
         7.01975323e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.39188322e-02,  -6.77480596e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.59582351e-02,   1.35780887e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.19703332e-03,   6.27405835e-03,  -4.78098890e-03,
         3.76440374e-02,   0.00000000e+00,   0.00000000e+00,
         6.53672067e-03,  -3.25653996e-02,   0.00000000e+00,
         0.00000000e+00,  -1.10630233e-02,   7.06998830e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.79456688e-02,  -1.98201192e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.23489082e-02,
        -9.77971807e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.67961037e-02,   6.71844343e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.23863636e-03,   3.29610343e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.69809667e-02,   2.67963846e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.27656745e-02,
         1.31493180e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.96626983e-04,   1.18654463e-03,  -1.93800286e-03,
         7.79776728e-03,   0.00000000e+00,   0.00000000e+00,
         6.52235207e-04,  -2.71825973e-03,   0.00000000e+00,
         0.00000000e+00,  -1.72192905e-03,   7.62756225e-03,
         0.00000000e+00,   0.00000000e+00,   2.64124487e-04,
        -2.86480351e-03,   0.00000000e+00,   0.00000000e+00,
         1.54962614e-04,   1.60384217e-04,   1.04701738e-03,
         7.13047313e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.15275159e-02,   4.62171643e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.33097282e-03,   2.19428151e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.68256797e-04,   3.56436553e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.54440442e-02,   1.83214203e-01,
        -7.35908937e-02,  -1.29874651e-03,  -1.43116809e-02,
        -3.83712805e-03,  -6.14334773e-02,  -2.63321038e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.32207856e-02,  -6.03636538e-03,
         6.15209759e-04,   1.68507967e-02,   3.77294628e-05,
         8.47482597e-02,   0.00000000e+00,   0.00000000e+00,
        -3.66832125e-02,  -1.46732850e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.32207856e-02,  -6.03636538e-03,
        -1.21898592e-02,  -4.98163643e-03,  -3.94768785e-02,
        -3.51872535e-02,   0.00000000e+00,   0.00000000e+00,
        -2.14641185e-02,   1.52181220e-01,   0.00000000e+00,
         0.00000000e+00,  -4.39719783e-02,  -4.41323800e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.75561728e-02,  -5.29108481e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.16978428e-02,  -5.62681907e-03,  -2.04266970e-03,
         1.07848500e-02,  -7.21983417e-03,   6.83021252e-02,
         0.00000000e+00,   0.00000000e+00,   2.74499807e-02,
        -2.44789957e-01,   0.00000000e+00,   0.00000000e+00,
        -1.04005476e-02,   1.02962996e-01,   0.00000000e+00,
         0.00000000e+00,   3.27839464e-03,  -2.13296418e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.75561728e-02,
        -5.29108481e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.16978428e-02,  -5.62681907e-03,
         4.13719301e-04,  -1.65487720e-03,   2.71054342e-03,
        -1.08457376e-02,   0.00000000e+00,   0.00000000e+00,
        -1.77155922e-02,   7.08773469e-02,   0.00000000e+00,
         0.00000000e+00,   2.09973964e-03,  -1.04139607e-02,
         0.00000000e+00,   0.00000000e+00,  -7.51739748e-03,
         3.64738138e-02,   0.00000000e+00,   0.00000000e+00,
        -4.37850850e-02,  -7.43833500e-05,   1.65742868e-03,
        -6.63061412e-03,   1.06945860e-02,  -4.35852957e-02,
         0.00000000e+00,   0.00000000e+00,  -7.02753876e-02,
         2.83168086e-01,   0.00000000e+00,   0.00000000e+00,
         6.82079099e-03,  -4.26725369e-02,   0.00000000e+00,
         0.00000000e+00,  -2.69211416e-02,   1.47582755e-01,
         0.00000000e+00,   0.00000000e+00,  -9.12888073e-03,
        -1.09658148e-03,  -4.17729860e-02,  -7.70251497e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.76737920e-04,  -2.65786190e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.33508774e-03,  -2.58559252e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.22813056e-02,  -6.83009082e-04,
         6.07821492e-04,  -2.43530348e-03,   3.56496327e-03,
        -1.62620334e-02,   0.00000000e+00,   0.00000000e+00,
        -1.26108758e-02,   5.52393756e-02,   0.00000000e+00,
         0.00000000e+00,  -2.40474051e-04,  -1.74413649e-02,
         0.00000000e+00,   0.00000000e+00,   1.48025436e-03,
         3.40844418e-02,   0.00000000e+00,   0.00000000e+00,
        -9.14917218e-04,  -2.05472993e-03,  -6.60358753e-03,
        -9.12695620e-03,   0.00000000e+00,   0.00000000e+00,
        -4.48056890e-02,  -5.20804189e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.76737920e-04,  -2.65786190e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.33508774e-03,  -2.58559252e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.22813056e-02,  -6.83009082e-04,
         1.76861997e-03,  -9.60405376e-03,   1.04673516e-02,
        -6.37156577e-02,   0.00000000e+00,   0.00000000e+00,
        -4.53002431e-02,   1.96057102e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.64366102e-04,   1.46631402e-02,
        -6.90776398e-03,   7.01975323e-02,   0.00000000e+00,
         0.00000000e+00,   1.39188322e-02,  -6.77480596e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.59582351e-02,   1.35780887e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.79456688e-02,  -1.98201192e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.19703332e-03,
         6.27405835e-03,  -4.78098890e-03,   3.76440374e-02,
         0.00000000e+00,   0.00000000e+00,   6.53672067e-03,
        -3.25653996e-02,   0.00000000e+00,   0.00000000e+00,
        -1.10630233e-02,   7.06998830e-02,   0.00000000e+00,
         0.00000000e+00,   2.23489082e-02,  -9.77971807e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.67961037e-02,   6.71844343e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.23863636e-03,   3.29610343e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.69809667e-02,   2.67963846e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.27656745e-02,
         1.31493180e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.15275159e-02,   4.62171643e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.33097282e-03,   2.19428151e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.96626983e-04,   1.18654463e-03,
        -1.93800286e-03,   7.79776728e-03,   0.00000000e+00,
         0.00000000e+00,   6.52235207e-04,  -2.71825973e-03,
         0.00000000e+00,   0.00000000e+00,  -1.72192905e-03,
         7.62756225e-03,   0.00000000e+00,   0.00000000e+00,
         2.64124487e-04,  -2.86480351e-03,   0.00000000e+00,
         0.00000000e+00,   1.54962614e-04,   1.60384217e-04,
         1.04701738e-03,   7.13047313e-04,   0.00000000e+00,
         0.00000000e+00,   3.68256797e-04,   3.56436553e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.54440442e-02,   1.83214203e-01,
         1.34144392e-01,   7.97346135e-03,   2.32128511e-02,
         2.00618258e-02,   1.09254666e-01,   8.57719997e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.23800407e-01,   1.59739731e-02,
        -8.13212333e-04,  -1.40829539e-02,  -1.04635352e-02,
        -5.83979281e-02,   0.00000000e+00,   0.00000000e+00,
         1.27309440e-01,   3.31623729e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.23800407e-01,   1.59739731e-02,
         1.67595729e-02,   3.21406381e-02,   5.94613548e-02,
         1.42144957e-01,   0.00000000e+00,   0.00000000e+00,
        -2.79837416e-03,  -7.70712633e-02,   0.00000000e+00,
         0.00000000e+00,   5.90389720e-02,   2.36155888e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.60209160e-02,   1.70327316e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.45405266e-02,   2.86092268e-02,   8.75920959e-03,
        -3.74626647e-02,   2.55912453e-02,  -1.57219356e-01,
         0.00000000e+00,   0.00000000e+00,   5.32198781e-02,
         5.20666559e-02,   0.00000000e+00,   0.00000000e+00,
         2.52423326e-02,  -2.22130392e-01,   0.00000000e+00,
         0.00000000e+00,   8.95411587e-02,   1.12646841e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.60209160e-02,
         1.70327316e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.45405266e-02,   2.86092268e-02,
        -3.14002728e-03,   1.25601091e-02,  -1.27407833e-02,
         5.09756060e-02,   0.00000000e+00,   0.00000000e+00,
         2.71298985e-03,  -1.09045608e-02,   0.00000000e+00,
         0.00000000e+00,  -1.57096738e-02,   7.01493266e-02,
         0.00000000e+00,   0.00000000e+00,   3.03220657e-04,
        -2.44855334e-02,   0.00000000e+00,   0.00000000e+00,
         1.57960015e-01,   1.30545695e-02,  -1.25514839e-02,
         5.02073403e-02,  -5.06673119e-02,   2.04523990e-01,
         0.00000000e+00,   0.00000000e+00,   1.00778689e-02,
        -4.52781993e-02,   0.00000000e+00,   0.00000000e+00,
        -5.89283718e-02,   2.83697220e-01,   0.00000000e+00,
         0.00000000e+00,  -5.96524479e-03,  -1.04170263e-01,
         0.00000000e+00,   0.00000000e+00,   2.69197964e-02,
         2.90898647e-02,   1.24985835e-01,   1.12076479e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.68785796e-03,   7.60030538e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.37342379e-03,   1.58509268e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.44780457e-01,   2.38348056e-02,
        -2.30447596e-03,   9.22420051e-03,  -8.70390310e-03,
         3.91733985e-02,   0.00000000e+00,   0.00000000e+00,
         2.10384989e-03,  -1.93168240e-02,   0.00000000e+00,
         0.00000000e+00,  -2.05173856e-03,   5.98731138e-02,
         0.00000000e+00,   0.00000000e+00,  -1.63481616e-02,
        -4.97405398e-02,   0.00000000e+00,   0.00000000e+00,
         8.56018569e-04,   1.42067190e-02,   1.00391624e-02,
         5.74338209e-02,   0.00000000e+00,   0.00000000e+00,
         1.47514505e-01,   3.62327790e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.68785796e-03,   7.60030538e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.37342379e-03,   1.58509268e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.44780457e-01,   2.38348056e-02,
        -1.62193900e-02,   6.93160883e-02,  -6.11214003e-02,
         2.85254571e-01,   0.00000000e+00,   0.00000000e+00,
         3.30277446e-03,  -6.92876085e-02,   0.00000000e+00,
         0.00000000e+00,  -3.29186260e-02,   2.01122638e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.97006796e-04,   4.59882625e-03,   4.22653465e-03,
         3.04380186e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.93443771e-03,  -3.04835732e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.30197747e-03,   6.68910463e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.04597457e-03,   5.32949762e-03,  -4.29645453e-03,
         4.30908609e-02,   0.00000000e+00,   0.00000000e+00,
         8.66607973e-03,  -4.59179571e-02,   0.00000000e+00,
         0.00000000e+00,  -1.46947482e-02,   1.15997447e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.14576300e-02,  -9.70841582e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.66070862e-02,
        -1.76671378e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.24059397e-03,   3.29626004e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.55014205e-02,   6.20908292e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.28540289e-02,   1.31563864e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.12028177e-02,
         2.48309210e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.56053731e-05,   3.02454479e-04,  -1.47632560e-03,
         6.07555629e-03,   0.00000000e+00,   0.00000000e+00,
         9.98812374e-04,  -4.45271261e-03,   0.00000000e+00,
         0.00000000e+00,  -3.62420849e-03,   2.06490326e-02,
         0.00000000e+00,   0.00000000e+00,   2.08904148e-03,
        -2.47404891e-02,   0.00000000e+00,   0.00000000e+00,
         5.21847639e-04,   8.66072656e-03,   6.12009291e-03,
         3.50129132e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.41643835e-03,   2.20111875e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.08316620e-03,   3.61319965e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.66673555e-03,   7.55807568e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.39080876e-02,   1.80516888e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.01870625e-02,   1.70853244e-01,  -2.03021303e-01,
        -1.49301159e-04,  -4.22870063e-02,  -6.91038982e-04,
        -1.98693362e-01,  -1.20309003e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.95794248e-01,  -3.20925844e-03,   5.28346488e-03,
         4.92394238e-03,   3.08043624e-02,   3.78827680e-02,
         0.00000000e+00,   0.00000000e+00,  -1.94168694e-01,
        -6.74950173e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.95794248e-01,  -3.20925844e-03,  -3.69398875e-02,
        -9.03387004e-04,  -1.42643374e-01,  -2.26316608e-02,
         0.00000000e+00,   0.00000000e+00,   1.63322685e-02,
         8.15767436e-02,   0.00000000e+00,   0.00000000e+00,
        -1.76694994e-01,  -6.05805310e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.37553221e-02,  -4.91379651e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.65330240e-01,
        -1.51215163e-02,  -5.78329727e-04,   5.98440255e-03,
         7.37883473e-03,   6.26662999e-02,   0.00000000e+00,
         0.00000000e+00,  -6.74747291e-02,  -1.56693919e-01,
         0.00000000e+00,   0.00000000e+00,   1.28168481e-02,
         1.74026290e-01,   0.00000000e+00,   0.00000000e+00,
        -1.02292633e-01,  -4.09170530e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.37553221e-02,  -4.91379651e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.65330240e-01,  -1.51215163e-02,   8.58710803e-05,
        -3.43484321e-04,   1.91822441e-03,  -7.69958719e-03,
         0.00000000e+00,   0.00000000e+00,  -9.48349345e-03,
         3.80466906e-02,   0.00000000e+00,   0.00000000e+00,
         2.60836953e-03,  -2.63296525e-02,   0.00000000e+00,
         0.00000000e+00,  -1.04652236e-02,   9.25053316e-02,
         0.00000000e+00,   0.00000000e+00,  -3.42602122e-01,
        -4.20118046e-02,   3.97203804e-04,  -1.59096524e-03,
         7.41086057e-03,  -3.30797830e-02,   0.00000000e+00,
         0.00000000e+00,  -3.64697626e-02,   1.55221652e-01,
         0.00000000e+00,   0.00000000e+00,   3.34649832e-03,
        -1.11619657e-01,   0.00000000e+00,   0.00000000e+00,
        -2.84192618e-02,   3.78371912e-01,   0.00000000e+00,
         0.00000000e+00,  -5.26202710e-02,  -8.73054544e-02,
        -2.48572591e-01,  -3.15215674e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.37249015e-04,  -2.92330314e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.99845594e-03,
        -1.58704911e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.06116551e-01,  -7.06373003e-02,   2.35465958e-04,
        -9.51484421e-04,   2.02481905e-03,  -1.60161424e-02,
         0.00000000e+00,   0.00000000e+00,  -4.73597288e-03,
         3.90574235e-02,   0.00000000e+00,   0.00000000e+00,
        -1.21501002e-02,  -5.30989889e-02,   0.00000000e+00,
         0.00000000e+00,   2.79110402e-02,   1.16516260e-01,
         0.00000000e+00,   0.00000000e+00,  -4.28286215e-04,
        -3.27011363e-02,  -1.31182475e-02,  -1.30109515e-01,
         0.00000000e+00,   0.00000000e+00,  -3.09176656e-01,
        -9.18580483e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.37249015e-04,  -2.92330314e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.99845594e-03,
        -1.58704911e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.06116551e-01,  -7.06373003e-02,  -9.32351046e-04,
        -2.93469097e-03,  -3.74337449e-03,  -5.16128213e-02,
         0.00000000e+00,   0.00000000e+00,  -3.14024404e-02,
         2.20052518e-01,   0.00000000e+00,   0.00000000e+00,
        -2.28276830e-02,  -1.65459264e-01,   0.00000000e+00,
         0.00000000e+00,  -4.77542142e-03,   2.66545061e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.97006796e-04,
         4.59882625e-03,   4.22653465e-03,   3.04380186e-02,
         0.00000000e+00,   0.00000000e+00,   3.93443771e-03,
        -3.04835732e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.30197747e-03,
         6.68910463e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.14576300e-02,  -9.70841582e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.04597457e-03,   5.32949762e-03,  -4.29645453e-03,
         4.30908609e-02,   0.00000000e+00,   0.00000000e+00,
         8.66607973e-03,  -4.59179571e-02,   0.00000000e+00,
         0.00000000e+00,  -1.46947482e-02,   1.15997447e-01,
         0.00000000e+00,   0.00000000e+00,   3.66070862e-02,
        -1.76671378e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.24059397e-03,
         3.29626004e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.55014205e-02,   6.20908292e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.28540289e-02,   1.31563864e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.12028177e-02,   2.48309210e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.41643835e-03,
         2.20111875e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.08316620e-03,   3.61319965e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.56053731e-05,
         3.02454479e-04,  -1.47632560e-03,   6.07555629e-03,
         0.00000000e+00,   0.00000000e+00,   9.98812374e-04,
        -4.45271261e-03,   0.00000000e+00,   0.00000000e+00,
        -3.62420849e-03,   2.06490326e-02,   0.00000000e+00,
         0.00000000e+00,   2.08904148e-03,  -2.47404891e-02,
         0.00000000e+00,   0.00000000e+00,   5.21847639e-04,
         8.66072656e-03,   6.12009291e-03,   3.50129132e-02,
         0.00000000e+00,   0.00000000e+00,   1.66673555e-03,
         7.55807568e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.39080876e-02,
         1.80516888e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.01870625e-02,   1.70853244e-01,
         6.84141542e-02,  -0.00000000e+00,   1.43132260e-02,
         5.83746733e-08,   6.84138510e-02,   1.21266908e-06,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.71844269e-02,   9.82602183e-09,
        -1.65456961e-03,  -2.46074635e-07,  -1.08423258e-02,
        -3.44217338e-06,   0.00000000e+00,   0.00000000e+00,
         7.08717300e-02,   7.48912762e-06,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.71844269e-02,   9.82602183e-09,
         1.25171897e-02,   3.43355144e-05,   5.05397441e-02,
         3.51184037e-04,   0.00000000e+00,   0.00000000e+00,
        -1.02715851e-02,  -5.16900883e-04,   0.00000000e+00,
         0.00000000e+00,   6.74078399e-02,   3.65531565e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.29605586e-02,   1.67833031e-06,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.20588991e-02,   4.25735439e-05,  -2.06765350e-04,
        -1.09375177e-04,  -6.31389379e-03,  -1.11389263e-03,
         0.00000000e+00,   0.00000000e+00,   3.60383258e-02,
         1.62923516e-03,   0.00000000e+00,   0.00000000e+00,
        -1.80634382e-02,  -9.79220628e-03,   0.00000000e+00,
         0.00000000e+00,   7.35136677e-02,   2.53222186e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.29605586e-02,
         1.67833031e-06,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.20588991e-02,   4.25735439e-05,
        -7.54821608e-04,   3.01928643e-03,  -7.59274007e-03,
         3.04053778e-02,   0.00000000e+00,   0.00000000e+00,
         1.09230264e-02,  -4.38408725e-02,   0.00000000e+00,
         0.00000000e+00,  -3.54104507e-02,   1.67750942e-01,
         0.00000000e+00,   0.00000000e+00,   7.25218415e-02,
        -3.74110975e-01,   0.00000000e+00,   0.00000000e+00,
         3.67452262e-01,   1.46980905e+00,  -1.61898300e-04,
         6.48281901e-04,  -1.28045829e-03,   6.54460101e-03,
         0.00000000e+00,   0.00000000e+00,   1.35263105e-03,
        -9.48179091e-03,   0.00000000e+00,   0.00000000e+00,
         5.34606302e-03,   4.63488514e-02,   0.00000000e+00,
         0.00000000e+00,  -2.00099259e-02,  -1.13393731e-01,
         0.00000000e+00,   0.00000000e+00,  -1.97291192e-01,
         1.22709088e+00,   1.90601513e-01,   4.66138174e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.10524452e-04,   1.95934747e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.43148790e-03,   3.13301436e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.92797679e-01,   1.30883403e-01,
        -1.63432356e-05,   6.84601902e-05,   5.47658009e-04,
         8.77962630e-04,   0.00000000e+00,   0.00000000e+00,
        -1.67608708e-03,  -1.44579404e-03,   0.00000000e+00,
         0.00000000e+00,   1.21903237e-02,   5.13927489e-03,
         0.00000000e+00,   0.00000000e+00,  -2.81759678e-02,
        -1.05029910e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.92797679e-01,   1.30883403e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.10524452e-04,   1.95934747e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.43148790e-03,   3.13301436e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.92797679e-01,   1.30883403e-01,
         4.15717926e-04,   5.54290568e-04,   4.18050488e-03,
         5.59831528e-03,   0.00000000e+00,   0.00000000e+00,
        -6.01099650e-03,  -8.11802369e-03,   0.00000000e+00,
         0.00000000e+00,   1.90615591e-02,   4.12888686e-02,
         0.00000000e+00,   0.00000000e+00,  -3.85657556e-02,
        -1.02269752e-01,   0.00000000e+00,   0.00000000e+00,
        -9.57718141e-02,   6.02755022e-01,   2.72859141e-01,
         7.48147524e-08,   5.70829650e-02,   1.26162390e-05,
         2.72788277e-01,   2.71694480e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.67948854e-01,   1.99898031e-05,  -6.59132990e-03,
        -3.16072523e-05,  -4.31025689e-02,  -5.47571777e-04,
         0.00000000e+00,   0.00000000e+00,   2.82393135e-01,
         1.03326800e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.67948854e-01,   1.99898031e-05,   4.98944372e-02,
         2.50603443e-04,   2.01131682e-01,   3.08479495e-03,
         0.00000000e+00,   0.00000000e+00,  -4.01586000e-02,
        -5.08902414e-03,   0.00000000e+00,   0.00000000e+00,
         2.65703320e-01,   2.39918664e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.31420104e-01,   1.44557710e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.46997483e-01,
         1.74896987e-03,  -7.69257070e-04,  -6.57796545e-04,
        -2.43365462e-02,  -7.68185758e-03,   0.00000000e+00,
         0.00000000e+00,   1.42169555e-01,   1.23101974e-02,
         0.00000000e+00,   0.00000000e+00,  -6.54702902e-02,
        -5.65662265e-02,   0.00000000e+00,   0.00000000e+00,
         2.79111338e-01,   1.32347432e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.31420104e-01,   1.44557710e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.46997483e-01,   1.74896987e-03,  -1.62113519e-04,
         6.48454076e-04,  -1.70193993e-03,   6.88178632e-03,
         0.00000000e+00,   0.00000000e+00,   2.52644588e-03,
        -1.04208428e-02,   0.00000000e+00,   0.00000000e+00,
        -6.24795774e-04,   5.11255385e-02,   0.00000000e+00,
         0.00000000e+00,  -8.24584759e-03,  -1.22804993e-01,
         0.00000000e+00,   0.00000000e+00,   1.06286859e+00,
         2.18963055e-01,  -7.54306588e-04,   3.01997312e-03,
        -6.57063603e-03,   3.17313345e-02,   0.00000000e+00,
         0.00000000e+00,   8.03621056e-03,  -4.75498722e-02,
         0.00000000e+00,   0.00000000e+00,   3.77744098e-03,
         2.09043195e-01,   0.00000000e+00,   0.00000000e+00,
        -3.63617503e-02,  -4.84984347e-01,   0.00000000e+00,
         0.00000000e+00,   9.80178012e-02,   5.40205143e-01,
         4.67451556e-01,   1.86980622e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.89913349e-04,   1.31873054e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.36170319e-02,
         2.10153620e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.23612089e-01,   4.29219142e-01,  -1.05239809e-04,
         4.33272196e-04,   1.49588527e-03,   5.93551384e-03,
         0.00000000e+00,   0.00000000e+00,  -5.29702062e-03,
        -1.01722097e-02,   0.00000000e+00,   0.00000000e+00,
         3.87404606e-02,   3.44727824e-02,   0.00000000e+00,
         0.00000000e+00,  -8.95355147e-02,  -6.89757008e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.23612089e-01,
         4.29219142e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.89913349e-04,   1.31873054e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.36170319e-02,
         2.10153620e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.23612089e-01,   4.29219142e-01,   1.65779186e-03,
         2.21163624e-03,   1.62390179e-02,   2.38681249e-02,
         0.00000000e+00,   0.00000000e+00,  -2.27689871e-02,
        -3.65217877e-02,   0.00000000e+00,   0.00000000e+00,
         6.69405952e-02,   1.70909996e-01,   0.00000000e+00,
         0.00000000e+00,  -1.31928684e-01,  -4.03471804e-01,
         0.00000000e+00,   0.00000000e+00,   9.43070757e-02,
         4.29823280e-01,   1.18017845e-01,   8.02880277e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.17945302e-03,   5.68062578e-06,   7.71962137e-03,
         7.16678973e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.60176785e-03,  -1.15057280e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.31604889e-03,   3.97179896e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.33232259e-04,   1.35384373e-04,   4.34498895e-03,
         1.41850465e-03,   0.00000000e+00,   0.00000000e+00,
        -1.94726383e-03,  -2.09585165e-03,   0.00000000e+00,
         0.00000000e+00,   1.23443259e-02,   7.87420517e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.25981345e-03,  -8.45653160e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.50887046e-03,
        -1.70621595e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.77656232e-05,   3.54566807e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.27945761e-03,   1.09017708e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.67767469e-04,   1.84487519e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.79400765e-03,
         4.37441936e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.43719322e-04,   2.97489808e-03,  -7.33469445e-03,
         2.97799922e-02,   0.00000000e+00,   0.00000000e+00,
         1.03568861e-02,  -4.27935624e-02,   0.00000000e+00,
         0.00000000e+00,  -2.87467375e-02,   1.62656561e-01,
         0.00000000e+00,   0.00000000e+00,   5.44549815e-02,
        -3.59094527e-01,   0.00000000e+00,   0.00000000e+00,
        -3.22983562e-02,   3.90960231e-01,  -7.17720403e-02,
         1.14552645e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.93222235e-05,   6.35584212e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.94521476e-03,   7.33529231e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.70525535e-04,   1.92480167e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.47988446e-03,   4.58137545e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.30167626e-02,   5.59983715e-01,
         4.88255892e-02,   3.45787914e-07,   1.02069643e-02,
         3.22551195e-05,   4.86463009e-02,   6.79040885e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.61770015e-02,   5.35504114e-05,
        -2.34307351e-03,  -7.45874800e-05,  -1.51286868e-02,
        -1.30711329e-03,   0.00000000e+00,   0.00000000e+00,
         5.34409235e-02,   2.39793623e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.61770015e-02,   5.35504114e-05,
         8.86775631e-03,   2.86414689e-04,   3.50424145e-02,
         4.17634442e-03,   0.00000000e+00,   0.00000000e+00,
        -1.28844659e-02,  -7.32617138e-03,   0.00000000e+00,
         0.00000000e+00,   4.04983040e-02,   2.58330798e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.17961842e-02,   2.41089476e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.47072471e-02,   1.89966587e-03,  -1.79215437e-04,
        -6.19739304e-04,  -7.15041300e-03,  -8.67595673e-03,
         0.00000000e+00,   0.00000000e+00,   2.52986218e-02,
         1.50297478e-02,   0.00000000e+00,   0.00000000e+00,
        -1.07636564e-02,  -5.42081439e-02,   0.00000000e+00,
         0.00000000e+00,   3.09561020e-02,   1.14080210e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.17961842e-02,
         2.41089476e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.47072471e-02,   1.89966587e-03,
        -1.73080006e-05,   6.92320022e-05,  -4.06000350e-04,
         1.64088932e-03,   0.00000000e+00,   0.00000000e+00,
         8.49339486e-04,  -3.46613529e-03,   0.00000000e+00,
         0.00000000e+00,  -3.73913361e-03,   1.78828407e-02,
         0.00000000e+00,   0.00000000e+00,   7.95190075e-03,
        -3.94052859e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.08903897e-04,
         4.36203467e-04,  -1.66629639e-03,   8.46525917e-03,
         0.00000000e+00,   0.00000000e+00,   2.89446676e-03,
        -1.67253996e-02,   0.00000000e+00,   0.00000000e+00,
        -7.86390369e-03,   7.17562738e-02,   0.00000000e+00,
         0.00000000e+00,   1.47761918e-02,  -1.52425066e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.93222235e-05,   6.35584212e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.94521476e-03,   7.33529231e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.76528410e-04,   3.10872681e-03,  -7.20965323e-03,
         3.27097603e-02,   0.00000000e+00,   0.00000000e+00,
         9.57390917e-03,  -4.87117205e-02,   0.00000000e+00,
         0.00000000e+00,  -2.55558828e-02,   1.74689089e-01,
         0.00000000e+00,   0.00000000e+00,   4.85885239e-02,
        -3.78070192e-01,   0.00000000e+00,   0.00000000e+00,
        -3.22983562e-02,   3.90960231e-01,  -7.17720403e-02,
         1.14552645e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.93222235e-05,   6.35584212e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.94521476e-03,   7.33529231e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.07976441e-04,   4.16226859e-04,   2.93429367e-03,
         8.86864714e-03,   0.00000000e+00,   0.00000000e+00,
        -3.77789174e-03,  -1.78788351e-02,   0.00000000e+00,
         0.00000000e+00,   2.42754491e-03,   7.51511009e-02,
         0.00000000e+00,   0.00000000e+00,   1.05253372e-03,
        -1.59061840e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.30167626e-02,   5.59983715e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.17945302e-03,   5.68062578e-06,
         7.71962137e-03,   7.16678973e-05,   0.00000000e+00,
         0.00000000e+00,  -2.60176785e-03,  -1.15057280e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.31604889e-03,   3.97179896e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.25981345e-03,  -8.45653160e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.33232259e-04,
         1.35384373e-04,   4.34498895e-03,   1.41850465e-03,
         0.00000000e+00,   0.00000000e+00,  -1.94726383e-03,
        -2.09585165e-03,   0.00000000e+00,   0.00000000e+00,
         1.23443259e-02,   7.87420517e-03,   0.00000000e+00,
         0.00000000e+00,  -7.50887046e-03,  -1.70621595e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.77656232e-05,   3.54566807e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.27945761e-03,   1.09017708e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.67767469e-04,   1.84487519e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.79400765e-03,
         4.37441936e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.93222235e-05,   6.35584212e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.94521476e-03,   7.33529231e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.43719322e-04,   2.97489808e-03,
        -7.33469445e-03,   2.97799922e-02,   0.00000000e+00,
         0.00000000e+00,   1.03568861e-02,  -4.27935624e-02,
         0.00000000e+00,   0.00000000e+00,  -2.87467375e-02,
         1.62656561e-01,   0.00000000e+00,   0.00000000e+00,
         5.44549815e-02,  -3.59094527e-01,   0.00000000e+00,
         0.00000000e+00,  -3.22983562e-02,   3.90960231e-01,
        -7.17720403e-02,   1.14552645e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.70525535e-04,   1.92480167e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.47988446e-03,   4.58137545e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.30167626e-02,   5.59983715e-01,
         3.72484223e-01,   3.43815510e-04,   7.76500324e-02,
         1.13795537e-03,   3.69991934e-01,   8.52225734e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.65349887e-01,   1.43802665e-03,
        -8.65546355e-03,  -1.26478695e-03,  -5.55233135e-02,
        -1.09231256e-02,   0.00000000e+00,   0.00000000e+00,
         3.80972106e-01,   1.48561295e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.65349887e-01,   1.43802665e-03,
         6.76516401e-02,   2.21926422e-03,   2.69966207e-01,
         2.03844851e-02,   0.00000000e+00,   0.00000000e+00,
        -4.82589170e-02,  -2.80382553e-02,   0.00000000e+00,
         0.00000000e+00,   3.50159175e-01,   6.94481341e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.78685186e-01,   2.44226877e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.34127743e-01,   1.01049943e-02,  -4.35655287e-04,
        -3.33204758e-03,  -2.66429516e-02,  -3.32931596e-02,
         0.00000000e+00,   0.00000000e+00,   1.84636484e-01,
         4.72213783e-02,   0.00000000e+00,   0.00000000e+00,
        -6.91705155e-02,  -1.28384998e-01,   0.00000000e+00,
         0.00000000e+00,   3.47507590e-01,   2.47443375e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.78685186e-01,
         2.44226877e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.34127743e-01,   1.01049943e-02,
        -2.77145284e-04,   1.10858114e-03,  -2.77181027e-03,
         1.11601674e-02,   0.00000000e+00,   0.00000000e+00,
         3.94272994e-03,  -1.60810048e-02,   0.00000000e+00,
         0.00000000e+00,  -2.78679584e-03,   5.87675525e-02,
         0.00000000e+00,   0.00000000e+00,  -6.06996137e-03,
        -1.28266387e-01,   0.00000000e+00,   0.00000000e+00,
         1.04075922e+00,   2.19667765e-01,  -1.10441514e-03,
         4.42140184e-03,  -9.44094874e-03,   4.44120982e-02,
         0.00000000e+00,   0.00000000e+00,   1.13273634e-02,
        -6.37988681e-02,   0.00000000e+00,   0.00000000e+00,
         6.40785464e-03,   2.19336188e-01,   0.00000000e+00,
         0.00000000e+00,  -5.42768508e-02,  -4.65593271e-01,
         0.00000000e+00,   0.00000000e+00,   1.27178936e-01,
         4.03525791e-01,   6.49546812e-01,   1.27495166e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.97212744e-04,   2.30345191e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.64137699e-02,   2.58666462e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.89029931e-01,   3.07916664e-01,
        -2.01822875e-04,   8.24066312e-04,   1.14146395e-03,
         1.03029109e-02,   0.00000000e+00,   0.00000000e+00,
        -5.50743429e-03,  -1.64952010e-02,   0.00000000e+00,
         0.00000000e+00,   4.33281207e-02,   4.24306403e-02,
         0.00000000e+00,   0.00000000e+00,  -1.00992451e-01,
        -7.74258528e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.89029931e-01,   3.07916664e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.97212744e-04,   2.30345191e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.64137699e-02,   2.58666462e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.89029931e-01,   3.07916664e-01,
         1.50875351e-03,   6.03501403e-03,   1.48997171e-02,
         5.95988685e-02,   0.00000000e+00,   0.00000000e+00,
        -2.11150962e-02,  -8.44603849e-02,   0.00000000e+00,
         0.00000000e+00,   6.80839998e-02,   2.72335999e-01,
         0.00000000e+00,   0.00000000e+00,  -1.40406511e-01,
        -5.61626045e-01,   0.00000000e+00,   0.00000000e+00,
         9.87584829e-02,   3.95033932e-01,   3.39519271e-01,
         1.35807708e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.95925546e-01,   7.83702183e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.65368177e-03,   4.00084331e-02,  -1.89821483e-03,
         9.72065333e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.57189652e-04,  -2.17465941e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.03603382e-03,   9.53421925e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.72081494e-02,   1.08992815e-01,  -5.58778161e-03,
         2.29925580e-02,   0.00000000e+00,   0.00000000e+00,
         6.14034504e-04,  -2.54854316e-03,   0.00000000e+00,
         0.00000000e+00,  -4.90742373e-03,   2.02669766e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.14034504e-04,  -2.54854316e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.56756365e-04,
        -6.77534587e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.81937552e-06,   2.72776442e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.52359030e-07,   3.85943781e-06,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.85281109e-04,   7.41470649e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.54706901e-05,
         1.05159142e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.43232709e-02,   1.77293086e-01,  -9.27297977e-03,
         3.70923093e-02,   0.00000000e+00,   0.00000000e+00,
         1.01489594e-03,  -4.06045063e-03,   0.00000000e+00,
         0.00000000e+00,  -8.11362933e-03,   3.24601496e-02,
         0.00000000e+00,   0.00000000e+00,   1.40170332e-04,
        -5.74512067e-04,   0.00000000e+00,   0.00000000e+00,
         1.53276624e-06,   1.20062622e-10,   9.58641451e-06,
         4.44343591e-07,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.51574266e-05,   3.41636218e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.12040383e-05,   4.94631887e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.49684976e-06,   1.98031116e-06,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.61281761e-04,   2.72600506e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.88877520e-04,   1.21852241e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.49073763e-04,   1.43319607e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.32302116e-02,   1.72924890e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.54533205e-04,
         8.72570803e-03,  -3.82543791e-03,   4.35591612e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.10422082e-04,  -1.13569778e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.40511072e-03,   3.93494085e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.52519810e-03,
         2.29424912e-02,  -2.46353612e-02,   1.11452000e-01,
         0.00000000e+00,   0.00000000e+00,   3.32510461e-03,
        -1.80630646e-02,   0.00000000e+00,   0.00000000e+00,
        -1.69475396e-02,   8.69304047e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.32510461e-03,
        -1.80630646e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.83210657e-03,  -1.77806237e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.47766603e-05,   1.79121748e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.64941325e-05,
         1.10955920e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.22536905e-03,
         4.93200427e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.38871283e-04,   3.28586471e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.27309436e-03,
         3.70924010e-02,  -4.43165568e-02,   1.77301182e-01,
         0.00000000e+00,   0.00000000e+00,   6.63460479e-03,
        -2.66221460e-02,   0.00000000e+00,   0.00000000e+00,
        -3.26688508e-02,   1.31243210e-01,   0.00000000e+00,
         0.00000000e+00,   3.71750181e-03,  -1.62577411e-02,
         0.00000000e+00,   0.00000000e+00,   1.46224847e-04,
         1.34966780e-05,   7.18265232e-04,   8.84961210e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.83946861e-04,   2.41731937e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.15793727e-04,
         2.13825800e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.09688007e-04,   1.84862087e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.99780303e-03,   1.80452829e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.42969811e-03,
         1.73938135e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.69034421e-03,   1.42924417e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.80801708e-02,
         7.23673663e-02,  -4.30821171e-02,   1.73073418e-01,
         3.94857934e-02,   6.96853019e-04,   7.67904895e-03,
         2.05884231e-03,   3.29626326e-02,   1.41287048e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.89851018e-02,   7.59404074e-02,
        -7.93878479e-04,  -1.17380491e-03,  -3.72666108e-03,
        -7.80731125e-03,   0.00000000e+00,   0.00000000e+00,
         3.46192020e-02,   6.02915943e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.39216274e-02,   3.23886101e-03,
         6.54056824e-03,   2.67293760e-03,   2.11816407e-02,
         1.88800074e-02,   0.00000000e+00,   0.00000000e+00,
        -2.41135488e-03,  -8.79973233e-03,   0.00000000e+00,
         0.00000000e+00,   2.35935231e-02,   2.36795879e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.44474809e-02,   1.26658669e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.60966029e-03,   1.07966863e-01,   4.53733085e-04,
        -2.42030202e-03,   1.30858229e-03,  -1.64498467e-02,
         0.00000000e+00,   0.00000000e+00,   1.45044591e-02,
         7.52435102e-03,   0.00000000e+00,   0.00000000e+00,
        -3.55456726e-04,  -1.73110363e-02,   0.00000000e+00,
         0.00000000e+00,   2.22239281e-02,   9.49818236e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.47854889e-02,
         2.83897465e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.23733172e-02,   3.01911560e-03,
        -6.81941994e-06,   2.72776798e-05,  -4.43252053e-05,
         1.78760584e-04,   0.00000000e+00,   0.00000000e+00,
         1.36686660e-05,  -6.08252513e-05,   0.00000000e+00,
         0.00000000e+00,   1.70220422e-04,   1.71527487e-04,
         0.00000000e+00,   0.00000000e+00,  -6.64112899e-04,
        -5.76004760e-05,   0.00000000e+00,   0.00000000e+00,
         1.86932751e-02,   1.72820284e-07,  -1.85272718e-04,
         7.41463936e-04,  -1.14206555e-03,   4.86536147e-03,
         0.00000000e+00,   0.00000000e+00,   2.25074695e-04,
        -1.66406699e-03,   0.00000000e+00,   0.00000000e+00,
         3.90927273e-04,   4.69701831e-03,   0.00000000e+00,
         0.00000000e+00,  -3.70013435e-03,  -1.62845823e-03,
         0.00000000e+00,   0.00000000e+00,   4.01290856e-03,
         3.09624327e-06,   1.86605132e-02,   1.14728113e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.36683372e-02,   1.74818094e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.06960210e-02,   8.62223938e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.82670262e-02,   7.87451818e-04,
        -8.49459853e-05,   3.41467065e-04,  -3.80030667e-04,
         2.25418641e-03,   0.00000000e+00,   0.00000000e+00,
        -1.79146861e-04,  -1.04234712e-03,   0.00000000e+00,
         0.00000000e+00,   1.23086056e-03,   2.22917838e-03,
         0.00000000e+00,   0.00000000e+00,  -3.61915432e-03,
        -1.10576560e-03,   0.00000000e+00,   0.00000000e+00,
         4.64056695e-04,   4.90535376e-06,   2.90028730e-03,
         1.48763062e-04,   0.00000000e+00,   0.00000000e+00,
         1.92433244e-02,   1.53257591e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.99875175e-05,   2.54616957e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.72395714e-04,   2.44832786e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.83110453e-02,   1.86159810e-05,
        -2.87685686e-04,   2.42712820e-03,  -1.61853974e-03,
         1.61418722e-02,   0.00000000e+00,   0.00000000e+00,
        -1.58947777e-03,  -5.68110558e-03,   0.00000000e+00,
         0.00000000e+00,   2.08096091e-03,   1.62147944e-02,
         0.00000000e+00,   0.00000000e+00,  -8.42465280e-03,
        -6.55086273e-03,   0.00000000e+00,   0.00000000e+00,
         3.42488203e-03,   2.75400608e-05,   1.34684519e-02,
         8.33011038e-04,   0.00000000e+00,   0.00000000e+00,
         2.61932055e-03,   6.37199052e-04,   0.00000000e+00,
         0.00000000e+00,   1.74442143e-02,   4.17179155e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.23195969e-02,   1.72437739e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.93878479e-04,  -1.17380491e-03,  -3.72666108e-03,
        -7.80731125e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.77068818e-03,   3.91410716e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.41135488e-03,  -8.79973233e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.53733085e-04,  -2.42030202e-03,   1.30858229e-03,
        -1.64498467e-02,   0.00000000e+00,   0.00000000e+00,
        -2.60066689e-02,   1.11031840e-01,   0.00000000e+00,
         0.00000000e+00,  -3.55456726e-04,  -1.73110363e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.78836054e-03,   2.21586067e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.21408778e-02,
         5.89529406e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.55821032e-05,  -6.23560010e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.45655611e-05,  -6.70671046e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.47866344e-04,  -1.84230031e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.68561538e-04,
        -2.44958193e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.01515886e-03,  -4.06066097e-03,   6.64255607e-03,
        -2.66285071e-02,   0.00000000e+00,   0.00000000e+00,
        -4.56776723e-02,   1.82853510e-01,   0.00000000e+00,
         0.00000000e+00,   6.16243227e-03,  -2.56392899e-02,
         0.00000000e+00,   0.00000000e+00,  -2.28622118e-02,
         9.38678959e-02,   0.00000000e+00,   0.00000000e+00,
        -2.48227786e-04,  -5.42516756e-05,  -1.00373343e-03,
        -2.50387991e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.29135764e-04,  -1.44897322e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.18131638e-04,  -2.89995195e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.46876859e-04,  -4.84662579e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.43516242e-03,  -8.10081773e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.54530788e-03,  -1.53268313e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.61032273e-03,  -2.04988678e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.76047318e-03,  -7.08015499e-03,   1.12335930e-02,
        -4.66852056e-02,   0.00000000e+00,   0.00000000e+00,
        -4.39501089e-02,   1.76983387e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.46826279e-03,
         3.63507732e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.57256391e-02,   1.06346464e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.50733072e-03,   1.74732304e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.19914887e-02,
         5.24738738e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.35678535e-02,   1.74276453e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.13827420e-02,   8.55829153e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.04962018e-05,
         2.87023905e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.56746303e-05,   3.94645717e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.20095426e-05,
         3.84417919e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.25353490e-02,   1.70328969e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.36335700e-04,   7.55632363e-03,   5.61429503e-03,
         3.13338839e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.88280039e-03,  -9.22257592e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.50149045e-03,   4.13532140e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.69982525e-03,   2.01008979e-02,  -1.37311911e-02,
         8.43573259e-02,   0.00000000e+00,   0.00000000e+00,
         1.50291969e-03,  -1.87977374e-02,   0.00000000e+00,
         0.00000000e+00,  -1.35439791e-02,   1.19185871e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.50291969e-03,  -1.87977374e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.68245152e-03,
        -4.50910663e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.60777410e-05,   3.84566017e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.04402057e-04,   1.71434989e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.51309143e-03,   6.22023327e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.56211083e-03,
         1.82227015e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.11537769e-03,   3.24615482e-02,  -3.27858412e-02,
         1.31336802e-01,   0.00000000e+00,   0.00000000e+00,
         6.30924617e-03,  -2.57567410e-02,   0.00000000e+00,
         0.00000000e+00,  -4.28883166e-02,   1.78543217e-01,
         0.00000000e+00,   0.00000000e+00,   8.74261354e-03,
        -5.35858490e-02,   0.00000000e+00,   0.00000000e+00,
         1.21066752e-03,   7.36903016e-03,   6.80040966e-03,
         4.03929134e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.81685812e-04,   3.91921548e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.24702636e-03,   1.33047964e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.41001714e-03,   2.98021231e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.85309145e-03,   2.09620363e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.22706378e-03,   5.58702605e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.05446209e-03,   7.89957210e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.58165820e-02,   6.33379209e-02,  -6.31623651e-02,
         2.56824913e-01,   0.00000000e+00,   0.00000000e+00,
         9.94981014e-03,  -4.56455224e-02,   0.00000000e+00,
         0.00000000e+00,  -4.05053699e-02,   1.75065863e-01,
         1.08932734e-01,   8.01087529e-05,   2.26894377e-02,
         3.70782594e-04,   1.06610542e-01,   6.45527756e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.00832889e-01,   3.44343727e-02,
        -2.35358981e-03,  -1.74443706e-04,  -1.42605499e-02,
        -3.99454092e-03,   0.00000000e+00,   0.00000000e+00,
         1.08404904e-01,   3.50258229e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.05054999e-01,   1.72195376e-03,
         1.98203975e-02,   4.84719655e-04,   7.65364639e-02,
         1.21432019e-02,   0.00000000e+00,   0.00000000e+00,
        -1.21445890e-02,  -7.87973045e-03,   0.00000000e+00,
         0.00000000e+00,   9.48071381e-02,   3.25049773e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.41420598e-02,   7.93654872e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.94256265e-02,   1.97702506e-01,  -2.50918650e-04,
        -3.51394575e-04,  -6.26447154e-03,  -1.05033612e-02,
         0.00000000e+00,   0.00000000e+00,   5.23672373e-02,
         7.34644855e-03,   0.00000000e+00,   0.00000000e+00,
        -1.47615711e-02,  -3.11358482e-02,   0.00000000e+00,
         0.00000000e+00,   9.41696057e-02,   2.99548475e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.03051817e-02,
         2.63653754e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.87092870e-02,   8.11357274e-03,
        -9.67984557e-07,   3.87193823e-06,  -2.52042783e-05,
         1.09924037e-04,   0.00000000e+00,   0.00000000e+00,
         5.29078435e-06,  -5.96472832e-05,   0.00000000e+00,
         0.00000000e+00,   1.28576359e-03,   3.62217369e-04,
         0.00000000e+00,   0.00000000e+00,  -4.30138961e-03,
        -3.53667856e-04,   0.00000000e+00,   0.00000000e+00,
         1.21756624e-01,   1.03419081e-04,  -2.61648184e-05,
         1.05714445e-04,  -4.22532213e-04,   3.03279346e-03,
         0.00000000e+00,   0.00000000e+00,  -4.75462258e-04,
        -1.69436290e-03,   0.00000000e+00,   0.00000000e+00,
         6.76504429e-03,   9.96097735e-03,   0.00000000e+00,
         0.00000000e+00,  -2.24963789e-02,  -9.56701277e-03,
         0.00000000e+00,   0.00000000e+00,   2.60189461e-02,
         4.52998113e-04,   1.19126546e-01,   7.20290271e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.15574351e-02,   8.69115251e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.69182168e-02,   1.69342545e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.13595758e-01,   3.84125712e-02,
        -1.11738904e-05,   4.94390704e-05,   4.21221718e-04,
         1.46864564e-03,   0.00000000e+00,   0.00000000e+00,
        -1.68535423e-03,  -1.13716326e-03,   0.00000000e+00,
         0.00000000e+00,   8.39924108e-03,   4.78778248e-03,
         0.00000000e+00,   0.00000000e+00,  -1.98864242e-02,
        -5.67275437e-03,   0.00000000e+00,   0.00000000e+00,
         2.15842027e-03,   1.48468299e-04,   1.27118380e-02,
         3.24148982e-03,   0.00000000e+00,   0.00000000e+00,
         1.20028511e-01,   3.11743715e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.39552405e-05,   2.50941820e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.64120092e-03,   1.34980811e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.17753400e-01,   2.07651935e-03,
         7.89138068e-04,   3.56109936e-04,   5.43823618e-03,
         1.02994661e-02,   0.00000000e+00,   0.00000000e+00,
        -9.25531474e-03,  -5.88633318e-03,   0.00000000e+00,
         0.00000000e+00,   2.04754430e-02,   3.29082551e-02,
         0.00000000e+00,   0.00000000e+00,  -4.55307880e-02,
        -3.01199165e-02,   0.00000000e+00,   0.00000000e+00,
         2.22061268e-02,   5.71960592e-04,   8.46437601e-02,
         1.32665629e-02,   0.00000000e+00,   0.00000000e+00,
         1.08068802e-02,   6.51840102e-03,   0.00000000e+00,
         0.00000000e+00,   1.05981167e-01,   3.57530776e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.84512780e-02,   1.75328494e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.05925678e-02,   1.78171837e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.35358981e-03,
        -1.74443706e-04,  -1.42605499e-02,  -3.99454092e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.23885037e-03,   1.81368380e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.21445890e-02,  -7.87973045e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.50918650e-04,
        -3.51394575e-04,  -6.26447154e-03,  -1.05033612e-02,
         0.00000000e+00,   0.00000000e+00,  -9.45121052e-03,
         5.68012068e-02,   0.00000000e+00,   0.00000000e+00,
        -1.47615711e-02,  -3.11358482e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.58780004e-03,
         2.93475649e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.41815116e-02,   1.16635741e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.83835364e-04,  -7.35959087e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.10961879e-03,
        -4.68247457e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.33651518e-03,
        -5.65777785e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.83124574e-03,  -3.22291125e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.44478441e-04,
        -5.77958554e-04,   4.03869362e-03,  -1.65146945e-02,
         0.00000000e+00,   0.00000000e+00,  -2.33072684e-02,
         9.42239412e-02,   0.00000000e+00,   0.00000000e+00,
         9.63022999e-03,  -5.42959421e-02,   0.00000000e+00,
         0.00000000e+00,  -4.22120713e-02,   2.11688129e-01,
         0.00000000e+00,   0.00000000e+00,  -1.93672887e-03,
        -2.35341314e-02,  -1.32743197e-02,  -1.14572827e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.03101697e-03,  -4.82590263e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.95883486e-03,
        -2.47489616e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.54623041e-03,  -6.72140296e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.71464594e-03,  -1.46623017e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.52997913e-03,
        -7.25685302e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.82265261e-03,  -1.74378561e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.35689530e-04,
        -1.01954655e-03,   5.88425515e-03,  -2.94734689e-02,
         0.00000000e+00,   0.00000000e+00,  -4.31444787e-02,
         1.81627224e-01,   0.00000000e+00,   0.00000000e+00,
         1.19813395e-02,  -9.61542469e-02,   0.00000000e+00,
         0.00000000e+00,  -3.76513058e-02,   1.98600711e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.11105460e-03,   1.63562095e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.15132661e-02,
         5.20912958e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.64985566e-03,   2.46376539e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.96418303e-02,   9.47944665e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.13903783e-02,
         8.55890244e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.02515316e-02,   1.61883660e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.61011968e-04,   1.07155893e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.30788612e-03,
         6.10907774e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.07882102e-03,   1.81680259e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.17018722e-02,
         1.67703526e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.91064011e-02,   1.59842027e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.72776353e-05,   3.55362233e-11,   1.78664628e-04,
         3.68717554e-07,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.04322182e-05,  -1.54454384e-06,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.18172209e-04,   2.13166057e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.85631270e-06,   1.25004221e-08,   1.07798795e-04,
         3.52157837e-06,   0.00000000e+00,   0.00000000e+00,
        -5.44905053e-05,  -1.18222515e-05,   0.00000000e+00,
         0.00000000e+00,  -1.20938842e-05,   1.40050335e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.12220788e-04,  -6.78667426e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.20033608e-04,
        -4.45080643e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.67326476e-03,   1.86934047e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.04068374e-02,   1.21834188e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.00085144e-03,   4.01410424e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.33481654e-03,
         2.63360082e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.83079000e-07,   1.53279625e-06,  -3.66327745e-05,
         1.59782775e-04,   0.00000000e+00,   0.00000000e+00,
         6.54339272e-05,  -3.05181047e-04,   0.00000000e+00,
         0.00000000e+00,  -1.87545352e-03,   9.83792699e-03,
         0.00000000e+00,   0.00000000e+00,   5.60356758e-03,
        -2.95663685e-02,   0.00000000e+00,   0.00000000e+00,
        -1.48687482e-01,   6.30088539e-01,  -2.67916296e-02,
         1.59051506e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.11613156e-04,   4.65441235e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.25989121e-04,   2.21599581e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.30939617e-04,   3.43219738e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.26920916e-03,   2.25522293e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.67651619e-02,   1.40544070e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.59825043e-07,   2.13100057e-07,   1.24428308e-05,
         3.33943692e-05,   0.00000000e+00,   0.00000000e+00,
        -1.38905001e-05,  -8.99031350e-05,   0.00000000e+00,
         0.00000000e+00,  -1.72865904e-03,   8.59093471e-03,
         0.00000000e+00,   0.00000000e+00,   5.74023765e-03,
        -2.72409276e-02,   0.00000000e+00,   0.00000000e+00,
        -9.19664312e-02,   3.69841572e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.41332428e-04,
         1.79818935e-07,   4.83725274e-03,   8.19068364e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.60044556e-03,  -2.03650787e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.25326424e-03,   1.60714874e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.04624627e-04,
         1.08288826e-06,   2.84563330e-03,   4.18261046e-04,
         0.00000000e+00,   0.00000000e+00,  -1.28980722e-03,
        -1.04288693e-03,   0.00000000e+00,   0.00000000e+00,
         6.40519953e-03,   1.02488532e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.04234405e-04,
        -4.18517818e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.62439248e-04,  -2.71141645e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.00366769e-03,   4.01635725e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.39153268e-03,
         2.63813811e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.62927576e-03,
         1.87465593e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.75307294e-02,   1.24528723e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.53138241e-06,
         1.01385811e-05,  -3.71876508e-04,   1.75707460e-03,
         0.00000000e+00,   0.00000000e+00,   7.74316339e-04,
        -3.92631972e-03,   0.00000000e+00,   0.00000000e+00,
        -5.81778577e-03,   5.04874697e-02,   0.00000000e+00,
         0.00000000e+00,   1.40617550e-02,  -1.36441687e-01,
         0.00000000e+00,   0.00000000e+00,  -7.57003510e-03,
         1.43674230e-01,  -4.98806077e-02,   6.67933984e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.33717740e-04,   2.97596710e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.34888123e-03,
         1.44900652e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.72522477e-03,   1.37879523e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.53679058e-02,
         9.32758956e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.40985453e-02,   5.21363242e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.13347130e-06,
         6.63334993e-06,   8.20069481e-05,   1.88468830e-03,
         0.00000000e+00,   0.00000000e+00,   2.06276212e-04,
        -4.61388092e-03,   0.00000000e+00,   0.00000000e+00,
        -5.11387490e-03,   5.65905954e-02,   0.00000000e+00,
         0.00000000e+00,   1.66292683e-02,  -1.54015866e-01,
         0.00000000e+00,   0.00000000e+00,  -3.67234311e-02,
         1.62101718e-01,  -7.18126246e-02,   3.87047334e-01,
         1.77293085e-01,   1.10525566e-09,   3.70922775e-02,
         1.03426231e-07,   1.77288074e-01,   1.74773750e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.74763815e-01,   7.23725413e-05,
        -4.06038847e-03,  -2.23100354e-07,  -2.65986997e-02,
        -3.55024152e-05,   0.00000000e+00,   0.00000000e+00,
         1.82799952e-01,   7.14105147e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.74274563e-01,   2.51954879e-06,
         3.24597858e-02,   1.41742658e-06,   1.31147273e-01,
         1.90311132e-04,   0.00000000e+00,   0.00000000e+00,
        -2.54150185e-02,  -3.77329307e-04,   0.00000000e+00,
         0.00000000e+00,   1.75921985e-01,   3.49497524e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.57944417e-02,   1.03002373e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.61216416e-01,   1.08348391e-02,  -5.73633648e-04,
        -3.46888277e-06,  -1.60585327e-02,  -4.36913469e-04,
         0.00000000e+00,   0.00000000e+00,   9.34058092e-02,
         8.53479145e-04,   0.00000000e+00,   0.00000000e+00,
        -4.74926924e-02,  -8.59760424e-03,   0.00000000e+00,
         0.00000000e+00,   1.95623187e-01,   2.14199217e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.55710714e-02,
         1.98645641e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.61554585e-01,   4.38766625e-04,
        -3.83229079e-07,   1.53291631e-06,  -2.80442254e-05,
         1.52911936e-04,   0.00000000e+00,   0.00000000e+00,
         2.47726688e-05,  -2.72652040e-04,   0.00000000e+00,
         0.00000000e+00,   5.87576361e-03,   3.63695329e-03,
         0.00000000e+00,   0.00000000e+00,  -1.93440353e-02,
        -9.60828626e-03,   0.00000000e+00,   0.00000000e+00,
         6.16836559e-01,   1.76693062e-02,  -1.98411010e-06,
         9.70076327e-06,   5.65844648e-04,   1.00689768e-03,
         0.00000000e+00,   0.00000000e+00,  -1.83737456e-03,
        -1.83696700e-03,   0.00000000e+00,   0.00000000e+00,
         2.76631518e-02,   2.37027197e-02,   0.00000000e+00,
         0.00000000e+00,  -7.90326121e-02,  -6.19661932e-02,
         0.00000000e+00,   0.00000000e+00,   1.20373041e-01,
         4.13197693e-02,   4.92279652e-01,   2.34205777e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.32067785e-03,   1.88576151e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.63950110e-02,   1.42405186e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.94431723e-01,   1.17772689e+00,
         1.23007906e-06,   2.99372772e-06,   1.70444093e-03,
         3.97317721e-04,   0.00000000e+00,   0.00000000e+00,
        -4.51206926e-03,  -7.99468895e-04,   0.00000000e+00,
         0.00000000e+00,   2.66630937e-02,   5.74363441e-03,
         0.00000000e+00,   0.00000000e+00,  -6.01137759e-02,
        -1.22860246e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.11916622e-01,   6.15574591e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.54259196e-04,   8.34029276e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.62544050e-02,   3.50144514e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.11916622e-01,   6.15574591e-02,
         1.43087685e-03,   9.23557921e-06,   1.39101728e-02,
         1.01202814e-03,   0.00000000e+00,   0.00000000e+00,
        -1.96488554e-02,  -1.89152523e-03,   0.00000000e+00,
         0.00000000e+00,   6.32607229e-02,   2.43435730e-02,
         0.00000000e+00,   0.00000000e+00,  -1.30653806e-01,
        -6.35973940e-02,   0.00000000e+00,   0.00000000e+00,
         1.03665488e-01,   3.61995496e-02,   3.25817992e-01,
         2.25430013e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.67126709e-01,   2.29057018e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.51456233e-03,   9.57050679e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.77311056e-02,   8.82544923e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.05224525e-03,   5.05671679e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.41047335e-04,   6.72408777e-07,   2.18282870e-03,
         2.03898917e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.91029283e-04,  -4.72841183e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.65949202e-03,   1.88627322e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.76904025e-05,   2.34763609e-06,   1.12308639e-03,
         9.07153900e-04,   0.00000000e+00,   0.00000000e+00,
        -3.86181565e-04,  -2.17650139e-03,   0.00000000e+00,
         0.00000000e+00,   1.03976987e-03,   1.06753594e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.74566883e-05,  -4.07105440e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.43890578e-03,
        -2.35330184e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.17349345e-04,   4.70030186e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.60428327e-04,   2.32354718e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.23448997e-04,   3.04775210e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.98110664e-03,
         1.57958456e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.24080947e-06,   4.97043854e-06,  -4.94208882e-04,
         2.15623757e-03,   0.00000000e+00,   0.00000000e+00,
         1.20948971e-03,  -5.37671607e-03,   0.00000000e+00,
         0.00000000e+00,  -6.33175819e-03,   3.21395159e-02,
         0.00000000e+00,   0.00000000e+00,   1.38318921e-02,
        -7.14425590e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.76293810e-03,   1.93582676e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.90329286e-02,   1.22366589e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.08742449e-01,   5.58084716e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.47514404e-04,   3.01066701e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.37900185e-03,   1.62671067e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.14474604e-06,   6.56567510e-06,  -5.20334693e-04,
         3.32853945e-03,   0.00000000e+00,   0.00000000e+00,
         1.50775560e-03,  -8.30285398e-03,   0.00000000e+00,
         0.00000000e+00,  -8.26748940e-03,   4.52850461e-02,
         0.00000000e+00,   0.00000000e+00,   1.89370516e-02,
        -9.97373567e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.24626276e-02,   3.59812836e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.44625559e-04,
         3.49264962e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.95535648e-04,   1.69677494e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.78346021e-05,   8.40481676e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.69084269e-04,
         5.19803626e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.02993226e-04,   4.49204865e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.85997825e-03,   1.95929517e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.57194382e-03,
         1.83250073e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.87894377e-02,   1.19310790e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.08742449e-01,
         5.58084716e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.07691309e-04,   6.93127115e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.04004233e-03,   2.76067544e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.24626276e-02,   3.59812836e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.32207973e-03,   3.39315869e-04,   1.48957430e-02,
         2.93044600e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.19111452e-03,  -3.59979618e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.29468575e-02,   7.52207713e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.16877196e-04,   8.93918633e-04,   7.14774634e-03,
         8.93185798e-03,   0.00000000e+00,   0.00000000e+00,
        -1.59660874e-03,  -1.20132980e-02,   0.00000000e+00,
         0.00000000e+00,   1.85570017e-02,   3.44430081e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.59660874e-03,  -1.20132980e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.58953294e-03,
        -6.36729206e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.64288862e-04,   3.45887678e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.47637886e-03,   2.27179651e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.48836927e-03,   1.43984679e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.86623725e-02,
         9.59114689e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.60592423e-04,   1.44241099e-03,  -3.63222460e-03,
         1.50459461e-02,   0.00000000e+00,   0.00000000e+00,
         5.03190171e-03,  -2.16361309e-02,   0.00000000e+00,
         0.00000000e+00,  -1.13611662e-02,   8.40410843e-02,
         0.00000000e+00,   0.00000000e+00,   1.77558790e-02,
        -1.82325142e-01,   0.00000000e+00,   0.00000000e+00,
        -2.44286386e-03,   1.21086231e-01,   2.20833076e-02,
         4.68417760e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.63896463e-04,   3.18377266e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.95623802e-05,   1.51242553e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.05736871e-03,   2.05730579e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.53224551e-02,   1.32795976e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.02013591e-02,   5.38919473e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.81857898e-04,   2.80234868e-03,  -5.43613987e-03,
         2.81154377e-02,   0.00000000e+00,   0.00000000e+00,
         7.26392495e-03,  -3.92468250e-02,   0.00000000e+00,
         0.00000000e+00,  -1.43032912e-02,   1.38456393e-01,
         0.00000000e+00,   0.00000000e+00,   2.53808972e-02,
        -2.86009472e-01,   0.00000000e+00,   0.00000000e+00,
        -3.10296369e-02,   1.39237407e-01,  -7.85641161e-02,
         5.91128257e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.26542576e-02,   3.91851091e-01,
         3.45846747e-01,   4.04314990e-06,   7.23498601e-02,
         2.33415835e-05,   3.45588124e-01,   7.44949814e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.42505965e-01,   3.15935159e-03,
        -7.06580664e-03,  -1.91311334e-05,  -4.60286430e-02,
        -8.75416870e-04,   0.00000000e+00,   0.00000000e+00,
         3.53079561e-01,   1.18295156e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.40517258e-01,   1.87573022e-04,
         6.33110736e-02,   3.57963919e-05,   2.55259118e-01,
         2.08772641e-03,   0.00000000e+00,   0.00000000e+00,
        -4.34531667e-02,  -2.92314092e-03,   0.00000000e+00,
         0.00000000e+00,   3.40348439e-01,   1.30443837e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.67257226e-01,   1.07616909e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.14492500e-01,   5.58015661e-02,  -9.90750886e-04,
        -3.83942145e-05,  -2.72473008e-02,  -2.96822414e-03,
         0.00000000e+00,   0.00000000e+00,   1.78233733e-01,
         4.52465475e-03,   0.00000000e+00,   0.00000000e+00,
        -7.80684136e-02,  -2.41144445e-02,   0.00000000e+00,
         0.00000000e+00,   3.61204806e-01,   4.79954877e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.67367512e-01,
         4.48018703e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.17121736e-01,   3.41642241e-03,
        -1.06550029e-07,   4.26200115e-07,   2.20723452e-06,
         4.15828462e-05,   0.00000000e+00,   0.00000000e+00,
        -3.53537092e-05,  -7.27325678e-05,   0.00000000e+00,
         0.00000000e+00,   7.96232275e-03,   8.38149282e-04,
         0.00000000e+00,   0.00000000e+00,  -2.56359362e-02,
        -2.13998848e-03,   0.00000000e+00,   0.00000000e+00,
         7.38201258e-01,   1.97584703e-03,  -2.05436325e-06,
         1.15836176e-05,   1.05491977e-03,   1.10635805e-03,
         0.00000000e+00,   0.00000000e+00,  -3.19308989e-03,
        -1.89438804e-03,   0.00000000e+00,   0.00000000e+00,
         4.30399345e-02,   1.80675479e-02,   0.00000000e+00,
         0.00000000e+00,  -1.21203819e-01,  -4.37493962e-02,
         0.00000000e+00,   0.00000000e+00,   1.56398720e-01,
         7.60399659e-03,   6.99247042e-01,   9.97968363e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.79027675e-03,   1.78143780e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.43760071e-03,   1.19589457e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.28932862e-01,   5.09880660e-01,
         2.38642788e-06,   5.57232962e-06,   2.86083919e-03,
         6.23600339e-04,   0.00000000e+00,   0.00000000e+00,
        -7.45091714e-03,  -1.13591579e-03,   0.00000000e+00,
         0.00000000e+00,   4.07043879e-02,   6.10754425e-03,
         0.00000000e+00,   0.00000000e+00,  -9.07414253e-02,
        -1.19945752e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.97153927e-01,   2.99623251e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.94741410e-04,   1.31180940e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.48142850e-02,   3.72329253e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.97153927e-01,   2.99623251e-02,
         2.77425477e-03,   3.74585457e-05,   2.57263584e-02,
         3.18543913e-03,   0.00000000e+00,   0.00000000e+00,
        -3.54251531e-02,  -5.09556260e-03,   0.00000000e+00,
         0.00000000e+00,   1.07990183e-01,   4.06216142e-02,
         0.00000000e+00,   0.00000000e+00,  -2.16827266e-01,
        -9.22429417e-02,   0.00000000e+00,   0.00000000e+00,
         1.33567835e-01,   7.55942954e-03,   4.87301335e-01,
         1.38435896e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.87776637e-01,   2.61234061e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.59786513e-03,   3.43914605e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.64257588e-02,   2.25703035e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.81512026e-01,   7.26048103e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.60005862e-01,   6.40023449e-01,   4.79714281e-02,
         1.91885713e-01,  -4.10034282e-02,   2.20380205e-01,
         1.93510029e-02,   8.45399593e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.79359442e-02,   1.87097050e-02,   4.47479715e-02,
        -1.87020471e-01,   8.41618523e-03,  -4.57626988e-02,
         0.00000000e+00,   0.00000000e+00,   3.61781628e-02,
         2.73719995e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.79359442e-02,   1.87097050e-02,  -5.83896594e-02,
         2.91132380e-01,   3.34684529e-03,   9.42999416e-02,
         0.00000000e+00,   0.00000000e+00,   8.60463855e-03,
        -4.23236017e-02,   0.00000000e+00,   0.00000000e+00,
         1.22433721e-03,   1.00389569e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.35432942e-02,   6.46518498e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.76984487e-02,
         1.45755430e-03,   6.91702698e-02,  -2.77601638e-01,
         1.38438458e-02,  -5.90103416e-02,   0.00000000e+00,
         0.00000000e+00,   1.21108827e-02,   1.26276943e-02,
         0.00000000e+00,   0.00000000e+00,   1.20895757e-02,
        -5.19648826e-02,   0.00000000e+00,   0.00000000e+00,
         1.73647439e-02,   3.02752266e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.35432942e-02,   6.46518498e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.76984487e-02,   1.45755430e-03,  -2.81962687e-04,
         1.12785075e-03,  -5.87832405e-05,   2.35962855e-04,
         0.00000000e+00,   0.00000000e+00,   1.27641928e-05,
        -5.45552885e-05,   0.00000000e+00,   0.00000000e+00,
         7.04819095e-05,   2.06495327e-04,   0.00000000e+00,
         0.00000000e+00,  -3.87048979e-04,  -7.71887561e-06,
         0.00000000e+00,   0.00000000e+00,   1.07391427e-02,
        -0.00000000e+00,  -7.66335196e-03,   3.06539346e-02,
        -1.55943350e-03,   6.41373275e-03,   0.00000000e+00,
         0.00000000e+00,   2.59706833e-04,  -1.48330880e-03,
         0.00000000e+00,   0.00000000e+00,  -5.14300816e-04,
         5.61301897e-03,   0.00000000e+00,   0.00000000e+00,
        -2.28289701e-03,  -2.10548188e-04,   0.00000000e+00,
         0.00000000e+00,   2.30583930e-03,   3.39522458e-09,
         1.07390966e-02,   1.84540349e-07,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.52097905e-05,   3.41243250e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.69195248e-04,
         4.82968528e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.05832869e-02,   3.60032652e-09,  -4.78499005e-02,
         1.91402038e-01,  -9.90040481e-03,   4.00462659e-02,
         0.00000000e+00,   0.00000000e+00,   1.01128537e-03,
        -5.08656671e-03,   0.00000000e+00,   0.00000000e+00,
        -7.75107631e-03,   3.50463080e-02,   0.00000000e+00,
         0.00000000e+00,  -2.00982633e-03,  -7.22719392e-04,
         0.00000000e+00,   0.00000000e+00,   2.41925637e-04,
         1.50917991e-08,   1.53038273e-03,   9.02018526e-07,
         0.00000000e+00,   0.00000000e+00,   1.10497514e-02,
         4.40477567e-06,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.52097905e-05,   3.41243250e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.69195248e-04,
         4.82968528e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.05832869e-02,   3.60032652e-09,  -2.44390878e-02,
         1.00223613e-01,  -3.60142730e-03,   2.24746264e-02,
         0.00000000e+00,   0.00000000e+00,  -6.59835610e-04,
        -6.27677716e-03,   0.00000000e+00,   0.00000000e+00,
        -1.17358233e-03,   2.04572173e-02,   0.00000000e+00,
         0.00000000e+00,  -5.17413422e-03,  -2.95916160e-03,
         0.00000000e+00,   0.00000000e+00,   1.96914782e-03,
         9.51781455e-06,   7.79838349e-03,   2.58975251e-04,
         0.00000000e+00,   0.00000000e+00,   1.06644551e-03,
         1.55850893e-03,   0.00000000e+00,   0.00000000e+00,
         1.03149131e-02,   1.67380157e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.44103083e-04,   1.96687274e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.04953856e-03,
         3.07839643e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.09883049e-03,   2.79530320e-06,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.90409677e-03,
         3.05361825e-05,  -5.22648111e-02,   2.13489984e-01,
         1.99242770e-01,   2.81832462e-02,   2.15809866e-02,
         8.27559724e-02,   8.95827887e-02,   3.58331155e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.58185996e-01,   6.79754801e-02,
         2.62842900e-03,  -4.11324938e-02,   1.62750825e-02,
        -2.01576253e-01,   0.00000000e+00,   0.00000000e+00,
         1.55829385e-01,   1.11616205e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.58185996e-01,   6.79754801e-02,
         1.63465106e-02,   8.39002093e-02,   2.90290430e-02,
         3.82710202e-01,   0.00000000e+00,   0.00000000e+00,
         1.56400262e-02,  -1.65857955e-01,   0.00000000e+00,
         0.00000000e+00,   4.24459329e-02,   3.71208529e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.42170416e-02,   4.33135445e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.68821428e-02,   3.04994054e-02,   1.36657691e-02,
        -5.88678803e-02,   5.69495316e-02,  -2.88708497e-01,
         0.00000000e+00,   0.00000000e+00,   5.75726009e-02,
         8.83115619e-02,   0.00000000e+00,   0.00000000e+00,
         3.44759668e-02,  -2.24823103e-01,   0.00000000e+00,
         0.00000000e+00,   9.29894571e-02,   6.93929227e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.42170416e-02,
         4.33135445e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.68821428e-02,   3.04994054e-02,
        -5.90425820e-05,   2.36170328e-04,  -2.80773594e-04,
         1.12943611e-03,   0.00000000e+00,   0.00000000e+00,
         8.31978490e-05,  -3.59488657e-04,   0.00000000e+00,
         0.00000000e+00,   7.06731650e-04,   8.38652364e-04,
         0.00000000e+00,   0.00000000e+00,  -2.86041126e-03,
        -2.23384044e-04,   0.00000000e+00,   0.00000000e+00,
         8.01829824e-02,   8.32852014e-07,  -1.61378212e-03,
         6.45721165e-03,  -7.39638030e-03,   3.10010513e-02,
         0.00000000e+00,   0.00000000e+00,   1.64182031e-03,
        -1.01596040e-02,   0.00000000e+00,   0.00000000e+00,
         1.00623127e-03,   2.34054389e-02,   0.00000000e+00,
         0.00000000e+00,  -1.61563294e-02,  -6.90421481e-03,
         0.00000000e+00,   0.00000000e+00,   1.72125627e-02,
         1.49134872e-05,   8.00252038e-02,   5.52468062e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.07240363e-04,   2.26187103e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.27615960e-03,   1.41854858e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.84901351e-02,   8.97010212e-05,
        -1.00364274e-02,   4.01550840e-02,  -4.71788994e-02,
         1.92266921e-01,   0.00000000e+00,   0.00000000e+00,
         6.50319575e-03,  -3.44132614e-02,   0.00000000e+00,
         0.00000000e+00,  -2.78207890e-02,   1.43365062e-01,
         0.00000000e+00,   0.00000000e+00,  -1.17329393e-02,
        -2.25950070e-02,   0.00000000e+00,   0.00000000e+00,
         2.15760764e-03,   3.71045088e-05,   1.32720320e-02,
         1.60088341e-03,   0.00000000e+00,   0.00000000e+00,
         8.23254979e-02,   4.43480847e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.07240363e-04,   2.26187103e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.27615960e-03,   1.41854858e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.84901351e-02,   8.97010212e-05,
        -4.02325587e-03,   2.28120893e-02,  -1.56552383e-02,
         1.10075246e-01,   0.00000000e+00,   0.00000000e+00,
        -4.25828806e-03,  -4.23939624e-02,   0.00000000e+00,
         0.00000000e+00,   4.74181156e-03,   9.09480620e-02,
         0.00000000e+00,   0.00000000e+00,  -3.44253755e-02,
        -3.93193000e-02,   0.00000000e+00,   0.00000000e+00,
         1.46893509e-02,   1.23505497e-04,   5.77185641e-02,
         3.76332038e-03,   0.00000000e+00,   0.00000000e+00,
         8.60984154e-03,   1.72377618e-02,   0.00000000e+00,
         0.00000000e+00,   7.45753118e-02,   1.84908669e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.41283827e-03,   1.34830069e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.95872593e-02,   8.91739784e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.74961365e-02,   3.97987924e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.05791150e-02,   2.50607973e-03,  -1.77054113e-02,
         9.46730991e-02,  -4.00427334e-02,   2.26827406e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.63720324e-03,   5.19682230e-02,  -1.83041614e-02,
         2.09167606e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.37084160e-02,  -1.67775988e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.43749622e-02,   2.78139447e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.86451910e-03,   2.03914356e-02,  -1.15218117e-02,
         1.03904627e-01,   0.00000000e+00,   0.00000000e+00,
         1.53632295e-02,  -7.83725302e-02,   0.00000000e+00,
         0.00000000e+00,  -1.54121279e-02,   1.41498776e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.31354939e-02,  -2.69461588e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.78115582e-02,
        -1.32173253e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.66749528e-04,   1.06704378e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.22437882e-04,   5.05133560e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.23138086e-03,   2.90237109e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.18797081e-03,
         1.37811541e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.03013015e-05,   3.61316459e-04,  -5.69940106e-04,
         2.39203083e-03,   0.00000000e+00,   0.00000000e+00,
         2.36138725e-04,  -1.20921590e-03,   0.00000000e+00,
         0.00000000e+00,  -1.76684654e-04,   2.47492569e-03,
         0.00000000e+00,   0.00000000e+00,  -7.27541002e-04,
        -1.41117711e-03,   0.00000000e+00,   0.00000000e+00,
         4.64056695e-04,   4.90535376e-06,   2.90028730e-03,
         1.48763062e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.67275196e-02,   1.87176863e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.25165106e-02,   9.15456320e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.10269592e-04,   5.19059528e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.18644432e-02,   9.58179836e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.39601147e-03,   4.66453733e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.61932055e-03,   6.37199052e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.93421169e-04,   3.03689214e-03,  -3.22113779e-03,
         1.87901877e-02,   0.00000000e+00,   0.00000000e+00,
         1.41455108e-03,  -1.20897375e-02,   0.00000000e+00,
         0.00000000e+00,  -1.91969064e-03,   2.25186656e-02,
         0.00000000e+00,   0.00000000e+00,  -6.28314877e-04,
        -1.75254918e-02,   0.00000000e+00,   0.00000000e+00,
         4.84899283e-05,   6.47770592e-05,   1.28866866e-03,
         1.81793019e-03,   0.00000000e+00,   0.00000000e+00,
        -1.51298352e-03,   9.82086216e-03,   0.00000000e+00,
         0.00000000e+00,   3.50958660e-03,   6.87091588e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.90330860e-02,   2.08497761e-01,  -1.84009752e-01,
        -4.01429249e-03,  -3.54382084e-02,  -1.06791839e-02,
        -1.50397782e-01,  -6.82379614e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.55422617e-01,  -1.64711621e-02,  -4.90790851e-04,
         5.67071625e-02,  -4.07728223e-03,   2.39541539e-01,
         0.00000000e+00,   0.00000000e+00,  -9.00911610e-02,
        -3.60364644e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.55422617e-01,  -1.64711621e-02,  -3.08881541e-02,
        -1.07293676e-02,  -9.98242313e-02,  -7.34865486e-02,
         0.00000000e+00,   0.00000000e+00,  -3.44942513e-02,
         3.08225815e-01,   0.00000000e+00,   0.00000000e+00,
        -1.12380260e-01,  -8.10466880e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.73549762e-02,  -1.21979656e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.00246020e-01,
        -1.14755709e-02,  -4.68104268e-03,   2.60612346e-02,
        -1.07841506e-02,   1.42996963e-01,   0.00000000e+00,
         0.00000000e+00,   1.08840510e-02,  -3.69177556e-01,
         0.00000000e+00,   0.00000000e+00,  -8.64512305e-03,
         1.81492590e-01,   0.00000000e+00,   0.00000000e+00,
        -4.58728388e-02,  -2.86251290e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.73549762e-02,  -1.21979656e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.00246020e-01,  -1.14755709e-02,   1.38574795e-05,
        -5.54299178e-05,   8.90715927e-05,  -3.64187652e-04,
         0.00000000e+00,   0.00000000e+00,  -3.06142294e-04,
         1.25779208e-03,   0.00000000e+00,   0.00000000e+00,
        -1.03409193e-03,  -3.59859612e-04,   0.00000000e+00,
         0.00000000e+00,   3.39822356e-03,   7.02734862e-04,
         0.00000000e+00,   0.00000000e+00,  -9.79147080e-02,
        -3.46316505e-06,   3.97892342e-04,  -1.59385721e-03,
         2.19232591e-03,  -1.06000085e-02,   0.00000000e+00,
         0.00000000e+00,  -7.60788807e-03,   3.50888892e-02,
         0.00000000e+00,   0.00000000e+00,  -5.78702780e-03,
        -1.12058851e-02,   0.00000000e+00,   0.00000000e+00,
         1.70076474e-02,   2.10437259e-02,   0.00000000e+00,
         0.00000000e+00,  -2.10115617e-02,  -4.67927678e-05,
        -9.74524771e-02,  -1.57140453e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.88748890e-05,  -1.07540483e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.17957154e-03,
        -1.10788406e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.52140705e-02,  -2.69378612e-04,   1.33353428e-03,
        -5.34436584e-03,   7.69762609e-03,  -3.53688057e-02,
         0.00000000e+00,   0.00000000e+00,  -4.79249047e-02,
         2.02582469e-01,   0.00000000e+00,   0.00000000e+00,
        -1.21911887e-03,  -3.61638569e-02,   0.00000000e+00,
         0.00000000e+00,  -5.09179795e-03,   1.09323377e-01,
         0.00000000e+00,   0.00000000e+00,  -2.99905939e-03,
        -1.19749645e-04,  -1.79332757e-02,  -4.41382385e-03,
         0.00000000e+00,   0.00000000e+00,  -9.99722824e-02,
        -1.16194120e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.88748890e-05,  -1.07540483e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.17957154e-03,
        -1.10788406e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.52140705e-02,  -2.69378612e-04,   1.29555807e-04,
        -6.90829029e-03,  -2.27254250e-03,  -4.39825588e-02,
         0.00000000e+00,   0.00000000e+00,  -1.32555757e-02,
         1.24363010e-01,   0.00000000e+00,   0.00000000e+00,
        -1.96062341e-02,  -5.19197617e-02,   0.00000000e+00,
         0.00000000e+00,   3.24543390e-02,   8.63313335e-02,
         0.00000000e+00,   0.00000000e+00,  -1.79236833e-02,
        -2.06804775e-04,  -6.98836282e-02,  -6.60182990e-03,
         0.00000000e+00,   0.00000000e+00,  -1.12573101e-02,
        -2.63964500e-02,   0.00000000e+00,   0.00000000e+00,
        -8.86849590e-02,  -2.75657425e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.68805216e-03,  -6.40765494e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.33516065e-02,
        -6.55930874e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.51429091e-02,  -8.06000956e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.27829734e-02,
        -3.95779986e-03,  -1.14140228e-03,  -1.79270402e-02,
        -8.18851225e-03,  -1.12483343e-01,   0.00000000e+00,
         0.00000000e+00,  -3.85063620e-02,   2.40465184e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.63720324e-03,
         5.19682230e-02,  -1.83041614e-02,   2.09167606e-01,
         0.00000000e+00,   0.00000000e+00,   3.37084160e-02,
        -1.67775988e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.43749622e-02,
         2.78139447e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.31354939e-02,  -2.69461588e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.86451910e-03,   2.03914356e-02,  -1.15218117e-02,
         1.03904627e-01,   0.00000000e+00,   0.00000000e+00,
         1.53632295e-02,  -7.83725302e-02,   0.00000000e+00,
         0.00000000e+00,  -1.54121279e-02,   1.41498776e-01,
         0.00000000e+00,   0.00000000e+00,   2.78115582e-02,
        -1.32173253e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.66749528e-04,
         1.06704378e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.22437882e-04,   5.05133560e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.23138086e-03,   2.90237109e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.18797081e-03,   1.37811541e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.67275196e-02,
         1.87176863e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.25165106e-02,   9.15456320e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.03013015e-05,
         3.61316459e-04,  -5.69940106e-04,   2.39203083e-03,
         0.00000000e+00,   0.00000000e+00,   2.36138725e-04,
        -1.20921590e-03,   0.00000000e+00,   0.00000000e+00,
        -1.76684654e-04,   2.47492569e-03,   0.00000000e+00,
         0.00000000e+00,  -7.27541002e-04,  -1.41117711e-03,
         0.00000000e+00,   0.00000000e+00,   4.64056695e-04,
         4.90535376e-06,   2.90028730e-03,   1.48763062e-04,
         0.00000000e+00,   0.00000000e+00,   9.10269592e-04,
         5.19059528e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.18644432e-02,
         9.58179836e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.39601147e-03,   4.66453733e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.61932055e-03,
         6.37199052e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.90330860e-02,   2.08497761e-01,
         2.69542227e-01,   2.87868712e-02,   4.09175302e-02,
         6.42433937e-02,   1.95650312e-01,   2.49413187e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.40399597e-01,   5.03197989e-02,
         1.33583735e-04,  -3.55467578e-02,  -1.16570035e-02,
        -1.44020331e-01,   0.00000000e+00,   0.00000000e+00,
         2.44382511e-01,   8.51244049e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.40399597e-01,   5.03197989e-02,
         3.10656561e-02,   7.65165141e-02,   1.05391182e-01,
         3.20852329e-01,   0.00000000e+00,   0.00000000e+00,
         2.76797490e-03,  -1.73165276e-01,   0.00000000e+00,
         0.00000000e+00,   1.11083909e-01,   4.44335635e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.05597442e-01,   4.46911193e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.71530368e-01,   6.15487345e-02,   1.16943832e-02,
        -5.16487285e-02,   3.04715180e-02,  -2.21619544e-01,
         0.00000000e+00,   0.00000000e+00,   1.02599305e-01,
         9.24970468e-02,   0.00000000e+00,   0.00000000e+00,
         2.60367531e-02,  -2.99798070e-01,   0.00000000e+00,
         0.00000000e+00,   1.69169173e-01,   1.48479632e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.05597442e-01,
         4.46911193e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.71530368e-01,   6.15487345e-02,
        -8.21502671e-05,   3.28601068e-04,  -4.33709342e-04,
         1.75100516e-03,   0.00000000e+00,   0.00000000e+00,
         3.49727788e-04,  -1.46691539e-03,   0.00000000e+00,
         0.00000000e+00,   1.44575118e-03,   3.40632016e-03,
         0.00000000e+00,   0.00000000e+00,  -6.30131203e-03,
        -4.00192228e-03,   0.00000000e+00,   0.00000000e+00,
         1.99724830e-01,   1.69644638e-04,  -1.62462042e-03,
         6.50127466e-03,  -6.62537895e-03,   2.95107271e-02,
         0.00000000e+00,   0.00000000e+00,   2.48032135e-03,
        -1.78197644e-02,   0.00000000e+00,   0.00000000e+00,
         5.25396747e-03,   4.62314105e-02,   0.00000000e+00,
         0.00000000e+00,  -3.41620979e-02,  -3.98445148e-02,
         0.00000000e+00,   0.00000000e+00,   4.26804671e-02,
         7.43080486e-04,   1.95410553e-01,   1.18153615e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.99411409e-04,   2.57310709e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.51162463e-03,   5.49787564e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.93158097e-01,   3.40624158e-03,
        -9.01028345e-03,   3.60536737e-02,  -3.55812074e-02,
         1.49573396e-01,   0.00000000e+00,   0.00000000e+00,
         6.04903834e-03,  -4.19783826e-02,   0.00000000e+00,
         0.00000000e+00,  -3.27964628e-02,   2.08221579e-01,
         0.00000000e+00,   0.00000000e+00,  -2.10662393e-02,
        -8.56603185e-02,   0.00000000e+00,   0.00000000e+00,
         4.75125618e-03,   7.61257178e-03,   2.76524143e-02,
         4.57101272e-02,   0.00000000e+00,   0.00000000e+00,
         1.90070067e-01,   6.47179688e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.99411409e-04,   2.57310709e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.51162463e-03,   5.49787564e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.93158097e-01,   3.40624158e-03,
        -3.29545580e-03,   2.21547160e-02,  -5.75943248e-03,
         9.93490572e-02,   0.00000000e+00,   0.00000000e+00,
        -1.06609910e-02,  -5.90759562e-02,   0.00000000e+00,
         0.00000000e+00,   2.00917648e-02,   1.45628824e-01,
         0.00000000e+00,   0.00000000e+00,  -7.05621126e-02,
        -1.12575873e-01,   0.00000000e+00,   0.00000000e+00,
         3.64260666e-02,   9.38221908e-04,   1.38846332e-01,
         2.17619537e-02,   0.00000000e+00,   0.00000000e+00,
         1.26727239e-02,   8.96882525e-02,   0.00000000e+00,
         0.00000000e+00,   1.73847385e-01,   5.86479579e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.73551050e-03,   1.47945047e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.00738826e-02,   2.65100177e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.06573329e-02,   5.28027978e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.63507369e-01,   1.72878965e-02,  -1.34449073e-02,
         8.56582708e-02,  -3.81121583e-02,   3.61027826e-01,
         0.00000000e+00,   0.00000000e+00,  -2.76780459e-02,
        -1.29560805e-01,   0.00000000e+00,   0.00000000e+00,
        -1.30733010e-02,   2.49194721e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.13361261e-03,
         1.63929303e-02,   6.48425623e-03,   8.94997728e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.06905301e-02,  -7.46343706e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.45464367e-03,   1.36732788e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.96912646e-03,
         1.87916145e-02,  -1.46894715e-02,   1.19756697e-01,
         0.00000000e+00,   0.00000000e+00,   2.14753891e-02,
        -1.08852698e-01,   0.00000000e+00,   0.00000000e+00,
        -2.36486126e-02,   2.17691919e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.71790200e-02,
        -1.31667222e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.38906285e-02,  -2.28382568e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.27176289e-04,   5.08924285e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.90320905e-04,
         8.34666711e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.43492741e-03,
         1.39787193e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.74446989e-03,   2.31121868e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.32367152e-04,
         5.29546773e-04,  -1.17649419e-03,   4.98067161e-03,
         0.00000000e+00,   0.00000000e+00,   1.16913522e-03,
        -5.38684946e-03,   0.00000000e+00,   0.00000000e+00,
        -1.35940991e-03,   1.25947033e-02,   0.00000000e+00,
         0.00000000e+00,  -4.67368100e-04,  -1.63626234e-02,
         0.00000000e+00,   0.00000000e+00,   2.15842027e-03,
         1.48468299e-04,   1.27118380e-02,   3.24148982e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.27958331e-02,   9.17690899e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.13300599e-02,
         1.70568481e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.96289858e-04,   1.92089437e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.22667341e-03,   4.73099029e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.12398949e-02,
         7.78429269e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.08068802e-02,   6.51840102e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.09182150e-04,
         3.39481621e-03,  -5.25786022e-03,   2.87934934e-02,
         0.00000000e+00,   0.00000000e+00,   4.72183648e-03,
        -2.90180631e-02,   0.00000000e+00,   0.00000000e+00,
        -6.62750443e-03,   6.38711274e-02,   0.00000000e+00,
         0.00000000e+00,   2.96710748e-03,  -7.41030416e-02,
         0.00000000e+00,   0.00000000e+00,   2.25861695e-04,
         3.16046199e-04,   5.49411220e-03,   9.07397036e-03,
         0.00000000e+00,   0.00000000e+00,  -1.10946732e-02,
         6.04638548e-02,   0.00000000e+00,   0.00000000e+00,
         1.34824930e-02,   2.81206085e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.42747364e-02,
         2.05745794e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.89457221e-02,   1.85951293e-01,
        -2.77256428e-01,  -4.60279430e-04,  -5.74691556e-02,
        -1.95994053e-03,  -2.65867108e-01,  -3.04551852e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.63116733e-01,  -8.45980605e-03,
         6.51791028e-03,   1.71020722e-02,   3.71925763e-02,
         1.04615581e-01,   0.00000000e+00,   0.00000000e+00,
        -2.47062049e-01,  -1.62820676e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.63116733e-01,  -8.45980605e-03,
        -5.02172226e-02,  -2.11944385e-03,  -1.88223941e-01,
        -4.66631768e-02,   0.00000000e+00,   0.00000000e+00,
         1.51561246e-02,   1.62451591e-01,   0.00000000e+00,
         0.00000000e+00,  -2.26428923e-01,  -9.78255289e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.23693082e-01,  -1.09695404e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.08575048e-01,  -2.64100273e-02,  -3.39508513e-03,
         1.96353859e-02,  -1.56207594e-03,   1.45034149e-01,
         0.00000000e+00,   0.00000000e+00,  -7.79853185e-02,
        -2.60561306e-01,   0.00000000e+00,   0.00000000e+00,
         4.10759167e-03,   2.80528897e-01,   0.00000000e+00,
         0.00000000e+00,  -1.27299377e-01,  -5.09197507e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.23693082e-01,
        -1.09695404e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.08575048e-01,  -2.64100273e-02,
         9.91743935e-05,  -3.96697574e-04,   7.77318264e-04,
        -3.13356766e-03,   0.00000000e+00,   0.00000000e+00,
        -1.03726508e-03,   4.25112577e-03,   0.00000000e+00,
         0.00000000e+00,  -1.39881107e-03,  -7.92392305e-03,
         0.00000000e+00,   0.00000000e+00,   7.66286818e-03,
         1.22520806e-02,   0.00000000e+00,   0.00000000e+00,
        -2.91491629e-01,  -4.43339407e-04,   6.35568144e-04,
        -2.54532031e-03,   4.87327903e-03,  -2.37279016e-02,
         0.00000000e+00,   0.00000000e+00,  -7.30602375e-03,
         4.04946629e-02,   0.00000000e+00,   0.00000000e+00,
        -9.91832741e-03,  -5.92395312e-02,   0.00000000e+00,
         0.00000000e+00,   3.94219295e-02,   1.01851641e-01,
         0.00000000e+00,   0.00000000e+00,  -6.20808241e-02,
        -1.84384454e-03,  -2.81294200e-01,  -2.72201194e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.17903491e-05,  -2.01064219e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.09176814e-02,  -8.00237276e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.78972966e-01,  -8.05749525e-03,
         7.24048897e-04,  -2.90981958e-03,   6.86191285e-03,
        -3.74708888e-02,   0.00000000e+00,   0.00000000e+00,
        -2.50856628e-02,   1.25318469e-01,   0.00000000e+00,
         0.00000000e+00,  -3.49819458e-03,  -9.97147543e-02,
         0.00000000e+00,   0.00000000e+00,  -6.42493510e-03,
         2.78838841e-01,   0.00000000e+00,   0.00000000e+00,
        -5.98192182e-03,  -2.39730576e-02,  -3.61398244e-02,
        -1.23691947e-01,   0.00000000e+00,   0.00000000e+00,
        -2.64317109e-01,  -1.44412795e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.17903491e-05,  -2.01064219e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.09176814e-02,  -8.00237276e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.78972966e-01,  -8.05749525e-03,
        -6.55946344e-04,  -6.57371191e-03,  -7.47379922e-03,
        -6.08805610e-02,   0.00000000e+00,   0.00000000e+00,
         4.75485876e-03,   1.08490918e-01,   0.00000000e+00,
         0.00000000e+00,  -4.18596059e-02,  -1.35537879e-01,
         0.00000000e+00,   0.00000000e+00,   7.92776799e-02,
         2.33419868e-01,   0.00000000e+00,   0.00000000e+00,
        -5.29890453e-02,  -2.03827318e-03,  -1.97910895e-01,
        -4.32069176e-02,   0.00000000e+00,   0.00000000e+00,
        -1.07876001e-02,  -1.90706452e-01,   0.00000000e+00,
         0.00000000e+00,  -2.42587459e-01,  -9.74238102e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.12397830e-02,  -9.03631727e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.48970264e-02,  -2.78117345e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.29270485e-01,  -1.10690662e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.25832038e-01,  -3.04021271e-02,  -5.67833832e-03,
        -9.88255229e-03,  -3.45710575e-02,  -1.04245385e-01,
         0.00000000e+00,   0.00000000e+00,   3.83792085e-04,
         2.94172499e-01,   0.00000000e+00,   0.00000000e+00,
        -6.76876235e-02,  -2.33085153e-01,   0.00000000e+00,
         0.00000000e+00,   1.11579176e-02,   2.96426323e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.13361261e-03,
         1.63929303e-02,   6.48425623e-03,   8.94997728e-02,
         0.00000000e+00,   0.00000000e+00,   1.06905301e-02,
        -7.46343706e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.45464367e-03,
         1.36732788e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.71790200e-02,  -1.31667222e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.96912646e-03,   1.87916145e-02,  -1.46894715e-02,
         1.19756697e-01,   0.00000000e+00,   0.00000000e+00,
         2.14753891e-02,  -1.08852698e-01,   0.00000000e+00,
         0.00000000e+00,  -2.36486126e-02,   2.17691919e-01,
         0.00000000e+00,   0.00000000e+00,   4.38906285e-02,
        -2.28382568e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.27176289e-04,
         5.08924285e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.90320905e-04,   8.34666711e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.43492741e-03,   1.39787193e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.74446989e-03,   2.31121868e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.27958331e-02,
         9.17690899e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.13300599e-02,   1.70568481e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.32367152e-04,
         5.29546773e-04,  -1.17649419e-03,   4.98067161e-03,
         0.00000000e+00,   0.00000000e+00,   1.16913522e-03,
        -5.38684946e-03,   0.00000000e+00,   0.00000000e+00,
        -1.35940991e-03,   1.25947033e-02,   0.00000000e+00,
         0.00000000e+00,  -4.67368100e-04,  -1.63626234e-02,
         0.00000000e+00,   0.00000000e+00,   2.15842027e-03,
         1.48468299e-04,   1.27118380e-02,   3.24148982e-03,
         0.00000000e+00,   0.00000000e+00,   1.96289858e-04,
         1.92089437e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.22667341e-03,
         4.73099029e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.12398949e-02,   7.78429269e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.08068802e-02,
         6.51840102e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.42747364e-02,   2.05745794e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.89457221e-02,   1.85951293e-01,   1.12785075e-03,
        -0.00000000e+00,   2.35910986e-04,   2.07473201e-07,
         1.12705796e-03,   3.17086571e-06,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.06702665e-03,   2.28319848e-08,  -5.43366311e-05,
        -8.74629348e-07,  -3.55350928e-04,  -8.64963578e-06,
         0.00000000e+00,   0.00000000e+00,   1.24533349e-03,
         1.66114508e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.06702665e-03,   2.28319848e-08,   1.75968892e-04,
         1.22105741e-04,   6.04501244e-04,   9.20436688e-04,
         0.00000000e+00,   0.00000000e+00,  -5.75940785e-05,
        -1.14105790e-03,   0.00000000e+00,   0.00000000e+00,
        -3.96766746e-05,   4.59466245e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.04103705e-04,   3.90028938e-06,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.07148051e-04,
         3.66915462e-05,   8.95257990e-05,  -3.88978698e-04,
         5.13272337e-04,  -2.92233092e-03,   0.00000000e+00,
         0.00000000e+00,  -2.22637411e-04,   3.59942364e-03,
         0.00000000e+00,   0.00000000e+00,   2.04826566e-03,
        -1.06815844e-02,   0.00000000e+00,   0.00000000e+00,
        -3.83675189e-03,   2.14517767e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.04103705e-04,   3.90028938e-06,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.07148051e-04,   3.66915462e-05,  -2.68478569e-03,
         1.07391427e-02,  -2.00454853e-02,   8.01836070e-02,
         0.00000000e+00,   0.00000000e+00,   2.44775948e-02,
        -9.79173054e-02,   0.00000000e+00,   0.00000000e+00,
        -4.98781934e-02,   1.99852063e-01,   0.00000000e+00,
         0.00000000e+00,   7.27343638e-02,  -2.91824134e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.76456642e-04,   2.30584015e-03,
        -4.29169910e-03,   1.72183229e-02,   0.00000000e+00,
         0.00000000e+00,   5.21930043e-03,  -2.10314825e-02,
         0.00000000e+00,   0.00000000e+00,  -1.03913867e-02,
         4.32005635e-02,   0.00000000e+00,   0.00000000e+00,
         1.48741878e-02,  -6.34078541e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.11613156e-04,   4.65441235e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.25989121e-04,
         2.21599581e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.04672608e-05,
         2.41929410e-04,  -5.18299132e-04,   2.17782992e-03,
         0.00000000e+00,   0.00000000e+00,   6.95421942e-04,
        -3.07533471e-03,   0.00000000e+00,   0.00000000e+00,
        -2.57422950e-03,   1.34729603e-02,   0.00000000e+00,
         0.00000000e+00,   6.28668380e-03,  -3.37879421e-02,
         0.00000000e+00,   0.00000000e+00,  -1.48687482e-01,
         6.30088539e-01,  -2.67916296e-02,   1.59051506e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.11613156e-04,   4.65441235e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.25989121e-04,
         2.21599581e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.83364003e-04,
         1.97152727e-03,  -3.55914362e-03,   1.47223011e-02,
         0.00000000e+00,   0.00000000e+00,   4.29749507e-03,
        -1.79837475e-02,   0.00000000e+00,   0.00000000e+00,
        -8.64340576e-03,   3.69937998e-02,   0.00000000e+00,
         0.00000000e+00,   1.24142601e-02,  -5.43609175e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.67651619e-02,
         1.40544070e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.84899283e-05,   6.47770592e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.25861695e-04,
         3.16046199e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.52260393e-05,   3.36347190e-05,
         2.22663933e-04,   3.14285890e-04,   0.00000000e+00,
         0.00000000e+00,  -3.01961864e-04,  -4.76279846e-04,
         0.00000000e+00,   0.00000000e+00,  -1.35816430e-03,
         9.10936460e-03,   0.00000000e+00,   0.00000000e+00,
         5.31695867e-03,  -2.78536206e-02,   0.00000000e+00,
         0.00000000e+00,  -9.19664312e-02,   3.69841572e-01,
         3.06537370e-02,   2.63365589e-07,   6.40208184e-03,
         4.45204825e-05,   3.04702275e-02,   7.07765058e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.89868906e-02,   4.90937602e-05,
        -1.45481376e-03,  -1.11692329e-04,  -9.36298856e-03,
        -1.35575690e-03,   0.00000000e+00,   0.00000000e+00,
         3.33423879e-02,   2.32866845e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.89868906e-02,   4.90937602e-05,
         5.38990769e-03,   8.89652171e-04,   2.07506626e-02,
         7.60989382e-03,   0.00000000e+00,   0.00000000e+00,
        -6.59048562e-03,  -1.05631188e-02,   0.00000000e+00,
         0.00000000e+00,   2.10136804e-02,   3.36236402e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.36421341e-02,   3.17070123e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.15618216e-02,   2.06715364e-03,   3.74287746e-04,
        -2.33629600e-03,  -1.11024856e-03,  -1.89410795e-02,
         0.00000000e+00,   0.00000000e+00,   1.19545287e-02,
         2.50862209e-02,   0.00000000e+00,   0.00000000e+00,
         2.09655465e-03,  -6.88514368e-02,   0.00000000e+00,
         0.00000000e+00,   4.52438161e-03,   1.29769680e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.36421341e-02,
         3.17070123e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.15618216e-02,   2.06715364e-03,
        -5.76460886e-04,   2.30584354e-03,  -4.30526132e-03,
         1.72291727e-02,   0.00000000e+00,   0.00000000e+00,
         5.25723496e-03,  -2.10618301e-02,   0.00000000e+00,
         0.00000000e+00,  -1.04844216e-02,   4.32749915e-02,
         0.00000000e+00,   0.00000000e+00,   1.50138214e-02,
        -6.35195609e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.68471648e-03,
         1.07392350e-02,  -1.98336547e-02,   8.04395548e-02,
         0.00000000e+00,   0.00000000e+00,   2.38720554e-02,
        -9.86310305e-02,   0.00000000e+00,   0.00000000e+00,
        -4.51603377e-02,   2.04272074e-01,   0.00000000e+00,
         0.00000000e+00,   6.18172626e-02,  -3.01709289e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.33717740e-04,   2.97596710e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.34888123e-03,   1.44900652e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.82364878e-04,   1.53110010e-03,  -3.07084093e-03,
         1.46751817e-02,   0.00000000e+00,   0.00000000e+00,
         3.86069819e-03,  -2.18490029e-02,   0.00000000e+00,
         0.00000000e+00,  -8.03043809e-03,   7.42564091e-02,
         0.00000000e+00,   0.00000000e+00,   1.46855249e-02,
        -1.64352226e-01,   0.00000000e+00,   0.00000000e+00,
        -7.57003510e-03,   1.43674230e-01,  -4.98806077e-02,
         6.67933984e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.33717740e-04,   2.97596710e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.34888123e-03,   1.44900652e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.70717174e-03,   7.86341943e-03,  -1.15708564e-02,
         5.91948568e-02,   0.00000000e+00,   0.00000000e+00,
         1.30870254e-02,  -7.29783528e-02,   0.00000000e+00,
         0.00000000e+00,  -2.52089149e-02,   1.53006151e-01,
         0.00000000e+00,   0.00000000e+00,   3.34413882e-02,
        -2.28288744e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.40985453e-02,   5.21363242e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.28866866e-03,   1.81793019e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.49411220e-03,   9.07397036e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.85340047e-04,
         9.15253042e-04,   5.65485644e-03,   9.79486093e-03,
         0.00000000e+00,   0.00000000e+00,  -7.24484685e-03,
        -1.57729977e-02,   0.00000000e+00,   0.00000000e+00,
         3.89845306e-03,   7.14751835e-02,   0.00000000e+00,
         0.00000000e+00,   6.93722324e-03,  -1.71698426e-01,
         0.00000000e+00,   0.00000000e+00,  -3.67234311e-02,
         1.62101718e-01,  -7.18126246e-02,   3.87047334e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.36183228e-04,   2.01288353e-05,   2.18722968e-03,
         1.86294996e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.42704187e-04,  -2.66141567e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.93458229e-03,   7.85912132e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.20449392e-05,   4.81289003e-04,   4.25007253e-04,
         3.69947046e-03,   0.00000000e+00,   0.00000000e+00,
         2.28223011e-04,  -4.63411969e-03,   0.00000000e+00,
         0.00000000e+00,   1.03976987e-03,   1.06753594e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.40005543e-04,  -1.56120548e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.24725808e-04,
        -1.74762985e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.17349345e-04,   4.70030186e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.60428327e-04,   2.32354718e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.23448997e-04,   3.04775210e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.98110664e-03,
         1.57958456e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.64582060e-03,   1.05832896e-02,  -1.95945022e-02,
         7.85574108e-02,   0.00000000e+00,   0.00000000e+00,
         2.37193368e-02,  -9.54161045e-02,   0.00000000e+00,
         0.00000000e+00,  -4.72250739e-02,   1.95712779e-01,
         0.00000000e+00,   0.00000000e+00,   6.72252741e-02,
        -2.85016087e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.93987506e-04,   1.48246521e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.10346916e-03,   2.26487509e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.08742449e-01,   5.58084716e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.47514404e-04,   3.01066701e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.37900185e-03,   1.62671067e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.27209845e-03,   5.09953845e-03,  -9.10865514e-03,
         3.76818212e-02,   0.00000000e+00,   0.00000000e+00,
         1.08276552e-02,  -4.55824524e-02,   0.00000000e+00,
         0.00000000e+00,  -2.04972055e-02,   9.42039106e-02,
         0.00000000e+00,   0.00000000e+00,   2.82800951e-02,
        -1.37109531e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.77331535e-02,   2.50857264e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.12209363e-04,   1.72009063e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.63917087e-03,
         3.06418453e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.24626276e-02,   3.59812836e-01,   1.91401125e-01,
         1.21817787e-06,   4.00155460e-02,   1.13505216e-04,
         1.90935175e-01,   1.77566188e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.87076819e-01,   1.33392031e-04,  -5.01828116e-03,
        -2.62913486e-04,  -3.24575124e-02,  -3.24469493e-03,
         0.00000000e+00,   0.00000000e+00,   1.98501400e-01,
         5.44142520e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.87076819e-01,   1.33392031e-04,   3.47897641e-02,
         1.01363567e-03,   1.39094765e-01,   9.83261810e-03,
         0.00000000e+00,   0.00000000e+00,  -2.80418895e-02,
        -1.47056404e-02,   0.00000000e+00,   0.00000000e+00,
         1.79333181e-01,   3.85178641e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.12701084e-02,   5.16336778e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.68600391e-01,
         2.62412090e-03,  -1.70835351e-04,  -2.19391218e-03,
        -1.51173226e-02,  -1.98875005e-02,   0.00000000e+00,
         0.00000000e+00,   9.59586727e-02,   2.84830009e-02,
         0.00000000e+00,   0.00000000e+00,  -3.95063848e-02,
        -7.09082021e-02,   0.00000000e+00,   0.00000000e+00,
         1.83911678e-01,   1.26569550e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.12701084e-02,   5.16336778e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.68600391e-01,   2.62412090e-03,  -6.04861255e-05,
         2.41944502e-04,  -5.37314369e-04,   2.19304211e-03,
         0.00000000e+00,   0.00000000e+00,   7.29264223e-04,
        -3.10240853e-03,   0.00000000e+00,   0.00000000e+00,
         4.95645878e-03,   7.44840971e-03,   0.00000000e+00,
         0.00000000e+00,  -1.82788839e-02,  -1.41354880e-02,
         0.00000000e+00,   0.00000000e+00,   6.16836559e-01,
         1.76693062e-02,  -3.82262725e-04,   1.53101838e-03,
        -2.56462293e-03,   1.42702073e-02,   0.00000000e+00,
         0.00000000e+00,   2.34729974e-03,  -2.06382842e-02,
         0.00000000e+00,   0.00000000e+00,   2.27730604e-02,
         4.96136103e-02,   0.00000000e+00,   0.00000000e+00,
        -7.39230793e-02,  -9.34653427e-02,   0.00000000e+00,
         0.00000000e+00,   1.20373041e-01,   4.13197693e-02,
         4.92279652e-01,   2.34205777e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.63264915e-04,   1.11666327e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.60109141e-02,
         6.55724436e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.11916622e-01,   6.15574591e-02,  -2.76106136e-03,
         1.10530550e-02,  -1.91954968e-02,   8.56516043e-02,
         0.00000000e+00,   0.00000000e+00,   2.13620043e-02,
        -1.08686841e-01,   0.00000000e+00,   0.00000000e+00,
        -2.72931514e-02,   2.38608543e-01,   0.00000000e+00,
         0.00000000e+00,   2.09502787e-02,  -3.72626705e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.94431723e-01,
         1.17772689e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.63264915e-04,   1.11666327e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.60109141e-02,
         6.55724436e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.11916622e-01,   6.15574591e-02,   1.19286424e-03,
         1.45737395e-03,   1.24518885e-02,   1.41641242e-02,
         0.00000000e+00,   0.00000000e+00,  -1.79811510e-02,
        -2.10173773e-02,   0.00000000e+00,   0.00000000e+00,
         6.09986619e-02,   5.10275021e-02,   0.00000000e+00,
         0.00000000e+00,  -1.28362381e-01,  -9.66466276e-02,
         0.00000000e+00,   0.00000000e+00,   1.03665488e-01,
         3.61995496e-02,   3.25817992e-01,   2.25430013e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.67126709e-01,   2.29057018e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.37503850e-03,   1.11044454e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.66675641e-02,
         6.25406491e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.14762899e-01,   4.08604220e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.18722721e-01,
         3.54410646e-02,   4.14997640e-03,   5.53986888e-03,
         3.05490404e-02,   4.59469324e-02,   0.00000000e+00,
         0.00000000e+00,  -3.65388718e-02,  -6.19268368e-02,
         0.00000000e+00,   0.00000000e+00,   6.41905731e-02,
         1.49747881e-01,   0.00000000e+00,   0.00000000e+00,
        -8.34272387e-02,  -2.51762839e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.05224525e-03,   5.05671679e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.36183228e-04,
         2.01288353e-05,   2.18722968e-03,   1.86294996e-04,
         0.00000000e+00,   0.00000000e+00,  -9.42704187e-04,
        -2.66141567e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.93458229e-03,
         7.85912132e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.40005543e-04,  -1.56120548e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.20449392e-05,   4.81289003e-04,   4.25007253e-04,
         3.69947046e-03,   0.00000000e+00,   0.00000000e+00,
         2.28223011e-04,  -4.63411969e-03,   0.00000000e+00,
         0.00000000e+00,   1.03976987e-03,   1.06753594e-02,
         0.00000000e+00,   0.00000000e+00,   9.24725808e-04,
        -1.74762985e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.17349345e-04,
         4.70030186e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.60428327e-04,   2.32354718e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.23448997e-04,   3.04775210e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.98110664e-03,   1.57958456e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.93987506e-04,
         1.48246521e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.10346916e-03,   2.26487509e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.64582060e-03,
         1.05832896e-02,  -1.95945022e-02,   7.85574108e-02,
         0.00000000e+00,   0.00000000e+00,   2.37193368e-02,
        -9.54161045e-02,   0.00000000e+00,   0.00000000e+00,
        -4.72250739e-02,   1.95712779e-01,   0.00000000e+00,
         0.00000000e+00,   6.72252741e-02,  -2.85016087e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.08742449e-01,
         5.58084716e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.47514404e-04,
         3.01066701e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.37900185e-03,   1.62671067e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.12209363e-04,   1.72009063e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.63917087e-03,   3.06418453e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.24626276e-02,   3.59812836e-01,
         9.92983895e-02,   1.23363076e-03,   1.98706110e-02,
         3.69699576e-03,   9.22798862e-02,   2.37271464e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.26829046e-02,   4.18010541e-03,
        -3.72262373e-03,  -3.82654667e-03,  -2.20945400e-02,
        -2.81249609e-02,   0.00000000e+00,   0.00000000e+00,
         9.76102446e-02,   3.56703534e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.26829046e-02,   4.18010541e-03,
         1.66680078e-02,   6.18394521e-03,   6.02310655e-02,
         4.65566589e-02,   0.00000000e+00,   0.00000000e+00,
        -1.19857430e-02,  -5.80161546e-02,   0.00000000e+00,
         0.00000000e+00,   6.08803677e-02,   1.12997942e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.25780375e-02,   5.86613418e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.55116717e-02,   1.64416737e-02,   1.39353745e-03,
        -8.21329895e-03,   1.11924445e-04,  -6.69491400e-02,
         0.00000000e+00,   0.00000000e+00,   3.29750552e-02,
         8.59147606e-02,   0.00000000e+00,   0.00000000e+00,
         6.78074131e-03,  -1.74450157e-01,   0.00000000e+00,
         0.00000000e+00,   2.69708974e-02,   2.75265294e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.25780375e-02,
         5.86613418e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.55116717e-02,   1.64416737e-02,
        -4.95261271e-04,   1.98104509e-03,  -3.70834087e-03,
         1.48416589e-02,   0.00000000e+00,   0.00000000e+00,
         4.53509360e-03,  -1.81738263e-02,   0.00000000e+00,
         0.00000000e+00,  -8.98323887e-03,   3.72656663e-02,
         0.00000000e+00,   0.00000000e+00,   1.28063418e-02,
        -5.46745828e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.03016048e-03,
         8.12181043e-03,  -1.49363504e-02,   6.18872520e-02,
         0.00000000e+00,   0.00000000e+00,   1.77286450e-02,
        -7.66916485e-02,   0.00000000e+00,   0.00000000e+00,
        -3.06130299e-02,   1.57329443e-01,   0.00000000e+00,
         0.00000000e+00,   3.85097357e-02,  -2.32343422e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.63896463e-04,   3.18377266e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.95623802e-05,   1.51242553e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.52018911e-04,   3.01328047e-03,  -5.98320815e-03,
         2.89122015e-02,   0.00000000e+00,   0.00000000e+00,
         7.11202482e-03,  -4.10919180e-02,   0.00000000e+00,
         0.00000000e+00,  -1.12798660e-02,   1.08850324e-01,
         0.00000000e+00,   0.00000000e+00,   1.45646482e-02,
        -2.10988251e-01,   0.00000000e+00,   0.00000000e+00,
        -2.44286386e-03,   1.21086231e-01,   2.20833076e-02,
         4.68417760e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.63896463e-04,   3.18377266e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.95623802e-05,   1.51242553e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.05566529e-03,   1.15702643e-02,  -1.28654320e-02,
         8.84434619e-02,   0.00000000e+00,   0.00000000e+00,
         1.35569452e-02,  -1.09359266e-01,   0.00000000e+00,
         0.00000000e+00,  -2.51343593e-02,   2.17833353e-01,
         0.00000000e+00,   0.00000000e+00,   3.02019241e-02,
        -3.15655317e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.02013591e-02,   5.38919473e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.50958660e-03,   6.87091588e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.34824930e-02,   2.81206085e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.35334722e-03,
         6.42385638e-03,   9.58608952e-03,   5.78221007e-02,
         0.00000000e+00,   0.00000000e+00,  -1.15901123e-02,
        -7.86761694e-02,   0.00000000e+00,   0.00000000e+00,
         7.81286591e-03,   1.84584346e-01,   0.00000000e+00,
         0.00000000e+00,   3.45635765e-03,  -3.34360538e-01,
         0.00000000e+00,   0.00000000e+00,  -3.10296369e-02,
         1.39237407e-01,  -7.85641161e-02,   5.91128257e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.26542576e-02,   3.91851091e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.60066509e-03,
         1.20162313e-03,   9.94159796e-03,   8.25999913e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.57530934e-03,  -8.89784920e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.29850082e-03,   1.51441124e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.23187351e-04,
         3.16602037e-03,   1.03760423e-03,   2.37571219e-02,
         0.00000000e+00,   0.00000000e+00,   2.85439878e-03,
        -2.75241129e-02,   0.00000000e+00,   0.00000000e+00,
         3.15932422e-03,   5.60416644e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.00508082e-04,
        -1.85085501e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.09907166e-03,  -7.74086130e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.22492304e-05,   1.29368386e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.41263668e-04,
         6.09746489e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.96796613e-04,
         3.48630241e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.56993682e-03,   1.55252096e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.27556973e-03,
         5.10231548e-03,  -9.39067066e-03,   3.79074337e-02,
         0.00000000e+00,   0.00000000e+00,   1.12400487e-02,
        -4.59123672e-02,   0.00000000e+00,   0.00000000e+00,
        -2.15312861e-02,   9.50311750e-02,   0.00000000e+00,
         0.00000000e+00,   2.94369812e-02,  -1.38035040e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.48050789e-03,   1.05948817e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.33303182e-02,
         6.22523707e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.41105324e-02,   2.39959167e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.70057482e-04,   1.04546312e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.64835919e-03,
         4.10252903e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.46648164e-03,
         9.92699891e-03,  -1.68616288e-02,   7.24586748e-02,
         0.00000000e+00,   0.00000000e+00,   1.94589309e-02,
        -8.57513233e-02,   0.00000000e+00,   0.00000000e+00,
        -3.54743747e-02,   1.76473292e-01,   0.00000000e+00,
         0.00000000e+00,   4.69573449e-02,  -2.48633634e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.86053476e-02,
         3.45303519e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.02653787e-03,
         2.46963813e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.76820597e-02,   1.23357557e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.86053476e-02,
         3.45303519e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.55122379e-02,   3.00419170e-01,
         4.23656913e-01,   4.43073969e-03,   8.57288038e-02,
         1.19257270e-02,   4.03662457e-01,   6.66564724e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.07721459e-01,   1.23654167e-02,
        -9.49229673e-03,  -1.12463247e-02,  -5.80193210e-02,
        -7.26186960e-02,   0.00000000e+00,   0.00000000e+00,
         4.16100566e-01,   8.64397359e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.07721459e-01,   1.23654167e-02,
         7.37037801e-02,   1.59393208e-02,   2.82810628e-01,
         1.04289596e-01,   0.00000000e+00,   0.00000000e+00,
        -3.94584340e-02,  -1.20136494e-01,   0.00000000e+00,
         0.00000000e+00,   3.50713304e-01,   1.96901517e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.95003226e-01,   1.43234241e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.49276283e-01,   3.01684052e-02,   2.34091230e-03,
        -1.62979528e-02,  -1.32967793e-02,  -1.21264807e-01,
         0.00000000e+00,   0.00000000e+00,   1.83282124e-01,
         1.47853834e-01,   0.00000000e+00,   0.00000000e+00,
        -4.41467853e-02,  -2.51917823e-01,   0.00000000e+00,
         0.00000000e+00,   3.37059150e-01,   3.41057993e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.95003226e-01,
         1.43234241e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.49276283e-01,   3.01684052e-02,
        -1.68173595e-05,   6.72694380e-05,  -1.37567218e-04,
         6.02470810e-04,   0.00000000e+00,   0.00000000e+00,
         1.55267892e-04,  -8.42063650e-04,   0.00000000e+00,
         0.00000000e+00,   7.73059932e-03,   1.83835371e-03,
         0.00000000e+00,   0.00000000e+00,  -2.53839509e-02,
        -3.29289296e-03,   0.00000000e+00,   0.00000000e+00,
         7.38201258e-01,   1.97584703e-03,  -4.55976919e-04,
         1.82830661e-03,  -2.36049658e-03,   1.62071433e-02,
         0.00000000e+00,   0.00000000e+00,   1.00914672e-03,
        -2.23761925e-02,   0.00000000e+00,   0.00000000e+00,
         3.88243101e-02,   4.35344979e-02,   0.00000000e+00,
         0.00000000e+00,  -1.17717351e-01,  -7.19747665e-02,
         0.00000000e+00,   0.00000000e+00,   1.56398720e-01,
         7.60399659e-03,   6.99247042e-01,   9.97968363e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.06742597e-04,   1.88446404e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.46099096e-02,   8.04258089e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.97153927e-01,   2.99623251e-02,
        -2.76254654e-03,   1.10698872e-02,  -1.71067278e-02,
         8.40715469e-02,   0.00000000e+00,   0.00000000e+00,
         1.61040347e-02,  -1.04041162e-01,   0.00000000e+00,
         0.00000000e+00,  -2.69343371e-03,   2.03255087e-01,
         0.00000000e+00,   0.00000000e+00,  -3.22109167e-02,
        -2.92735897e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.28932862e-01,   5.09880660e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.06742597e-04,   1.88446404e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.46099096e-02,   8.04258089e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.97153927e-01,   2.99623251e-02,
         1.98488941e-03,   5.91862263e-03,   2.17596787e-02,
         4.80832294e-02,   0.00000000e+00,   0.00000000e+00,
        -3.17874374e-02,  -6.25183093e-02,   0.00000000e+00,
         0.00000000e+00,   1.03645917e-01,   1.07917905e-01,
         0.00000000e+00,   0.00000000e+00,  -2.14159873e-01,
        -1.60267554e-01,   0.00000000e+00,   0.00000000e+00,
         1.33567835e-01,   7.55942954e-03,   4.87301335e-01,
         1.38435896e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.87776637e-01,   2.61234061e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.84750451e-02,   8.29511492e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.03621563e-01,   2.63146591e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.18722721e-01,   3.54410646e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.42060676e-01,   7.83702183e-02,   6.15413692e-03,
         2.46165477e-02,   4.51040143e-02,   1.80416057e-01,
         0.00000000e+00,   0.00000000e+00,  -5.43913492e-02,
        -2.17565397e-01,   0.00000000e+00,   0.00000000e+00,
         9.90280317e-02,   3.96112127e-01,   0.00000000e+00,
         0.00000000e+00,  -1.35204047e-01,  -5.40816187e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.81512026e-01,
         7.26048103e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.60005862e-01,   6.40023449e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.65368177e-03,
         4.00084331e-02,  -1.89821483e-03,   9.72065333e-03,
         0.00000000e+00,   0.00000000e+00,   4.57189652e-04,
        -2.17465941e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.03603382e-03,
         9.53421925e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.14034504e-04,  -2.54854316e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.72081494e-02,   1.08992815e-01,  -5.58778161e-03,
         2.29925580e-02,   0.00000000e+00,   0.00000000e+00,
         6.14034504e-04,  -2.54854316e-03,   0.00000000e+00,
         0.00000000e+00,  -4.90742373e-03,   2.02669766e-02,
         0.00000000e+00,   0.00000000e+00,   1.56756365e-04,
        -6.77534587e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.81937552e-06,
         2.72776442e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.52359030e-07,   3.85943781e-06,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.85281109e-04,   7.41470649e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.54706901e-05,   1.05159142e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.51574266e-05,
         3.41636218e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.12040383e-05,   4.94631887e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.43232709e-02,
         1.77293086e-01,  -9.27297977e-03,   3.70923093e-02,
         0.00000000e+00,   0.00000000e+00,   1.01489594e-03,
        -4.06045063e-03,   0.00000000e+00,   0.00000000e+00,
        -8.11362933e-03,   3.24601496e-02,   0.00000000e+00,
         0.00000000e+00,   1.40170332e-04,  -5.74512067e-04,
         0.00000000e+00,   0.00000000e+00,   1.53276624e-06,
         1.20062622e-10,   9.58641451e-06,   4.44343591e-07,
         0.00000000e+00,   0.00000000e+00,   2.49684976e-06,
         1.98031116e-06,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.61281761e-04,
         2.72600506e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.88877520e-04,   1.21852241e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.49073763e-04,
         1.43319607e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.93421169e-04,   3.03689214e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.09182150e-04,   3.39481621e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.27209845e-03,   5.09953845e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.32302116e-02,   1.72924890e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.54533205e-04,   8.72570803e-03,
        -3.82543791e-03,   4.35591612e-02,   0.00000000e+00,
         0.00000000e+00,   7.10422082e-04,  -1.13569778e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.40511072e-03,   3.93494085e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.32510461e-03,  -1.80630646e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.52519810e-03,
         2.29424912e-02,  -2.46353612e-02,   1.11452000e-01,
         0.00000000e+00,   0.00000000e+00,   3.32510461e-03,
        -1.80630646e-02,   0.00000000e+00,   0.00000000e+00,
        -1.69475396e-02,   8.69304047e-02,   0.00000000e+00,
         0.00000000e+00,   2.83210657e-03,  -1.77806237e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.47766603e-05,   1.79121748e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.64941325e-05,   1.10955920e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.22536905e-03,   4.93200427e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.38871283e-04,
         3.28586471e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.83946861e-04,   2.41731937e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.15793727e-04,   2.13825800e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.27309436e-03,   3.70924010e-02,
        -4.43165568e-02,   1.77301182e-01,   0.00000000e+00,
         0.00000000e+00,   6.63460479e-03,  -2.66221460e-02,
         0.00000000e+00,   0.00000000e+00,  -3.26688508e-02,
         1.31243210e-01,   0.00000000e+00,   0.00000000e+00,
         3.71750181e-03,  -1.62577411e-02,   0.00000000e+00,
         0.00000000e+00,   1.46224847e-04,   1.34966780e-05,
         7.18265232e-04,   8.84961210e-04,   0.00000000e+00,
         0.00000000e+00,  -1.09688007e-04,   1.84862087e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.99780303e-03,   1.80452829e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.42969811e-03,   1.73938135e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.69034421e-03,   1.42924417e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.22113779e-03,   1.87901877e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.25786022e-03,
         2.87934934e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.10865514e-03,   3.76818212e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.80801708e-02,
         7.23673663e-02,  -4.30821171e-02,   1.73073418e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.46826279e-03,   3.63507732e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.50733072e-03,
         1.74732304e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.57256391e-02,   1.06346464e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.19914887e-02,   5.24738738e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.04962018e-05,
         2.87023905e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.56746303e-05,   3.94645717e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.35678535e-02,   1.74276453e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.13827420e-02,
         8.55829153e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.20095426e-05,   3.84417919e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.95695635e-04,
         2.75792858e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.31771379e-03,   6.16689257e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.13288419e-03,
         8.79389864e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.25353490e-02,   1.70328969e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.93878479e-04,
        -1.17380491e-03,  -3.72666108e-03,  -7.80731125e-03,
         0.00000000e+00,   0.00000000e+00,  -6.77068818e-03,
         3.91410716e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.41135488e-03,
        -8.79973233e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.78836054e-03,   2.21586067e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.53733085e-04,  -2.42030202e-03,   1.30858229e-03,
        -1.64498467e-02,   0.00000000e+00,   0.00000000e+00,
        -2.60066689e-02,   1.11031840e-01,   0.00000000e+00,
         0.00000000e+00,  -3.55456726e-04,  -1.73110363e-02,
         0.00000000e+00,   0.00000000e+00,  -1.21408778e-02,
         5.89529406e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.55821032e-05,
        -6.23560010e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.45655611e-05,  -6.70671046e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.47866344e-04,  -1.84230031e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.68561538e-04,  -2.44958193e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.29135764e-04,
        -1.44897322e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.18131638e-04,  -2.89995195e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.01515886e-03,
        -4.06066097e-03,   6.64255607e-03,  -2.66285071e-02,
         0.00000000e+00,   0.00000000e+00,  -4.56776723e-02,
         1.82853510e-01,   0.00000000e+00,   0.00000000e+00,
         6.16243227e-03,  -2.56392899e-02,   0.00000000e+00,
         0.00000000e+00,  -2.28622118e-02,   9.38678959e-02,
         0.00000000e+00,   0.00000000e+00,  -2.48227786e-04,
        -5.42516756e-05,  -1.00373343e-03,  -2.50387991e-03,
         0.00000000e+00,   0.00000000e+00,   5.46876859e-04,
        -4.84662579e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.43516242e-03,
        -8.10081773e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.54530788e-03,  -1.53268313e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.61032273e-03,
        -2.04988678e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.41455108e-03,  -1.20897375e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.72183648e-03,  -2.90180631e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.08276552e-02,  -4.55824524e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.76047318e-03,  -7.08015499e-03,   1.12335930e-02,
        -4.66852056e-02,   0.00000000e+00,   0.00000000e+00,
        -4.39501089e-02,   1.76983387e-01,   3.94857934e-02,
         6.96853019e-04,   7.67904895e-03,   2.05884231e-03,
         3.29626326e-02,   1.41287048e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.39216274e-02,   3.23886101e-03,  -7.93878479e-04,
        -1.17380491e-03,  -3.72666108e-03,  -7.80731125e-03,
         0.00000000e+00,   0.00000000e+00,   3.46192020e-02,
         6.02915943e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.89851018e-02,   7.59404074e-02,   6.54056824e-03,
         2.67293760e-03,   2.11816407e-02,   1.88800074e-02,
         0.00000000e+00,   0.00000000e+00,  -2.41135488e-03,
        -8.79973233e-03,   0.00000000e+00,   0.00000000e+00,
         2.35935231e-02,   2.36795879e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.47854889e-02,   2.83897465e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.23733172e-02,
         3.01911560e-03,   4.53733085e-04,  -2.42030202e-03,
         1.30858229e-03,  -1.64498467e-02,   0.00000000e+00,
         0.00000000e+00,   1.45044591e-02,   7.52435102e-03,
         0.00000000e+00,   0.00000000e+00,  -3.55456726e-04,
        -1.73110363e-02,   0.00000000e+00,   0.00000000e+00,
         2.22239281e-02,   9.49818236e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.44474809e-02,   1.26658669e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.60966029e-03,   1.07966863e-01,  -6.81941994e-06,
         2.72776798e-05,  -4.43252053e-05,   1.78760584e-04,
         0.00000000e+00,   0.00000000e+00,   1.36686660e-05,
        -6.08252513e-05,   0.00000000e+00,   0.00000000e+00,
         1.70220422e-04,   1.71527487e-04,   0.00000000e+00,
         0.00000000e+00,  -6.64112899e-04,  -5.76004760e-05,
         0.00000000e+00,   0.00000000e+00,   1.86932751e-02,
         1.72820284e-07,  -1.85272718e-04,   7.41463936e-04,
        -1.14206555e-03,   4.86536147e-03,   0.00000000e+00,
         0.00000000e+00,   2.25074695e-04,  -1.66406699e-03,
         0.00000000e+00,   0.00000000e+00,   3.90927273e-04,
         4.69701831e-03,   0.00000000e+00,   0.00000000e+00,
        -3.70013435e-03,  -1.62845823e-03,   0.00000000e+00,
         0.00000000e+00,   4.01290856e-03,   3.09624327e-06,
         1.86605132e-02,   1.14728113e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.99875175e-05,   2.54616957e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.72395714e-04,
         2.44832786e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.83110453e-02,   1.86159810e-05,  -8.49459853e-05,
         3.41467065e-04,  -3.80030667e-04,   2.25418641e-03,
         0.00000000e+00,   0.00000000e+00,  -1.79146861e-04,
        -1.04234712e-03,   0.00000000e+00,   0.00000000e+00,
         1.23086056e-03,   2.22917838e-03,   0.00000000e+00,
         0.00000000e+00,  -3.61915432e-03,  -1.10576560e-03,
         0.00000000e+00,   0.00000000e+00,   4.64056695e-04,
         4.90535376e-06,   2.90028730e-03,   1.48763062e-04,
         0.00000000e+00,   0.00000000e+00,   1.92433244e-02,
         1.53257591e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.36683372e-02,   1.74818094e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.06960210e-02,
         8.62223938e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.82670262e-02,   7.87451818e-04,  -2.87685686e-04,
         2.42712820e-03,  -1.61853974e-03,   1.61418722e-02,
         0.00000000e+00,   0.00000000e+00,  -1.58947777e-03,
        -5.68110558e-03,   0.00000000e+00,   0.00000000e+00,
         2.08096091e-03,   1.62147944e-02,   0.00000000e+00,
         0.00000000e+00,  -8.42465280e-03,  -6.55086273e-03,
         0.00000000e+00,   0.00000000e+00,   3.42488203e-03,
         2.75400608e-05,   1.34684519e-02,   8.33011038e-04,
         0.00000000e+00,   0.00000000e+00,   2.61932055e-03,
         6.37199052e-04,   0.00000000e+00,   0.00000000e+00,
         1.74442143e-02,   4.17179155e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.02719969e-03,   1.45961232e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.56830796e-03,
         1.45807517e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.75513783e-03,   8.34810292e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.65336770e-02,
         5.29642589e-04,   6.44103083e-04,   1.96687274e-03,
         3.41283827e-03,   1.34830069e-02,   0.00000000e+00,
         0.00000000e+00,  -5.68805216e-03,  -6.40765494e-03,
         0.00000000e+00,   0.00000000e+00,   7.73551050e-03,
         1.47945047e-02,   0.00000000e+00,   0.00000000e+00,
        -1.12397830e-02,  -9.03631727e-03,   0.00000000e+00,
         0.00000000e+00,   4.84899283e-05,   6.47770592e-05,
         1.28866866e-03,   1.81793019e-03,   0.00000000e+00,
         0.00000000e+00,   9.37503850e-03,   1.11044454e-03,
         0.00000000e+00,   0.00000000e+00,   3.50958660e-03,
         6.87091588e-03,   0.00000000e+00,   0.00000000e+00,
         1.84750451e-02,   8.29511492e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.23195969e-02,   1.72437739e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.36335700e-04,
         7.55632363e-03,   5.61429503e-03,   3.13338839e-02,
         0.00000000e+00,   0.00000000e+00,  -1.88280039e-03,
        -9.22257592e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.50149045e-03,
         4.13532140e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.50291969e-03,  -1.87977374e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.69982525e-03,   2.01008979e-02,  -1.37311911e-02,
         8.43573259e-02,   0.00000000e+00,   0.00000000e+00,
         1.50291969e-03,  -1.87977374e-02,   0.00000000e+00,
         0.00000000e+00,  -1.35439791e-02,   1.19185871e-01,
         0.00000000e+00,   0.00000000e+00,   2.68245152e-03,
        -4.50910663e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.60777410e-05,
         3.84566017e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.04402057e-04,   1.71434989e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.51309143e-03,   6.22023327e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.56211083e-03,   1.82227015e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.81685812e-04,
         3.91921548e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.24702636e-03,   1.33047964e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.11537769e-03,
         3.24615482e-02,  -3.27858412e-02,   1.31336802e-01,
         0.00000000e+00,   0.00000000e+00,   6.30924617e-03,
        -2.57567410e-02,   0.00000000e+00,   0.00000000e+00,
        -4.28883166e-02,   1.78543217e-01,   0.00000000e+00,
         0.00000000e+00,   8.74261354e-03,  -5.35858490e-02,
         0.00000000e+00,   0.00000000e+00,   1.21066752e-03,
         7.36903016e-03,   6.80040966e-03,   4.03929134e-02,
         0.00000000e+00,   0.00000000e+00,  -3.41001714e-03,
         2.98021231e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.85309145e-03,
         2.09620363e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.22706378e-03,   5.58702605e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.05446209e-03,
         7.89957210e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.91969064e-03,   2.25186656e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.62750443e-03,   6.38711274e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.04972055e-02,   9.42039106e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.58165820e-02,   6.33379209e-02,  -6.31623651e-02,
         2.56824913e-01,   0.00000000e+00,   0.00000000e+00,
         9.94981014e-03,  -4.56455224e-02,   0.00000000e+00,
         0.00000000e+00,  -4.05053699e-02,   1.75065863e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.11105460e-03,   1.63562095e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.64985566e-03,
         2.46376539e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.15132661e-02,   5.20912958e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.96418303e-02,   9.47944665e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.61011968e-04,
         1.07155893e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.30788612e-03,   6.10907774e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.13903783e-02,   8.55890244e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.02515316e-02,
         1.61883660e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.07882102e-03,   1.81680259e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.31771379e-03,
         6.16689257e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.72126010e-03,   2.97178852e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.24955447e-02,
         5.74287639e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.17018722e-02,   1.67703526e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.91064011e-02,   1.59842027e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.35358981e-03,  -1.74443706e-04,
        -1.42605499e-02,  -3.99454092e-03,   0.00000000e+00,
         0.00000000e+00,   1.23885037e-03,   1.81368380e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.21445890e-02,  -7.87973045e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.58780004e-03,   2.93475649e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.50918650e-04,
        -3.51394575e-04,  -6.26447154e-03,  -1.05033612e-02,
         0.00000000e+00,   0.00000000e+00,  -9.45121052e-03,
         5.68012068e-02,   0.00000000e+00,   0.00000000e+00,
        -1.47615711e-02,  -3.11358482e-02,   0.00000000e+00,
         0.00000000e+00,  -1.41815116e-02,   1.16635741e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.83835364e-04,  -7.35959087e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.10961879e-03,  -4.68247457e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.33651518e-03,  -5.65777785e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.83124574e-03,
        -3.22291125e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.03101697e-03,  -4.82590263e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.95883486e-03,  -2.47489616e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.44478441e-04,  -5.77958554e-04,
         4.03869362e-03,  -1.65146945e-02,   0.00000000e+00,
         0.00000000e+00,  -2.33072684e-02,   9.42239412e-02,
         0.00000000e+00,   0.00000000e+00,   9.63022999e-03,
        -5.42959421e-02,   0.00000000e+00,   0.00000000e+00,
        -4.22120713e-02,   2.11688129e-01,   0.00000000e+00,
         0.00000000e+00,  -1.93672887e-03,  -2.35341314e-02,
        -1.32743197e-02,  -1.14572827e-01,   0.00000000e+00,
         0.00000000e+00,   8.54623041e-03,  -6.72140296e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.71464594e-03,  -1.46623017e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.52997913e-03,  -7.25685302e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.82265261e-03,  -1.74378561e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.28314877e-04,  -1.75254918e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.96710748e-03,
        -7.41030416e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.82800951e-02,  -1.37109531e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.35689530e-04,
        -1.01954655e-03,   5.88425515e-03,  -2.94734689e-02,
         0.00000000e+00,   0.00000000e+00,  -4.31444787e-02,
         1.81627224e-01,   0.00000000e+00,   0.00000000e+00,
         1.19813395e-02,  -9.61542469e-02,   0.00000000e+00,
         0.00000000e+00,  -3.76513058e-02,   1.98600711e-01,
         1.08932734e-01,   8.01087529e-05,   2.26894377e-02,
         3.70782594e-04,   1.06610542e-01,   6.45527756e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.05054999e-01,   1.72195376e-03,
        -2.35358981e-03,  -1.74443706e-04,  -1.42605499e-02,
        -3.99454092e-03,   0.00000000e+00,   0.00000000e+00,
         1.08404904e-01,   3.50258229e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.00832889e-01,   3.44343727e-02,
         1.98203975e-02,   4.84719655e-04,   7.65364639e-02,
         1.21432019e-02,   0.00000000e+00,   0.00000000e+00,
        -1.21445890e-02,  -7.87973045e-03,   0.00000000e+00,
         0.00000000e+00,   9.48071381e-02,   3.25049773e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.03051817e-02,   2.63653754e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.87092870e-02,   8.11357274e-03,  -2.50918650e-04,
        -3.51394575e-04,  -6.26447154e-03,  -1.05033612e-02,
         0.00000000e+00,   0.00000000e+00,   5.23672373e-02,
         7.34644855e-03,   0.00000000e+00,   0.00000000e+00,
        -1.47615711e-02,  -3.11358482e-02,   0.00000000e+00,
         0.00000000e+00,   9.41696057e-02,   2.99548475e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.41420598e-02,
         7.93654872e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.94256265e-02,   1.97702506e-01,
        -9.67984557e-07,   3.87193823e-06,  -2.52042783e-05,
         1.09924037e-04,   0.00000000e+00,   0.00000000e+00,
         5.29078435e-06,  -5.96472832e-05,   0.00000000e+00,
         0.00000000e+00,   1.28576359e-03,   3.62217369e-04,
         0.00000000e+00,   0.00000000e+00,  -4.30138961e-03,
        -3.53667856e-04,   0.00000000e+00,   0.00000000e+00,
         1.21756624e-01,   1.03419081e-04,  -2.61648184e-05,
         1.05714445e-04,  -4.22532213e-04,   3.03279346e-03,
         0.00000000e+00,   0.00000000e+00,  -4.75462258e-04,
        -1.69436290e-03,   0.00000000e+00,   0.00000000e+00,
         6.76504429e-03,   9.96097735e-03,   0.00000000e+00,
         0.00000000e+00,  -2.24963789e-02,  -9.56701277e-03,
         0.00000000e+00,   0.00000000e+00,   2.60189461e-02,
         4.52998113e-04,   1.19126546e-01,   7.20290271e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.39552405e-05,   2.50941820e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.64120092e-03,   1.34980811e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.17753400e-01,   2.07651935e-03,
        -1.11738904e-05,   4.94390704e-05,   4.21221718e-04,
         1.46864564e-03,   0.00000000e+00,   0.00000000e+00,
        -1.68535423e-03,  -1.13716326e-03,   0.00000000e+00,
         0.00000000e+00,   8.39924108e-03,   4.78778248e-03,
         0.00000000e+00,   0.00000000e+00,  -1.98864242e-02,
        -5.67275437e-03,   0.00000000e+00,   0.00000000e+00,
         2.15842027e-03,   1.48468299e-04,   1.27118380e-02,
         3.24148982e-03,   0.00000000e+00,   0.00000000e+00,
         1.20028511e-01,   3.11743715e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.15574351e-02,   8.69115251e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.69182168e-02,   1.69342545e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.13595758e-01,   3.84125712e-02,
         7.89138068e-04,   3.56109936e-04,   5.43823618e-03,
         1.02994661e-02,   0.00000000e+00,   0.00000000e+00,
        -9.25531474e-03,  -5.88633318e-03,   0.00000000e+00,
         0.00000000e+00,   2.04754430e-02,   3.29082551e-02,
         0.00000000e+00,   0.00000000e+00,  -4.55307880e-02,
        -3.01199165e-02,   0.00000000e+00,   0.00000000e+00,
         2.22061268e-02,   5.71960592e-04,   8.46437601e-02,
         1.32665629e-02,   0.00000000e+00,   0.00000000e+00,
         1.08068802e-02,   6.51840102e-03,   0.00000000e+00,
         0.00000000e+00,   1.05981167e-01,   3.57530776e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.56830796e-03,   1.45807517e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.27489267e-02,   6.94173579e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.52666926e-02,   3.21897402e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.96776679e-02,   1.05390798e-02,   3.04953856e-03,
         3.07839643e-04,   1.95872593e-02,   8.91739784e-03,
         0.00000000e+00,   0.00000000e+00,  -2.33516065e-02,
        -6.55930874e-03,   0.00000000e+00,   0.00000000e+00,
         4.00738826e-02,   2.65100177e-02,   0.00000000e+00,
         0.00000000e+00,  -5.48970264e-02,  -2.78117345e-02,
         0.00000000e+00,   0.00000000e+00,   2.25861695e-04,
         3.16046199e-04,   5.49411220e-03,   9.07397036e-03,
         0.00000000e+00,   0.00000000e+00,   5.66675641e-02,
         6.25406491e-03,   0.00000000e+00,   0.00000000e+00,
         1.34824930e-02,   2.81206085e-02,   0.00000000e+00,
         0.00000000e+00,   1.03621563e-01,   2.63146591e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.84512780e-02,
         1.75328494e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.05925678e-02,   1.78171837e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.72776353e-05,
         3.55362233e-11,   1.78664628e-04,   3.68717554e-07,
         0.00000000e+00,   0.00000000e+00,  -6.04322182e-05,
        -1.54454384e-06,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.18172209e-04,
         2.13166057e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.12220788e-04,  -6.78667426e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.85631270e-06,   1.25004221e-08,   1.07798795e-04,
         3.52157837e-06,   0.00000000e+00,   0.00000000e+00,
        -5.44905053e-05,  -1.18222515e-05,   0.00000000e+00,
         0.00000000e+00,  -1.20938842e-05,   1.40050335e-03,
         0.00000000e+00,   0.00000000e+00,   8.20033608e-04,
        -4.45080643e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.67326476e-03,
         1.86934047e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.04068374e-02,   1.21834188e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.00085144e-03,   4.01410424e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.33481654e-03,   2.63360082e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.11613156e-04,
         4.65441235e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.25989121e-04,   2.21599581e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.83079000e-07,
         1.53279625e-06,  -3.66327745e-05,   1.59782775e-04,
         0.00000000e+00,   0.00000000e+00,   6.54339272e-05,
        -3.05181047e-04,   0.00000000e+00,   0.00000000e+00,
        -1.87545352e-03,   9.83792699e-03,   0.00000000e+00,
         0.00000000e+00,   5.60356758e-03,  -2.95663685e-02,
         0.00000000e+00,   0.00000000e+00,  -1.48687482e-01,
         6.30088539e-01,  -2.67916296e-02,   1.59051506e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.30939617e-04,
         3.43219738e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.26920916e-03,   2.25522293e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.67651619e-02,
         1.40544070e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.84899283e-05,   6.47770592e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.25861695e-04,   3.16046199e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.59825043e-07,   2.13100057e-07,   1.24428308e-05,
         3.33943692e-05,   0.00000000e+00,   0.00000000e+00,
        -1.38905001e-05,  -8.99031350e-05,   0.00000000e+00,
         0.00000000e+00,  -1.72865904e-03,   8.59093471e-03,
         0.00000000e+00,   0.00000000e+00,   5.74023765e-03,
        -2.72409276e-02,   0.00000000e+00,   0.00000000e+00,
        -9.19664312e-02,   3.69841572e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.41332428e-04,   1.79818935e-07,
         4.83725274e-03,   8.19068364e-05,   0.00000000e+00,
         0.00000000e+00,  -1.60044556e-03,  -2.03650787e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.25326424e-03,   1.60714874e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.04234405e-04,  -4.18517818e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.04624627e-04,
         1.08288826e-06,   2.84563330e-03,   4.18261046e-04,
         0.00000000e+00,   0.00000000e+00,  -1.28980722e-03,
        -1.04288693e-03,   0.00000000e+00,   0.00000000e+00,
         6.40519953e-03,   1.02488532e-02,   0.00000000e+00,
         0.00000000e+00,  -5.62439248e-04,  -2.71141645e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.00366769e-03,   4.01635725e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.39153268e-03,   2.63813811e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.62927576e-03,   1.87465593e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.75307294e-02,
         1.24528723e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.33717740e-04,   2.97596710e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.34888123e-03,   1.44900652e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.53138241e-06,   1.01385811e-05,
        -3.71876508e-04,   1.75707460e-03,   0.00000000e+00,
         0.00000000e+00,   7.74316339e-04,  -3.92631972e-03,
         0.00000000e+00,   0.00000000e+00,  -5.81778577e-03,
         5.04874697e-02,   0.00000000e+00,   0.00000000e+00,
         1.40617550e-02,  -1.36441687e-01,   0.00000000e+00,
         0.00000000e+00,  -7.57003510e-03,   1.43674230e-01,
        -4.98806077e-02,   6.67933984e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.72522477e-03,   1.37879523e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.53679058e-02,   9.32758956e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.40985453e-02,   5.21363242e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.28866866e-03,   1.81793019e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.49411220e-03,
         9.07397036e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.13347130e-06,
         6.63334993e-06,   8.20069481e-05,   1.88468830e-03,
         0.00000000e+00,   0.00000000e+00,   2.06276212e-04,
        -4.61388092e-03,   0.00000000e+00,   0.00000000e+00,
        -5.11387490e-03,   5.65905954e-02,   0.00000000e+00,
         0.00000000e+00,   1.66292683e-02,  -1.54015866e-01,
         0.00000000e+00,   0.00000000e+00,  -3.67234311e-02,
         1.62101718e-01,  -7.18126246e-02,   3.87047334e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.44625559e-04,   3.49264962e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.78346021e-05,
         8.40481676e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.95535648e-04,   1.69677494e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.69084269e-04,   5.19803626e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.57194382e-03,
         1.83250073e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.87894377e-02,   1.19310790e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.02993226e-04,   4.49204865e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.85997825e-03,
         1.95929517e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.08742449e-01,   5.58084716e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.13288419e-03,
         8.79389864e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.24955447e-02,   5.74287639e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.77331535e-02,
         2.50857264e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.07691309e-04,   6.93127115e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.04004233e-03,   2.76067544e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.24626276e-02,   3.59812836e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.41047335e-04,
         6.72408777e-07,   2.18282870e-03,   2.03898917e-04,
         0.00000000e+00,   0.00000000e+00,  -8.91029283e-04,
        -4.72841183e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.65949202e-03,
         1.88627322e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.74566883e-05,  -4.07105440e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.76904025e-05,   2.34763609e-06,   1.12308639e-03,
         9.07153900e-04,   0.00000000e+00,   0.00000000e+00,
        -3.86181565e-04,  -2.17650139e-03,   0.00000000e+00,
         0.00000000e+00,   1.03976987e-03,   1.06753594e-02,
         0.00000000e+00,   0.00000000e+00,   2.43890578e-03,
        -2.35330184e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.17349345e-04,
         4.70030186e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.60428327e-04,   2.32354718e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.23448997e-04,   3.04775210e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.98110664e-03,   1.57958456e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.76293810e-03,
         1.93582676e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.90329286e-02,   1.22366589e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.24080947e-06,
         4.97043854e-06,  -4.94208882e-04,   2.15623757e-03,
         0.00000000e+00,   0.00000000e+00,   1.20948971e-03,
        -5.37671607e-03,   0.00000000e+00,   0.00000000e+00,
        -6.33175819e-03,   3.21395159e-02,   0.00000000e+00,
         0.00000000e+00,   1.38318921e-02,  -7.14425590e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.08742449e-01,
         5.58084716e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.47514404e-04,
         3.01066701e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.37900185e-03,   1.62671067e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.51298352e-03,   9.82086216e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.10946732e-02,   6.04638548e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.77331535e-02,   2.50857264e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.14474604e-06,   6.56567510e-06,  -5.20334693e-04,
         3.32853945e-03,   0.00000000e+00,   0.00000000e+00,
         1.50775560e-03,  -8.30285398e-03,   0.00000000e+00,
         0.00000000e+00,  -8.26748940e-03,   4.52850461e-02,
         0.00000000e+00,   0.00000000e+00,   1.89370516e-02,
        -9.97373567e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.24626276e-02,   3.59812836e-01,   1.77293085e-01,
         1.10525566e-09,   3.70922775e-02,   1.03426231e-07,
         1.77288074e-01,   1.74773750e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.74274563e-01,   2.51954879e-06,  -4.06038847e-03,
        -2.23100354e-07,  -2.65986997e-02,  -3.55024152e-05,
         0.00000000e+00,   0.00000000e+00,   1.82799952e-01,
         7.14105147e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.74763815e-01,   7.23725413e-05,   3.24597858e-02,
         1.41742658e-06,   1.31147273e-01,   1.90311132e-04,
         0.00000000e+00,   0.00000000e+00,  -2.54150185e-02,
        -3.77329307e-04,   0.00000000e+00,   0.00000000e+00,
         1.75921985e-01,   3.49497524e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.55710714e-02,   1.98645641e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.61554585e-01,
         4.38766625e-04,  -5.73633648e-04,  -3.46888277e-06,
        -1.60585327e-02,  -4.36913469e-04,   0.00000000e+00,
         0.00000000e+00,   9.34058092e-02,   8.53479145e-04,
         0.00000000e+00,   0.00000000e+00,  -4.74926924e-02,
        -8.59760424e-03,   0.00000000e+00,   0.00000000e+00,
         1.95623187e-01,   2.14199217e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.57944417e-02,   1.03002373e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.61216416e-01,   1.08348391e-02,  -3.83229079e-07,
         1.53291631e-06,  -2.80442254e-05,   1.52911936e-04,
         0.00000000e+00,   0.00000000e+00,   2.47726688e-05,
        -2.72652040e-04,   0.00000000e+00,   0.00000000e+00,
         5.87576361e-03,   3.63695329e-03,   0.00000000e+00,
         0.00000000e+00,  -1.93440353e-02,  -9.60828626e-03,
         0.00000000e+00,   0.00000000e+00,   6.16836559e-01,
         1.76693062e-02,  -1.98411010e-06,   9.70076327e-06,
         5.65844648e-04,   1.00689768e-03,   0.00000000e+00,
         0.00000000e+00,  -1.83737456e-03,  -1.83696700e-03,
         0.00000000e+00,   0.00000000e+00,   2.76631518e-02,
         2.37027197e-02,   0.00000000e+00,   0.00000000e+00,
        -7.90326121e-02,  -6.19661932e-02,   0.00000000e+00,
         0.00000000e+00,   1.20373041e-01,   4.13197693e-02,
         4.92279652e-01,   2.34205777e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.54259196e-04,   8.34029276e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.62544050e-02,
         3.50144514e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.11916622e-01,   6.15574591e-02,   1.23007906e-06,
         2.99372772e-06,   1.70444093e-03,   3.97317721e-04,
         0.00000000e+00,   0.00000000e+00,  -4.51206926e-03,
        -7.99468895e-04,   0.00000000e+00,   0.00000000e+00,
         2.66630937e-02,   5.74363441e-03,   0.00000000e+00,
         0.00000000e+00,  -6.01137759e-02,  -1.22860246e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.11916622e-01,
         6.15574591e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.32067785e-03,   1.88576151e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.63950110e-02,
         1.42405186e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.94431723e-01,   1.17772689e+00,   1.43087685e-03,
         9.23557921e-06,   1.39101728e-02,   1.01202814e-03,
         0.00000000e+00,   0.00000000e+00,  -1.96488554e-02,
        -1.89152523e-03,   0.00000000e+00,   0.00000000e+00,
         6.32607229e-02,   2.43435730e-02,   0.00000000e+00,
         0.00000000e+00,  -1.30653806e-01,  -6.35973940e-02,
         0.00000000e+00,   0.00000000e+00,   1.03665488e-01,
         3.61995496e-02,   3.25817992e-01,   2.25430013e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.67126709e-01,   2.29057018e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.75513783e-03,   8.34810292e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.52666926e-02,
         3.21897402e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.14762899e-01,   4.08604220e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.18722721e-01,
         3.54410646e-02,   5.09883049e-03,   2.79530320e-06,
         3.74961365e-02,   3.97987924e-04,   0.00000000e+00,
         0.00000000e+00,  -4.51429091e-02,  -8.06000956e-04,
         0.00000000e+00,   0.00000000e+00,   9.06573329e-02,
         5.28027978e-03,   0.00000000e+00,   0.00000000e+00,
        -1.29270485e-01,  -1.10690662e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.14762899e-01,   4.08604220e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.18722721e-01,   3.54410646e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.51456233e-03,   9.57050679e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.77311056e-02,   8.82544923e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.05224525e-03,   5.05671679e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.32207973e-03,
         3.39315869e-04,   1.48957430e-02,   2.93044600e-03,
         0.00000000e+00,   0.00000000e+00,  -4.19111452e-03,
        -3.59979618e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.29468575e-02,
         7.52207713e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.59660874e-03,  -1.20132980e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.16877196e-04,   8.93918633e-04,   7.14774634e-03,
         8.93185798e-03,   0.00000000e+00,   0.00000000e+00,
        -1.59660874e-03,  -1.20132980e-02,   0.00000000e+00,
         0.00000000e+00,   1.85570017e-02,   3.44430081e-02,
         0.00000000e+00,   0.00000000e+00,  -3.58953294e-03,
        -6.36729206e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.64288862e-04,
         3.45887678e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.47637886e-03,   2.27179651e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.48836927e-03,   1.43984679e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.86623725e-02,   9.59114689e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.63896463e-04,
         3.18377266e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.95623802e-05,   1.51242553e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.60592423e-04,
         1.44241099e-03,  -3.63222460e-03,   1.50459461e-02,
         0.00000000e+00,   0.00000000e+00,   5.03190171e-03,
        -2.16361309e-02,   0.00000000e+00,   0.00000000e+00,
        -1.13611662e-02,   8.40410843e-02,   0.00000000e+00,
         0.00000000e+00,   1.77558790e-02,  -1.82325142e-01,
         0.00000000e+00,   0.00000000e+00,  -2.44286386e-03,
         1.21086231e-01,   2.20833076e-02,   4.68417760e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.05736871e-03,
         2.05730579e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.53224551e-02,   1.32795976e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.02013591e-02,
         5.38919473e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.50958660e-03,   6.87091588e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.34824930e-02,   2.81206085e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.81857898e-04,   2.80234868e-03,  -5.43613987e-03,
         2.81154377e-02,   0.00000000e+00,   0.00000000e+00,
         7.26392495e-03,  -3.92468250e-02,   0.00000000e+00,
         0.00000000e+00,  -1.43032912e-02,   1.38456393e-01,
         0.00000000e+00,   0.00000000e+00,   2.53808972e-02,
        -2.86009472e-01,   0.00000000e+00,   0.00000000e+00,
        -3.10296369e-02,   1.39237407e-01,  -7.85641161e-02,
         5.91128257e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.26542576e-02,   3.91851091e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.94353490e-04,   1.48588928e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.51432036e-05,
         5.15683610e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.51432036e-05,   5.15683610e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.31461838e-03,   2.61925718e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.19250908e-03,
         8.84159855e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.31259428e-02,   5.79330824e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.19250908e-03,   8.84159855e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.31259428e-02,
         5.79330824e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.41105324e-02,   2.39959167e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.96790595e-03,
         1.69309090e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.16259545e-02,   1.07581978e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.86053476e-02,
         3.45303519e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.96790595e-03,   1.69309090e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.16259545e-02,   1.07581978e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.86053476e-02,   3.45303519e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.55122379e-02,   3.00419170e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.60066509e-03,   1.20162313e-03,
         9.94159796e-03,   8.25999913e-03,   0.00000000e+00,
         0.00000000e+00,  -2.57530934e-03,  -8.89784920e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.29850082e-03,   1.51441124e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.00508082e-04,  -1.85085501e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.23187351e-04,
         3.16602037e-03,   1.03760423e-03,   2.37571219e-02,
         0.00000000e+00,   0.00000000e+00,   2.85439878e-03,
        -2.75241129e-02,   0.00000000e+00,   0.00000000e+00,
         3.15932422e-03,   5.60416644e-02,   0.00000000e+00,
         0.00000000e+00,   7.09907166e-03,  -7.74086130e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.22492304e-05,   1.29368386e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.41263668e-04,   6.09746489e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.96796613e-04,   3.48630241e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.56993682e-03,
         1.55252096e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.48050789e-03,   1.05948817e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.33303182e-02,   6.22523707e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.27556973e-03,   5.10231548e-03,
        -9.39067066e-03,   3.79074337e-02,   0.00000000e+00,
         0.00000000e+00,   1.12400487e-02,  -4.59123672e-02,
         0.00000000e+00,   0.00000000e+00,  -2.15312861e-02,
         9.50311750e-02,   0.00000000e+00,   0.00000000e+00,
         2.94369812e-02,  -1.38035040e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.41105324e-02,   2.39959167e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.70057482e-04,   1.04546312e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.64835919e-03,   4.10252903e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.02653787e-03,   2.46963813e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.76820597e-02,
         1.23357557e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.86053476e-02,   3.45303519e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.46648164e-03,
         9.92699891e-03,  -1.68616288e-02,   7.24586748e-02,
         0.00000000e+00,   0.00000000e+00,   1.94589309e-02,
        -8.57513233e-02,   0.00000000e+00,   0.00000000e+00,
        -3.54743747e-02,   1.76473292e-01,   0.00000000e+00,
         0.00000000e+00,   4.69573449e-02,  -2.48633634e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.86053476e-02,
         3.45303519e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.55122379e-02,   3.00419170e-01,
         3.45846747e-01,   4.04314990e-06,   7.23498601e-02,
         2.33415835e-05,   3.45588124e-01,   7.44949814e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.40517258e-01,   1.87573022e-04,
        -7.06580664e-03,  -1.91311334e-05,  -4.60286430e-02,
        -8.75416870e-04,   0.00000000e+00,   0.00000000e+00,
         3.53079561e-01,   1.18295156e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.42505965e-01,   3.15935159e-03,
         6.33110736e-02,   3.57963919e-05,   2.55259118e-01,
         2.08772641e-03,   0.00000000e+00,   0.00000000e+00,
        -4.34531667e-02,  -2.92314092e-03,   0.00000000e+00,
         0.00000000e+00,   3.40348439e-01,   1.30443837e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.67367512e-01,   4.48018703e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.17121736e-01,   3.41642241e-03,  -9.90750886e-04,
        -3.83942145e-05,  -2.72473008e-02,  -2.96822414e-03,
         0.00000000e+00,   0.00000000e+00,   1.78233733e-01,
         4.52465475e-03,   0.00000000e+00,   0.00000000e+00,
        -7.80684136e-02,  -2.41144445e-02,   0.00000000e+00,
         0.00000000e+00,   3.61204806e-01,   4.79954877e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.67257226e-01,
         1.07616909e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.14492500e-01,   5.58015661e-02,
        -1.06550029e-07,   4.26200115e-07,   2.20723452e-06,
         4.15828462e-05,   0.00000000e+00,   0.00000000e+00,
        -3.53537092e-05,  -7.27325678e-05,   0.00000000e+00,
         0.00000000e+00,   7.96232275e-03,   8.38149282e-04,
         0.00000000e+00,   0.00000000e+00,  -2.56359362e-02,
        -2.13998848e-03,   0.00000000e+00,   0.00000000e+00,
         7.38201258e-01,   1.97584703e-03,  -2.05436325e-06,
         1.15836176e-05,   1.05491977e-03,   1.10635805e-03,
         0.00000000e+00,   0.00000000e+00,  -3.19308989e-03,
        -1.89438804e-03,   0.00000000e+00,   0.00000000e+00,
         4.30399345e-02,   1.80675479e-02,   0.00000000e+00,
         0.00000000e+00,  -1.21203819e-01,  -4.37493962e-02,
         0.00000000e+00,   0.00000000e+00,   1.56398720e-01,
         7.60399659e-03,   6.99247042e-01,   9.97968363e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.94741410e-04,   1.31180940e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.48142850e-02,   3.72329253e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.97153927e-01,   2.99623251e-02,
         2.38642788e-06,   5.57232962e-06,   2.86083919e-03,
         6.23600339e-04,   0.00000000e+00,   0.00000000e+00,
        -7.45091714e-03,  -1.13591579e-03,   0.00000000e+00,
         0.00000000e+00,   4.07043879e-02,   6.10754425e-03,
         0.00000000e+00,   0.00000000e+00,  -9.07414253e-02,
        -1.19945752e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.97153927e-01,   2.99623251e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.79027675e-03,   1.78143780e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.43760071e-03,   1.19589457e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.28932862e-01,   5.09880660e-01,
         2.77425477e-03,   3.74585457e-05,   2.57263584e-02,
         3.18543913e-03,   0.00000000e+00,   0.00000000e+00,
        -3.54251531e-02,  -5.09556260e-03,   0.00000000e+00,
         0.00000000e+00,   1.07990183e-01,   4.06216142e-02,
         0.00000000e+00,   0.00000000e+00,  -2.16827266e-01,
        -9.22429417e-02,   0.00000000e+00,   0.00000000e+00,
         1.33567835e-01,   7.55942954e-03,   4.87301335e-01,
         1.38435896e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.87776637e-01,   2.61234061e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.65336770e-02,   5.29642589e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.96776679e-02,   1.05390798e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.18722721e-01,   3.54410646e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.42060676e-01,   7.83702183e-02,   9.90409677e-03,
         3.05361825e-05,   7.05791150e-02,   2.50607973e-03,
         0.00000000e+00,   0.00000000e+00,  -8.27829734e-02,
        -3.95779986e-03,   0.00000000e+00,   0.00000000e+00,
         1.63507369e-01,   1.72878965e-02,   0.00000000e+00,
         0.00000000e+00,  -2.25832038e-01,  -3.04021271e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.18722721e-01,
         3.54410646e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.42060676e-01,   7.83702183e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.59786513e-03,
         3.43914605e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.64257588e-02,   2.25703035e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.81512026e-01,
         7.26048103e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.60005862e-01,   6.40023449e-01,
         3.82896793e-02,   1.53158717e-01,  -3.80885178e-02,
         1.97621797e-01,   1.35134480e-02,   7.65172569e-02,
         4.74278239e-02,  -1.97745322e-01,   9.03843181e-03,
        -4.83197565e-02,   2.82175507e-02,   2.61896328e-02,
        -1.67682679e-02,   6.99135291e-02,  -3.19556821e-03,
         1.70836137e-02,   8.24955358e-04,  -4.04685757e-03,
         3.02592111e-02,   1.61741713e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.05508769e-02,   1.47433910e-02,
        -5.91655643e-02,   2.82768908e-01,  -7.33779778e-04,
         8.97619330e-02,   9.27257929e-03,  -4.50389898e-02,
        -3.27835185e-03,   1.59236875e-02,   0.00000000e+00,
         0.00000000e+00,  -3.41616213e-03,   9.85678327e-02,
         8.00682097e-02,  -3.21194955e-01,   1.61287269e-02,
        -6.81745642e-02,   8.90561150e-03,   1.37526277e-02,
         7.27613540e-04,  -3.10872652e-03,   0.00000000e+00,
         0.00000000e+00,   1.41049296e-02,  -6.00524074e-02,
         1.37984789e-02,   3.36878009e-03,  -2.83083870e-02,
         1.13559565e-01,  -5.70236608e-03,   2.41033483e-02,
         7.27613540e-04,  -3.10872652e-03,   1.07063631e-02,
         6.05892207e-03,   0.00000000e+00,   0.00000000e+00,
        -4.98684568e-03,   2.12317323e-02,   1.72685639e-04,
        -7.98467916e-04,   1.42258541e-02,   1.39267282e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.09636134e-02,
         4.95982127e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.42869077e-02,   1.11037178e-03,
        -5.22588432e-07,   2.09035373e-06,   4.90701156e-08,
         4.37332540e-07,   3.35245021e-10,  -1.99973187e-09,
        -6.54482668e-07,  -5.40596045e-08,   0.00000000e+00,
         0.00000000e+00,   9.35467116e-05,   3.82717551e-07,
        -5.88494196e-08,  -2.82936485e-10,  -2.98380083e-04,
        -7.64874267e-09,   0.00000000e+00,   0.00000000e+00,
         8.24631036e-03,  -0.00000000e+00,  -3.83058382e-05,
         1.53581392e-04,   2.43888580e-05,   3.24415615e-05,
         1.00240431e-07,  -1.82826608e-06,  -8.11701968e-05,
        -5.22787221e-06,   0.00000000e+00,   0.00000000e+00,
         6.68757942e-04,   2.86049201e-05,  -3.54273444e-06,
        -8.28928456e-07,  -1.78025528e-03,  -5.70836509e-07,
         0.00000000e+00,   0.00000000e+00,   1.77059510e-03,
         5.33311242e-12,   8.24631015e-03,   8.38056735e-10,
         3.60941688e-05,  -1.44384907e-04,   7.15186699e-06,
        -3.02204854e-05,   1.44493735e-05,   2.29547988e-06,
        -1.94708503e-07,   4.42137091e-06,   0.00000000e+00,
         0.00000000e+00,   1.59334842e-07,  -2.64525120e-05,
         3.68039961e-04,   3.45514473e-07,   1.58477594e-05,
         6.23228821e-07,   0.00000000e+00,   0.00000000e+00,
        -7.26201548e-06,  -9.19951981e-15,  -4.59442996e-05,
        -3.87901023e-10,   8.13859012e-03,   2.36727304e-11,
        -8.00072779e-05,   3.21690282e-04,   6.44503746e-05,
         6.87143072e-05,   2.78400670e-07,  -5.19586907e-06,
        -1.89266690e-04,  -1.16323644e-05,   0.00000000e+00,
         0.00000000e+00,   7.45458462e-04,   6.11066317e-05,
        -4.33859396e-06,  -3.32376801e-06,  -1.65137999e-03,
        -8.74011382e-07,   0.00000000e+00,   0.00000000e+00,
         1.76574923e-04,   2.38899434e-11,   1.11713113e-03,
         2.76544168e-09,  -1.33189214e-05,  -1.71983506e-09,
         8.46234522e-03,   7.98103064e-09,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.47419428e-05,   1.06795512e-06,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.67980755e-04,   1.56994440e-07,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.13799373e-03,   1.16621435e-11,
        -2.18407020e-03,   1.06184287e-02,   6.25205470e-04,
         3.48946462e-03,   3.58787649e-04,  -1.81980902e-03,
        -1.64190590e-03,   2.49659852e-04,   0.00000000e+00,
         0.00000000e+00,   2.00692723e-03,   3.89105816e-03,
         5.51023698e-04,  -2.50316783e-03,  -4.66688703e-03,
         7.94312725e-04,   0.00000000e+00,   0.00000000e+00,
         1.51388063e-03,   1.69849560e-08,   6.03757089e-03,
         1.28870055e-06,  -4.34113167e-05,  -1.18342415e-06,
         1.06204286e-03,   2.76494805e-06,   0.00000000e+00,
         0.00000000e+00,   8.20384345e-03,   1.61154520e-04,
         3.09445739e-03,  -1.24192912e-02,   6.06204964e-04,
        -2.64278913e-03,   7.36813520e-04,   5.44057657e-04,
        -1.72784890e-06,   1.54974255e-04,   0.00000000e+00,
         0.00000000e+00,   4.97769063e-04,  -2.33087440e-03,
         2.38145989e-03,   1.42695047e-04,   8.56129801e-05,
         7.90517954e-06,   0.00000000e+00,   0.00000000e+00,
        -1.00961225e-06,  -1.57791959e-11,  -2.74303420e-05,
        -3.98156366e-08,   3.92692690e-03,   1.99194446e-08,
        -1.23651381e-05,  -1.54730737e-07,   0.00000000e+00,
         0.00000000e+00,  -6.39156010e-05,  -1.00855674e-04,
         7.67255986e-03,   6.68091644e-06,  -6.46601276e-03,
         3.26725928e-02,   1.61615298e-03,   1.13928943e-02,
         1.28482412e-03,  -6.42503321e-03,  -4.21924702e-03,
         1.17424346e-03,   0.00000000e+00,   0.00000000e+00,
         2.78613261e-03,   1.29751650e-02,   2.05109323e-03,
        -8.96879918e-03,  -6.80089278e-03,   2.90868507e-03,
         0.00000000e+00,   0.00000000e+00,   2.45335857e-05,
         6.03846627e-08,   6.66067986e-04,   4.55665769e-06,
        -1.13534189e-05,  -4.20160753e-06,   4.22600090e-03,
         9.73701566e-06,   0.00000000e+00,   0.00000000e+00,
         2.03460386e-03,   5.31017437e-04,   2.05162615e-05,
        -3.59095551e-04,   8.92333984e-03,   1.74009825e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.12915267e-04,
         2.11264296e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.39952597e-03,   4.86608604e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.92637417e-03,
         9.23165632e-09,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.67052487e-03,   2.41750486e-06,
        -6.82837675e-02,   2.76041614e-01,   1.80646400e-01,
         2.26338628e-02,   2.05332808e-02,   7.09013907e-02,
         8.17705891e-02,   3.27082356e-01,   2.88048399e-03,
        -4.33933982e-02,   1.75872062e-02,  -2.13814920e-01,
         1.41584435e-01,   1.11631897e-01,  -1.01840488e-03,
         1.53418831e-02,  -6.21801639e-03,   7.55949899e-02,
         1.14098735e-03,  -2.04990086e-02,   1.44408234e-01,
         6.08994390e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.44811634e-01,   5.36519450e-02,   1.43178069e-02,
         7.77206637e-02,   2.16696557e-02,   3.69780572e-01,
         1.72877759e-02,  -1.78160719e-01,  -6.11215180e-03,
         6.29893262e-02,   0.00000000e+00,   0.00000000e+00,
         3.22540875e-02,   3.68918404e-01,   1.59032428e-02,
        -6.79941769e-02,   6.71687349e-02,  -3.33079988e-01,
         4.98667515e-02,   9.71411261e-02,   3.48781773e-03,
        -2.25898655e-02,   0.00000000e+00,   0.00000000e+00,
         4.17129687e-02,  -2.59574356e-01,   8.35524117e-02,
         7.95445326e-02,  -5.62264541e-03,   2.40395718e-02,
        -2.37477340e-02,   1.17761559e-01,   3.48781773e-03,
        -2.25898655e-02,   5.84986600e-02,   4.12340613e-02,
         0.00000000e+00,   0.00000000e+00,  -1.47477615e-02,
         9.17733938e-02,   2.23220082e-03,  -2.00149403e-02,
         8.90768269e-02,   3.00100827e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.97317898e-02,   3.32473377e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.98660291e-02,   2.29337327e-02,  -1.48933948e-07,
         5.95735791e-07,   2.42736670e-07,   3.11078714e-06,
         2.98739765e-07,  -1.21494998e-06,  -4.28786732e-06,
        -7.35220363e-08,   0.00000000e+00,   0.00000000e+00,
         6.07824813e-04,   3.58879526e-06,  -1.11936437e-06,
        -2.86501154e-06,  -1.94075952e-03,   5.36645989e-07,
         0.00000000e+00,   0.00000000e+00,   5.37428723e-02,
         5.45453099e-10,  -1.58201141e-05,   6.46087392e-05,
         1.07802027e-04,   3.47931218e-04,   4.97041864e-05,
        -2.33466299e-04,  -5.02024861e-04,   7.67664317e-06,
         0.00000000e+00,   0.00000000e+00,   4.19873032e-03,
         4.73217238e-04,   1.15444120e-05,  -4.92050355e-04,
        -1.14577813e-02,   1.00685673e-04,   0.00000000e+00,
         0.00000000e+00,   1.15393221e-02,   1.71305143e-08,
         5.37424559e-02,   1.57588245e-06,   7.63845263e-06,
        -3.06097539e-05,   2.86415318e-05,  -1.54143599e-04,
         8.50133334e-05,   3.06747607e-05,   1.56762024e-05,
         3.03730130e-05,   0.00000000e+00,   0.00000000e+00,
        -1.60026774e-04,  -1.28737499e-04,   2.37454718e-03,
         4.35413694e-05,   4.80070279e-04,   1.70417699e-05,
         0.00000000e+00,   0.00000000e+00,  -2.28042675e-04,
        -4.81162561e-09,  -1.44255909e-03,  -7.57901662e-07,
         5.32315045e-02,   2.84671898e-07,  -3.56925094e-05,
         1.48828614e-04,   2.81764020e-04,   8.02207904e-04,
         1.20093404e-04,  -5.74910470e-04,  -1.15619915e-03,
         2.34376055e-05,   0.00000000e+00,   0.00000000e+00,
         4.47882485e-03,   1.11545323e-03,   1.52350425e-04,
        -1.19444436e-03,  -1.04262249e-02,   2.48248102e-04,
         0.00000000e+00,   0.00000000e+00,   1.03032710e-03,
         3.44916253e-08,   6.51770207e-03,   3.37430439e-06,
        -3.76455303e-04,  -1.71475129e-06,   5.48433835e-02,
         7.30663697e-06,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.80830350e-05,   1.35743623e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.36914978e-03,
         1.32865280e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.31516506e-02,   1.47536120e-07,   4.96061825e-04,
         3.59277953e-03,   3.52324501e-03,   1.74278816e-02,
         1.29786715e-03,  -1.07042632e-02,  -8.70677863e-03,
         8.21704741e-04,   0.00000000e+00,   0.00000000e+00,
         1.30075166e-02,   2.00035404e-02,   2.53774981e-03,
        -1.79100096e-02,  -2.91506719e-02,   4.13319869e-03,
         0.00000000e+00,   0.00000000e+00,   9.86622316e-03,
         2.82927411e-07,   3.93415993e-02,   3.36267419e-05,
        -1.36878058e-03,  -1.44905711e-05,   6.18132362e-03,
         7.74196593e-05,   0.00000000e+00,   0.00000000e+00,
         5.34021887e-02,   1.24365119e-03,   6.12176057e-04,
        -2.64756600e-03,   2.34186673e-03,  -1.31938394e-02,
         4.06803198e-03,   4.27029569e-03,   4.75177246e-04,
         9.83636799e-04,   0.00000000e+00,   0.00000000e+00,
         4.53815697e-04,  -1.06308262e-02,   1.50046008e-02,
         3.99485277e-03,   2.46342325e-03,   3.09534320e-04,
         0.00000000e+00,   0.00000000e+00,  -3.16664701e-05,
        -1.51135644e-07,  -8.54844982e-04,  -2.70909047e-05,
         2.57688843e-02,   5.10937665e-06,  -3.34438811e-04,
        -6.53837417e-05,   0.00000000e+00,   0.00000000e+00,
        -2.56704423e-03,  -8.90344198e-04,   5.09324358e-02,
         2.99453577e-04,   2.30520404e-03,   1.08416534e-02,
         1.01621520e-02,   5.19893608e-02,   3.54684021e-03,
        -3.18517466e-02,  -2.14946198e-02,   3.44499141e-03,
         0.00000000e+00,   0.00000000e+00,   2.04759525e-02,
         5.88141245e-02,   8.29854182e-03,  -5.19523548e-02,
        -4.03038415e-02,   1.27112563e-02,   0.00000000e+00,
         0.00000000e+00,   1.43057411e-04,   7.48251305e-07,
         3.87043641e-03,   8.98032308e-05,  -3.41328070e-04,
        -3.78267023e-05,   2.72200291e-02,   2.07757380e-04,
         0.00000000e+00,   0.00000000e+00,   1.17169588e-02,
         3.53226974e-03,  -1.30593503e-03,  -2.50455814e-03,
         5.67367832e-02,   1.01205034e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.42548506e-03,   1.58972725e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.51596144e-02,   1.17986235e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.56953185e-02,   1.94186688e-06,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.05731212e-02,   9.70243579e-05,  -2.54026507e-02,
         1.19581705e-01,  -5.66717561e-02,   2.88892573e-01,
        -1.94732562e-01,  -4.01701328e-03,  -3.75995477e-02,
        -1.10093729e-02,  -1.60015134e-01,  -7.17330475e-02,
         1.12987255e-03,   4.78597753e-02,  -5.11140914e-04,
         2.25308357e-01,  -9.60424533e-02,  -3.84169813e-01,
        -1.47088183e-03,  -2.21018782e-03,  -6.69118702e-03,
        -1.42332691e-02,  -1.14826600e-02,   6.78555760e-02,
        -1.65313383e-01,  -1.75814903e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.64833916e-01,  -1.56636259e-02,
        -3.26609557e-02,  -1.14921618e-02,  -1.05858482e-01,
        -7.96437121e-02,  -3.41575832e-02,   3.08803903e-01,
        -4.61214695e-03,  -1.43607915e-02,   0.00000000e+00,
         0.00000000e+00,  -1.19230005e-01,  -8.96221412e-02,
        -4.31568633e-03,   2.43296659e-02,  -1.10378049e-02,
         1.45864771e-01,   1.81815641e-02,  -4.21757015e-01,
        -5.79338579e-03,   3.55324703e-02,   0.00000000e+00,
         0.00000000e+00,  -9.49389949e-03,   1.91063219e-01,
        -4.30334044e-02,  -3.34599455e-01,   4.38509419e-04,
        -2.87744322e-03,  -1.25068251e-05,  -1.97896059e-02,
        -2.59890428e-02,   1.16315098e-01,  -7.17665437e-02,
        -1.34611688e-02,   0.00000000e+00,   0.00000000e+00,
        -2.89279650e-03,  -2.03603034e-02,  -1.10154365e-02,
         6.14041679e-02,  -1.07277092e-01,  -1.29321775e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.17605632e-02,
        -1.11062870e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.07062540e-01,  -1.00780497e-02,
         5.41104953e-10,  -2.16441981e-09,  -1.19731966e-06,
        -1.81024373e-08,  -5.05555378e-07,   2.05593492e-06,
         5.07173033e-06,   4.89563944e-09,   0.00000000e+00,
         0.00000000e+00,  -7.18990072e-04,  -2.69299457e-08,
         2.85885988e-06,   1.02644510e-06,   2.29254823e-03,
         3.46233677e-09,   0.00000000e+00,   0.00000000e+00,
        -6.35290024e-02,  -1.30299105e-11,   1.02223906e-07,
        -1.82985286e-06,  -2.19440956e-04,  -1.81501849e-05,
        -2.66727428e-05,   1.62543828e-04,   5.75724784e-04,
         5.79721867e-06,   0.00000000e+00,   0.00000000e+00,
        -5.06359669e-03,  -2.82294073e-05,   1.61611693e-04,
         1.02160267e-04,   1.34508568e-02,   3.64541619e-06,
         0.00000000e+00,   0.00000000e+00,  -1.36405416e-02,
        -3.92050295e-10,  -6.35289506e-02,  -1.77188283e-07,
        -4.30237120e-06,   1.72968756e-05,  -1.08948103e-05,
         1.07401276e-04,  -4.54944544e-05,  -2.49937063e-04,
        -4.13213299e-05,   1.42263727e-05,   0.00000000e+00,
         0.00000000e+00,   2.75713222e-04,   1.88603082e-04,
        -2.74284440e-03,  -3.08046337e-04,  -8.29636317e-04,
         5.25616854e-05,   0.00000000e+00,   0.00000000e+00,
         3.87768927e-04,   5.35675218e-09,   2.45316570e-03,
         4.80029826e-07,  -6.30265349e-02,  -6.61226577e-07,
        -4.70044509e-07,  -4.59711293e-06,  -5.40538378e-04,
        -4.64050442e-05,  -4.89719605e-05,   3.47282886e-04,
         1.31829730e-03,   1.51254327e-05,   0.00000000e+00,
         0.00000000e+00,  -5.53168582e-03,  -7.17067972e-05,
         1.85924004e-04,   2.27228689e-04,   1.21008530e-02,
         8.86341191e-06,   0.00000000e+00,   0.00000000e+00,
        -1.17443201e-03,  -6.42692162e-10,  -7.43013715e-03,
        -3.76932996e-07,   6.24111168e-04,   9.81030884e-07,
        -6.47102286e-02,  -8.28924143e-07,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.05062843e-04,  -1.63183347e-06,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.79107377e-03,  -2.13979406e-06,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.28498106e-02,  -3.13292018e-08,
        -1.36757475e-03,  -4.38719101e-04,  -8.02255243e-03,
        -3.24792757e-03,  -8.16215350e-04,   1.20442335e-02,
         9.54012579e-03,   2.85081997e-04,   0.00000000e+00,
         0.00000000e+00,  -1.99381610e-02,  -3.93319819e-03,
         1.20858557e-03,   8.10266090e-03,   3.29762445e-02,
        -1.42475406e-04,   0.00000000e+00,   0.00000000e+00,
        -1.16628630e-02,  -3.57833923e-09,  -4.65145639e-02,
        -3.48565346e-06,   2.33069866e-03,   1.21092717e-05,
        -7.06607514e-03,  -8.56624705e-06,   0.00000000e+00,
         0.00000000e+00,  -6.34393277e-02,  -2.68856479e-04,
        -2.53689082e-04,   1.33645974e-03,  -4.46251405e-04,
         7.88172240e-03,  -1.31266022e-03,  -1.88979992e-02,
        -1.37823562e-03,   8.88026146e-04,   0.00000000e+00,
         0.00000000e+00,   8.30949466e-04,   1.13748515e-02,
        -1.46629348e-02,  -1.83022224e-02,  -4.98769037e-03,
         2.84776322e-03,   0.00000000e+00,   0.00000000e+00,
         5.38834728e-05,   1.08245245e-07,   1.46242183e-03,
         1.09376424e-05,  -3.05525721e-02,  -2.08276936e-05,
         5.75209561e-04,   2.40922837e-05,   0.00000000e+00,
         0.00000000e+00,   4.59621280e-03,   6.17367172e-04,
        -6.05483194e-02,  -1.12295047e-03,  -4.95091655e-03,
        -1.43644068e-03,  -2.32863766e-02,  -1.03851731e-02,
        -2.21563895e-03,   3.69624138e-02,   2.31704446e-02,
         4.82332288e-04,   0.00000000e+00,   0.00000000e+00,
        -3.74664720e-02,  -1.23651438e-02,   1.58422548e-03,
         2.47822853e-02,   4.34123493e-02,  -8.34292103e-04,
         0.00000000e+00,   0.00000000e+00,  -1.63275705e-04,
        -8.28129195e-09,  -4.43542886e-03,  -8.53861980e-06,
         5.73198673e-04,   3.21358363e-05,  -3.21200959e-02,
        -2.12890156e-05,   0.00000000e+00,   0.00000000e+00,
        -1.42049726e-02,  -7.77301546e-04,   2.77492229e-03,
         1.78438002e-03,  -6.89782149e-02,  -2.28941049e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.26077962e-03,
        -4.92254123e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.79221346e-02,  -4.65302674e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.03930087e-02,
        -4.53599966e-07,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.99077581e-02,  -3.97145069e-05,
         8.87394474e-04,  -2.31824902e-02,  -1.32544773e-04,
        -1.53595359e-01,  -5.30531369e-02,   3.13339602e-01,
         6.88483576e-02,   1.42022867e-03,   1.32934476e-02,
         3.89240111e-03,   5.65738933e-02,   2.53614622e-02,
        -1.47088183e-03,  -2.21018782e-03,  -6.69118702e-03,
        -1.42332691e-02,   5.96337250e-02,   1.09624679e-02,
        -2.51037426e-03,   4.23898395e-02,  -1.70709839e-02,
         1.90082814e-01,   3.58341299e-02,  -1.78499500e-01,
         3.27695169e-02,   1.31078068e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.82775900e-02,   5.53792804e-03,
         1.15473916e-02,   4.06309278e-03,   3.74266253e-02,
         2.81583045e-02,  -4.61214695e-03,  -1.43607915e-02,
        -4.55720645e-02,   2.73262758e-01,   0.00000000e+00,
         0.00000000e+00,   4.21541725e-02,   3.16862119e-02,
         4.38509419e-04,  -2.87744322e-03,  -1.25068251e-05,
        -1.97896059e-02,   2.53881059e-02,   1.05872770e-02,
         7.35499773e-02,  -3.12504607e-01,   0.00000000e+00,
         0.00000000e+00,  -2.89279650e-03,  -2.03603034e-02,
         3.84591691e-02,   1.16358213e-02,  -3.23043088e-03,
         1.72083573e-02,  -1.10687577e-02,   9.68879954e-02,
         1.64280331e-02,  -8.40168302e-02,  -6.44295466e-03,
         1.43285588e-01,   0.00000000e+00,   0.00000000e+00,
        -1.66532056e-02,   1.40674039e-01,   3.26582242e-02,
        -1.53698319e-01,   1.46836166e-02,   1.11235166e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.53711904e-02,
         3.92666543e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.78523241e-02,   3.56312863e-03,
         1.80514293e-07,  -7.22057173e-07,   1.44587135e-06,
        -4.66051297e-06,  -1.26932561e-06,   5.07774039e-06,
        -1.43504243e-06,   9.88256282e-07,   0.00000000e+00,
         0.00000000e+00,   1.75769674e-04,  -8.96396110e-06,
        -3.03144902e-06,   1.20762277e-05,  -5.53821603e-04,
        -2.05717472e-06,   0.00000000e+00,   0.00000000e+00,
         1.54771756e-02,  -2.33303477e-09,   2.20031040e-05,
        -8.77665129e-05,   1.75283903e-04,  -5.34170369e-04,
        -1.43945521e-04,   5.81533463e-04,  -1.23836957e-04,
         5.22785020e-05,   0.00000000e+00,   0.00000000e+00,
         1.39132201e-03,  -9.67179060e-04,  -3.13792348e-04,
         1.27290550e-03,  -3.04790368e-03,  -2.31851455e-04,
         0.00000000e+00,   0.00000000e+00,   3.32317441e-03,
        -5.63560718e-08,   1.54783191e-02,  -4.29818325e-06,
        -1.33048580e-06,   5.32999275e-06,  -1.13635580e-05,
         5.20048214e-05,   3.16697154e-05,  -4.41664635e-05,
         3.51579114e-05,  -1.54755339e-04,   0.00000000e+00,
         0.00000000e+00,  -1.30623823e-05,   8.13423758e-05,
         6.79034746e-04,  -9.15506164e-05,   8.01999822e-06,
        -7.73837559e-05,   0.00000000e+00,   0.00000000e+00,
        -3.57786656e-06,   1.99890769e-08,  -2.31541217e-05,
         2.06929826e-06,   1.54567868e-02,  -7.92878142e-07,
         5.13109123e-05,  -2.04094446e-04,   4.05795239e-04,
        -1.22615790e-03,  -3.29001304e-04,   1.33296432e-03,
        -2.69273459e-04,   9.76867222e-05,   0.00000000e+00,
         0.00000000e+00,   1.71322187e-03,  -2.19410630e-03,
        -7.06217185e-04,   2.87501052e-03,  -2.42687619e-03,
        -5.34202790e-04,   0.00000000e+00,   0.00000000e+00,
         1.58913718e-04,  -1.06346992e-07,   1.00759143e-03,
        -8.84582121e-06,   3.97719046e-05,   4.40411981e-06,
         1.55062636e-02,  -1.84827712e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.59089353e-05,  -1.89764549e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.66298054e-04,  -2.53331705e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.54738161e-02,  -4.11819837e-07,
         8.82726249e-04,  -1.77004587e-03,   4.24369524e-03,
        -9.53867435e-03,  -2.52431977e-03,   9.93663845e-03,
        -3.45304624e-03,   7.98501587e-03,   0.00000000e+00,
         0.00000000e+00,   8.49393161e-03,  -1.55347747e-02,
        -4.90354081e-03,   1.94654621e-02,  -7.06423039e-03,
        -3.35215633e-04,   0.00000000e+00,   0.00000000e+00,
         2.84152902e-03,  -7.12273261e-07,   1.13507374e-02,
        -7.21632748e-05,  -2.75773340e-05,   2.32607013e-05,
         9.97586884e-04,  -1.60393799e-04,   0.00000000e+00,
         0.00000000e+00,   1.59069656e-02,  -1.54784655e-03,
        -5.65950595e-05,   1.98868024e-04,  -4.46967914e-04,
         1.72135293e-03,   1.69931202e-03,  -1.57401196e-03,
         2.87882919e-03,  -1.20942768e-02,   0.00000000e+00,
         0.00000000e+00,  -6.16163064e-04,   2.29570228e-03,
         5.10729635e-03,  -2.43711530e-03,   1.33120361e-03,
        -5.70664698e-03,   0.00000000e+00,   0.00000000e+00,
        -6.55257453e-07,   6.34109537e-07,  -3.11375366e-05,
         6.98350118e-05,   7.54243922e-03,  -1.13675333e-05,
        -1.72676216e-06,   1.57321890e-04,   0.00000000e+00,
         0.00000000e+00,  -3.46024059e-04,   1.09242920e-03,
         1.54790338e-02,  -3.39263845e-04,   2.71887342e-03,
        -4.37625289e-03,   1.15824875e-02,  -2.30166944e-02,
        -6.31138435e-03,   2.40677955e-02,  -9.42057230e-03,
         2.51314881e-02,   0.00000000e+00,   0.00000000e+00,
         1.83510924e-02,  -3.71519865e-02,  -1.18616786e-02,
         4.65106038e-02,  -8.89951432e-03,   1.90480026e-03,
         0.00000000e+00,   0.00000000e+00,   2.25377592e-05,
        -1.79254362e-06,   6.47680606e-04,  -1.85895420e-04,
         2.41873572e-05,   5.36654127e-05,   7.68764504e-03,
        -4.16167979e-04,   0.00000000e+00,   0.00000000e+00,
         3.09758085e-03,  -4.02781985e-03,  -5.34491109e-04,
         2.64240645e-03,   1.86468154e-02,  -1.04677358e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.49219353e-03,
        -6.66653446e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.72286990e-03,  -6.97522362e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.55648912e-03,
        -4.17055958e-06,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.54926922e-02,  -1.10613989e-04,
        -3.13741325e-04,   8.19624801e-03,   4.68616539e-05,
         5.43041598e-02,  -7.92739377e-03,  -3.33031778e-02,
        -6.28627862e-02,   2.72129022e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.03040951e-03,   4.16084201e-02,
        -1.94366758e-02,   1.85050593e-01,   3.63135960e-02,
        -1.76581636e-01,  -1.28387950e-02,   6.24310361e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.72027047e-02,   2.68185451e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.35559578e-02,  -3.10149725e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.60059583e-02,   1.09654487e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.07539439e-03,
         1.61910275e-02,  -1.10731795e-02,   8.98913132e-02,
         1.64340136e-02,  -8.16619484e-02,  -5.81030124e-03,
         2.88718588e-02,   0.00000000e+00,   0.00000000e+00,
        -1.76759636e-02,   1.33475585e-01,   3.28727764e-02,
        -1.50844191e-01,  -1.16222815e-02,   5.33314752e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.09321902e-07,   2.05066330e-06,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.72793952e-07,   1.00791938e-06,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.23944790e-05,   1.53305489e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.50267578e-05,
         7.88630979e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.42547571e-05,  -1.40098009e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.04751751e-06,  -6.86251816e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.43481477e-05,   3.22451689e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.67917860e-05,   1.67195306e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.00481145e-06,   1.60653585e-05,
        -1.78011081e-05,   9.82816768e-05,   2.58134773e-05,
        -1.06332890e-04,  -2.03628315e-05,   1.80409585e-05,
         0.00000000e+00,   0.00000000e+00,   8.44130304e-05,
         1.77773038e-04,   5.01789279e-05,  -2.33150823e-04,
        -3.38236470e-04,   5.63415621e-05,   0.00000000e+00,
         0.00000000e+00,   1.52027696e-04,   5.24772108e-09,
         9.61731616e-04,   3.98718712e-07,  -4.95796206e-05,
        -3.01828392e-07,   2.53985276e-04,   8.03527537e-07,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.56448085e-03,   1.02556854e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.26475705e-06,   5.24687049e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.12337477e-04,   1.04038915e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.79633582e-03,  -1.20062310e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.12322974e-03,  -5.86872919e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.31285944e-05,  -1.23554575e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.58076950e-03,   3.12030277e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.71446924e-04,
         1.58770285e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.29593500e-04,   2.80004097e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.14202359e-04,
         1.03295840e-03,  -7.55095392e-04,   5.73419161e-03,
         1.21249691e-03,  -5.67087535e-03,  -7.96455333e-04,
         1.16426565e-03,   0.00000000e+00,   0.00000000e+00,
        -7.75180143e-04,   9.08144526e-03,   2.40257275e-03,
        -1.09861012e-02,  -2.46299928e-03,   3.02214163e-03,
         0.00000000e+00,   0.00000000e+00,   2.11095014e-05,
         1.06535841e-07,   5.72241037e-04,   8.69163050e-06,
        -4.43705372e-05,  -7.38768626e-06,   2.31981068e-04,
         1.84501350e-05,   0.00000000e+00,   0.00000000e+00,
         1.74977616e-03,   4.40756135e-04,  -1.28307982e-04,
        -5.05220808e-04,   9.85272414e-04,   1.27453445e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.42641647e-02,   2.66241796e-01,
         2.65478914e-01,   2.30533255e-02,   4.21502911e-02,
         5.54546763e-02,   1.98608374e-01,   2.28229597e-01,
        -1.24702599e-04,  -3.75211643e-02,  -1.41358549e-02,
        -1.53021814e-01,   2.44238814e-01,   8.60867853e-02,
         4.40890268e-05,   1.32657348e-02,   4.99777943e-03,
         5.41013812e-02,  -2.05727424e-03,  -1.64046896e-02,
         2.39147320e-01,   4.54872498e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.38419964e-01,   3.96873161e-02,
         3.16564882e-02,   7.05097124e-02,   1.07223479e-01,
         3.08942891e-01,   1.80058212e-03,  -1.86446611e-01,
        -6.36601914e-04,   6.59188315e-02,   0.00000000e+00,
         0.00000000e+00,   1.11350244e-01,   4.45400977e-01,
         1.35850244e-02,  -5.96364833e-02,   3.61577790e-02,
        -2.55130205e-01,   1.01807402e-01,   1.02022178e-01,
         1.58019352e-03,  -2.39386954e-02,   0.00000000e+00,
         0.00000000e+00,   3.18469360e-02,  -3.47713953e-01,
         1.69109128e-01,   1.75094424e-01,  -4.80303143e-03,
         2.10846809e-02,  -1.27837054e-02,   9.02021489e-02,
         1.58019352e-03,  -2.39386954e-02,   1.05718182e-01,
         4.27769292e-02,   0.00000000e+00,   0.00000000e+00,
        -1.12595922e-02,   1.22935447e-01,   1.61738715e-03,
        -4.58709938e-02,   1.73111957e-01,   6.15695066e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.06276864e-01,
         3.43133222e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.73683790e-01,   4.53516612e-02,
        -2.35062771e-05,   9.40251086e-05,  -1.50525319e-04,
         6.10268901e-04,   1.79737983e-04,  -7.19009374e-04,
        -5.19213929e-05,   1.73188892e-04,   0.00000000e+00,
         0.00000000e+00,   9.23178855e-04,   1.23368448e-03,
         4.27553909e-04,  -1.73207610e-03,  -4.04434817e-03,
         4.61930418e-04,   0.00000000e+00,   0.00000000e+00,
         1.09081939e-01,   3.50718711e-07,  -1.75498318e-04,
         7.04009928e-04,  -7.47126674e-04,   4.42990283e-03,
         1.25044886e-03,  -5.07946585e-03,  -1.21502299e-03,
         1.11789694e-03,   0.00000000e+00,   0.00000000e+00,
         6.37548203e-03,   8.69549555e-03,   2.66849085e-03,
        -1.19203846e-02,  -2.35469977e-02,   3.04919881e-03,
         0.00000000e+00,   0.00000000e+00,   2.34205159e-02,
         3.46821806e-06,   1.09071032e-01,   4.05957624e-05,
         8.20396609e-06,  -3.28882170e-05,   5.24280265e-05,
        -2.98701340e-04,   9.06908701e-05,   3.36620963e-04,
         4.57734827e-05,   3.42736838e-05,   0.00000000e+00,
         0.00000000e+00,  -3.69258692e-04,  -6.78099734e-04,
         4.56401883e-03,   9.27947887e-04,   1.38337498e-03,
         8.61763412e-06,   0.00000000e+00,   0.00000000e+00,
        -6.85684183e-04,  -2.63667718e-06,  -4.33645864e-03,
        -2.13241578e-05,   1.08488057e-01,   1.01513831e-05,
        -2.02593764e-04,   8.19548413e-04,  -3.67911310e-04,
         4.99284216e-03,   1.34175105e-03,  -5.57045630e-03,
        -2.39862732e-03,   1.09537305e-03,   0.00000000e+00,
         0.00000000e+00,   6.81300594e-03,   9.48376816e-03,
         2.78511245e-03,  -1.26687299e-02,  -2.08451100e-02,
         3.09351920e-03,   0.00000000e+00,   0.00000000e+00,
         1.78593379e-03,   5.53363151e-06,   1.12916154e-02,
         5.95649782e-05,  -9.56951766e-04,  -2.50410871e-05,
         1.10610396e-01,   8.53958032e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.37657425e-04,   1.35177523e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.68449752e-03,   2.34043064e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.08118891e-01,   5.07528891e-06,
         8.41602086e-04,   4.82331828e-03,   6.90144498e-03,
         2.48883977e-02,   3.28255176e-03,  -2.25097684e-02,
        -1.55874456e-02,   3.73032711e-03,   0.00000000e+00,
         0.00000000e+00,   2.33096978e-02,   4.20995596e-02,
         7.20536516e-03,  -4.80200624e-02,  -5.75191209e-02,
         1.10242267e-02,   0.00000000e+00,   0.00000000e+00,
         2.00093607e-02,   6.50842420e-05,   7.97394448e-02,
         5.10981134e-04,  -4.10383863e-03,  -1.01588480e-04,
         1.06003030e-02,   6.10624007e-04,   0.00000000e+00,
         0.00000000e+00,   1.08155578e-01,   3.45180698e-03,
         5.28316560e-04,  -2.35531240e-03,   1.09983152e-03,
        -1.11476389e-02,   7.42782132e-03,   6.09735404e-03,
         1.18373397e-03,   8.55784650e-04,   0.00000000e+00,
         0.00000000e+00,  -1.28437116e-03,  -1.66754122e-02,
         2.92064273e-02,   1.21636691e-02,   6.77269264e-03,
         6.01014222e-04,   0.00000000e+00,   0.00000000e+00,
        -7.30297260e-05,  -8.95605848e-05,  -2.43323195e-03,
        -6.36378111e-04,   5.26952857e-02,   1.01036713e-04,
        -7.21302808e-04,  -6.95903810e-04,   0.00000000e+00,
         0.00000000e+00,  -7.70855620e-03,  -2.73295184e-03,
         1.05518950e-01,   1.32432327e-03,   4.44545460e-03,
         1.16477074e-02,   2.41365431e-02,   5.58856521e-02,
         4.05221410e-03,  -4.55800927e-02,  -3.69269452e-02,
         7.07044363e-03,   0.00000000e+00,   0.00000000e+00,
         4.17693114e-02,   8.85104420e-02,   1.19367003e-02,
        -9.16170713e-02,  -7.52077990e-02,   2.06625589e-02,
         0.00000000e+00,   0.00000000e+00,   2.05059466e-04,
         1.73699473e-04,   6.42262224e-03,   1.31225001e-03,
        -8.45462616e-04,  -1.99264578e-04,   5.43290561e-02,
         1.52630038e-03,   0.00000000e+00,   0.00000000e+00,
         1.98727616e-02,   7.91400406e-03,  -3.62325953e-03,
        -5.23629608e-03,   1.12392174e-01,   1.76660434e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.74086444e-03,
         2.26860959e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.94954810e-02,   3.19436093e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.23681090e-02,
         3.24746281e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.03855879e-01,   3.85535936e-04,
        -2.03319098e-02,   1.07232828e-01,  -6.02162660e-02,
         4.55745485e-01,  -2.65473123e-02,  -1.76370431e-01,
         9.38589229e-03,   6.23563639e-02,   0.00000000e+00,
         0.00000000e+00,  -2.06605432e-02,   3.17783438e-01,
        -3.20849161e-01,  -4.61058000e-04,  -6.65767089e-02,
        -2.01021556e-03,  -3.08928095e-01,  -3.22025244e-02,
         8.45827287e-03,   1.41104986e-02,   4.68176329e-02,
         9.95804209e-02,  -2.90870481e-01,  -1.74515379e-01,
        -2.74527026e-03,  -3.30419475e-04,  -1.58500680e-02,
        -7.11955694e-03,  -2.83619036e-04,   3.11246569e-02,
        -3.05640345e-01,  -9.15234892e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.04177515e-01,  -7.96294699e-03,
        -5.81702438e-02,  -2.23226869e-03,  -2.19248236e-01,
        -5.08053925e-02,   2.23540595e-02,   1.65584852e-01,
        -1.28589849e-02,  -1.23873527e-02,   0.00000000e+00,
         0.00000000e+00,  -2.65091624e-01,  -1.10163104e-01,
        -2.39687596e-03,   1.63250640e-02,   3.96956351e-03,
         1.43210811e-01,  -9.38039785e-02,  -2.93982995e-01,
        -5.97859811e-03,   4.71860351e-02,   0.00000000e+00,
         0.00000000e+00,   1.24397256e-02,   3.00429947e-01,
        -1.51244567e-01,  -6.04978270e-01,  -2.92692633e-04,
        -4.26165298e-04,  -6.81271904e-03,  -1.27790044e-02,
        -9.16255500e-03,   5.99218627e-02,  -1.44174119e-01,
        -1.22324442e-02,   0.00000000e+00,   0.00000000e+00,
        -1.47390324e-02,  -3.27858582e-02,  -1.34455912e-02,
         1.14191451e-01,  -2.45081774e-01,  -3.01237043e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.43335842e-01,
        -9.87729623e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.43106501e-01,  -2.22226122e-02,
         1.48007726e-08,  -5.92030902e-08,  -2.39614881e-06,
        -1.84358398e-06,  -1.00507371e-06,   4.11759197e-06,
         1.20736776e-05,  -7.87363816e-09,   0.00000000e+00,
         0.00000000e+00,  -1.73067930e-03,  -5.48953414e-06,
         6.56378582e-06,   1.12445717e-05,   5.52705402e-03,
        -5.03058417e-07,   0.00000000e+00,   0.00000000e+00,
        -1.53629202e-01,  -5.64571945e-09,   3.68953505e-07,
        -3.95827881e-06,  -4.57235587e-04,  -1.17026356e-04,
        -3.43303860e-05,   2.58913931e-04,   1.26721198e-03,
         8.10204550e-06,   0.00000000e+00,   0.00000000e+00,
        -1.18255128e-02,  -3.25181723e-04,   3.61118368e-04,
         6.49898867e-04,   3.18265686e-02,  -9.24032678e-06,
         0.00000000e+00,   0.00000000e+00,  -3.29862642e-02,
        -6.49756358e-08,  -1.53628022e-01,  -3.90314595e-06,
        -9.20880687e-05,   3.68447938e-04,  -5.63675562e-04,
         2.39411956e-03,   4.83733258e-04,  -2.88930847e-03,
        -2.48724719e-04,   6.50656956e-04,   0.00000000e+00,
         0.00000000e+00,  -2.98291430e-04,   4.81779610e-03,
        -5.01785885e-03,  -6.85802476e-03,  -2.77844899e-03,
         1.73082976e-03,   0.00000000e+00,   0.00000000e+00,
         1.18178378e-03,   3.17563856e-07,   7.47359641e-03,
         1.33664101e-05,  -1.53128723e-01,  -2.02992648e-05,
        -1.39944643e-06,  -5.67508603e-06,  -1.14148734e-03,
        -1.59374151e-04,  -1.91468679e-05,   3.91285386e-04,
         2.86088377e-03,   2.13297641e-05,   0.00000000e+00,
         0.00000000e+00,  -1.25356393e-02,  -4.12128459e-04,
         4.06393273e-04,   8.82866070e-04,   2.76580593e-02,
         1.06203289e-05,   0.00000000e+00,   0.00000000e+00,
        -2.32262142e-03,  -7.69247293e-08,  -1.46929034e-02,
        -5.52035637e-06,   1.55063284e-03,   2.22045328e-05,
        -1.55370066e-01,  -8.27901114e-06,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.30216704e-04,  -8.83431766e-06,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.62176985e-03,  -2.40688882e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.52380439e-01,  -8.62958767e-07,
        -2.42487173e-03,  -1.22451495e-04,  -1.62034488e-02,
        -2.91705073e-03,   1.44019665e-03,   7.91737204e-03,
         1.91915216e-02,   1.89412152e-04,   0.00000000e+00,
         0.00000000e+00,  -4.44370460e-02,  -6.70613346e-03,
         3.96206728e-03,   1.55699637e-02,   7.58209412e-02,
        -9.52362483e-05,   0.00000000e+00,   0.00000000e+00,
        -2.82036179e-02,  -5.51138480e-07,  -1.12475926e-01,
        -3.85804573e-05,   7.04479476e-03,   2.68447830e-04,
        -1.39639353e-02,  -5.44808256e-05,   0.00000000e+00,
         0.00000000e+00,  -1.53411787e-01,  -6.93039158e-04,
        -5.42971608e-04,   2.48224024e-03,  -1.89185469e-03,
         1.75120172e-02,  -5.50449234e-03,  -2.56289764e-02,
        -3.16726174e-03,   4.18253117e-03,   0.00000000e+00,
         0.00000000e+00,   5.23993033e-05,   3.54868916e-02,
        -3.13660656e-02,  -5.69717704e-02,  -1.43151096e-02,
         1.07838883e-02,   0.00000000e+00,   0.00000000e+00,
         1.63923072e-04,   1.55044439e-06,   4.44195783e-03,
         9.18902981e-05,  -7.44651086e-02,  -4.01531297e-04,
         1.41209533e-03,   1.42789481e-04,   0.00000000e+00,
         0.00000000e+00,   1.39406739e-02,   2.20056790e-03,
        -1.49695694e-01,  -4.71505209e-03,  -8.72740149e-03,
        -3.46003401e-04,  -4.69292564e-02,  -7.77011624e-03,
         5.14019770e-03,   2.19375075e-02,   4.59109779e-02,
         2.92478623e-04,   0.00000000e+00,   0.00000000e+00,
        -8.15639579e-02,  -1.68165448e-02,   7.49844930e-03,
         4.06399164e-02,   9.57993208e-02,  -5.90285081e-04,
         0.00000000e+00,   0.00000000e+00,  -3.22603121e-04,
        -1.22612927e-06,  -8.75442810e-03,  -8.35508596e-05,
         1.27153763e-03,   7.05020307e-04,  -7.66197772e-02,
        -1.16957286e-04,   0.00000000e+00,   0.00000000e+00,
        -2.81006743e-02,  -1.61434458e-03,   6.64927933e-03,
         5.65063413e-03,  -1.61583458e-01,  -3.84318682e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.06496637e-02,
        -5.44312080e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.14737304e-02,  -1.22880450e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.38634467e-02,
        -5.97989855e-06,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.46941221e-01,  -1.62140830e-04,
        -5.16429144e-03,  -1.03244592e-02,  -3.70375618e-02,
        -1.38045569e-01,   2.10914176e-04,   3.90814086e-01,
        -2.10413464e-02,  -4.68091922e-02,   0.00000000e+00,
         0.00000000e+00,  -8.98660768e-02,  -3.33896464e-01,
         3.07817425e-02,   4.12180702e-01,   1.13437309e-01,
         1.63008619e-04,   2.35384212e-02,   7.10718528e-04,
         1.09222575e-01,   1.13853117e-02,  -2.74527026e-03,
        -3.30419475e-04,  -1.58500680e-02,  -7.11955694e-03,
         1.11680501e-01,   6.17946358e-03,   1.66407560e-03,
         1.32927521e-02,   7.59071598e-03,   8.19604165e-02,
         1.10420082e-02,  -7.97080104e-02,   9.92179242e-02,
         5.87568845e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.07542992e-01,   2.81532691e-03,   2.05662869e-02,
         7.89226163e-04,   7.75159573e-02,   1.79624188e-02,
        -1.28589849e-02,  -1.23873527e-02,  -9.47030450e-03,
         1.34927718e-01,   0.00000000e+00,   0.00000000e+00,
         9.37240426e-02,   3.89485390e-02,  -2.92692633e-04,
        -4.26165298e-04,  -6.81271904e-03,  -1.27790044e-02,
         5.30478782e-02,   1.01535161e-02,   3.17835576e-02,
        -1.52998586e-01,   0.00000000e+00,   0.00000000e+00,
        -1.47390324e-02,  -3.27858582e-02,   9.15380436e-02,
         3.02045430e-02,  -3.12125327e-03,   1.52703587e-02,
        -1.28910559e-02,   1.11584389e-01,   2.27779676e-02,
        -1.16976225e-01,   3.10900851e-02,   9.81099908e-02,
         0.00000000e+00,   0.00000000e+00,  -2.40375185e-02,
         2.19289087e-01,   5.18567860e-02,  -2.67674553e-01,
         4.85844783e-02,   1.94337913e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.06768730e-02,   3.49215157e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.59511278e-02,   7.85687990e-03,   7.45974110e-05,
        -2.98389644e-04,   4.85962197e-04,  -1.94084073e-03,
        -5.73139461e-04,   2.29255362e-03,   1.35122232e-04,
        -5.53212243e-04,   0.00000000e+00,   0.00000000e+00,
         1.44497278e-03,  -3.92952634e-03,  -1.38226250e-03,
         5.52695016e-03,  -1.10866899e-03,  -1.47494425e-03,
         0.00000000e+00,   0.00000000e+00,   4.12143902e-02,
        -1.11728873e-06,   4.45463667e-04,  -1.78114599e-03,
         2.98377637e-03,  -1.14525605e-02,  -3.36388164e-03,
         1.34554361e-02,   4.39710219e-04,  -3.02194257e-03,
         0.00000000e+00,   0.00000000e+00,   8.80617879e-03,
        -2.28333424e-02,  -7.97860647e-03,   3.18348997e-02,
        -6.29300186e-03,  -8.17542621e-03,   0.00000000e+00,
         0.00000000e+00,   8.85197350e-03,  -1.08096247e-05,
         4.12431569e-02,  -1.07256352e-04,  -4.15918310e-06,
         1.66287828e-05,  -1.25373093e-04,   5.01396467e-04,
         2.63548330e-04,  -8.21986032e-04,   2.24415837e-05,
        -8.89210242e-05,   0.00000000e+00,   0.00000000e+00,
        -3.92452009e-04,   1.42927922e-03,   2.33822308e-03,
        -2.36250790e-03,   1.15448754e-04,  -4.88458043e-05,
         0.00000000e+00,   0.00000000e+00,  -7.30323923e-05,
         8.37449439e-06,  -4.64220172e-04,   5.65701903e-05,
         4.10673278e-02,  -2.66135163e-05,   4.14131609e-04,
        -1.65328329e-03,   2.89379345e-03,  -1.04077666e-02,
        -3.02789670e-03,   1.21118632e-02,  -1.13096239e-04,
        -2.38522675e-03,   0.00000000e+00,   0.00000000e+00,
         8.23577040e-03,  -2.01711852e-02,  -6.93286080e-03,
         2.76833564e-02,  -5.32282879e-03,  -6.66561568e-03,
         0.00000000e+00,   0.00000000e+00,   4.63956243e-04,
        -1.71613152e-05,   2.94819569e-03,  -1.47600750e-04,
         1.00728239e-06,   5.79384615e-05,   4.15163424e-02,
        -1.90712622e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.40666514e-04,  -3.26780825e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.90503493e-03,
        -5.84170545e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.11253713e-02,  -1.32844093e-05,   1.94453844e-03,
        -4.49482765e-03,   1.18390029e-02,  -2.86585411e-02,
        -8.66086612e-03,   3.31672131e-02,  -4.04489931e-03,
        -2.75068050e-03,   0.00000000e+00,   0.00000000e+00,
         2.60307824e-02,  -5.58156960e-02,  -1.96475827e-02,
         7.62795829e-02,  -1.63484992e-02,  -1.23269974e-02,
         0.00000000e+00,   0.00000000e+00,   7.61785082e-03,
        -2.06431494e-04,   3.05095607e-02,  -1.31342117e-03,
        -4.87695931e-04,   2.28063535e-04,   3.10172883e-03,
        -1.30422210e-03,   0.00000000e+00,   0.00000000e+00,
         4.27560345e-02,  -5.79951805e-03,  -4.25428866e-05,
         1.10429873e-04,  -1.02850759e-03,   3.10307899e-03,
         4.31105855e-03,  -4.59123592e-03,   1.46911295e-03,
        -5.81697446e-03,   0.00000000e+00,   0.00000000e+00,
        -2.70142916e-03,   8.18031166e-03,   1.46630653e-02,
        -1.23986515e-02,   2.82775947e-03,  -9.29139263e-03,
         0.00000000e+00,   0.00000000e+00,  -8.12486568e-05,
         2.85540387e-04,  -6.92462848e-04,   1.68740029e-03,
         2.00498794e-02,  -2.51222776e-04,  -3.69554342e-04,
         1.52154749e-03,   0.00000000e+00,   0.00000000e+00,
        -2.11450199e-03,   4.56554809e-03,   4.10310887e-02,
        -2.00160121e-03,   4.50526594e-03,  -6.13624191e-03,
         2.35174052e-02,  -3.83457410e-02,  -1.22933690e-02,
         4.37302825e-02,  -1.22453820e-02,   4.58149440e-03,
         0.00000000e+00,   0.00000000e+00,   4.10198270e-02,
        -7.23195418e-02,  -2.58258596e-02,   9.67098592e-02,
        -2.28855191e-02,  -3.06714924e-03,   0.00000000e+00,
         0.00000000e+00,   2.01807027e-04,  -5.51592710e-04,
         2.58661173e-03,  -3.37376001e-03,  -9.45758129e-05,
         4.21633374e-04,   2.11763591e-02,  -3.20837718e-03,
         0.00000000e+00,   0.00000000e+00,   8.80945356e-03,
        -1.16522704e-02,  -1.79705960e-03,   6.53375034e-03,
         4.83185471e-02,  -2.06307283e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.58961123e-03,  -1.81994677e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.23866045e-02,  -3.12216001e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.00625100e-02,  -7.90085996e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.08960665e-02,  -5.76943964e-04,   1.82585275e-03,
         3.65024756e-03,   1.30947555e-02,   4.88064788e-02,
        -2.10413464e-02,  -4.68091922e-02,  -5.18637615e-02,
         2.74967246e-01,   0.00000000e+00,   0.00000000e+00,
         3.17724562e-02,   1.18050227e-01,  -5.77664635e-02,
        -1.31465341e-01,  -4.07006091e-02,   2.49500643e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.93475995e-04,
         1.31759312e-02,   1.98687071e-03,   7.94432730e-02,
         1.25048386e-02,  -7.85186084e-02,  -4.42112808e-03,
         2.77605202e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.40166422e-02,
         1.30548127e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.26218346e-02,
        -1.50643438e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.15335602e-02,   5.32604981e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.22473574e-03,   1.51196865e-02,  -1.52997158e-02,
         1.07066329e-01,   2.36162445e-02,  -1.14621077e-01,
        -8.34960333e-03,   4.05246706e-02,   0.00000000e+00,
         0.00000000e+00,  -2.92485533e-02,   2.07697536e-01,
         5.38320590e-02,  -2.59773461e-01,  -1.90325070e-02,
         9.18437877e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.50704183e-07,
         2.22671789e-06,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.23663446e-06,   4.14056194e-06,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.82555826e-05,   1.45488970e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.64564694e-05,   2.53084291e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.74156720e-05,
        -7.53197052e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.32606626e-05,  -1.40887428e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.98561815e-05,
         2.44513680e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.72587443e-05,   4.08237134e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.20347540e-05,
         3.68169402e-04,  -5.84815465e-04,   2.37645873e-03,
         6.96669310e-04,  -2.79233426e-03,  -1.87037179e-04,
         6.57335016e-04,   0.00000000e+00,   0.00000000e+00,
        -9.63898551e-04,   4.75275992e-03,   1.63551250e-03,
        -6.62989477e-03,  -1.01435524e-03,   1.75134159e-03,
         0.00000000e+00,   0.00000000e+00,   2.85146110e-04,
         2.83328190e-07,   1.80143592e-03,   1.13209368e-05,
        -1.50729187e-04,  -9.31658723e-06,   3.97361591e-04,
         1.96178527e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.16908482e-04,
         5.58380908e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.09670921e-04,   8.82304166e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.65261939e-03,
         2.53191557e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.22199150e-03,
        -5.94773860e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.76982508e-03,  -1.02849015e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.62821538e-05,
        -3.43885785e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.38323580e-04,   1.60105298e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.63391866e-03,   2.47675134e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.04583268e-04,   6.77137643e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.83355040e-04,   2.43496567e-03,  -3.27848756e-03,
         1.59303439e-02,   4.29476179e-03,  -1.82388198e-02,
        -1.69404106e-03,   4.43600641e-03,   0.00000000e+00,
         0.00000000e+00,  -5.53723399e-03,   3.12205329e-02,
         9.75068363e-03,  -4.22083357e-02,  -5.72396074e-03,
         1.13662922e-02,   0.00000000e+00,   0.00000000e+00,
         3.94204177e-05,   9.29084973e-07,   1.06370716e-03,
         5.41631336e-05,  -1.31972688e-04,  -4.11236484e-05,
         3.50094275e-04,   9.50936152e-05,   0.00000000e+00,
         0.00000000e+00,   3.08070838e-03,   1.62162476e-03,
        -2.59756709e-04,  -2.09193426e-03,   9.57577267e-04,
         4.39781709e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.93030008e-02,
         2.58417697e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.09123736e-02,   2.26260635e-01,
         2.09035373e-06,   6.77626358e-21,   3.97731727e-07,
         1.58403251e-07,   1.58013696e-06,   2.04086691e-06,
        -1.95855988e-09,  -1.64687945e-10,   2.88606044e-07,
        -1.20684300e-06,   2.04329239e-06,   1.68567036e-08,
         1.12939788e-07,  -6.67997569e-07,   6.52111037e-07,
        -4.02550472e-06,  -1.26347979e-06,   5.07306374e-06,
         2.77022382e-06,  -2.37595671e-06,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.04564742e-06,   6.68784944e-09,
        -2.30278802e-05,   9.36423910e-05,  -1.51144090e-04,
         6.10763918e-04,   1.79740222e-04,  -7.19011165e-04,
        -4.15659197e-05,   1.64904514e-04,   0.00000000e+00,
         0.00000000e+00,  -6.13715481e-04,   2.46319995e-03,
         1.44471020e-08,  -5.89201538e-08,   1.16519878e-06,
        -4.69266206e-06,   2.17171951e-07,   3.13979544e-06,
        -3.01031082e-06,   1.20593171e-05,   0.00000000e+00,
         0.00000000e+00,   4.34354783e-04,  -1.73751680e-03,
        -2.81782139e-06,   1.87498575e-05,   7.45878501e-05,
        -2.98381995e-04,   4.84752966e-04,  -1.93987334e-03,
        -5.73132493e-04,   2.29254804e-03,   1.40502835e-04,
        -5.57516725e-04,   0.00000000e+00,   0.00000000e+00,
         8.65907815e-04,  -3.46627437e-03,  -1.38157892e-03,
         5.52640329e-03,   7.41163330e-04,  -2.95481011e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.94256822e-07,
         1.23074909e-06,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.32899521e-07,   4.54354989e-06,
        -2.06157759e-03,   8.24631036e-03,  -1.34357179e-02,
         5.37428727e-02,   1.58822506e-02,  -6.35290024e-02,
        -3.86929463e-03,   1.54771739e-02,   0.00000000e+00,
         0.00000000e+00,  -2.72703750e-02,   1.09082202e-01,
         3.84072987e-02,  -1.53629206e-01,  -1.03039467e-02,
         4.12135522e-02,   0.00000000e+00,   0.00000000e+00,
         8.96769840e-06,   3.58707936e-05,  -4.42648769e-04,
         1.77059510e-03,  -2.88482112e-03,   1.15393317e-02,
         3.41013522e-03,  -1.36405418e-02,  -8.30818428e-04,
         3.32313792e-03,   0.00000000e+00,   0.00000000e+00,
        -5.85555617e-03,   2.34243258e-02,   8.24656484e-03,
        -3.29863282e-02,  -2.21145858e-03,   8.83993603e-03,
         0.00000000e+00,   0.00000000e+00,  -6.12543303e-05,
         2.56625721e-04,  -1.85186017e-05,   1.08560004e-04,
         1.81550386e-06,  -7.26201549e-06,   5.70118010e-05,
        -2.28048392e-04,  -9.69374750e-05,   3.87770478e-04,
         8.89436114e-07,  -3.55385306e-06,   0.00000000e+00,
         0.00000000e+00,   1.72197032e-04,  -6.88941649e-04,
        -2.95236810e-04,   1.18193403e-03,   1.57828029e-05,
        -6.26776618e-05,   0.00000000e+00,   0.00000000e+00,
         5.62893939e-05,  -2.26842912e-04,   1.28243438e-05,
        -5.41437301e-05,   4.66988857e-06,   1.71272223e-05,
        -4.41437084e-05,   1.76574929e-04,  -2.57561009e-04,
         1.03034498e-03,   2.93607671e-04,  -1.17443239e-03,
        -3.97795996e-05,   1.58848307e-04,   0.00000000e+00,
         0.00000000e+00,  -4.47619093e-04,   1.79237594e-03,
         5.80663734e-04,  -2.32270504e-03,  -1.12026249e-04,
         4.43624679e-04,   0.00000000e+00,   0.00000000e+00,
        -1.08213352e-04,   4.36093377e-04,  -2.46541156e-05,
         1.04088428e-04,   3.52696944e-06,  -1.49167656e-05,
        -2.75896223e-07,   3.80446456e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.80021538e-05,   1.52029127e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.10694131e-05,   2.85255747e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.50451404e-06,   9.36796078e-06,
        -3.78454234e-04,   1.51388487e-03,  -2.46642630e-03,
         9.86640250e-03,   2.91571423e-03,  -1.16628654e-02,
        -7.10477491e-04,   2.84089293e-03,   0.00000000e+00,
         0.00000000e+00,  -5.02154599e-03,   2.00898096e-02,
         7.05104439e-03,  -2.82042810e-02,  -1.84239596e-03,
         7.36176593e-03,   0.00000000e+00,   0.00000000e+00,
        -1.41010021e-03,   5.65161414e-03,  -3.09127291e-04,
         1.25918381e-03,   2.60994341e-05,  -1.06233578e-04,
        -5.01747674e-05,   2.04228377e-04,   0.00000000e+00,
         0.00000000e+00,  -5.12902097e-04,   2.07387979e-03,
         2.52388269e-07,  -1.00961619e-06,   7.96181513e-06,
        -3.18537638e-05,  -1.33723492e-05,   5.39129028e-05,
        -3.06888695e-08,   1.34454671e-07,   0.00000000e+00,
         0.00000000e+00,   4.62083919e-05,  -1.84951079e-04,
        -4.06236600e-05,   1.65187830e-04,  -6.88286131e-05,
         2.75604352e-04,   0.00000000e+00,   0.00000000e+00,
         1.97722860e-03,  -7.90910836e-03,   4.24520065e-04,
        -1.69894540e-03,  -2.43855752e-05,   1.10214171e-04,
         3.73565110e-05,  -1.49648115e-04,   0.00000000e+00,
         0.00000000e+00,   3.65020959e-04,  -1.46095777e-03,
        -3.72405707e-06,   3.03143847e-05,  -6.07678580e-06,
         2.45486819e-05,  -3.54264670e-05,   1.43535354e-04,
         4.08153079e-05,  -1.63281092e-04,  -5.78113597e-06,
         2.08625725e-05,   0.00000000e+00,   0.00000000e+00,
        -1.04098475e-04,   4.21025825e-04,   8.10040637e-05,
        -3.24111877e-04,   1.19765240e-04,  -4.85959280e-04,
         0.00000000e+00,   0.00000000e+00,  -3.80111633e-03,
         1.52048382e-02,  -8.16117139e-04,   3.26613174e-03,
         3.73565110e-05,  -1.49648115e-04,  -7.67697161e-05,
         3.20062139e-04,   0.00000000e+00,   0.00000000e+00,
        -7.01733287e-04,   2.80861324e-03,   1.02987236e-05,
        -4.13215738e-05,  -1.81657105e-05,   8.82586382e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.17839421e-06,
         2.11368524e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.30606712e-06,   3.99102728e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.95381997e-06,
         3.23716349e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.63303517e-06,   8.82012077e-06,
         3.47078044e-08,   4.62770725e-08,  -1.02160143e-06,
         5.29136437e-06,  -2.57465997e-07,  -3.96026152e-07,
         5.33549339e-06,  -2.10073464e-05,   0.00000000e+00,
         0.00000000e+00,  -7.59034734e-04,   3.03857140e-03,
         3.23054847e-06,  -1.63422741e-05,   2.42429053e-03,
        -9.69626569e-03,   0.00000000e+00,   0.00000000e+00,
        -3.37257287e-02,   1.34902915e-01,   1.53447127e-04,
         1.79019818e-07,   2.39016611e-05,   3.28313190e-05,
         5.57539706e-05,   3.89569663e-04,  -1.29501042e-06,
        -7.12065398e-07,   4.86724261e-05,  -2.32640891e-04,
         1.41599006e-04,   2.79264283e-05,   1.53145742e-05,
        -8.24156891e-05,   8.05264293e-05,  -4.58364389e-04,
        -1.40293609e-04,   5.78611932e-04,   2.18429499e-04,
        -2.21534663e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.44407649e-04,   1.18637863e-05,  -1.41002578e-04,
         6.76413336e-04,  -1.05647771e-03,   4.67738367e-03,
         1.26370610e-03,  -5.09007164e-03,  -8.51249254e-05,
         2.13978488e-04,   0.00000000e+00,   0.00000000e+00,
        -4.12853833e-03,   1.70987118e-02,   8.84333429e-07,
        -4.37058275e-06,   1.43931909e-04,  -5.97960353e-04,
         1.73747063e-05,   2.17549857e-04,  -3.14749861e-04,
         1.27367151e-03,   0.00000000e+00,   0.00000000e+00,
         3.04102698e-03,  -1.22184136e-02,  -1.35490760e-04,
         1.04718617e-03,   4.44307198e-04,  -1.78022082e-03,
         2.80804282e-03,  -1.13119736e-02,  -3.35926836e-03,
         1.34517455e-02,   9.39334461e-04,  -3.42164197e-03,
         0.00000000e+00,   0.00000000e+00,   4.87306931e-03,
        -1.96868548e-02,  -7.94045301e-03,   3.18043769e-02,
         4.32986141e-03,  -1.66737168e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.00316398e-05,   8.28591922e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.84929778e-05,   2.59455084e-04,  -4.42648776e-04,
         1.77059510e-03,  -2.88482920e-03,   1.15393381e-02,
         3.41013533e-03,  -1.36405419e-02,  -8.30804001e-04,
         3.32312637e-03,   0.00000000e+00,   0.00000000e+00,
        -5.85253413e-03,   2.34219082e-02,   8.24652664e-03,
        -3.29862976e-02,  -2.22128418e-03,   8.84779652e-03,
         0.00000000e+00,   0.00000000e+00,   2.52272571e-04,
         5.80419979e-06,  -2.06157728e-03,   8.24631078e-03,
        -1.34351215e-02,   5.37436378e-02,   1.58821823e-02,
        -6.35290835e-02,  -3.87092296e-03,   1.54750955e-02,
         0.00000000e+00,   0.00000000e+00,  -2.72550718e-02,
         1.09101479e-01,   3.84057858e-02,  -1.53630949e-01,
        -1.03443068e-02,   4.11627147e-02,   0.00000000e+00,
         0.00000000e+00,   3.85546517e-05,   6.29014015e-05,
         1.22284916e-04,   4.89139663e-04,   1.14861860e-05,
        -4.59447763e-05,   3.60748787e-04,  -1.44340420e-03,
        -6.12995548e-04,   2.45340903e-03,   5.49808348e-06,
        -2.08524659e-05,   0.00000000e+00,   0.00000000e+00,
         1.08648070e-03,  -4.35967563e-03,  -1.85947107e-03,
         7.47982040e-03,   1.09583954e-04,  -4.02473111e-04,
         0.00000000e+00,   0.00000000e+00,   6.65056735e-06,
        -4.92047089e-05,   3.24397317e-05,  -2.51918179e-04,
         2.16813768e-04,   9.12214997e-05,  -2.79281308e-04,
         1.11713271e-03,  -1.62822192e-03,   6.52011349e-03,
         1.85740583e-03,  -7.43041132e-03,  -2.54912168e-04,
         1.00115706e-03,   0.00000000e+00,   0.00000000e+00,
        -2.81298050e-03,   1.13432417e-02,   3.67205828e-03,
        -1.46974897e-02,  -7.55228081e-04,   2.81513827e-03,
         0.00000000e+00,   0.00000000e+00,  -1.27853603e-05,
         9.45934235e-05,  -6.23636506e-05,   4.84299236e-04,
         8.91214034e-06,  -8.60682572e-05,   2.04316487e-04,
         2.11912956e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.40138949e-04,   9.61895171e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.41536572e-04,
         1.80569893e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.21449600e-04,   4.64513308e-05,  -1.50821342e-03,
         6.03791614e-03,  -9.82906915e-03,   3.93701615e-02,
         1.16278551e-02,  -4.65174208e-02,  -2.83984264e-03,
         1.12803007e-02,   0.00000000e+00,   0.00000000e+00,
        -2.00295468e-02,   8.03261745e-02,   2.81215265e-02,
        -1.12516542e-01,  -7.34156193e-03,   2.89674770e-02,
         0.00000000e+00,   0.00000000e+00,  -2.58112447e-04,
         1.21837193e-03,  -1.27993349e-03,   5.81713734e-03,
         1.15929487e-04,  -5.65308012e-04,  -2.22868243e-04,
         1.08677444e-03,   0.00000000e+00,   0.00000000e+00,
        -1.85463996e-03,   8.25438821e-03,   6.85483248e-06,
        -2.74679552e-05,   2.20741431e-04,  -8.87560035e-04,
        -3.59033378e-04,   1.46810181e-03,  -1.16306486e-05,
         5.42295014e-05,   0.00000000e+00,   0.00000000e+00,
         7.96369652e-04,  -3.22005939e-03,  -1.08758011e-03,
         4.51552065e-03,  -3.32802164e-04,   1.39967174e-03,
         0.00000000e+00,   0.00000000e+00,   4.23818129e-04,
        -1.69838385e-03,   1.96528275e-03,  -7.92301228e-03,
        -6.86138314e-05,   7.10813593e-04,   2.32151353e-04,
        -9.61584939e-04,   0.00000000e+00,   0.00000000e+00,
         1.47816948e-03,  -6.02737477e-03,  -2.86817223e-05,
         8.15606772e-04,  -1.62329934e-04,   6.67274994e-04,
        -9.51594150e-04,   3.94742768e-03,   1.10694436e-03,
        -4.44243720e-03,  -1.59618177e-04,   4.59943606e-04,
         0.00000000e+00,   0.00000000e+00,  -1.91504848e-03,
         7.98238658e-03,   2.20065828e-03,  -8.84761996e-03,
         2.63512677e-04,  -1.51528077e-03,   0.00000000e+00,
         0.00000000e+00,  -8.14767705e-04,   3.26505219e-03,
        -3.77815106e-03,   1.52315677e-02,   2.32151353e-04,
        -9.61584939e-04,  -3.94154115e-04,   2.05922113e-03,
         0.00000000e+00,   0.00000000e+00,  -2.84170184e-03,
         1.15873059e-02,   2.63837492e-04,  -1.11627167e-03,
        -3.98654721e-04,   2.38092781e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.36129677e-04,   5.75388202e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.34137703e-04,   1.09243902e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.21444552e-05,   2.10625469e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.08558760e-04,   2.34955172e-04,   2.30727783e-06,
         4.47669176e-06,  -1.91131746e-04,   8.54574721e-04,
        -8.75612739e-06,  -7.29805904e-05,   5.47480386e-04,
        -2.17044250e-03,   0.00000000e+00,   0.00000000e+00,
        -5.14713197e-03,   2.07650863e-02,   1.64579258e-04,
        -9.04841982e-04,   1.38853932e-02,  -5.54858391e-02,
         0.00000000e+00,   0.00000000e+00,  -1.44827450e-02,
         5.79309863e-02,  -3.37256886e-02,   1.34902966e-01,
        -1.44381820e-04,  -4.11618126e-09,  -3.01021895e-05,
        -4.17240188e-07,  -1.39302047e-04,  -1.97887358e-05,
        -1.48764064e-06,   1.50450912e-05,  -1.24401310e-05,
         1.08637532e-04,  -8.79689826e-05,  -2.15957440e-04,
         4.19119687e-06,   9.12646610e-07,   2.25085899e-05,
         2.49071030e-05,  -2.11756745e-06,  -1.71366372e-05,
        -1.49458954e-04,  -7.06184700e-06,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.38943391e-04,  -1.53949029e-06,
        -2.48164535e-05,  -6.47188133e-06,  -5.28755763e-05,
        -2.14458458e-04,  -1.10670555e-04,   4.97710104e-04,
         1.15966933e-05,   6.16151153e-05,   0.00000000e+00,
         0.00000000e+00,   1.30075705e-04,  -1.07756725e-03,
        -9.17159654e-05,   3.68150256e-04,  -5.96384672e-04,
         2.42028685e-03,   6.95159984e-04,  -3.05844985e-03,
        -1.48011789e-04,   5.70086611e-04,   0.00000000e+00,
         0.00000000e+00,  -1.40375056e-03,   5.70216340e-03,
         3.24052280e-03,  -1.34647301e-02,  -3.37517859e-06,
         1.60015792e-05,  -1.04010941e-04,   4.84306745e-04,
         1.84120882e-04,  -7.58444074e-04,  -7.48164302e-05,
        -1.11146131e-05,   0.00000000e+00,   0.00000000e+00,
        -2.93849458e-04,   1.35039718e-03,   1.32770016e-04,
        -5.98145446e-04,  -2.03701759e-04,   2.06474606e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.48301693e-05,
        -9.52303220e-06,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.07945636e-04,  -4.39223887e-05,
         1.81550387e-06,  -7.26201550e-06,   5.70065292e-05,
        -2.28044175e-04,  -9.69436404e-05,   3.87775411e-04,
         9.11990340e-07,  -3.57189644e-06,   0.00000000e+00,
         0.00000000e+00,   1.68997136e-04,  -6.86381732e-04,
        -2.95456600e-04,   1.18210986e-03,   2.59674522e-05,
        -7.08253812e-05,   0.00000000e+00,   0.00000000e+00,
        -2.26210911e-04,  -8.42668421e-07,   1.14857214e-05,
        -4.59444047e-05,   3.60057070e-04,  -1.44285083e-03,
        -6.13287283e-04,   2.45364242e-03,   7.37228878e-06,
        -2.23518301e-05,   0.00000000e+00,   0.00000000e+00,
         1.06842103e-03,  -4.34522789e-03,  -1.86897312e-03,
         7.48742204e-03,   1.57882502e-04,  -4.41111949e-04,
         0.00000000e+00,   0.00000000e+00,  -4.69025706e-05,
        -6.36219862e-06,  -2.06108459e-04,  -6.10796260e-05,
        -2.03464752e-03,   8.13859014e-03,  -1.33077872e-02,
         5.32317180e-02,   1.57564271e-02,  -6.30270309e-02,
        -3.86444447e-03,   1.54561921e-02,   0.00000000e+00,
         0.00000000e+00,  -2.71188418e-02,   1.08495670e-01,
         3.82758373e-02,  -1.53143948e-01,  -1.02751487e-02,
         4.10473677e-02,   0.00000000e+00,   0.00000000e+00,
         4.18478483e-06,   1.75153053e-05,  -2.56967233e-05,
         2.85229893e-04,  -1.12422022e-04,  -4.49688090e-04,
         3.32814369e-06,  -1.33193719e-05,   9.27653407e-05,
        -3.77091266e-04,  -1.55991374e-04,   6.25063064e-04,
        -6.51730537e-06,   4.14354878e-05,   0.00000000e+00,
         0.00000000e+00,   2.22745725e-04,  -9.68799079e-04,
        -3.90415656e-04,   1.57504333e-03,   3.63279535e-05,
         2.96819246e-05,   0.00000000e+00,   0.00000000e+00,
        -5.54323162e-06,  -7.66060480e-06,  -2.91243655e-05,
        -5.56390526e-05,  -9.03531235e-05,   4.30644387e-04,
        -2.16008392e-04,  -4.00243111e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.21315218e-05,  -4.96707423e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.94873454e-05,  -1.53489813e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.08461973e-04,  -9.83863358e-06,
         9.74468373e-06,  -4.37082245e-05,   3.31457965e-04,
        -1.37468141e-03,  -5.83636993e-04,   2.34357779e-03,
         2.15998642e-05,  -1.60810572e-05,   0.00000000e+00,
         0.00000000e+00,   9.97573895e-04,  -4.18271850e-03,
        -1.83012975e-03,   7.36838744e-03,   1.65942817e-04,
        -2.94847464e-04,   0.00000000e+00,   0.00000000e+00,
        -2.52092690e-05,  -6.51866156e-05,  -5.13260421e-05,
        -4.31503589e-04,  -1.37295203e-03,   5.64559414e-03,
         1.32802820e-06,  -1.54405744e-04,   0.00000000e+00,
         0.00000000e+00,  -5.12025926e-06,  -7.64642850e-04,
        -9.81714784e-04,   3.92693327e-03,  -6.44165784e-03,
         2.57735431e-02,   7.63499936e-03,  -3.05708848e-02,
        -1.88563362e-03,   7.53109074e-03,   0.00000000e+00,
         0.00000000e+00,  -1.31883995e-02,   5.28079849e-02,
         1.86891852e-02,  -7.49249664e-02,  -4.96763882e-03,
         1.97627918e-02,   0.00000000e+00,   0.00000000e+00,
        -2.68822996e-05,   1.12211550e-04,  -1.75652526e-04,
         7.96444549e-04,   1.89863740e-03,  -8.01712612e-03,
        -8.04700459e-05,   3.68703392e-04,   0.00000000e+00,
         0.00000000e+00,  -7.96279803e-04,   3.36695108e-03,
         1.75314584e-03,  -7.72175411e-03,  -1.09671901e-06,
        -1.24069674e-05,   5.68546427e-05,  -3.56372873e-04,
        -1.46400065e-04,   6.07814827e-04,   2.70842976e-05,
         5.13478604e-05,   0.00000000e+00,   0.00000000e+00,
         1.80483170e-04,  -1.02002121e-03,  -5.16120668e-04,
         2.13514694e-03,   2.41206671e-05,   3.26676190e-04,
         0.00000000e+00,   0.00000000e+00,   3.61368277e-05,
        -1.48672368e-04,   2.13743086e-04,  -9.46858326e-04,
        -3.76481949e-03,   1.51061012e-02,  -3.85868716e-05,
        -2.74970922e-04,   0.00000000e+00,   0.00000000e+00,
         2.01395218e-04,  -9.93975082e-04,  -1.84686821e-03,
         7.48099402e-03,  -6.42639541e-05,  -4.76121627e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.48835025e-06,
        -4.64747963e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.69666529e-07,  -1.46566066e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.81564058e-05,
        -3.30480547e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.46087344e-04,  -5.33591647e-05,
        -2.44034945e-06,  -3.30021683e-06,  -3.79581504e-06,
        -7.53793768e-05,  -8.10147077e-05,   4.35420850e-04,
        -3.64136046e-05,   1.26323887e-04,   0.00000000e+00,
         0.00000000e+00,   3.30875138e-04,  -1.50681784e-03,
        -2.88578572e-03,   1.18039596e-02,  -9.62935312e-04,
         3.79662768e-03,   0.00000000e+00,   0.00000000e+00,
         4.90584500e-04,  -1.96234360e-03,   3.10369432e-03,
        -1.24151984e-02,  -3.36391732e-02,   1.34556927e-01,
         3.21067343e-04,   8.30585292e-07,   4.64137641e-05,
         8.31435956e-05,   7.87339099e-05,   9.64631991e-04,
        -2.91657400e-06,  -2.63988934e-06,   1.21172633e-04,
        -5.75773853e-04,   2.90509745e-04,   7.56975222e-05,
         3.60522049e-05,  -1.91887480e-04,   1.86952838e-04,
        -1.05108398e-03,  -3.20693952e-04,   1.32631844e-03,
         4.64964390e-04,  -4.89703557e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.98054527e-04,   3.25295491e-05,
        -1.31943822e-04,   7.63028459e-04,  -1.17434284e-03,
         5.63798739e-03,   1.37927511e-03,  -5.60047554e-03,
         1.70699943e-04,  -9.60088758e-04,   0.00000000e+00,
         0.00000000e+00,  -4.29215381e-03,   1.83678960e-02,
         1.49138841e-06,  -7.98775390e-06,   3.18784399e-04,
        -1.32759154e-03,   6.82027966e-05,   3.21405654e-04,
        -7.10893596e-04,   2.87875165e-03,   0.00000000e+00,
         0.00000000e+00,   3.22512693e-03,  -1.30207415e-02,
        -5.77986149e-05,   1.25421958e-03,   4.11012129e-04,
        -1.65078771e-03,   2.47447405e-03,  -1.00723110e-02,
        -3.01699017e-03,   1.21031379e-02,   9.92657589e-04,
        -3.26982981e-03,   0.00000000e+00,   0.00000000e+00,
         4.12023412e-03,  -1.68787561e-02,  -6.88953114e-03,
         2.76486927e-02,   3.81823338e-03,  -1.39784654e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.15957355e-04,
         1.19862851e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.69260092e-04,   3.18636056e-04,
        -4.41437383e-05,   1.76574953e-04,  -2.57580984e-04,
         1.03036096e-03,   2.93607935e-04,  -1.17443260e-03,
        -3.97437263e-05,   1.58819608e-04,   0.00000000e+00,
         0.00000000e+00,  -4.41889281e-04,   1.78779209e-03,
         5.80598896e-04,  -2.32265317e-03,  -1.30677694e-04,
         4.58545835e-04,   0.00000000e+00,   0.00000000e+00,
         4.34878388e-04,   1.61998501e-06,  -2.79282528e-04,
         1.11713369e-03,  -1.62852017e-03,   6.52035210e-03,
         1.85742716e-03,  -7.43042838e-03,  -2.54412183e-04,
         1.00075707e-03,   0.00000000e+00,   0.00000000e+00,
        -2.79559910e-03,   1.13293366e-02,   3.67094318e-03,
        -1.46965976e-02,  -8.11120234e-04,   2.85985199e-03,
         0.00000000e+00,   0.00000000e+00,   9.01676855e-05,
         1.22309869e-05,   3.96232498e-04,   1.17422317e-04,
         3.33024213e-06,  -1.33210507e-05,   9.43905911e-05,
        -3.78391466e-04,  -1.55451066e-04,   6.24630817e-04,
        -1.06160721e-05,   4.47145011e-05,   0.00000000e+00,
         0.00000000e+00,   2.40079479e-04,  -9.82666083e-04,
        -3.71022929e-04,   1.55952915e-03,  -6.20056236e-07,
         5.92403324e-05,   0.00000000e+00,   0.00000000e+00,
        -5.54323162e-06,  -7.66060480e-06,  -2.91243655e-05,
        -5.56390526e-05,   4.04682427e-04,   3.46159465e-05,
        -2.11558381e-03,   8.46235121e-03,  -1.37085625e-02,
         5.48488635e-02,   1.61772981e-02,  -6.47108503e-02,
        -3.88234176e-03,   1.54924015e-02,   0.00000000e+00,
         0.00000000e+00,  -2.76259128e-02,   1.10674443e-01,
         3.88399294e-02,  -1.55376275e-01,  -1.04386833e-02,
         4.13733079e-02,   0.00000000e+00,   0.00000000e+00,
         1.19579258e-05,   2.82575880e-05,   1.51436770e-05,
         3.63251204e-04,   4.14945008e-05,  -2.46026625e-04,
         2.26707494e-04,   9.06829975e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.29202041e-05,   2.54327912e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.30525382e-05,   4.03949156e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.00757002e-04,   1.89142473e-05,
        -2.63048776e-04,   1.06283825e-03,  -1.53417553e-03,
         6.24981898e-03,   1.76483430e-03,  -7.07329380e-03,
        -2.50940431e-04,   8.38428053e-04,   0.00000000e+00,
         0.00000000e+00,  -2.71402948e-03,   1.12620900e-02,
         3.48944487e-03,  -1.40171849e-02,  -6.04992482e-04,
         1.66115495e-03,   0.00000000e+00,   0.00000000e+00,
         4.84634725e-05,   1.25317785e-04,   9.86715731e-05,
         8.29542591e-04,   1.32802820e-06,  -1.54405744e-04,
        -1.37481429e-03,   5.86211362e-03,   0.00000000e+00,
         0.00000000e+00,   9.84342481e-06,   1.46998502e-03,
         3.10233931e-06,  -1.25287126e-05,   1.00709246e-04,
        -4.13502187e-04,  -1.30537455e-04,   5.88689897e-04,
        -4.32646415e-05,   1.90552193e-04,   0.00000000e+00,
         0.00000000e+00,   3.76703528e-04,  -1.57430888e-03,
        -2.97389377e-04,   1.51037725e-03,  -3.43342176e-04,
         1.50057776e-03,   0.00000000e+00,   0.00000000e+00,
         3.61368277e-05,  -1.48672368e-04,   2.13743086e-04,
        -9.46858326e-04,   1.43691370e-04,   1.89374260e-04,
         1.99450520e-03,  -8.03421230e-03,   0.00000000e+00,
         0.00000000e+00,   2.01395218e-04,  -9.93975082e-04,
         2.38282998e-04,   3.22488706e-04,  -1.04775518e-03,
         4.22874188e-03,  -6.77720781e-03,   2.74055469e-02,
         8.02588647e-03,  -3.21380749e-02,  -1.90930287e-03,
         7.26139035e-03,   0.00000000e+00,   0.00000000e+00,
        -1.38557636e-02,   5.60741561e-02,   1.91620489e-02,
        -7.67424182e-02,  -4.57781337e-03,   1.73949608e-02,
         0.00000000e+00,   0.00000000e+00,  -7.75561079e-05,
         3.20691252e-04,  -4.75379337e-04,   2.12420131e-03,
         7.80152853e-05,  -3.68252648e-04,  -3.71953912e-03,
         1.57517392e-02,   0.00000000e+00,   0.00000000e+00,
        -1.07869149e-03,   4.76077854e-03,   1.02037020e-03,
        -4.19976496e-03,  -3.48506817e-03,   1.54374893e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.38121448e-05,
         2.39084706e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.26769663e-05,   3.93310608e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.69475979e-04,
         6.35331191e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.80845113e-04,   1.02580143e-04,
         4.18933324e-06,   1.19467268e-05,  -4.68727847e-04,
         2.06225556e-03,  -1.25832100e-05,  -1.74206217e-04,
         1.23199792e-03,  -4.89017337e-03,   0.00000000e+00,
         0.00000000e+00,  -5.38198033e-03,   2.18897171e-02,
         1.51509423e-04,  -1.10824263e-03,   1.19528359e-02,
        -4.77003319e-02,   0.00000000e+00,   0.00000000e+00,
        -9.43122484e-04,   3.77250070e-03,  -5.96668648e-03,
         2.38675555e-02,   5.88286284e-04,  -2.35394805e-03,
        -3.40516431e-02,   1.36207370e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.69868801e-06,   1.50204598e-05,
        -1.77564330e-05,   9.82459368e-05,   2.56980483e-05,
        -1.06240547e-04,  -4.45192054e-06,   5.31222977e-06,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.87557913e-05,   3.00308096e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.94079756e-05,  -2.40534061e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.36651978e-05,  -2.65179772e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.18575021e-05,
         3.68027600e-04,  -5.91455345e-04,   2.38177063e-03,
         6.97530203e-04,  -2.79302297e-03,  -1.61945079e-04,
         6.37261336e-04,   0.00000000e+00,   0.00000000e+00,
        -1.23207329e-03,   4.96729971e-03,   1.66032937e-03,
        -6.64974827e-03,  -3.03268813e-04,   1.18247245e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.80084143e-05,   1.52034136e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.13265617e-05,   2.85461466e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.40477659e-04,   9.62166139e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.52105801e-04,
         1.81415431e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.24696458e-05,  -4.99412415e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.00543810e-05,  -1.61943442e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.35702294e-05,   2.54847932e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.03367099e-04,   4.20200805e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.03449843e-03,   8.13799373e-03,
        -1.32878665e-02,   5.31517613e-02,   1.57124429e-02,
        -6.28498341e-02,  -3.86858272e-03,   1.54735072e-02,
         0.00000000e+00,   0.00000000e+00,  -2.70281367e-02,
         1.08122697e-01,   3.80948402e-02,  -1.52381087e-01,
        -1.02854942e-02,   4.11154080e-02,   0.00000000e+00,
         0.00000000e+00,   1.30135923e-06,   1.35304846e-05,
        -4.08463592e-05,   2.56288099e-04,   4.90409202e-05,
        -2.15840948e-04,  -9.42785483e-05,   4.14942688e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.29990347e-04,   9.24266150e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.85409568e-04,   1.96361473e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.37226123e-03,   5.56527683e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.43979009e-05,  -5.83766538e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.19450555e-04,  -4.84471952e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.94493566e-03,  -7.79228944e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.28627264e-05,   2.61965391e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.52640450e-04,
         1.04291662e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.73903488e-03,   1.49802600e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.81585532e-04,
         3.92637699e-03,  -6.42340646e-03,   2.56969219e-02,
         7.59814859e-03,  -3.03933794e-02,  -1.88954753e-03,
         7.55265876e-03,   0.00000000e+00,   0.00000000e+00,
        -1.30943727e-02,   5.24024600e-02,   1.84656461e-02,
        -7.38692542e-02,  -5.00642531e-03,   1.99761397e-02,
         0.00000000e+00,   0.00000000e+00,  -8.08498765e-06,
         3.48765690e-05,  -6.44696770e-05,   3.03916775e-04,
         2.84457510e-05,  -1.26329780e-04,  -5.46854362e-05,
         2.42862251e-04,   0.00000000e+00,   0.00000000e+00,
        -6.91519950e-04,   2.84991456e-03,   9.38546814e-04,
        -3.77700250e-03,  -1.80430610e-03,   7.26108546e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.90941941e-05,   3.99776616e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.89319866e-03,   1.15785118e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.34861686e-02,   1.33944700e-01,
         9.91262324e-03,   9.41073959e-04,   1.37225082e-03,
         2.89182833e-03,   5.60755851e-03,   1.57604308e-02,
         5.08002890e-05,  -1.57341913e-03,   6.83454327e-04,
        -1.02127330e-02,   8.75196896e-03,   4.38968605e-03,
         9.42641090e-05,  -1.13927616e-03,   6.23259543e-04,
        -6.64232580e-03,  -2.06756688e-03,   9.57123613e-03,
         1.01702043e-02,  -2.91358456e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.75652468e-03,   1.99888103e-03,
         5.86845646e-04,   5.02712343e-03,  -9.02990532e-04,
         3.11319461e-02,   4.22827986e-03,  -2.32663509e-02,
         1.63124565e-03,  -1.00446259e-02,   0.00000000e+00,
         0.00000000e+00,  -8.65232187e-03,   6.76691754e-02,
         5.84879980e-04,  -2.53025286e-03,   3.74081787e-03,
        -1.88724640e-02,   3.01967363e-03,   6.65379046e-03,
        -4.57383738e-03,   1.92016993e-02,   0.00000000e+00,
         0.00000000e+00,   1.08218244e-02,  -5.09132298e-02,
         3.78812642e-03,   1.57091164e-02,   8.85350526e-04,
        -3.64747732e-03,   5.31958229e-03,  -2.34430047e-02,
        -7.91630325e-03,   3.25715628e-02,   7.36750473e-03,
        -1.18806037e-02,   0.00000000e+00,   0.00000000e+00,
         9.61891970e-03,  -4.26862058e-02,  -1.83224106e-02,
         7.52194452e-02,   1.68183754e-02,  -3.88604971e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.69407016e-03,
         2.29502617e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.82890742e-03,   3.99217899e-03,
        -3.78475465e-04,   1.51390186e-03,  -2.46650845e-03,
         9.86646822e-03,   2.91571505e-03,  -1.16628661e-02,
        -7.10732189e-04,   2.84109669e-03,   0.00000000e+00,
         0.00000000e+00,  -4.94245671e-03,   2.00265382e-02,
         7.05042011e-03,  -2.82037815e-02,  -2.09554913e-03,
         7.56428847e-03,   0.00000000e+00,   0.00000000e+00,
         5.64740916e-03,   5.60664215e-06,  -1.50976659e-03,
         6.03915868e-03,  -9.82071380e-03,   3.93634773e-02,
         1.16272483e-02,  -4.65169354e-02,  -2.88062809e-03,
         1.13129291e-02,   0.00000000e+00,   0.00000000e+00,
        -1.95208124e-02,   7.99191869e-02,   2.80923235e-02,
        -1.12493180e-01,  -8.73410668e-03,   3.00815128e-02,
         0.00000000e+00,   0.00000000e+00,   1.19966597e-03,
         5.21491976e-05,   5.55561107e-03,   3.48701701e-04,
         1.12213345e-05,  -4.48895452e-05,   3.43875717e-04,
        -1.38461561e-03,  -5.74144041e-04,   2.33598343e-03,
         6.72674108e-06,  -4.18255875e-06,   0.00000000e+00,
         0.00000000e+00,   9.90852621e-04,  -4.17734148e-03,
        -1.52448773e-03,   7.12387382e-03,   2.20444858e-04,
        -3.38449096e-04,   0.00000000e+00,   0.00000000e+00,
        -5.42364344e-05,  -4.19648833e-05,  -3.59956209e-04,
        -1.84599456e-04,   5.58792439e-03,   7.68930110e-05,
        -2.66244560e-04,   1.06539488e-03,  -1.50809900e-03,
         6.22895776e-03,   1.76284936e-03,  -7.07170585e-03,
        -3.48099135e-04,   9.16155017e-04,   0.00000000e+00,
         0.00000000e+00,  -2.20448204e-03,   1.08544521e-02,
         3.45847225e-03,  -1.39924069e-02,  -1.76101075e-03,
         2.58596956e-03,   0.00000000e+00,   0.00000000e+00,
         1.04266647e-04,   8.06752456e-05,   6.91996576e-04,
         3.54882589e-04,  -9.84956324e-05,  -7.45468157e-05,
         5.72604245e-03,   1.81428226e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.19675960e-04,   9.16014640e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.82655405e-04,   1.72141140e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.53668986e-03,   3.81159562e-05,
        -2.00060007e-03,   8.32470934e-03,  -1.29619062e-02,
         5.43349271e-02,   1.57758143e-02,  -6.36409700e-02,
        -4.46044343e-03,   1.47460806e-02,   0.00000000e+00,
         0.00000000e+00,  -2.59602048e-02,   1.10744433e-01,
         3.81363719e-02,  -1.53931566e-01,  -1.25013580e-02,
         3.84063959e-02,   0.00000000e+00,   0.00000000e+00,
         7.76312959e-04,   1.04250775e-03,   3.04315630e-03,
         4.33615120e-03,  -2.37670826e-04,  -5.78602397e-04,
         4.56909462e-04,   1.11233219e-03,   0.00000000e+00,
         0.00000000e+00,   2.78640621e-03,   1.11456249e-02,
         4.44039760e-05,  -1.87511336e-04,   7.96040956e-04,
        -3.58081235e-03,  -8.22351863e-04,   4.95221890e-03,
        -1.13848126e-04,   9.06688451e-04,   0.00000000e+00,
         0.00000000e+00,   2.28905458e-03,  -1.07310405e-02,
        -2.15063728e-03,   1.50736168e-02,  -1.62391997e-04,
         3.00386010e-03,   0.00000000e+00,   0.00000000e+00,
         3.54051303e-04,  -1.45218205e-03,   1.21449488e-03,
        -5.81643508e-03,   2.54292567e-03,   6.95586704e-04,
         1.29654299e-04,  -9.36582346e-04,   0.00000000e+00,
         0.00000000e+00,   1.42832028e-03,  -8.57154244e-03,
         4.71188403e-03,   2.49659037e-03,  -3.15453626e-04,
         2.41106343e-03,  -1.85375068e-03,   1.43888373e-02,
         3.30883470e-03,  -1.47883474e-02,  -1.83544655e-03,
        -8.13979334e-05,   0.00000000e+00,   0.00000000e+00,
        -3.51804552e-03,   2.66266497e-02,   6.65081941e-03,
        -2.94155395e-02,  -3.26093878e-03,  -1.99595651e-03,
         0.00000000e+00,   0.00000000e+00,  -6.80644709e-04,
         2.79174238e-03,  -2.33480150e-03,   1.11817856e-02,
         1.29654299e-04,  -9.36582346e-04,   2.36111455e-03,
         2.00893370e-03,   0.00000000e+00,   0.00000000e+00,
        -2.74586940e-03,   1.64783323e-02,   4.03670724e-04,
        -3.45312082e-03,   4.14582624e-03,   7.33881901e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.06435443e-04,
         1.92572542e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.38015426e-04,   3.65577912e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.61036801e-03,
         2.08404192e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.92186163e-03,   7.00378773e-04,
        -8.70995902e-04,   4.43080698e-03,  -5.87375538e-03,
         3.05081787e-02,  -3.85241784e-04,  -7.54123392e-03,
         8.48570686e-03,  -3.20401528e-02,   0.00000000e+00,
         0.00000000e+00,  -1.72114672e-02,   8.29574931e-02,
        -6.57936668e-04,  -1.78020951e-02,   3.36916107e-02,
        -1.29914470e-01,   0.00000000e+00,   0.00000000e+00,
        -1.23829369e-02,   4.95318771e-02,  -4.93855319e-02,
         1.97552615e-01,   2.95051913e-03,  -1.18133381e-02,
        -5.67221535e-03,   2.27105112e-02,   0.00000000e+00,
         0.00000000e+00,  -3.36645270e-02,   1.34978099e-01,
        -1.24037431e-02,  -2.07308019e-05,  -2.56702174e-03,
        -1.04207761e-04,  -1.17589497e-02,  -1.91318627e-03,
         2.25318357e-04,   9.53253787e-04,   1.08117022e-03,
         6.65978510e-03,  -9.84225918e-03,  -1.20743201e-02,
         1.54317894e-04,   3.01376615e-05,   8.24152290e-04,
         7.04456763e-04,  -4.55177867e-04,   1.49579945e-04,
        -1.18771668e-02,  -2.89480043e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.16983981e-02,  -4.10443857e-04,
        -2.23399759e-03,  -1.45461079e-04,  -7.97100577e-03,
        -3.89096907e-03,  -7.34013853e-04,   1.26268222e-02,
         5.59161485e-04,   1.35544264e-03,   0.00000000e+00,
         0.00000000e+00,  -8.49557588e-03,  -1.09064484e-02,
        -5.58573932e-04,   2.49472210e-03,  -3.11366273e-03,
         1.84894636e-02,   1.39707073e-03,  -3.11502269e-02,
        -9.09583495e-04,   2.37638857e-03,   0.00000000e+00,
         0.00000000e+00,  -7.05331976e-03,   4.11714668e-02,
         1.14417419e-02,  -9.12180164e-02,   4.67713371e-06,
         7.26538567e-05,  -9.74508296e-06,   2.28806898e-03,
        -3.73613536e-05,  -1.11250000e-03,  -5.70136912e-03,
        -8.05888066e-05,   0.00000000e+00,   0.00000000e+00,
        -3.09283273e-04,   6.26659495e-03,  -7.65580286e-04,
        -5.57350835e-05,  -1.00487596e-02,   1.00982262e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.45156212e-03,
        -6.08895706e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.08280107e-03,  -1.60280061e-03,
         2.52407993e-07,  -1.00963197e-06,   7.77696013e-06,
        -3.17058798e-05,  -1.35017339e-05,   5.40164106e-05,
         7.54636056e-07,  -4.93805270e-07,   0.00000000e+00,
         0.00000000e+00,  -6.56688944e-05,  -9.54492500e-05,
        -4.03688481e-05,   1.64983980e-04,   2.87915684e-04,
        -9.79108493e-06,   0.00000000e+00,   0.00000000e+00,
        -7.90903563e-03,  -9.69755973e-08,   6.83545376e-06,
        -2.74524523e-05,   1.89749244e-04,  -8.62766286e-04,
        -3.65341509e-04,   1.47314831e-03,   7.08462993e-05,
        -1.17520569e-05,   0.00000000e+00,   0.00000000e+00,
         2.25100032e-05,  -2.60097167e-03,  -1.07596737e-03,
         4.50623046e-03,   1.73365877e-03,  -2.53497004e-04,
         0.00000000e+00,   0.00000000e+00,  -1.69791903e-03,
        -9.94116983e-07,  -7.89980679e-03,  -3.09406487e-05,
        -9.81736218e-04,   3.92695042e-03,  -6.43959096e-03,
         2.57718896e-02,   7.62826936e-03,  -3.05655008e-02,
        -1.89269070e-03,   7.53673640e-03,   0.00000000e+00,
         0.00000000e+00,  -1.30960954e-02,   5.27341415e-02,
         1.82924120e-02,  -7.46075478e-02,  -5.21431511e-03,
         1.99601328e-02,   0.00000000e+00,   0.00000000e+00,
         1.07958944e-04,   4.33855533e-06,   6.54217937e-04,
         1.32548178e-04,  -7.85865993e-03,  -2.11288253e-04,
         2.98352301e-06,  -1.24336596e-05,   2.56453211e-05,
        -3.53451047e-04,  -1.42009648e-04,   5.97867651e-04,
         1.42454204e-04,   4.19771172e-05,   0.00000000e+00,
         0.00000000e+00,  -4.50992005e-04,  -9.12152453e-04,
        -3.19414863e-04,   1.52799764e-03,   1.47908653e-03,
         4.26347938e-05,   0.00000000e+00,   0.00000000e+00,
        -1.48345155e-04,  -1.08678204e-06,  -9.30809349e-04,
        -3.12163776e-05,   1.26983273e-04,   2.02740736e-04,
        -8.01314049e-03,  -2.80957534e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.55764620e-07,  -4.64137213e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.06238093e-04,  -1.43921033e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.78758439e-03,  -6.27338802e-06,
        -7.54809718e-05,  -9.16033775e-05,  -6.89839629e-05,
        -2.88879241e-03,  -1.08990006e-03,   5.16625746e-03,
         9.69628404e-04,   3.99072273e-05,   0.00000000e+00,
         0.00000000e+00,  -1.42871379e-04,  -8.78549970e-03,
        -3.44434473e-03,   1.61085828e-02,   4.07311055e-03,
        -3.84541941e-04,   0.00000000e+00,   0.00000000e+00,
        -1.44966039e-03,  -9.21269264e-06,  -5.72068885e-03,
        -2.68288103e-04,  -4.04413403e-05,   2.76228031e-03,
        -8.51586334e-04,  -1.51589840e-04,   0.00000000e+00,
         0.00000000e+00,  -7.49969444e-03,  -1.42913067e-03,
        -1.91605218e-03,   7.67757055e-03,  -1.26395297e-02,
         5.11570260e-02,   1.47861578e-02,  -6.13905323e-02,
        -3.97577839e-03,   1.52245859e-02,   0.00000000e+00,
         0.00000000e+00,  -2.59658864e-02,   1.06512192e-01,
         3.59504698e-02,  -1.53231984e-01,  -1.08832726e-02,
         3.95298878e-02,   0.00000000e+00,   0.00000000e+00,
         1.04042595e-05,   1.90117315e-05,   2.62047547e-04,
         5.83023357e-04,  -2.85133462e-03,  -4.03816974e-03,
         4.12069711e-05,   4.80149528e-04,   0.00000000e+00,
         0.00000000e+00,  -3.97786515e-04,   6.58432681e-03,
        -3.88490326e-03,  -1.55396131e-02,  -3.31927292e-04,
        -7.71407083e-05,  -1.66512459e-03,  -2.21720649e-03,
        -5.23769215e-04,   4.42333322e-03,   2.22905189e-03,
         4.31572053e-04,   0.00000000e+00,   0.00000000e+00,
        -2.70900144e-03,  -5.96770255e-03,  -1.96368327e-03,
         1.25410042e-02,   4.73070002e-03,   1.31154265e-03,
         0.00000000e+00,   0.00000000e+00,  -1.54876727e-05,
        -2.06924568e-05,  -4.14794271e-04,  -5.73366261e-04,
        -1.67453814e-03,   7.34312997e-03,  -3.89479618e-03,
        -2.67631848e-04,   0.00000000e+00,   0.00000000e+00,
        -1.18001794e-03,  -2.18616989e-03,  -3.05504183e-03,
         1.52416426e-02,  -7.71046593e-03,  -2.27221666e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.16745945e-04,
        -2.74470438e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.79491117e-03,  -8.63810689e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.74222707e-03,
        -3.23833924e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.20103031e-03,  -2.34474181e-04,
        -1.91911067e-04,  -4.11772666e-04,  -8.84800470e-04,
        -6.29860153e-03,  -2.58174179e-03,   2.35528319e-02,
        -1.30852262e-03,   2.43950433e-03,   0.00000000e+00,
         0.00000000e+00,  -4.48695553e-04,  -1.98277822e-02,
        -1.36954572e-02,   8.74121731e-02,  -6.05041630e-03,
         1.67734750e-02,   0.00000000e+00,   0.00000000e+00,
         6.81708798e-05,  -2.72863546e-04,   1.85101478e-03,
        -7.41850862e-03,  -3.27770803e-02,   1.31124478e-01,
         5.42432223e-04,  -2.19929914e-03,   0.00000000e+00,
         0.00000000e+00,   5.86107593e-03,  -2.44086080e-02,
        -3.31188797e-02,   1.33241338e-01,   3.01193897e-02,
         3.40427088e-03,   4.00727839e-03,   9.47999394e-03,
         1.72501225e-02,   4.63189845e-02,   2.92858735e-04,
        -5.63146091e-03,   1.60561490e-03,  -3.02987663e-02,
         2.64249670e-02,   1.40499290e-02,   1.24652255e-04,
        -2.30087596e-03,   1.31794209e-03,  -1.48050581e-02,
        -4.97238029e-03,   2.29965922e-02,   2.98380385e-02,
        -6.27540056e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.63730466e-02,   6.43997487e-03,   2.27095723e-03,
         1.33873053e-02,   2.38430850e-03,   7.32874397e-02,
         6.95280698e-03,  -4.79005670e-02,   4.53140749e-03,
        -2.60962386e-02,   0.00000000e+00,   0.00000000e+00,
        -7.33494080e-03,   1.27793844e-01,   2.09635539e-03,
        -9.00500890e-03,   1.03097637e-02,  -5.35613323e-02,
         9.55661788e-03,   1.84043714e-02,  -1.09110112e-02,
         4.57500699e-02,   0.00000000e+00,   0.00000000e+00,
         1.83349382e-02,  -9.67356617e-02,   1.41522738e-02,
         3.53168568e-02,   7.13108620e-04,  -3.10251605e-03,
         4.57905082e-03,  -2.31950576e-02,  -9.93423822e-03,
         4.18429779e-02,   1.78856393e-02,  -1.95233226e-02,
         0.00000000e+00,   0.00000000e+00,   9.49817184e-03,
        -4.71022177e-02,  -2.24427290e-02,   9.40033547e-02,
         3.24113104e-02,  -4.73046129e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.12471899e-02,   6.26211908e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.79305739e-02,   9.11591939e-03,  -6.15226663e-06,
         2.46090665e-05,  -3.56345816e-05,   1.43701846e-04,
         4.08173690e-05,  -1.63282741e-04,  -6.60808339e-06,
         2.15241304e-05,   0.00000000e+00,   0.00000000e+00,
         1.10130913e-04,   2.49642315e-04,   7.95311662e-05,
        -3.22933559e-04,  -5.65414197e-04,   6.21842698e-05,
         0.00000000e+00,   0.00000000e+00,   1.52046983e-02,
         1.86430404e-07,  -1.67856148e-04,   6.71695965e-04,
        -9.27497036e-04,   3.92814999e-03,   1.10543343e-03,
        -4.44122845e-03,  -2.80406763e-04,   5.56574475e-04,
         0.00000000e+00,   0.00000000e+00,  -4.76106384e-04,
         6.83123290e-03,   2.12433649e-03,  -8.78656253e-03,
        -3.66541855e-03,   1.62786421e-03,   0.00000000e+00,
         0.00000000e+00,   3.26415861e-03,   1.91113678e-06,
         1.51869564e-02,   5.94817437e-05,   4.14742374e-06,
        -1.66022816e-05,   9.01677036e-05,  -3.83023321e-04,
        -1.20114374e-04,   5.86786274e-04,  -5.63709322e-06,
         7.75249730e-05,   0.00000000e+00,   0.00000000e+00,
         1.17707777e-04,  -9.69800893e-04,   3.20989547e-04,
         1.46545877e-03,   2.86688098e-04,   1.16622245e-04,
         0.00000000e+00,   0.00000000e+00,  -1.48345155e-04,
        -1.08678204e-06,  -9.30809349e-04,  -3.12163776e-05,
         1.50885425e-02,   2.34116041e-05,  -1.05915964e-03,
         4.23786544e-03,  -6.70295835e-03,   2.73461473e-02,
         8.02085585e-03,  -3.21340504e-02,  -2.19462464e-03,
         7.48964776e-03,   0.00000000e+00,   0.00000000e+00,
        -1.23548267e-02,   5.48734067e-02,   1.90747414e-02,
        -7.66725721e-02,  -8.01560191e-03,   2.01451916e-02,
         0.00000000e+00,   0.00000000e+00,   3.15979803e-04,
         5.86252376e-06,   1.95946960e-03,   1.76322157e-04,
        -2.30578676e-04,  -1.21377479e-04,   1.54241457e-02,
         4.36791356e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.44337674e-05,   2.39222223e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.73559842e-04,
         3.81956383e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.49712148e-02,   1.20602532e-05,  -3.69962406e-04,
         2.45467045e-03,  -1.79706011e-03,   1.43434848e-02,
         3.30783813e-03,  -1.47875501e-02,  -2.23073128e-03,
         2.34829854e-04,   0.00000000e+00,   0.00000000e+00,
        -1.47208272e-03,   2.49898795e-02,   6.39055238e-03,
        -2.92073259e-02,  -8.42645699e-03,   2.13645806e-03,
         0.00000000e+00,   0.00000000e+00,   2.78689463e-03,
         1.77109093e-05,   1.09977186e-02,   5.15769542e-04,
        -8.51586334e-04,  -1.51589840e-04,   1.15371778e-03,
         2.97485111e-03,   0.00000000e+00,   0.00000000e+00,
         1.44177618e-02,   2.74742734e-03,   9.72344418e-05,
        -4.20470095e-04,   7.52743265e-04,  -4.15150077e-03,
         2.51545582e-04,   3.80308138e-03,  -3.10302303e-04,
         2.46305541e-03,   0.00000000e+00,   0.00000000e+00,
         1.24794616e-03,  -9.13326063e-03,   2.17068994e-03,
         9.23350564e-03,   2.51423746e-04,   4.89496366e-03,
         0.00000000e+00,   0.00000000e+00,  -1.54876727e-05,
        -2.06924568e-05,  -4.14794271e-04,  -5.73366261e-04,
         7.27359351e-03,   1.84624650e-04,   7.59757982e-04,
        -3.99127518e-03,   0.00000000e+00,   0.00000000e+00,
        -1.18001794e-03,  -2.18616989e-03,   1.41085893e-02,
         1.51073762e-03,  -1.68705426e-03,   1.02284135e-02,
        -1.10215385e-02,   6.43271607e-02,   1.65291129e-02,
        -7.06952727e-02,  -7.93287128e-03,   1.07960135e-02,
         0.00000000e+00,   0.00000000e+00,  -2.25774050e-02,
         1.25641707e-01,   3.91948686e-02,  -1.64465848e-01,
        -1.85267394e-02,   3.28455009e-02,   0.00000000e+00,
         0.00000000e+00,   3.21222521e-05,   4.80282681e-05,
         8.43703620e-04,   1.38704114e-03,  -1.32722020e-04,
        -4.21355174e-04,   5.69548245e-03,   8.09304881e-03,
         0.00000000e+00,   0.00000000e+00,   1.25692438e-03,
         9.64994050e-03,   1.21754878e-03,  -9.41462843e-03,
         8.18288829e-03,   3.27315532e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.11293278e-04,   1.49371775e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.45362649e-03,   2.40097771e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.19423155e-03,   6.22553413e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.38435960e-02,   4.50764084e-04,  -3.22146198e-03,
         1.57900477e-02,  -1.67015424e-02,   8.85290853e-02,
        -1.17394047e-03,  -2.35760823e-02,   2.05694343e-02,
        -7.58814463e-02,   0.00000000e+00,   0.00000000e+00,
        -2.85863114e-02,   1.58001607e-01,  -4.68495470e-03,
        -4.44926275e-02,   4.38884362e-02,  -1.59678215e-01,
         0.00000000e+00,   0.00000000e+00,  -1.31054873e-04,
         5.24565585e-04,  -3.55847701e-03,   1.42616864e-02,
         5.42432223e-04,  -2.19929914e-03,  -3.35377200e-02,
         1.34208502e-01,   0.00000000e+00,   0.00000000e+00,
        -1.12676053e-02,   4.69242445e-02,   2.58817532e-03,
        -1.31480326e-02,  -3.49335479e-02,   1.42459923e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.02150893e-05,
         9.09768581e-04,  -4.64067604e-04,   5.50136938e-03,
         1.11023408e-03,  -5.58906508e-03,  -3.66299836e-04,
         8.20141248e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.67737108e-03,
         9.80319801e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.58206404e-03,
        -1.11296942e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.69273066e-04,   1.42716066e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.85994909e-04,   2.43707757e-03,  -3.56390565e-03,
         1.61586784e-02,   4.37549132e-03,  -1.83034034e-02,
        -1.10334536e-03,   3.96344985e-03,   0.00000000e+00,
         0.00000000e+00,  -7.21403091e-03,   3.25619704e-02,
         1.02181788e-02,  -4.25823318e-02,  -2.42069153e-03,
         8.72367683e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.30977161e-06,
         2.12419543e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.82346363e-06,   4.03241901e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.44558572e-04,   5.82131318e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.63863916e-04,   1.11621999e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.30796145e-05,
        -5.33478076e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.04537302e-05,  -1.79064783e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.06470550e-05,
         2.52552634e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.29366616e-05,   4.49518364e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.81595784e-04,
         3.92638520e-03,  -6.42303914e-03,   2.56966280e-02,
         7.59807225e-03,  -3.03933183e-02,  -1.89130363e-03,
         7.55406364e-03,   0.00000000e+00,   0.00000000e+00,
        -1.30693851e-02,   5.23824699e-02,   1.84623398e-02,
        -7.38666092e-02,  -5.07421008e-03,   2.00303675e-02,
         0.00000000e+00,   0.00000000e+00,   3.07941694e-05,
         3.77324337e-06,   1.70038367e-04,   1.16310339e-04,
        -5.02258228e-06,  -9.95551135e-05,   9.65564604e-06,
         1.91389386e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.92980053e-04,
         2.23496111e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.06485414e-03,   4.93807478e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.83411434e-04,
         2.68342775e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.65136931e-04,
        -7.39976738e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.17330615e-04,  -2.79360412e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.12327099e-04,
        -3.75602672e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.07345457e-04,   2.38862874e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.18377944e-03,   6.11090245e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.75390009e-03,   7.22076066e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.91687575e-03,   7.67233800e-03,  -1.26129602e-02,
         5.06458895e-02,   1.49645287e-02,  -5.99375440e-02,
        -3.90773992e-03,   1.54097317e-02,   0.00000000e+00,
         0.00000000e+00,  -2.58434898e-02,   1.04145031e-01,
         3.66846363e-02,  -1.47062827e-01,  -1.04043116e-02,
         4.04633585e-02,   0.00000000e+00,   0.00000000e+00,
         2.34802895e-06,   8.24812575e-06,   4.62838014e-05,
         2.84775139e-04,   1.98470971e-05,  -1.86106718e-04,
        -3.81549836e-05,   3.57780220e-04,   0.00000000e+00,
         0.00000000e+00,  -1.01159704e-03,   5.44714571e-03,
         1.72698440e-03,  -7.37688595e-03,  -3.32003522e-03,
         1.41816690e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.47999401e-03,
         1.86219917e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.79526962e-02,   7.30837590e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.24949230e-02,
         1.29980467e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.24457335e-02,   1.29821728e-01,
         5.49903320e-01,   2.90654411e-03,   1.12842542e-01,
         8.98555095e-03,   5.31130984e-01,   6.22055482e-02,
        -1.58201481e-02,  -9.81645614e-03,  -9.57982819e-02,
        -7.70627688e-02,   5.50833913e-01,   1.01127054e-01,
         5.59326699e-03,   3.47064135e-03,   3.38698074e-02,
         2.72458032e-02,  -8.92339549e-03,  -3.25063764e-02,
         5.28749636e-01,   2.06778770e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.25594739e-01,   9.18513740e-03,
         9.75183821e-02,   1.29525943e-02,   3.75165327e-01,
         1.07440211e-01,  -7.04105508e-02,  -1.41279840e-01,
         2.48938890e-02,   4.99499665e-02,   0.00000000e+00,
         0.00000000e+00,   4.59210927e-01,   2.35141265e-01,
         1.29365017e-03,  -1.54908125e-02,  -3.07221377e-02,
        -1.43097908e-01,   2.43942432e-01,   1.95828871e-01,
         2.30627456e-03,  -6.54872890e-02,   0.00000000e+00,
         0.00000000e+00,  -7.38861749e-02,  -3.46680386e-01,
         4.22880651e-01,   5.35307672e-01,  -4.57374403e-04,
         5.47682928e-03,   1.08619160e-02,   5.05927505e-02,
         2.30627456e-03,  -6.54872890e-02,   2.49650171e-01,
         3.37560998e-02,   0.00000000e+00,   0.00000000e+00,
         2.61227076e-02,   1.22570026e-01,   4.48385724e-03,
        -1.81265597e-01,   4.33977631e-01,   8.66982069e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.50465562e-01,
         1.06028468e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.35562914e-01,   2.26111403e-02,
        -2.31385363e-08,   9.25541450e-08,   4.83950487e-06,
         6.02479334e-07,   1.38682651e-07,  -7.12945071e-07,
        -2.11328316e-05,   1.67313552e-07,   0.00000000e+00,
         0.00000000e+00,   3.03765923e-03,   1.21623455e-06,
        -1.50597440e-05,  -1.71004011e-06,  -9.69660185e-03,
         4.48216177e-07,   0.00000000e+00,   0.00000000e+00,
         2.69805830e-01,   1.71704650e-10,  -6.62984398e-07,
         6.85290155e-06,   8.20806820e-04,   4.50238677e-05,
        -3.24786779e-05,  -5.40025500e-05,  -2.17774714e-03,
         9.73952337e-06,   0.00000000e+00,   0.00000000e+00,
         2.06988769e-02,   8.82791907e-05,  -8.12395126e-04,
        -1.23262475e-04,  -5.55067391e-02,   2.78667741e-05,
         0.00000000e+00,   0.00000000e+00,   5.79309840e-02,
         3.14628665e-09,   2.69805773e-01,   2.11252810e-07,
         1.59788865e-06,  -6.53080732e-06,  -4.14183879e-05,
        -4.52813185e-05,   3.93660093e-04,   5.56810099e-05,
         1.33572837e-04,  -9.66526558e-06,   0.00000000e+00,
         0.00000000e+00,  -1.43807385e-03,  -9.16586412e-05,
         1.17061533e-02,   1.30408342e-04,   3.81729527e-03,
        -2.75567856e-05,   0.00000000e+00,   0.00000000e+00,
        -1.96234150e-03,  -2.80043730e-09,  -1.24150405e-02,
        -2.10570133e-07,   2.69113679e-01,   2.34344534e-07,
         1.18270440e-06,   1.43520299e-05,   1.99200150e-03,
         9.36720878e-05,  -9.00040709e-05,  -1.12269529e-04,
        -4.90435523e-03,   1.89091540e-05,   0.00000000e+00,
         0.00000000e+00,   2.17540437e-02,   1.80897909e-04,
        -9.19915780e-04,  -2.51102469e-04,  -4.77419612e-02,
         5.55057635e-05,   0.00000000e+00,   0.00000000e+00,
         3.77249667e-03,   5.38369106e-09,   2.38672519e-02,
         4.04809829e-07,  -2.35364696e-03,  -4.01457041e-07,
         2.72414141e-01,   7.97298130e-07,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.98501676e-04,   1.69992007e-06,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.15763679e-02,   2.85855901e-06,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.67889381e-01,   2.55184214e-08,
         4.07574822e-03,   4.73411688e-04,   2.78782447e-02,
         3.50657858e-03,  -4.13540853e-03,  -4.54110053e-03,
        -3.27536558e-02,   9.51337324e-04,   0.00000000e+00,
         0.00000000e+00,   7.76656340e-02,   7.05581205e-03,
        -1.01394044e-02,  -1.02169209e-02,  -1.31733960e-01,
         2.42598645e-03,   0.00000000e+00,   0.00000000e+00,
         4.95318286e-02,   6.47037397e-08,   1.97548682e-01,
         5.24380081e-06,  -1.18091150e-02,  -5.63078639e-06,
         2.27023925e-02,   1.08248859e-05,   0.00000000e+00,
         0.00000000e+00,   2.69716205e-01,   3.19991466e-04,
         3.05086838e-05,  -5.89708466e-04,  -2.60942525e-03,
        -4.91890170e-03,   1.85931326e-02,   6.61293235e-03,
         3.48747413e-03,  -1.39729307e-03,   0.00000000e+00,
         0.00000000e+00,  -1.17193205e-02,  -1.08112822e-02,
         7.51757940e-02,   1.63151721e-02,   1.95590463e-02,
        -3.71409510e-03,   0.00000000e+00,   0.00000000e+00,
        -2.72796036e-04,  -9.00132833e-08,  -7.41309006e-03,
        -7.22473954e-06,   1.31118419e-01,   8.07846184e-06,
        -2.18821030e-03,  -1.47851217e-05,   0.00000000e+00,
         0.00000000e+00,  -2.40469939e-02,  -4.82152143e-04,
         2.65908311e-01,   7.65818823e-04,   1.47009728e-02,
         1.45209989e-03,   8.03829919e-02,   1.08614578e-02,
        -1.29741407e-02,  -1.41359221e-02,  -7.82800554e-02,
         3.19814544e-03,   0.00000000e+00,   0.00000000e+00,
         1.41630472e-01,   2.18281808e-02,  -2.07804602e-02,
        -3.16162232e-02,  -1.65631539e-01,   7.93776482e-03,
         0.00000000e+00,   0.00000000e+00,   5.24435801e-04,
         1.73045727e-07,   1.42512695e-02,   1.38891757e-05,
        -2.18821030e-03,  -1.47851217e-05,   1.34186894e-01,
         2.88112839e-05,   0.00000000e+00,   0.00000000e+00,
         4.62290607e-02,   9.26911730e-04,  -1.20997834e-02,
        -1.39766567e-03,   2.82875548e-01,   2.72573193e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.83587358e-02,
         3.51007842e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.26063938e-02,   6.36487036e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.29980177e-01,
         3.87677634e-07,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.59614361e-01,   3.87943624e-05,
         6.61190990e-03,   2.64476396e-02,   6.34822549e-02,
         2.53929020e-01,  -8.84098836e-02,  -3.53639534e-01,
         3.12576141e-02,   1.25030456e-01,   0.00000000e+00,
         0.00000000e+00,   1.67975672e-01,   6.71902690e-01,
        -2.68146371e-01,  -1.07258548e+00,   9.48040586e-02,
         3.79216234e-01,   0.00000000e+00,   0.00000000e+00,
         7.47520249e-07,   2.99008100e-06,   5.24881510e-05,
         2.09952604e-04,  -5.53004452e-05,  -2.21201781e-04,
         1.06312151e-04,   4.25248603e-04,   0.00000000e+00,
         0.00000000e+00,   4.46481129e-03,   1.78592452e-02,
        -7.27372043e-03,  -2.90948817e-02,   1.39833388e-02,
         5.59333553e-02,   0.00000000e+00,   0.00000000e+00,
         2.85036216e-01,   1.14014487e+00,   1.06032883e-01,
         4.24131531e-01,  -7.15457770e-02,   4.09779048e-01,
         4.96416436e-02,   1.54676167e-01,   2.78122641e-02,
        -1.16381506e-01,   5.18992716e-03,  -2.84562218e-02,
         8.28032125e-02,   4.24447299e-02,  -9.83312029e-03,
         4.11470761e-02,  -1.83491634e-03,   1.00607937e-02,
         1.30139832e-04,  -6.30674028e-04,   8.31252921e-02,
         4.08838913e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.31713035e-02,   4.06609144e-02,  -9.53180862e-02,
         5.07983278e-01,   1.72183837e-02,   1.66015366e-01,
         5.42658032e-03,  -2.67359223e-02,  -1.91858587e-03,
         9.45257598e-03,   0.00000000e+00,   0.00000000e+00,
         1.43221969e-02,   1.72320804e-01,   5.63280931e-02,
        -2.25900277e-01,   1.13822216e-02,  -4.78387452e-02,
         2.91492579e-02,   1.59752150e-02,   1.58422140e-04,
        -6.62970186e-04,   0.00000000e+00,   0.00000000e+00,
         9.95854954e-03,  -4.21250358e-02,   3.84806659e-02,
         3.67691919e-03,  -1.99149883e-02,   7.98678089e-02,
        -4.02422305e-03,   1.69135506e-02,   1.58422140e-04,
        -6.62970186e-04,   2.95413327e-02,   1.43344475e-02,
         0.00000000e+00,   0.00000000e+00,  -3.52087896e-03,
         1.48934492e-02,   3.97520959e-05,  -1.74946819e-04,
         3.85790473e-02,   3.24394790e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.95973434e-02,   1.41000521e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.85931018e-02,   3.18209486e-03,  -7.19230232e-04,
         2.87692093e-03,  -1.50040120e-04,   6.01893890e-04,
         1.37332946e-07,  -5.49765430e-07,   1.58264572e-05,
        -7.06151009e-05,   0.00000000e+00,   0.00000000e+00,
         1.24213746e-04,   5.26728140e-04,  -1.91946737e-08,
        -7.77847774e-08,  -8.12836248e-04,  -9.99113368e-06,
         0.00000000e+00,   0.00000000e+00,   2.25274263e-02,
        -0.00000000e+00,  -4.56528081e-03,   1.82621406e-02,
        -8.65674242e-04,   3.82136669e-03,   7.35041469e-06,
        -3.03668748e-05,  -1.04182147e-04,  -4.92354746e-04,
         0.00000000e+00,   0.00000000e+00,   1.01493582e-03,
         3.34444915e-03,  -1.29465871e-06,  -4.72259745e-06,
        -4.85521810e-03,  -6.96235320e-05,   0.00000000e+00,
         0.00000000e+00,   4.83694330e-03,   7.26143453e-09,
         2.25274028e-02,   9.40088814e-08,   1.39760581e-03,
        -5.59042900e-03,   2.92129671e-04,  -1.16960866e-03,
         1.39264383e-05,   1.09535438e-04,  -3.38443067e-05,
         1.37829002e-04,   0.00000000e+00,   0.00000000e+00,
         2.51628571e-04,  -1.02355014e-03,   1.00264689e-03,
         1.55218826e-05,   5.66231572e-06,   1.95028616e-05,
         0.00000000e+00,   0.00000000e+00,  -4.75713658e-06,
        -2.44349774e-12,  -3.00932930e-05,  -1.42319222e-08,
         2.22243840e-02,   1.01985065e-09,  -3.73891244e-03,
         1.49603684e-02,  -5.57665776e-04,   3.13292254e-03,
         7.92320675e-06,  -3.44647060e-05,  -4.05122963e-04,
        -5.00776068e-04,   0.00000000e+00,   0.00000000e+00,
         1.40285146e-03,   2.74304441e-03,  -1.73282952e-06,
        -6.80645355e-06,  -4.51505171e-03,  -7.06583074e-05,
         0.00000000e+00,   0.00000000e+00,   4.88653527e-04,
         3.25460006e-08,   3.09153975e-03,   2.51014462e-07,
        -8.83330772e-06,  -6.33402319e-08,   2.31335143e-02,
         3.62182918e-07,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.58325290e-05,   1.01901548e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.00290081e-03,
         1.44379512e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.22242895e-02,   9.52792276e-10,  -1.68762673e-02,
         7.27352693e-02,  -3.03165140e-04,   1.77384904e-02,
         2.85143793e-04,  -1.39369428e-03,  -3.94198991e-03,
        -1.86867773e-03,   0.00000000e+00,   0.00000000e+00,
         4.00998500e-03,   1.66630954e-02,   4.05354244e-04,
        -1.81750595e-03,  -1.23076832e-02,   2.03013314e-04,
         0.00000000e+00,   0.00000000e+00,   4.12982847e-03,
         2.33232062e-05,   1.64572190e-02,   1.48843520e-04,
        -1.72994770e-05,  -4.53272706e-05,   2.91007208e-03,
         1.23944918e-04,   0.00000000e+00,   0.00000000e+00,
         2.22305932e-02,   1.15823860e-03,   9.57578234e-03,
        -3.83302250e-02,   1.97575307e-03,  -8.04667772e-03,
         2.01245105e-03,   1.46570668e-03,  -1.57110254e-04,
         7.30592205e-04,   0.00000000e+00,   0.00000000e+00,
         1.70785727e-03,  -7.05421970e-03,   6.51797481e-03,
         2.74919559e-04,   3.24342789e-05,   1.01858547e-04,
         0.00000000e+00,   0.00000000e+00,  -6.60294388e-07,
        -4.30440948e-09,  -1.78927884e-05,  -3.30193952e-07,
         1.07192815e-02,   8.71749288e-07,  -8.07028983e-06,
        -6.82173082e-07,   0.00000000e+00,   0.00000000e+00,
         1.95118954e-05,  -3.11391911e-04,   2.09131990e-02,
         2.02587374e-05,  -2.68256008e-02,   1.26192953e-01,
         3.43347567e-03,   3.54354470e-02,   8.75619043e-04,
        -4.34381678e-03,  -1.02641322e-02,  -2.95881467e-03,
         0.00000000e+00,   0.00000000e+00,   7.77492601e-03,
         3.50957333e-02,   1.48030940e-03,  -6.42055612e-03,
        -1.70477755e-02,   1.31373042e-03,   0.00000000e+00,
         0.00000000e+00,   4.71999661e-05,   8.29487872e-05,
         1.71429231e-03,   5.28667202e-04,   3.20601354e-05,
        -1.61203874e-04,   1.14566666e-02,   4.38211603e-04,
         0.00000000e+00,   0.00000000e+00,   5.23346874e-03,
         3.03984284e-03,   2.30253452e-04,  -1.10436947e-03,
         2.38876691e-02,   6.97635367e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.06101446e-03,   1.26704078e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.52689115e-03,   2.35855978e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.07192086e-02,   8.11381300e-07,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.09134277e-02,   1.73868820e-05,  -8.51828890e-02,
         3.56083859e-01,  -9.11353889e-03,   8.20171931e-02,
        -8.54851583e-03,  -1.41907051e-02,   3.02235676e-03,
         5.01717189e-03,   0.00000000e+00,   0.00000000e+00,
        -2.20863039e-03,   7.51743653e-02,  -1.79977026e-02,
        -7.12467089e-03,   6.36314877e-03,   2.51895155e-03,
         0.00000000e+00,   0.00000000e+00,  -1.57901241e-05,
         6.36660164e-05,  -9.19826555e-05,   4.05129388e-04,
         2.31600929e-05,  -1.27739832e-04,  -6.38364659e-05,
         3.33217751e-04,   0.00000000e+00,   0.00000000e+00,
        -4.51196033e-04,   4.27393442e-03,  -5.19417404e-04,
        -9.70971065e-04,  -1.20132865e-03,   1.23400620e-02,
         0.00000000e+00,   0.00000000e+00,   2.96942545e-02,
         1.67975705e-02,  -5.65401963e-02,   2.47063646e-01,
         3.63430570e-01,   6.17979699e-02,   3.59258913e-02,
         1.65648769e-01,   1.61487606e-01,   6.45950423e-01,
         1.64548793e-03,  -2.56206704e-02,   1.01683653e-02,
        -1.25118612e-01,   2.83665100e-01,   1.54309598e-01,
        -5.81767838e-04,   9.05827489e-03,  -3.59506004e-03,
         4.42361096e-02,   1.90484809e-04,  -3.23468250e-03,
         2.84136526e-01,   1.46304167e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.84203872e-01,   1.45160534e-01,
         2.93127378e-02,   1.56339883e-01,   5.86017913e-02,
         6.61011765e-01,   1.04551528e-02,  -1.05698313e-01,
        -3.69645473e-03,   3.73699968e-02,   0.00000000e+00,
         0.00000000e+00,   8.36817573e-02,   6.27022717e-01,
         1.12875570e-02,  -4.77630135e-02,   4.87719915e-02,
        -2.32728425e-01,   1.10463510e-01,   1.06974798e-01,
         8.38208553e-04,  -4.71081389e-03,   0.00000000e+00,
         0.00000000e+00,   3.17692384e-02,  -1.80851170e-01,
         1.68315049e-01,   7.96946388e-02,  -3.99075405e-03,
         1.68867754e-02,  -1.72435030e-02,   8.22819238e-02,
         8.38208553e-04,  -4.71081389e-03,   1.12537970e-01,
         9.53161280e-02,   0.00000000e+00,   0.00000000e+00,
        -1.12321219e-02,   6.39405443e-02,   6.89273302e-04,
        -4.54577850e-03,   1.70020914e-01,   6.84444110e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.12834322e-01,
         9.36506038e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.70264609e-01,   6.68372356e-02,
        -1.50581811e-04,   6.02327242e-04,  -7.17657804e-04,
         2.87901749e-03,   1.08270651e-06,  -4.34572853e-06,
         1.06903104e-04,  -4.62981178e-04,   0.00000000e+00,
         0.00000000e+00,   7.07666539e-04,   2.13288021e-03,
        -1.96413835e-07,  -4.56114545e-06,  -3.88375295e-03,
        -2.81885489e-04,   0.00000000e+00,   0.00000000e+00,
         1.09311142e-01,   7.37642450e-07,  -9.76851708e-04,
         3.91030866e-03,  -4.24980251e-03,   1.86795261e-02,
         7.76602004e-05,  -3.38703132e-04,  -2.46177821e-04,
        -3.30695934e-03,   0.00000000e+00,   0.00000000e+00,
         5.37497213e-03,   1.42113547e-02,   4.45784443e-05,
        -5.13454197e-04,  -2.30298176e-02,  -2.05436715e-03,
         0.00000000e+00,   0.00000000e+00,   2.34665205e-02,
         1.63324497e-05,   1.09260457e-01,   1.93078635e-04,
         2.92457814e-04,  -1.16987118e-03,   1.39153501e-03,
        -5.59820413e-03,   9.95842829e-06,   7.43187532e-04,
        -2.08186278e-04,   9.07968518e-04,   0.00000000e+00,
         0.00000000e+00,   8.95436861e-04,  -4.15890808e-03,
         4.75157775e-03,   4.87374474e-04,   2.19462882e-04,
         5.62190958e-04,   0.00000000e+00,   0.00000000e+00,
        -1.64799541e-04,  -3.51722426e-07,  -1.03563640e-03,
        -2.90034437e-05,   1.07924374e-01,   2.00899308e-05,
        -8.35497098e-04,   3.35518760e-03,  -2.95263229e-03,
         1.59967660e-02,   1.22718292e-04,  -5.67571845e-04,
        -1.61251315e-03,  -3.48667043e-03,   0.00000000e+00,
         0.00000000e+00,   6.81267634e-03,   1.27670602e-02,
         1.57241768e-04,  -1.08242831e-03,  -2.12018545e-02,
        -2.20349401e-03,   0.00000000e+00,   0.00000000e+00,
         2.30028216e-03,   3.35604258e-05,   1.45260642e-02,
         3.01981190e-04,  -2.83457193e-04,  -6.14533200e-05,
         1.11983560e-01,   3.98055750e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.26185484e-05,   6.91253127e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.75808119e-03,   4.47958384e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.07904835e-01,   1.90101726e-05,
        -1.87159974e-03,   1.89932381e-02,  -4.98762571e-03,
         8.61986998e-02,   1.21219851e-03,  -8.54366026e-03,
        -1.50903784e-02,  -1.36628485e-02,   0.00000000e+00,
         0.00000000e+00,   1.85157548e-02,   7.49378556e-02,
         2.28273101e-03,  -1.45112328e-02,  -5.66269600e-02,
        -6.68622895e-03,   0.00000000e+00,   0.00000000e+00,
         2.00083094e-02,   2.37645294e-04,   7.95848070e-02,
         1.78003640e-03,  -8.74679602e-04,  -4.66180134e-04,
         1.33977318e-02,   1.91699399e-03,   0.00000000e+00,
         0.00000000e+00,   1.06372780e-01,   1.07287866e-02,
         1.98199034e-03,  -8.05166754e-03,   9.06395134e-03,
        -3.88420941e-02,   7.57652484e-03,   1.03489770e-02,
        -6.69753203e-04,   4.88799576e-03,   0.00000000e+00,
         0.00000000e+00,   5.82891841e-03,  -2.94286251e-02,
         2.97599457e-02,   7.55905542e-03,   1.08444082e-03,
         3.05964846e-03,   0.00000000e+00,   0.00000000e+00,
        -2.25988765e-05,  -1.29904059e-06,  -5.86647424e-04,
        -1.42373732e-04,   5.20672530e-02,   1.14928482e-04,
        -2.00512972e-04,  -3.04958058e-04,   0.00000000e+00,
         0.00000000e+00,  -1.22395414e-03,  -3.03340012e-03,
         1.01589410e-01,   1.26949942e-03,   9.67653543e-04,
         3.74081047e-02,   7.35523636e-03,   1.63510250e-01,
         2.78094033e-03,  -2.26872511e-02,  -3.93201416e-02,
        -2.33487082e-02,   0.00000000e+00,   0.00000000e+00,
         3.45327491e-02,   1.52315711e-01,   6.86910613e-03,
        -4.01339083e-02,  -7.59354229e-02,  -8.56752628e-03,
         0.00000000e+00,   0.00000000e+00,   1.65185957e-04,
         6.23116562e-04,   7.62155678e-03,   4.35844406e-03,
         2.81668137e-05,  -1.21967720e-03,   5.48707351e-02,
         4.27985041e-03,   0.00000000e+00,   0.00000000e+00,
         2.19727772e-02,   2.29159870e-02,   5.76620261e-04,
        -8.06573243e-03,   1.10221296e-01,   4.62064116e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.86690901e-03,
         8.95166164e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.99506181e-02,   6.34035978e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.20512568e-02,
         1.05521561e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.01540760e-01,   1.08173718e-03,
        -1.26303595e-02,   8.48306496e-02,  -4.95677512e-02,
         3.95212605e-01,  -3.27476774e-02,  -9.40259791e-02,
         1.15780524e-02,   3.32432037e-02,   0.00000000e+00,
         0.00000000e+00,  -2.59432628e-04,   3.26927844e-01,
        -8.17964549e-02,  -8.99569361e-02,   2.89194140e-02,
         3.18045798e-02,   0.00000000e+00,   0.00000000e+00,
        -1.03890242e-04,   4.18015202e-04,  -7.46814033e-04,
         3.16858178e-03,   1.97111833e-04,  -9.63260540e-04,
        -7.54029382e-04,   3.39397033e-03,   0.00000000e+00,
         0.00000000e+00,  -4.25589598e-03,   2.87891190e-02,
        -1.55126231e-03,  -9.47123740e-03,  -8.67668629e-03,
         7.03423744e-02,   0.00000000e+00,   0.00000000e+00,
         1.43751710e-01,   1.50979395e-01,  -8.05049837e-03,
         1.23287739e-01,  -2.46872406e-02,   2.80243330e-01,
        -1.14456837e-01,  -2.56622474e-03,  -2.20255901e-02,
        -6.68380795e-03,  -9.34516806e-02,  -4.22225754e-02,
        -7.43682502e-03,   1.14636760e-01,  -2.26945257e-02,
         3.99397298e-01,  -5.54810580e-02,  -2.21924232e-01,
        -2.29620592e-04,  -3.42865689e-04,  -1.05845948e-03,
        -2.23552707e-03,  -7.27689714e-03,   3.73774038e-02,
        -9.68155014e-02,  -1.11660944e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.67966018e-02,  -1.10904958e-02,
        -1.91004987e-02,  -7.11425906e-03,  -6.13423968e-02,
        -4.82602729e-02,  -6.65802496e-02,   4.95157898e-01,
        -6.97164229e-04,  -2.42239101e-03,   0.00000000e+00,
         0.00000000e+00,  -6.85455675e-02,  -5.55252194e-02,
        -8.78286137e-03,   4.63209104e-02,  -1.99389156e-02,
         2.11296738e-01,   2.04296473e-02,  -2.81609304e-01,
        -3.43983670e-03,   1.81126855e-02,   0.00000000e+00,
         0.00000000e+00,  -2.11179240e-02,   2.67281019e-01,
        -1.45435001e-02,  -2.30572163e-01,   1.12802449e-04,
        -6.26474433e-04,   2.75511132e-04,  -4.26065595e-03,
        -1.85655404e-02,   7.86155004e-02,  -4.17339048e-02,
        -9.19466767e-03,   0.00000000e+00,   0.00000000e+00,
        -1.82351808e-04,  -4.44965336e-03,  -8.43837897e-03,
         3.93828722e-02,  -6.22244353e-02,  -9.42994643e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.17424663e-02,
        -9.06422453e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.22304070e-02,  -9.24761847e-03,
         1.37468460e-07,  -5.49873841e-07,   1.58630133e-07,
        -3.60646743e-06,  -7.05906935e-04,   2.82367711e-03,
         2.82321707e-06,   1.24761211e-06,   0.00000000e+00,
         0.00000000e+00,  -4.41713431e-04,  -3.47213247e-06,
        -3.41725290e-04,   1.38464070e-03,   1.41053463e-03,
         1.18978351e-06,   0.00000000e+00,   0.00000000e+00,
        -3.90556224e-02,  -3.55710594e-09,   7.37820808e-06,
        -3.03891095e-05,  -9.03387347e-05,  -2.04303984e-04,
        -4.44671043e-03,   1.78798474e-02,   3.44187488e-04,
         7.84581534e-05,   0.00000000e+00,   0.00000000e+00,
        -3.09387402e-03,  -2.08318140e-04,  -1.91527440e-03,
         8.77133672e-03,   8.30737549e-03,   8.10932622e-05,
         0.00000000e+00,   0.00000000e+00,  -8.38575628e-03,
        -6.83599959e-08,  -3.90542478e-02,  -4.73347822e-06,
        -3.76625945e-05,   1.50806664e-04,  -2.01548889e-04,
         9.12393386e-04,   1.32529708e-03,  -5.57391858e-03,
         1.29931834e-05,  -3.00673708e-04,   0.00000000e+00,
         0.00000000e+00,   2.22969551e-04,   1.02022751e-03,
        -1.01838521e-03,  -2.90222535e-03,  -1.11997209e-03,
        -2.93024079e-04,   0.00000000e+00,   0.00000000e+00,
         5.45597512e-04,   6.83983029e-06,   3.44882137e-03,
         5.17860283e-05,  -3.87010161e-02,  -2.56227906e-05,
         7.54334376e-06,  -3.41608156e-05,  -2.89911462e-04,
        -2.37468042e-04,  -3.56911711e-03,   1.45312740e-02,
         8.08529268e-04,   1.06823593e-04,   0.00000000e+00,
         0.00000000e+00,  -3.40883384e-03,  -2.57754565e-04,
        -1.40326182e-03,   7.11322251e-03,   7.54147131e-03,
         1.15841576e-04,   0.00000000e+00,   0.00000000e+00,
        -7.65992843e-04,  -1.08124649e-07,  -4.84415455e-03,
        -7.45458738e-06,   9.72677668e-04,   5.53555430e-05,
        -3.98663671e-02,  -1.14098656e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.25530224e-05,  -1.47998864e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.72006628e-03,  -1.56363078e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.85889931e-02,  -8.83109614e-07,
        -7.34304625e-04,  -5.78135543e-04,  -4.43829573e-03,
        -4.02326487e-03,  -1.47035267e-02,   7.18308804e-02,
         5.79744343e-03,   1.12849597e-03,   0.00000000e+00,
         0.00000000e+00,  -1.18165120e-02,  -4.53039720e-03,
        -4.72356077e-03,   3.69731820e-02,   2.02247830e-02,
         1.05383730e-03,   0.00000000e+00,   0.00000000e+00,
        -7.16981667e-03,  -5.72873545e-07,  -2.85852895e-02,
        -4.08579093e-05,   3.23374189e-03,   2.27567324e-04,
        -4.59360441e-03,  -5.95700029e-05,   0.00000000e+00,
         0.00000000e+00,  -3.88460081e-02,  -6.46688123e-04,
        -7.96576645e-04,   3.71292883e-03,  -2.33479040e-03,
         1.82780292e-02,   6.88852031e-03,  -4.22188770e-02,
        -1.15503838e-03,  -2.87747074e-03,   0.00000000e+00,
         0.00000000e+00,  -5.72139748e-04,   2.28293272e-02,
        -4.74395671e-03,  -2.80211566e-02,  -5.79363061e-03,
        -1.46431280e-03,   0.00000000e+00,   0.00000000e+00,
         3.99239744e-05,   1.44664193e-04,   1.82740096e-03,
         9.53289416e-04,  -1.86620990e-02,  -3.45918190e-04,
         7.04796426e-04,   8.37828689e-04,   0.00000000e+00,
         0.00000000e+00,   5.55301320e-03,   4.16369826e-03,
        -3.62000750e-02,  -3.75640145e-03,  -2.80276005e-03,
        -1.40111351e-03,  -1.33953829e-02,  -9.74619251e-03,
        -2.07745683e-02,   1.24120175e-01,   1.41895585e-02,
         2.33896820e-03,   0.00000000e+00,   0.00000000e+00,
        -2.21762548e-02,  -1.12516564e-02,  -5.73879089e-03,
         6.57048829e-02,   2.65827472e-02,   2.04623077e-03,
         0.00000000e+00,   0.00000000e+00,  -1.06164443e-04,
        -1.33167578e-06,  -2.87111487e-03,  -8.83290615e-05,
         8.08284666e-04,   4.23875729e-04,  -1.97979748e-02,
        -1.21894682e-04,   0.00000000e+00,   0.00000000e+00,
        -8.93018680e-03,  -1.48408265e-03,   2.92679113e-03,
         7.45372018e-03,  -4.21005623e-02,  -3.42263653e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.13023431e-03,
        -6.90306916e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.08822948e-02,  -7.24575475e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.86376734e-02,
        -5.55479616e-06,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.65366941e-02,  -1.22163493e-04,
         2.38968801e-03,  -2.29412681e-02,   2.60618087e-03,
        -1.22309066e-01,  -6.14742677e-02,   3.97826036e-01,
        -5.68949510e-03,  -1.84676260e-02,   0.00000000e+00,
         0.00000000e+00,  -1.21155748e-02,  -1.48321857e-01,
         5.00603510e-03,   2.51555154e-01,  -1.36771453e-02,
        -2.83470964e-02,   0.00000000e+00,   0.00000000e+00,
         1.22388488e-04,  -4.90446341e-04,   7.67340474e-04,
        -3.14607742e-03,  -3.35547940e-04,   1.42578991e-03,
         5.93238125e-04,  -2.53550323e-03,   0.00000000e+00,
         0.00000000e+00,   2.19555448e-03,  -1.56511771e-02,
        -3.03594503e-03,   2.21352354e-02,   2.34396074e-03,
        -3.05940732e-02,   0.00000000e+00,   0.00000000e+00,
        -6.71066879e-02,  -2.03990024e-01,  -3.23920760e-03,
        -1.66509459e-02,  -1.31982114e-02,  -9.24291104e-02,
        -4.62592953e-02,   2.55274093e-01,   4.04666030e-02,
         9.07297458e-04,   7.78722207e-03,   2.36308296e-03,
         3.30401585e-02,   1.49279347e-02,  -2.29620592e-04,
        -3.42865689e-04,  -1.05845948e-03,  -2.23552707e-03,
         3.42762231e-02,   4.13490759e-03,  -8.00510700e-03,
         1.13788211e-01,  -2.53140792e-02,   3.93864651e-01,
         2.07144709e-02,  -1.05190072e-01,   1.95687419e-02,
         7.82749677e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.42227668e-02,   3.92108240e-03,   6.75304608e-03,
         2.51527041e-03,   2.16878124e-02,   1.70625831e-02,
        -6.97164229e-04,  -2.42239101e-03,  -6.83056430e-02,
         4.89162786e-01,   0.00000000e+00,   0.00000000e+00,
         2.42345178e-02,   1.96311296e-02,   1.12802449e-04,
        -6.26474433e-04,   2.75511132e-04,  -4.26065595e-03,
         1.47339749e-02,   3.57363622e-03,   5.24513476e-02,
        -2.21445112e-01,   0.00000000e+00,   0.00000000e+00,
        -1.82351808e-04,  -4.44965336e-03,   2.19848811e-02,
         3.78522822e-03,  -8.50368955e-03,   4.47704653e-02,
        -1.92570603e-02,   2.00752152e-01,   9.66939692e-03,
        -5.03173090e-02,  -7.20178243e-03,   9.92410940e-02,
         0.00000000e+00,   0.00000000e+00,  -2.15692217e-02,
         2.56268689e-01,   2.38255386e-02,  -1.10115288e-01,
         5.15668279e-03,   8.10683312e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.47581905e-02,   3.20468732e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.20017714e-02,   3.26952687e-03,   1.81106047e-05,
        -7.24424189e-05,   1.17676022e-04,  -4.71599513e-04,
        -1.09329649e-06,   4.38082295e-06,  -7.45161941e-04,
         2.98437569e-03,   0.00000000e+00,   0.00000000e+00,
         4.87668485e-06,  -4.60397132e-04,  -2.17769772e-06,
         1.11947085e-05,  -3.72844946e-05,   1.53778748e-03,
         0.00000000e+00,   0.00000000e+00,  -9.14309974e-03,
        -3.18199900e-06,   1.79744407e-04,  -7.19495989e-04,
         9.87284695e-04,  -4.29372936e-03,  -1.04839423e-04,
         4.37679682e-04,  -4.60857519e-03,   1.92746979e-02,
         0.00000000e+00,   0.00000000e+00,   1.46242470e-04,
        -4.90490880e-03,  -2.31305050e-04,   1.10118749e-03,
         9.96401557e-05,   1.01239136e-02,   0.00000000e+00,
         0.00000000e+00,  -1.95112572e-03,  -4.83181922e-05,
        -8.99878526e-03,  -5.43321397e-04,  -3.46052058e-05,
         1.38437721e-04,  -2.25145225e-04,   9.21535675e-04,
         4.72985660e-05,  -3.28118014e-04,   1.43760187e-03,
        -5.79944408e-03,   0.00000000e+00,   0.00000000e+00,
        -1.54823948e-04,   9.20952021e-04,  -3.93710336e-04,
        -3.80487545e-04,   5.70788098e-04,  -3.00890706e-03,
         0.00000000e+00,   0.00000000e+00,   7.38102576e-05,
         1.42545676e-06,   4.47741194e-04,   8.16160626e-05,
        -8.41742173e-03,  -6.05756680e-05,   2.57070383e-04,
        -1.03053075e-03,   1.21047851e-03,  -5.74506376e-03,
        -2.19854121e-04,   9.29530304e-04,  -3.58939036e-03,
         1.64226101e-02,   0.00000000e+00,   0.00000000e+00,
         2.39778063e-04,  -7.24408697e-03,  -5.35365883e-04,
         2.40535915e-03,   1.11311000e-03,   8.91358580e-03,
         0.00000000e+00,   0.00000000e+00,  -6.66687890e-04,
        -9.04783519e-05,  -4.14319309e-03,  -8.07911257e-04,
         1.48673183e-04,   1.60966345e-04,  -1.02812460e-02,
        -1.04227246e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.21455907e-05,  -3.06287439e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.00582700e-04,
        -3.41348944e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.40245792e-03,  -5.73704892e-05,   1.66481330e-03,
        -6.35412029e-03,   5.60005596e-03,  -3.02151959e-02,
        -1.48748927e-03,   6.95644213e-03,  -1.48115909e-02,
         7.57940393e-02,   0.00000000e+00,   0.00000000e+00,
         5.41100182e-03,  -3.84745760e-02,  -3.45544596e-03,
         1.57474409e-02,  -2.07239153e-03,   3.79437302e-02,
         0.00000000e+00,   0.00000000e+00,  -1.59147269e-03,
        -3.48544515e-04,  -5.94792495e-03,  -2.89989320e-03,
         2.72287086e-04,   6.81856411e-04,  -3.23177219e-03,
        -3.45681088e-03,   0.00000000e+00,   0.00000000e+00,
        -4.94941526e-03,  -1.47259578e-02,  -1.86200818e-04,
         7.53864656e-04,  -1.12272560e-03,   5.25037368e-03,
         3.66504625e-04,  -4.09470515e-03,   9.39272433e-03,
        -3.88033386e-02,   0.00000000e+00,   0.00000000e+00,
        -8.61837562e-04,   5.63522620e-03,  -7.26776791e-04,
        -4.68221324e-03,   4.08338011e-03,  -1.97312242e-02,
         0.00000000e+00,   0.00000000e+00,   9.19862032e-06,
         4.44722538e-06,   1.87564107e-04,   3.60740165e-04,
        -3.74227001e-03,  -2.28153815e-04,  -1.44297175e-05,
         7.44287450e-04,   0.00000000e+00,   0.00000000e+00,
        -2.03086215e-04,   4.06898043e-03,  -4.81502694e-03,
        -1.77870763e-03,   3.98855334e-03,  -1.43609631e-02,
         1.17238810e-02,  -6.41839262e-02,  -3.49106926e-03,
         1.64834704e-02,  -2.12819611e-02,   1.28676099e-01,
         0.00000000e+00,   0.00000000e+00,   1.36000215e-02,
        -8.34431836e-02,  -8.33383041e-03,   3.71154311e-02,
        -3.12529567e-03,   6.24211129e-02,   0.00000000e+00,
         0.00000000e+00,   9.63160912e-05,  -7.68550301e-04,
        -1.10049631e-03,  -5.87143101e-03,  -2.05262716e-04,
         1.50761944e-03,  -4.09301547e-03,  -6.43595464e-03,
         0.00000000e+00,   0.00000000e+00,  -1.01662504e-05,
        -2.82703064e-02,  -1.58729705e-03,   9.26113855e-03,
         6.37013120e-04,  -5.28962827e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.84813325e-04,  -3.68597551e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.53332852e-04,  -3.95816480e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.73282622e-03,  -2.08387033e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.81465419e-03,  -1.52342405e-03,  -8.44882298e-04,
         8.11096313e-03,  -9.21424083e-04,   4.32427849e-02,
        -5.68949510e-03,  -1.84676260e-02,  -7.55550497e-02,
         3.52120993e-01,   0.00000000e+00,   0.00000000e+00,
         4.28350254e-03,   5.24396954e-02,  -1.36771453e-02,
        -2.83470964e-02,  -2.88431726e-02,   1.81399670e-01,
         0.00000000e+00,   0.00000000e+00,  -2.62934129e-05,
         1.04930360e-04,   1.65159228e-04,  -6.91504296e-04,
         4.20788007e-05,  -1.41761139e-04,   6.48613579e-04,
        -2.66479366e-03,   0.00000000e+00,   0.00000000e+00,
         4.49203628e-03,  -1.82180182e-02,  -5.93434473e-05,
         1.75138306e-04,   1.14713610e-02,  -4.54471109e-02,
         0.00000000e+00,   0.00000000e+00,   2.37257970e-02,
         7.21213645e-02,   1.14523283e-03,   5.88699837e-03,
         4.66627239e-03,   3.26786254e-02,  -2.64354302e-03,
        -8.32053787e-03,  -4.95305129e-02,   2.44977953e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.08629013e-03,
         1.13666989e-01,  -2.56883012e-02,   3.93074273e-01,
         2.07333705e-02,  -1.05114474e-01,  -7.33035344e-03,
         3.71635786e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.85521278e-02,
         4.88306342e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.24427861e-02,
        -2.21314669e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.85413248e-02,   7.82465515e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.46380786e-03,   4.45489731e-02,  -1.91596525e-02,
         1.99245783e-01,   9.66083542e-03,  -5.01868659e-02,
        -3.41562112e-03,   1.77437366e-02,   0.00000000e+00,
         0.00000000e+00,  -2.16336928e-02,   2.54695499e-01,
         2.38195669e-02,  -1.09932960e-01,  -8.42148865e-03,
         3.88671709e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.05905070e-04,
         2.82366547e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.42104751e-04,   1.38462313e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.44691754e-03,   1.78738721e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.93553887e-03,   8.75945816e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.36855734e-03,
        -5.47795946e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.61387927e-04,  -2.68386661e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.57099871e-03,
         1.45205743e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.42719121e-03,   7.08781467e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.57558356e-05,
         1.43172240e-04,  -1.90917641e-04,   8.62082078e-04,
         1.90975668e-05,  -8.01203578e-05,   1.32777480e-05,
        -2.83193165e-04,   0.00000000e+00,   0.00000000e+00,
         1.95219316e-04,   9.70948151e-04,   4.07624926e-05,
        -2.01364879e-04,  -1.02312968e-03,  -2.75683978e-04,
         0.00000000e+00,   0.00000000e+00,   4.97932937e-04,
         6.83719463e-06,   3.14743068e-03,   5.11873408e-05,
        -5.34725922e-05,  -1.23474291e-05,   8.93611960e-04,
         5.42427142e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.48066824e-02,
         7.13838465e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.88445898e-03,   3.61343372e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.94901926e-03,
         2.19430976e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.23076794e-03,
        -3.76261880e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.31486096e-03,  -1.85738921e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.74582312e-05,
        -5.97435563e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.11291066e-02,   1.22862603e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.99804450e-03,   6.33021695e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.39327962e-04,   4.04825691e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.53970116e-04,   3.51902844e-03,  -2.16280228e-03,
         1.69754307e-02,   7.78555658e-04,  -3.81733889e-03,
        -1.09715262e-03,  -2.58040275e-03,   0.00000000e+00,
         0.00000000e+00,  -6.61701707e-04,   2.15032723e-02,
         1.82352497e-03,  -8.60854817e-03,  -5.34551850e-03,
        -1.17075952e-03,   0.00000000e+00,   0.00000000e+00,
         3.32993647e-05,   1.44655636e-04,   1.64848875e-03,
         9.48840302e-04,   1.76449607e-05,  -2.80156324e-04,
         6.33395020e-04,   8.28557457e-04,   0.00000000e+00,
         0.00000000e+00,   5.01240631e-03,   4.01200528e-03,
         1.78786177e-04,  -1.80832847e-03,   2.62950219e-03,
         7.06137872e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.75665900e-02,
         3.45591702e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.36787737e-02,   1.71377458e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.14484329e-05,
         3.36340569e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.82673962e-03,   1.27440849e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.99978297e-02,   2.43507075e-01,
         4.60466678e-01,   6.33554665e-02,   6.58376741e-02,
         1.27119934e-01,   3.25229666e-01,   4.47709465e-01,
        -3.22742881e-04,  -2.21364637e-02,  -9.94662500e-03,
        -8.93768904e-02,   4.09344061e-01,   1.14418450e-01,
         1.14106840e-04,   7.82642181e-03,   3.51666299e-03,
         3.15995026e-02,  -4.68248041e-04,  -2.60552397e-03,
         4.08185206e-01,   1.07970107e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.08019655e-01,   1.07048915e-01,
         5.02697020e-02,   1.43562800e-01,   1.75024160e-01,
         5.53948795e-01,  -2.15239193e-04,  -1.10189482e-01,
         7.60985464e-05,   3.89578650e-02,   0.00000000e+00,
         0.00000000e+00,   1.86616665e-01,   7.46466658e-01,
         9.65504662e-03,  -4.18822335e-02,   2.71622550e-02,
        -1.77165583e-01,   1.75380643e-01,   1.10082165e-01,
         3.88705943e-04,  -4.90649956e-03,   0.00000000e+00,
         0.00000000e+00,   2.57093895e-02,  -2.44620998e-01,
         2.85238789e-01,   1.70526764e-01,  -3.41357447e-03,
         1.48076056e-02,  -9.60330735e-03,   6.26374926e-02,
         3.88705943e-04,  -4.90649956e-03,   1.76342641e-01,
         9.79391985e-02,   0.00000000e+00,   0.00000000e+00,
        -9.08964184e-03,   8.64865834e-02,   6.68071650e-04,
        -1.13909274e-02,   2.86892182e-01,   1.42335657e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.76480069e-01,
         9.62044890e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.87128381e-01,   1.38308356e-01,
        -1.95655980e-04,   7.82623921e-04,  -8.38548268e-04,
         3.36985205e-03,   1.11492888e-04,  -4.46037188e-04,
         1.22001534e-04,  -5.54097012e-04,   0.00000000e+00,
         0.00000000e+00,   1.03567073e-03,   5.21062250e-03,
         3.55170070e-04,  -1.44528770e-03,  -7.16606834e-03,
        -1.15573035e-03,   0.00000000e+00,   0.00000000e+00,
         2.06399532e-01,   5.40453405e-04,  -1.29770786e-03,
         5.19456409e-03,  -4.90355595e-03,   2.24341772e-02,
         8.13608542e-04,  -3.33430419e-03,  -7.92598623e-04,
        -4.15383592e-03,   0.00000000e+00,   0.00000000e+00,
         7.78543762e-03,   3.44607494e-02,   2.20929505e-03,
        -1.02038950e-02,  -4.16019694e-02,  -7.85161365e-03,
         0.00000000e+00,   0.00000000e+00,   4.39796402e-02,
         1.39152079e-03,   2.04359450e-01,   6.99903207e-03,
         2.56935776e-04,  -1.02779590e-03,   1.04716487e-03,
        -4.28029049e-03,   4.51922094e-05,   1.16244938e-03,
        -1.77612404e-04,   9.39182786e-04,   0.00000000e+00,
         0.00000000e+00,   9.44091831e-04,  -6.14251410e-03,
         8.39921588e-03,   2.69619564e-03,   1.01020468e-03,
         2.06126940e-03,   0.00000000e+00,   0.00000000e+00,
        -7.21376777e-04,  -1.89909918e-04,  -4.51143196e-03,
        -1.17598837e-03,   2.03863685e-01,   1.56521594e-03,
        -1.20262080e-03,   4.82742222e-03,  -3.54143788e-03,
         2.10503515e-02,   8.68958929e-04,  -3.67998878e-03,
        -2.99639903e-03,  -4.65514530e-03,   0.00000000e+00,
         0.00000000e+00,   9.76719533e-03,   3.23961422e-02,
         2.27496231e-03,  -1.07604314e-02,  -3.70972304e-02,
        -7.95340486e-03,   0.00000000e+00,   0.00000000e+00,
         3.69683446e-03,   9.67282155e-04,   2.31636832e-02,
         5.81348529e-03,  -8.95951372e-04,  -1.02014132e-03,
         2.08450652e-01,   5.90353357e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.57138094e-05,   1.07455256e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.46176411e-03,   2.33017543e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.03659430e-01,   1.48351304e-03,
        -1.67510513e-03,   2.12111675e-02,   1.95513529e-03,
         8.81863513e-02,   2.20572810e-03,  -1.57481893e-02,
        -2.42051351e-02,  -1.47816665e-02,   0.00000000e+00,
         0.00000000e+00,   3.10154886e-02,   1.27997477e-01,
         6.05105530e-03,  -4.10962198e-02,  -9.85416431e-02,
        -2.04344567e-02,   0.00000000e+00,   0.00000000e+00,
         3.73136391e-02,   2.37381734e-03,   1.47160489e-01,
         1.42812658e-02,  -3.86164825e-03,  -2.64842343e-03,
         1.99491288e-02,   1.28998915e-02,   0.00000000e+00,
         0.00000000e+00,   1.94309945e-01,   3.93676917e-02,
         1.72906142e-03,  -7.07118302e-03,   6.16354569e-03,
        -2.96963269e-02,   1.23300038e-02,   1.25076124e-02,
        -1.62267806e-05,   4.95873758e-03,   0.00000000e+00,
         0.00000000e+00,   5.67245600e-03,  -4.18820249e-02,
         5.13367151e-02,   2.30332410e-02,   4.39620613e-03,
         9.62918313e-03,   0.00000000e+00,   0.00000000e+00,
         3.03017973e-05,  -5.48339268e-04,  -1.87954215e-03,
        -3.81957456e-03,   9.80940405e-02,   2.47970817e-03,
        -9.39502576e-05,  -3.75117797e-03,   0.00000000e+00,
         0.00000000e+00,  -5.58974765e-03,  -1.23501694e-02,
         1.91594355e-01,   9.66870588e-03,   3.35011733e-03,
         3.86355803e-02,   2.98472558e-02,   1.56064105e-01,
         2.52274544e-03,  -3.10108566e-02,  -6.09486811e-02,
        -2.38042215e-02,   0.00000000e+00,   0.00000000e+00,
         6.23085867e-02,   2.19249846e-01,   9.81595424e-03,
        -7.50140892e-02,  -1.26555973e-01,  -2.54609555e-02,
         0.00000000e+00,   0.00000000e+00,  -1.07780815e-04,
         2.61921792e-03,   1.00989441e-02,   1.76847484e-02,
        -1.76472673e-04,  -3.42108831e-03,   9.94626626e-02,
         1.73411218e-02,   0.00000000e+00,   0.00000000e+00,
         3.01847481e-02,   5.70676664e-02,  -1.29490837e-04,
        -1.91957687e-02,   1.95778173e-01,   9.00738668e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.25690314e-02,
         1.09186858e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.17254242e-02,   1.87603073e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.79570200e-02,
         2.22217392e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.91029560e-01,   8.07962288e-03,
        -9.42284458e-03,   8.09457366e-02,  -1.03222155e-02,
         3.34978070e-01,  -6.12599114e-02,  -1.09006388e-01,
         2.16586494e-02,   3.85395780e-02,   0.00000000e+00,
         0.00000000e+00,   2.82969171e-02,   4.69726310e-01,
        -1.48835119e-01,  -2.14568741e-01,   5.26211611e-02,
         7.58615058e-02,   0.00000000e+00,   0.00000000e+00,
        -6.99627308e-04,   2.80313048e-03,  -4.58723953e-03,
         1.86757394e-02,   6.51737942e-04,  -2.93305310e-03,
        -4.36845935e-03,   1.81403623e-02,   0.00000000e+00,
         0.00000000e+00,  -1.28534769e-02,   7.17084053e-02,
        -1.10665423e-03,  -2.48475814e-02,  -1.66376320e-02,
         1.27378390e-01,   0.00000000e+00,   0.00000000e+00,
         2.75256218e-01,   3.81506170e-01,  -5.33011695e-04,
         1.16899447e-01,   1.17648241e-02,   4.73617184e-01,
        -3.01783442e-02,  -1.08334705e-01,   1.06696559e-02,
         3.83021023e-02,   0.00000000e+00,   0.00000000e+00,
         2.75924228e-02,   3.29552546e-01,  -2.25679813e-01,
        -2.93952267e-04,  -4.68778836e-02,  -1.23066106e-03,
        -2.18613253e-01,  -1.88202296e-02,   4.19274178e-03,
         3.59404279e-02,   3.15664091e-02,   1.70092478e-01,
        -2.06650286e-01,  -9.99453575e-02,  -6.06369885e-04,
        -5.11365655e-05,  -3.63887409e-03,  -1.12914777e-03,
        -1.69362811e-03,   1.67157186e-02,  -2.17080216e-01,
        -5.81986067e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.16985847e-01,  -5.77176210e-03,  -4.09624688e-02,
        -1.38822116e-03,  -1.56078855e-01,  -3.05726949e-02,
         2.22895601e-03,   2.48603515e-01,  -3.07856339e-03,
        -2.13268409e-03,   0.00000000e+00,   0.00000000e+00,
        -1.91452208e-01,  -7.08917201e-02,  -8.47112923e-03,
         4.12383553e-02,  -1.71741877e-02,   2.28086029e-01,
        -6.84179259e-02,  -1.87472622e-01,  -4.31333645e-03,
         2.48238022e-02,   0.00000000e+00,   0.00000000e+00,
        -1.80200836e-02,   4.13133862e-01,  -1.06165213e-01,
        -4.24660853e-01,  -6.46089049e-05,  -9.14580183e-05,
        -1.59287411e-03,  -2.72006057e-03,  -7.83178519e-03,
         3.88975972e-02,  -1.03295751e-01,  -8.41825672e-03,
         0.00000000e+00,   0.00000000e+00,  -3.72668273e-03,
        -7.87512391e-03,  -1.27843348e-02,   7.17078117e-02,
        -1.79900542e-01,  -2.46850541e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.03237280e-01,  -8.28748238e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.79743185e-01,  -2.40556274e-02,   2.91064113e-08,
        -1.16425645e-07,  -1.48903760e-06,  -3.52704644e-06,
        -3.47219424e-04,   1.38903600e-03,   9.56878366e-06,
         1.79752337e-06,   0.00000000e+00,   0.00000000e+00,
        -1.43525801e-03,  -1.29452313e-05,  -6.39333592e-04,
         2.61721106e-03,   4.58761431e-03,   1.07577415e-05,
         0.00000000e+00,   0.00000000e+00,  -1.27601691e-01,
        -1.97721091e-06,   1.22802435e-06,  -6.74074390e-06,
        -3.43368776e-04,  -2.03096421e-04,  -2.20361207e-03,
         9.00200685e-03,   1.00498059e-03,   1.12158971e-04,
         0.00000000e+00,   0.00000000e+00,  -9.68488630e-03,
        -6.88549935e-04,  -3.41966636e-03,   1.69818869e-02,
         2.62443648e-02,   5.36420469e-04,   0.00000000e+00,
         0.00000000e+00,  -2.73951213e-02,  -9.93597427e-06,
        -1.27525776e-01,  -2.18418986e-04,  -2.55474998e-04,
         1.02201939e-03,  -1.27294431e-03,   5.30699212e-03,
         9.18191472e-04,  -4.45148670e-03,   4.89605239e-05,
        -7.34624233e-04,   0.00000000e+00,   0.00000000e+00,
        -1.15472811e-03,   1.03393508e-02,  -2.92741546e-03,
        -1.07224069e-02,  -3.16586930e-03,  -2.13599914e-03,
         0.00000000e+00,   0.00000000e+00,   1.78380494e-03,
         3.68079232e-04,   1.12003530e-02,   2.19796183e-03,
        -1.27161709e-01,  -1.12049594e-03,  -2.92955756e-08,
        -8.16928071e-06,  -8.90588580e-04,  -2.44164028e-04,
        -1.72274033e-03,   7.36880532e-03,   2.28331511e-03,
         1.50414358e-04,   0.00000000e+00,   0.00000000e+00,
        -1.02186747e-02,  -7.65521794e-04,  -2.36006533e-03,
         1.34079542e-02,   2.26780804e-02,   5.92759830e-04,
         0.00000000e+00,   0.00000000e+00,  -1.92394158e-03,
        -4.87082340e-06,  -1.21238587e-02,  -1.61463865e-04,
         2.31927444e-03,   1.52280823e-03,  -1.28759944e-01,
        -1.77560499e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.82967319e-04,  -2.23810294e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.45652036e-03,
        -1.10561806e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.26460233e-01,  -6.47849954e-05,  -1.71486275e-03,
        -1.21332360e-04,  -1.19863665e-02,  -3.09595484e-03,
        -5.33700575e-03,   3.74639380e-02,   1.47410517e-02,
         1.19024278e-03,   0.00000000e+00,   0.00000000e+00,
        -3.47400077e-02,  -8.46336941e-03,  -6.88348621e-03,
         6.84322044e-02,   6.10936224e-02,   4.00708385e-03,
         0.00000000e+00,   0.00000000e+00,  -2.34217152e-02,
        -1.50132045e-05,  -9.32506425e-02,  -5.67199042e-04,
         9.86390777e-03,   4.86312083e-03,  -1.14164886e-02,
        -5.19455406e-04,   0.00000000e+00,   0.00000000e+00,
        -1.26402078e-01,  -3.20812067e-03,  -1.60619115e-03,
         6.77425233e-03,  -6.12674781e-03,   3.62684102e-02,
        -1.13131376e-03,  -3.09112709e-02,  -1.93719577e-03,
        -3.71387806e-03,   0.00000000e+00,   0.00000000e+00,
        -5.51099743e-03,   6.85114110e-02,  -1.83548695e-02,
        -7.30856758e-02,  -1.45537311e-02,  -8.15073903e-03,
         0.00000000e+00,   0.00000000e+00,   2.14414002e-05,
         9.56539516e-04,   5.33701497e-03,   6.43004193e-03,
        -6.11453947e-02,  -3.93526049e-03,   1.19747246e-03,
         4.93875318e-03,   0.00000000e+00,   0.00000000e+00,
         1.61096057e-02,   2.12868641e-02,  -1.20354078e-01,
        -2.10983415e-02,  -6.18116420e-03,  -2.91377241e-04,
        -3.46680295e-02,  -6.90419981e-03,  -3.90782920e-03,
         6.42401135e-02,   3.52548629e-02,   2.24447643e-03,
         0.00000000e+00,   0.00000000e+00,  -6.25468124e-02,
        -1.71238758e-02,  -6.14923695e-03,   1.10677985e-01,
         7.58802289e-02,   6.19727832e-03,   0.00000000e+00,
         0.00000000e+00,  -2.64854040e-04,  -1.11318828e-05,
        -7.10052391e-03,  -5.84457940e-04,   1.10352719e-03,
         5.31453425e-03,  -6.32426684e-02,  -6.66126120e-04,
         0.00000000e+00,   0.00000000e+00,  -2.18955485e-02,
        -4.67047839e-03,   4.58592507e-03,   2.89479640e-02,
        -1.30758281e-01,  -7.97878816e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.00649191e-03,  -7.44534672e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.30346818e-02,  -2.63909913e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.12237135e-02,  -1.51140960e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.21142503e-01,  -1.20507507e-03,  -2.73275423e-04,
        -2.13042126e-02,  -1.70641955e-02,  -1.41742744e-01,
         9.87365318e-03,   2.47661060e-01,  -1.49490732e-02,
        -2.73295541e-02,   0.00000000e+00,   0.00000000e+00,
        -5.22608141e-02,  -2.91828185e-01,   6.00683982e-02,
         5.28337257e-01,  -4.10330786e-02,  -8.05982953e-02,
         0.00000000e+00,   0.00000000e+00,   2.97756721e-04,
        -1.19390206e-03,   1.93977625e-03,  -7.97870330e-03,
        -2.56147145e-03,   1.04888658e-02,   1.45006738e-03,
        -6.24668590e-03,   0.00000000e+00,   0.00000000e+00,
         5.05691466e-03,  -3.69524627e-02,  -1.19257327e-02,
         7.44743825e-02,   3.30406212e-03,  -6.36444698e-02,
         0.00000000e+00,   0.00000000e+00,  -2.19231653e-01,
        -5.96991430e-01,  -1.01844242e-02,  -1.53121167e-02,
        -4.87319939e-02,  -1.07639354e-01,  -1.65326736e-02,
         2.88009733e-01,  -7.63169740e-03,  -1.41825386e-02,
         0.00000000e+00,   0.00000000e+00,  -9.32880700e-02,
        -2.32090102e-01,   3.64697866e-03,   2.91985632e-01,
         7.97898630e-02,   1.03927821e-04,   1.65738347e-02,
         4.35104390e-04,   7.72914568e-02,   6.65395598e-03,
        -6.06369885e-04,  -5.11365655e-05,  -3.63887409e-03,
        -1.12914777e-03,   7.69829984e-02,   2.17666936e-03,
         2.69205287e-03,   3.58138713e-02,   2.25606552e-02,
         1.67297980e-01,   5.45088817e-03,  -4.69425020e-02,
         7.28283574e-02,   3.52169821e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.67160820e-02,   2.04062606e-03,
         1.44824197e-02,   4.90810296e-04,   5.51822085e-02,
         1.08090799e-02,  -3.07856339e-03,  -2.13268409e-03,
        -5.39009966e-03,   2.43325391e-01,   0.00000000e+00,
         0.00000000e+00,   6.76885774e-02,   2.50640080e-02,
        -6.46089049e-05,  -9.14580183e-05,  -1.59287411e-03,
        -2.72006057e-03,   3.66652698e-02,   3.29995319e-03,
         2.25609264e-02,  -1.09103599e-01,   0.00000000e+00,
         0.00000000e+00,  -3.72668273e-03,  -7.87512391e-03,
         6.39938845e-02,   1.02852363e-02,  -8.63102811e-03,
         4.10120082e-02,  -2.11163500e-02,   2.21354222e-01,
         1.26092506e-02,  -6.92968952e-02,   2.40446828e-02,
         6.59579312e-02,   0.00000000e+00,   0.00000000e+00,
        -2.72431528e-02,   3.93643925e-01,   3.72610561e-02,
        -1.98414332e-01,   3.71456332e-02,   1.48582533e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.64998905e-02,
         2.93006750e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.35488126e-02,   8.50494863e-03,
         2.06331291e-04,  -8.25325165e-04,   1.05834760e-03,
        -4.23556593e-03,  -3.52988915e-04,   1.41200862e-03,
        -4.68393471e-04,   1.88267466e-03,   0.00000000e+00,
         0.00000000e+00,   1.79936813e-03,  -8.32807953e-03,
        -1.14423561e-03,   4.59623768e-03,  -1.71715467e-04,
         4.25758566e-03,   0.00000000e+00,   0.00000000e+00,
        -2.34737295e-02,  -1.73534908e-03,   1.23558488e-03,
        -4.94226592e-03,   6.26530555e-03,  -2.54904656e-02,
        -2.08602788e-03,   8.39581596e-03,  -2.83038205e-03,
         1.24679313e-02,   0.00000000e+00,   0.00000000e+00,
         1.00825472e-02,  -4.91992269e-02,  -6.41649571e-03,
         2.66651089e-02,  -9.41381106e-04,   2.64450517e-02,
         0.00000000e+00,   0.00000000e+00,  -4.02700559e-03,
        -4.19179244e-03,  -1.77994622e-02,  -1.92962450e-02,
        -7.50711476e-06,   3.00384060e-05,  -2.11966037e-04,
         9.07334093e-04,   3.12522963e-04,  -1.43902013e-03,
         7.49192132e-04,  -3.15163029e-03,   0.00000000e+00,
         0.00000000e+00,  -3.54265777e-04,   3.15284577e-03,
         9.63445104e-05,  -4.74577019e-03,   7.29493616e-04,
        -7.41811899e-03,   0.00000000e+00,   0.00000000e+00,
         4.45980613e-04,   6.05029352e-04,   2.78286745e-03,
         3.27274304e-03,  -2.06192500e-02,  -4.48779950e-03,
         1.15097894e-03,  -4.60348283e-03,   5.67339870e-03,
        -2.37036966e-02,  -1.88231692e-03,   7.65487216e-03,
        -2.26823281e-03,   1.16186600e-02,   0.00000000e+00,
         0.00000000e+00,   8.25566427e-03,  -4.42357206e-02,
        -5.48148372e-03,   2.31204111e-02,   5.19714824e-04,
         2.30301731e-02,   0.00000000e+00,   0.00000000e+00,
        -9.23021748e-04,  -2.54585883e-03,  -5.53627519e-03,
        -1.41430174e-02,   4.20176366e-04,   2.35855338e-03,
        -2.09456702e-02,  -1.37612898e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.84560519e-04,  -1.32183614e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.95470132e-05,  -3.95098645e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.03947658e-02,  -4.25496811e-03,
         3.60870148e-03,  -1.25300944e-02,   1.61562224e-02,
        -6.49127748e-02,  -4.95425892e-03,   2.11970709e-02,
        -8.20252443e-03,   4.28478365e-02,   0.00000000e+00,
         0.00000000e+00,   2.55015641e-02,  -1.19669022e-01,
        -1.43146028e-02,   6.43336640e-02,  -8.25026648e-03,
         7.70937966e-02,   0.00000000e+00,   0.00000000e+00,
        -2.78033558e-03,  -6.31712153e-03,  -7.56755134e-03,
        -3.40455390e-02,   1.84178106e-03,   5.81218809e-03,
        -1.23472242e-03,  -2.72725279e-02,   0.00000000e+00,
         0.00000000e+00,   5.18374895e-04,  -7.45918487e-02,
        -4.13481613e-05,   1.60884499e-04,  -8.85815702e-04,
         4.63585368e-03,   2.34629935e-03,  -7.97625677e-03,
         4.47113076e-03,  -2.00414247e-02,   0.00000000e+00,
         0.00000000e+00,  -1.59607817e-03,   1.44230106e-02,
         3.39417994e-03,  -2.25090679e-02,   6.43787656e-03,
        -4.10051628e-02,   0.00000000e+00,   0.00000000e+00,
        -3.53743970e-04,   1.74572954e-03,  -5.06833914e-04,
         1.02367679e-02,  -8.03633131e-03,  -6.27855540e-03,
        -1.22653759e-03,   8.28307533e-03,   0.00000000e+00,
         0.00000000e+00,  -4.40512914e-04,   2.33804913e-02,
        -7.49398293e-03,  -1.86766265e-02,   6.07966332e-03,
        -1.71882206e-02,   2.37603030e-02,  -8.83241070e-02,
        -6.35165678e-03,   2.83937539e-02,  -1.12442383e-02,
         6.89162670e-02,   0.00000000e+00,   0.00000000e+00,
         3.46766670e-02,  -1.54447067e-01,  -1.74319948e-02,
         8.08470572e-02,  -1.31417400e-02,   1.10283289e-01,
         0.00000000e+00,   0.00000000e+00,   1.20085498e-03,
        -5.66446485e-03,   3.75827002e-03,  -3.49683075e-02,
        -5.25553994e-04,   5.47914096e-03,  -3.60454901e-03,
        -3.22871861e-02,   0.00000000e+00,   0.00000000e+00,
         1.11988108e-02,  -8.78244071e-02,  -3.63533781e-03,
         2.64719135e-02,   1.21341964e-02,  -1.16051105e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.20282131e-03,
        -7.20943137e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.72931017e-03,  -1.82349560e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.96237946e-03,
        -5.60834683e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.30998046e-03,  -1.56181086e-02,
         9.66174525e-05,   7.53217660e-03,   6.03310417e-03,
         5.01136276e-02,  -1.49490732e-02,  -2.73295541e-02,
        -2.71234154e-02,   1.80023864e-01,   0.00000000e+00,
         0.00000000e+00,   1.84769880e-02,   1.03176844e-01,
        -4.10330786e-02,  -8.05982953e-02,  -4.14832901e-02,
         3.28866653e-01,   0.00000000e+00,   0.00000000e+00,
         1.48656346e-03,  -5.94687741e-03,   8.46786083e-03,
        -3.39261772e-02,  -4.42636301e-04,   1.82596871e-03,
         7.33534940e-03,  -2.94516926e-02,   0.00000000e+00,
         0.00000000e+00,   1.95324931e-02,  -7.73861896e-02,
        -2.06842585e-03,   6.91299071e-03,   2.46781086e-02,
        -9.40211058e-02,   0.00000000e+00,   0.00000000e+00,
         7.75100943e-02,   2.11068344e-01,   3.60073770e-03,
         5.41365077e-03,   1.72293617e-02,   3.80562584e-02,
        -7.63169740e-03,  -1.41825386e-02,  -3.54201610e-02,
         2.52909740e-01,   0.00000000e+00,   0.00000000e+00,
         3.29823134e-02,   8.20562423e-02,  -2.49332714e-02,
        -4.74668971e-02,  -2.72063705e-02,   2.33248343e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.47766875e-03,
         3.57957918e-02,   2.12741190e-02,   1.66898766e-01,
         5.54525738e-03,  -4.68944034e-02,  -1.96054455e-03,
         1.65796753e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.47853618e-03,
         2.42571373e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.26193968e-02,
        -1.08972824e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.99716444e-03,   3.85277115e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.65387081e-03,   4.09796729e-02,  -2.16795160e-02,
         2.20392535e-01,   1.26677210e-02,  -6.91661208e-02,
        -4.47871570e-03,   2.44539165e-02,   0.00000000e+00,
         0.00000000e+00,  -2.85607341e-02,   3.90859648e-01,
         3.74184127e-02,  -1.97784906e-01,  -1.32294067e-02,
         6.99275240e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.47128523e-04,
         1.38864214e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.41546249e-04,   2.61419359e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.20475069e-03,   8.97482762e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.53490644e-03,   1.68060596e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.69818829e-04,
        -2.69061134e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.20818447e-03,  -5.05871463e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.73367597e-03,
         7.33300248e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.49161699e-03,   1.32062312e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.55204874e-04,
         1.02092250e-03,  -1.27364157e-03,   5.27333659e-03,
         4.31360409e-04,  -1.73677766e-03,   6.73628674e-05,
        -7.15705398e-04,   0.00000000e+00,   0.00000000e+00,
        -1.40102524e-03,   1.02204069e-02,   1.32806292e-03,
        -5.53822844e-03,  -2.46825944e-03,  -2.03201651e-03,
         0.00000000e+00,   0.00000000e+00,   1.40824246e-03,
         3.67108489e-04,   8.83384536e-03,   2.16581000e-03,
        -3.06811396e-04,  -5.26147479e-04,   1.87080979e-03,
         1.49897078e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.84865331e-03,
         3.69056927e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.22454311e-03,   6.58541304e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.63570675e-03,
         4.76019518e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.33980996e-03,
        -1.85938513e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.40058339e-03,  -3.49052882e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.03309231e-04,
        -1.98497888e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.52795886e-03,   6.29261010e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.89858622e-03,   1.05342425e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.11052796e-04,   5.20744392e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.61096536e-03,   6.74614119e-03,  -6.39491559e-03,
         3.54167867e-02,   2.56118743e-03,  -1.14793612e-02,
        -1.53341755e-03,  -3.41409704e-03,   0.00000000e+00,
         0.00000000e+00,  -7.09282467e-03,   6.58149063e-02,
         7.42621561e-03,  -3.50078171e-02,  -1.15757773e-02,
        -6.79088604e-03,   0.00000000e+00,   0.00000000e+00,
        -3.01928816e-05,   9.54097837e-04,   3.95377867e-03,
         6.30459991e-03,   5.30017621e-05,  -1.78374900e-03,
         8.07766218e-04,   4.82059024e-03,   0.00000000e+00,
         0.00000000e+00,   1.18502913e-02,   2.03157253e-02,
         5.82980276e-04,  -9.83981000e-03,   2.74309966e-03,
         2.74887061e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.24087109e-02,
         1.70361408e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.59906741e-02,   3.00370853e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.89929399e-03,
         7.62132463e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.14396248e-02,   4.85321446e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.81183735e-02,   2.47895456e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.16139919e-02,   2.24857302e-01,   2.87692093e-03,
        -0.00000000e+00,   6.01785552e-04,   4.33352004e-07,
         2.87587264e-03,   4.19313672e-06,  -5.49738327e-07,
        -1.08411720e-10,  -3.41606372e-06,  -7.46712351e-07,
         2.82365859e-03,   2.46831711e-08,  -7.01582714e-05,
        -1.82731805e-06,  -4.60490811e-04,  -9.06604646e-06,
         4.61445525e-07,   3.13702934e-06,   2.98297772e-03,
         1.86396557e-06,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.82364852e-03,   2.25924245e-08,   4.62754195e-04,
         2.55895781e-04,   1.81776513e-03,   1.24480133e-03,
         1.07193745e-04,  -4.42597873e-04,  -4.12188084e-04,
        -1.26745317e-04,   0.00000000e+00,   0.00000000e+00,
         1.70313297e-03,   4.67665272e-03,  -6.81245604e-08,
        -3.86408680e-08,  -1.26347139e-06,  -3.70749941e-06,
         1.38348250e-03,   4.47446091e-06,  -1.48324200e-06,
         1.06391439e-05,   0.00000000e+00,   0.00000000e+00,
         3.54368168e-04,  -1.44464618e-03,   2.59475730e-03,
         2.99383468e-05,   1.93842374e-04,  -8.15334031e-04,
         7.07350441e-04,  -3.95476820e-03,  -3.51534784e-04,
         1.41084531e-03,   1.44815289e-03,   3.49437568e-04,
         0.00000000e+00,   0.00000000e+00,   1.06133457e-03,
        -7.73765268e-03,  -1.14284796e-03,   4.59512756e-03,
         2.91856424e-03,   1.78536190e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.38357035e-03,   4.08304348e-06,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.59619037e-03,   2.40042965e-05,  -5.63185657e-03,
         2.25274263e-02,  -2.73275549e-02,   1.09311695e-01,
         9.76390449e-03,  -3.90556251e-02,   2.28478056e-03,
        -9.14548624e-03,   0.00000000e+00,   0.00000000e+00,
        -5.14309912e-02,   2.06804872e-01,   3.18998048e-02,
        -1.27603174e-01,   5.32613579e-03,  -2.47752413e-02,
         0.00000000e+00,   0.00000000e+00,   1.49578060e-02,
         5.98312241e-02,  -1.20922902e-03,   4.83694511e-03,
        -5.85270300e-03,   2.34717113e-02,   2.09638971e-03,
        -8.38578515e-03,   4.48344848e-04,  -1.96789465e-03,
         0.00000000e+00,   0.00000000e+00,  -1.05348397e-02,
         4.50031047e-02,   6.84566750e-03,  -2.74025670e-02,
        -2.29727107e-04,  -7.22961522e-03,   0.00000000e+00,
         0.00000000e+00,  -1.17381454e-02,   6.49509352e-02,
         6.35699193e-03,   2.53859430e-02,   1.18928186e-06,
        -4.75713719e-06,   4.12222444e-05,  -1.65169151e-04,
        -1.30052401e-04,   5.47359761e-04,  -1.86108238e-05,
         7.53623219e-05,   0.00000000e+00,   0.00000000e+00,
         2.25256414e-04,  -9.47216471e-04,  -1.30014411e-04,
         1.89913471e-03,  -2.56724082e-04,   1.16719311e-03,
         0.00000000e+00,   0.00000000e+00,   3.88554746e-03,
        -1.61985541e-02,   7.65848360e-04,  -4.04821611e-03,
         1.18196908e-02,   6.47072506e-03,  -1.22132870e-04,
         4.88661664e-04,  -5.44588339e-04,   2.30945682e-03,
         1.91406696e-04,  -7.66027756e-04,   8.59467774e-05,
        -6.92586086e-04,   0.00000000e+00,   0.00000000e+00,
        -4.92101556e-04,   4.31843097e-03,   4.78994259e-04,
        -1.92721949e-03,  -6.67851702e-04,  -2.74999487e-03,
         0.00000000e+00,   0.00000000e+00,  -7.46975735e-03,
         3.11408547e-02,  -1.47230255e-03,   7.78247915e-03,
         8.77021994e-05,  -4.18380301e-04,   1.16967081e-02,
         7.05740974e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.18136406e-04,   4.99692669e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.60031328e-05,
         1.52250496e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.18653109e-02,   6.25309597e-03,  -1.01059161e-03,
         4.13565927e-03,  -4.78162729e-03,   2.00695946e-02,
         1.79194051e-03,  -7.16997862e-03,   8.10098379e-05,
        -1.68653054e-03,   0.00000000e+00,   0.00000000e+00,
        -8.52102944e-03,   3.90415522e-02,   5.85090305e-03,
        -2.34331078e-02,  -7.04281849e-04,  -7.97796451e-03,
         0.00000000e+00,   0.00000000e+00,  -2.19093541e-02,
         1.05613470e-01,   2.51896292e-04,   3.23747899e-02,
         8.17913053e-04,  -3.90701508e-03,  -1.57239414e-03,
         7.51102771e-03,   0.00000000e+00,   0.00000000e+00,
        -1.03575135e-03,   3.68322814e-02,   1.61038213e-07,
        -6.61370491e-07,   5.52424122e-06,  -2.37975347e-05,
         1.25582891e-04,   7.61370596e-05,  -2.75380532e-06,
         1.40091659e-05,   0.00000000e+00,   0.00000000e+00,
         1.53308054e-04,  -6.46744273e-04,   8.67318757e-04,
         2.79837630e-04,  -4.30567379e-04,   1.80718827e-03,
         0.00000000e+00,   0.00000000e+00,   1.20111333e-02,
        -4.81182556e-02,   2.53001492e-03,  -1.04103431e-02,
         3.93597068e-03,   2.91065574e-03,   1.47342469e-04,
        -6.07084933e-04,   0.00000000e+00,   0.00000000e+00,
         2.16846412e-03,  -8.96311601e-03,   5.43989897e-03,
         6.85108938e-04,   6.59644965e-05,   6.79371629e-05,
         5.40525206e-04,   3.22845162e-04,   2.53109140e-05,
        -1.06511961e-04,  -7.34709527e-04,  -1.03729806e-04,
         0.00000000e+00,   0.00000000e+00,   1.15018208e-03,
         1.61284761e-03,   6.18719090e-05,  -2.72512642e-04,
        -1.37772107e-03,  -3.60160401e-03,   0.00000000e+00,
         0.00000000e+00,  -2.30907620e-02,   9.25047750e-02,
        -4.86381849e-03,   2.00133284e-02,   1.47342469e-04,
        -6.07084933e-04,   3.72935586e-03,   3.76195640e-03,
         0.00000000e+00,   0.00000000e+00,  -4.16875640e-03,
         1.72311115e-02,   3.77527552e-05,  -1.60695353e-04,
         5.38695919e-03,   9.10448184e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.27237930e-04,   6.95047834e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.80847892e-04,   2.25265218e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.01261388e-03,   2.59486806e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.45953684e-03,   6.01519955e-04,   6.36344214e-05,
         1.26379989e-07,   4.13832930e-04,   3.83666505e-06,
        -4.90358634e-04,  -2.48643650e-07,   1.21973837e-04,
        -1.36834399e-05,   0.00000000e+00,   0.00000000e+00,
         3.50074436e-04,   1.96336908e-03,  -1.18121856e-03,
        -1.07218332e-05,   1.88183857e-03,  -6.26309750e-03,
         0.00000000e+00,   0.00000000e+00,  -4.35666719e-02,
         1.74267165e-01,  -9.35246025e-03,   3.74178324e-02,
         3.15111490e-04,  -1.26757450e-03,  -6.05785001e-04,
         2.43684424e-03,   0.00000000e+00,   0.00000000e+00,
        -7.95447685e-03,   3.19930771e-02,  -1.71116809e-05,
        -1.76494779e-04,   3.28962921e-05,   3.39301781e-04,
         0.00000000e+00,   0.00000000e+00,   2.07676814e-03,
         1.93128490e-06,   1.30436260e-04,   1.73915014e-04,
         6.31730754e-04,   8.48938972e-04,  -2.26935835e-04,
        -3.02631975e-04,  -4.97820014e-05,  -9.44067545e-05,
         0.00000000e+00,   0.00000000e+00,   4.36935818e-04,
         4.62498935e-03,  -7.35552803e-04,  -1.00090098e-03,
         2.27666956e-03,  -9.86774136e-03,   0.00000000e+00,
         0.00000000e+00,  -3.36026972e-02,   1.34781894e-01,
         1.82617591e-02,   5.08677906e-07,   3.79804301e-03,
         9.03928881e-05,   1.80494076e-02,   8.40158045e-04,
        -3.00327122e-05,  -4.60373324e-07,  -1.60180823e-04,
        -1.48430313e-04,   1.78449703e-02,   4.65028122e-05,
        -4.35375050e-04,  -2.27400423e-04,  -2.93104537e-03,
        -1.15906530e-03,  -1.82179756e-05,   3.68382525e-04,
         1.89595489e-02,   4.20198558e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.78415464e-02,   4.31009987e-05,
         2.88052067e-03,   1.85198127e-03,   1.10981666e-02,
         9.63279916e-03,   6.03129631e-04,  -3.16592106e-03,
        -2.34609061e-03,  -2.91104233e-03,   0.00000000e+00,
         0.00000000e+00,   9.85981192e-03,   3.28012499e-02,
        -3.53231840e-06,  -2.93246970e-06,   1.70680402e-07,
        -4.77927986e-04,   8.64333472e-03,   3.24449418e-04,
        -2.01085889e-04,   1.07701216e-03,   0.00000000e+00,
         0.00000000e+00,   2.20280439e-03,  -1.01987025e-02,
         1.57431788e-02,   1.65161072e-03,   1.14850946e-03,
        -4.87260558e-03,   3.96562375e-03,  -2.36507202e-02,
        -2.01697658e-03,   8.34057492e-03,   9.10800794e-03,
         2.91721933e-03,   0.00000000e+00,   0.00000000e+00,
         5.81117899e-03,  -4.57821324e-02,  -6.37042389e-03,
         2.66282514e-02,   1.79402290e-02,   1.13397636e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.64718148e-03,
         2.93281879e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.58061469e-02,   1.33321691e-03,
        -1.20923809e-03,   4.83695237e-03,  -5.87034948e-03,
         2.34858284e-02,   2.09644571e-03,  -8.38582995e-03,
         4.97019144e-04,  -2.00683409e-03,   0.00000000e+00,
         0.00000000e+00,  -1.05852799e-02,   4.50434568e-02,
         6.84568318e-03,  -2.74025796e-02,  -3.76640370e-04,
        -7.11208461e-03,   0.00000000e+00,   0.00000000e+00,
         5.82015526e-02,   8.99917679e-03,  -5.63182132e-03,
         2.25274733e-02,  -2.72547773e-02,   1.09405266e-01,
         9.76208274e-03,  -3.90577979e-02,   2.07990838e-03,
        -9.40627631e-03,   0.00000000e+00,   0.00000000e+00,
        -4.89026649e-02,   2.09608724e-01,   3.18131881e-02,
        -1.27689590e-01,  -1.58021102e-03,  -3.22716460e-02,
         0.00000000e+00,   0.00000000e+00,   6.34385921e-03,
         2.53964492e-02,   2.61680508e-02,   1.04672203e-01,
         7.52759405e-06,  -3.01109415e-05,   2.64520571e-04,
        -1.06912902e-03,  -8.24387534e-04,   3.47035315e-03,
        -1.27080429e-04,   5.41473361e-04,   0.00000000e+00,
         0.00000000e+00,   1.24327692e-03,  -5.77975548e-03,
        -1.25957190e-03,   1.21659017e-02,  -1.00073244e-03,
         6.29962295e-03,   0.00000000e+00,   0.00000000e+00,
         2.54818102e-04,  -3.63939191e-03,   1.50042681e-03,
        -1.75288247e-02,   4.60667452e-02,   2.34917080e-02,
        -7.72700298e-04,   3.09164305e-03,  -3.46035028e-03,
         1.46911128e-02,   1.20746205e-03,  -4.84874787e-03,
         5.90974768e-04,  -4.59524554e-03,   0.00000000e+00,
         0.00000000e+00,  -3.48898572e-03,   2.71356204e-02,
         2.97214269e-03,  -1.22382649e-02,  -3.60011594e-03,
        -1.56919448e-02,   0.00000000e+00,   0.00000000e+00,
        -4.89874184e-04,   6.99653645e-03,  -2.88449035e-03,
         3.36982288e-02,   1.34541474e-04,  -2.11577254e-03,
         4.58780809e-02,   2.64586051e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.49020847e-04,   3.16834856e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.69884382e-04,   9.76879379e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.61367297e-02,   2.23911455e-02,
        -3.97498854e-03,   1.64946096e-02,  -1.85386464e-02,
         8.02787991e-02,   7.12073016e-03,  -2.86056736e-02,
        -3.91304216e-04,  -7.34518979e-03,   0.00000000e+00,
         0.00000000e+00,  -3.22555936e-02,   1.57814132e-01,
         2.31449045e-02,  -9.36836366e-02,  -6.11063671e-03,
        -3.52110707e-02,   0.00000000e+00,   0.00000000e+00,
         3.51474786e-03,   2.97645086e-02,   3.11580848e-03,
         1.31560974e-01,   1.76005524e-03,  -1.57544534e-02,
        -3.38361214e-03,   3.02870947e-02,   0.00000000e+00,
         0.00000000e+00,   4.99705268e-03,   1.36845574e-01,
         4.27767763e-06,  -1.80665668e-05,   1.61730698e-04,
        -7.41076229e-04,   4.04509564e-04,   2.09160254e-03,
        -1.08843604e-04,   5.97866334e-04,   0.00000000e+00,
         0.00000000e+00,   1.27151689e-03,  -6.34042179e-03,
         3.75784280e-03,   7.69337967e-03,  -2.17213458e-03,
         1.15690084e-02,   0.00000000e+00,   0.00000000e+00,
         2.51020929e-03,  -1.03944986e-02,   1.09910091e-02,
        -4.90735426e-02,   1.70546348e-02,   1.90202690e-02,
         8.06172797e-04,  -4.09249297e-03,   0.00000000e+00,
         0.00000000e+00,   7.54825778e-03,  -3.77415916e-02,
         2.69032322e-02,   1.52370028e-02,   6.66767976e-05,
         1.84675961e-03,   1.75961644e-03,   9.04799634e-03,
         6.53173677e-04,  -2.90775990e-03,  -4.11872298e-03,
        -3.45684967e-03,   0.00000000e+00,   0.00000000e+00,
         4.30611162e-03,   2.23190144e-02,   1.57192480e-03,
        -7.52241691e-03,  -8.09162075e-03,  -2.54883949e-02,
         0.00000000e+00,   0.00000000e+00,  -4.82574322e-03,
         1.99828682e-02,  -2.11296276e-02,   9.43412632e-02,
         8.06172797e-04,  -4.09249297e-03,   1.59241580e-02,
         2.47590739e-02,   0.00000000e+00,   0.00000000e+00,
        -1.45111222e-02,   7.25561930e-02,   7.35646657e-04,
        -4.13532487e-03,   2.58716525e-02,   2.10358698e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.49237404e-04,
         1.90824138e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.11527368e-03,   6.17540390e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.74739821e-02,
         1.68914748e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.72858939e-02,   1.30859287e-02,
         4.01961085e-04,   9.97439544e-06,   2.48581556e-03,
         5.82478105e-04,  -3.10442503e-03,  -4.86650165e-05,
         1.06607535e-03,  -1.41223719e-03,   0.00000000e+00,
         0.00000000e+00,   1.92682480e-03,   1.34644880e-02,
        -7.28488856e-03,  -5.98971460e-04,   1.08845345e-02,
        -3.58595161e-02,   0.00000000e+00,   0.00000000e+00,
        -9.35454018e-03,   3.74194964e-02,  -4.35572787e-02,
         1.74279018e-01,   1.99444994e-03,  -8.02404550e-03,
        -3.83422343e-03,   1.54257987e-02,   0.00000000e+00,
         0.00000000e+00,  -3.16223329e-02,   1.27627514e-01,
         8.06264535e-04,  -4.80924783e-03,  -1.55000048e-03,
         9.24552195e-03,   0.00000000e+00,   0.00000000e+00,
         1.29285942e-02,   1.35470945e-04,   8.27923997e-04,
         1.10517228e-03,   3.81760614e-03,   6.17111295e-03,
        -1.47127175e-03,  -2.01237225e-03,   9.83351830e-05,
        -2.70553746e-03,   0.00000000e+00,   0.00000000e+00,
         2.36652248e-03,   3.05637863e-02,  -4.51845538e-03,
        -7.07272511e-03,   1.28041369e-02,  -5.64472393e-02,
         0.00000000e+00,   0.00000000e+00,  -1.41106560e-02,
         5.82880980e-02,  -3.28086066e-02,   1.35655259e-01,
        -5.59042683e-03,  -2.88668723e-09,  -1.16952806e-03,
        -2.82475718e-07,  -5.58618009e-03,  -1.60320516e-05,
         9.91590238e-05,   4.13493692e-05,   6.61061882e-04,
         2.22304769e-04,  -5.47164473e-03,  -1.36365138e-04,
         1.37670485e-04,   6.17168122e-07,   8.96718688e-04,
         2.40445454e-05,  -2.41716225e-04,  -9.69061809e-05,
        -5.78105535e-03,  -2.45183006e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.47656067e-03,  -1.86504538e-06,
        -1.02246890e-03,  -4.27216193e-06,  -4.09420085e-03,
        -1.67197911e-04,   4.80965207e-04,   8.13830982e-04,
         8.30619391e-04,   1.32597350e-04,   0.00000000e+00,
         0.00000000e+00,  -5.25520906e-03,  -1.18307339e-03,
        -2.36147270e-04,   1.00655721e-03,  -7.98235516e-04,
         4.92722508e-03,  -2.22288971e-03,  -1.93862176e-03,
        -8.99100718e-05,  -6.23527757e-04,   0.00000000e+00,
         0.00000000e+00,  -1.35975755e-03,   1.05033744e-02,
        -2.31038109e-03,  -1.12160344e-02,   1.68652454e-05,
         1.05405179e-05,   4.53603945e-04,   3.74878108e-04,
         6.43230346e-05,  -1.24046018e-03,  -2.91515309e-03,
        -2.20154107e-04,   0.00000000e+00,   0.00000000e+00,
         1.13745681e-03,   1.95946769e-03,   1.51590677e-04,
        -4.78996712e-03,  -5.73056479e-03,  -2.25007226e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.67792943e-03,
        -1.24127326e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.97397336e-03,  -1.12988368e-04,
         1.18928491e-06,  -4.75713964e-06,   4.09576998e-05,
        -1.64957515e-04,  -1.38471461e-04,   5.54095008e-04,
        -1.74033945e-05,   7.43963785e-05,   0.00000000e+00,
         0.00000000e+00,   1.67382764e-05,  -7.80401961e-04,
        -5.31838539e-04,   2.22059402e-03,   4.11877121e-04,
         6.32312146e-04,   0.00000000e+00,   0.00000000e+00,
        -1.59524175e-02,  -3.28182147e-04,   7.51015748e-06,
        -3.00969923e-05,   2.35170478e-04,  -1.04564895e-03,
        -8.67656884e-04,   3.50496863e-03,  -4.57801290e-05,
         4.76433121e-04,   0.00000000e+00,   0.00000000e+00,
         2.77446331e-04,  -5.00709101e-03,  -2.96687846e-03,
         1.35317470e-02,   1.65476312e-03,   4.17522650e-03,
         0.00000000e+00,   0.00000000e+00,  -3.16787735e-03,
        -9.01235542e-04,  -1.32061556e-02,  -5.76355874e-03,
        -5.55609567e-03,   2.22243847e-02,  -2.69748153e-02,
         1.07939441e-01,   9.66724691e-03,  -3.87202332e-02,
         2.08542554e-03,  -8.46285349e-03,   0.00000000e+00,
         0.00000000e+00,  -5.04767912e-02,   2.05037597e-01,
         3.14402722e-02,  -1.28002081e-01,   3.75237515e-03,
        -2.39850996e-02,   0.00000000e+00,   0.00000000e+00,
        -9.32821121e-04,   1.66727346e-02,  -4.17552756e-03,
         6.36855262e-02,  -7.76788126e-03,  -3.10715250e-02,
         2.14916259e-06,  -8.84931648e-06,   1.72085908e-05,
        -3.01985947e-04,  -2.39164244e-04,   1.02482907e-03,
         1.02224085e-04,   1.98125623e-04,   0.00000000e+00,
         0.00000000e+00,  -5.67806989e-04,  -1.28265682e-03,
        -6.51171695e-04,   3.89916514e-03,   1.67710865e-03,
         1.35300755e-03,   0.00000000e+00,   0.00000000e+00,
        -1.52669394e-04,  -2.26083026e-04,  -6.94814286e-04,
        -1.45228793e-03,  -5.64246417e-03,   2.85037788e-02,
        -1.37116046e-02,  -1.71242066e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.34437675e-06,  -5.70010043e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.76069790e-04,  -4.70740763e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.36536495e-02,  -1.48060029e-03,
        -3.81669581e-05,  -2.86332857e-05,  -2.03707811e-04,
        -1.00295757e-03,  -7.40894045e-04,   3.40727607e-03,
         5.31121800e-04,   4.74788640e-04,   0.00000000e+00,
         0.00000000e+00,  -8.74477959e-04,  -5.03815966e-03,
        -2.71120761e-03,   1.49232131e-02,   3.23600207e-03,
         4.69681128e-03,   0.00000000e+00,   0.00000000e+00,
        -2.63225340e-03,  -1.14688192e-03,  -8.34048736e-03,
        -7.67401929e-03,  -1.72565015e-02,   1.03801468e-01,
        -4.23951885e-04,  -1.71213134e-03,   0.00000000e+00,
         0.00000000e+00,  -9.29022095e-03,  -9.59383014e-03,
        -2.67900947e-03,   1.07195046e-02,  -1.29463862e-02,
         5.21258398e-02,   4.41653225e-03,  -1.88088232e-02,
         8.23532937e-04,  -3.88079618e-03,   0.00000000e+00,
         0.00000000e+00,  -2.38503750e-02,   1.00035241e-01,
         1.41980477e-02,  -6.42100144e-02,   6.26683129e-04,
        -1.32089670e-02,   0.00000000e+00,   0.00000000e+00,
        -1.36907365e-03,   7.15469119e-03,  -3.98631677e-03,
         3.58530302e-02,   7.07350177e-03,  -5.58925833e-02,
        -2.69572432e-03,   1.39098070e-02,   0.00000000e+00,
         0.00000000e+00,  -6.93212944e-03,   5.62832384e-02,
         1.72262862e-03,  -4.78782069e-02,  -1.59138305e-04,
        -8.24512170e-06,  -1.12955729e-03,  -2.93497914e-04,
        -1.02921560e-06,   1.07132683e-03,   1.40999451e-03,
         2.15413662e-04,   0.00000000e+00,   0.00000000e+00,
        -2.56644514e-03,  -1.50911034e-03,  -5.30492052e-04,
         6.62174964e-03,   3.74034642e-03,   2.06642063e-03,
         0.00000000e+00,   0.00000000e+00,   1.17144407e-04,
        -5.82926484e-04,   4.35824444e-04,  -3.79621428e-03,
        -2.20069604e-02,   9.11547512e-02,  -5.70873703e-03,
        -1.88595710e-03,   0.00000000e+00,   0.00000000e+00,
         1.19622492e-04,  -3.97135680e-03,  -1.01346917e-02,
         4.47496803e-02,  -8.74427921e-03,  -2.27761226e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.64630385e-04,
        -5.43360468e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.58693187e-03,  -4.71802100e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.76175953e-03,
        -1.37842549e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.80458847e-03,  -1.52651037e-03,
        -1.25519352e-04,  -8.79627622e-06,  -9.10052992e-04,
        -7.75286803e-05,   1.09185103e-03,   2.83870731e-04,
        -2.48782696e-04,   9.09280582e-05,   0.00000000e+00,
         0.00000000e+00,  -1.73425599e-03,  -1.02425796e-03,
         9.97256378e-04,   7.64188353e-03,  -1.25202757e-03,
         2.47348173e-03,   0.00000000e+00,   0.00000000e+00,
         3.17199823e-04,  -1.26924517e-03,   2.00192608e-03,
        -8.03002641e-03,  -4.34499503e-02,   1.73826077e-01,
         3.72780935e-04,  -1.52919767e-03,   0.00000000e+00,
         0.00000000e+00,   1.79420758e-03,  -7.65851596e-03,
        -2.09996015e-02,   8.47139400e-02,   5.21166763e-05,
        -1.45368006e-03,   0.00000000e+00,   0.00000000e+00,
        -4.98022841e-03,  -1.42641172e-04,  -2.55426085e-04,
        -3.40595569e-04,  -1.28643282e-03,  -1.77344926e-03,
         5.68417975e-04,   1.28435866e-03,   1.13583861e-04,
         2.99658158e-04,   0.00000000e+00,   0.00000000e+00,
        -2.25732515e-03,  -4.82983367e-03,  -7.58746394e-04,
         1.44993265e-02,  -4.34908117e-04,   4.21971128e-03,
         0.00000000e+00,   0.00000000e+00,   3.83402241e-04,
        -2.05380023e-03,   2.45518906e-03,  -1.28491239e-02,
        -3.32782250e-02,   1.34597767e-01,   1.49585989e-02,
         2.35934546e-06,   3.07240658e-03,   2.28864662e-04,
         1.44269272e-02,   2.09311842e-03,  -3.30453884e-05,
        -1.68982990e-06,  -1.26180087e-04,  -3.68453141e-04,
         1.44357219e-02,   1.27402781e-04,  -3.67493944e-04,
        -5.30879283e-04,  -2.58339095e-03,  -2.70996819e-03,
        -1.17645768e-04,   8.47763622e-04,   1.56482169e-02,
         1.03252435e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.44318570e-02,   1.18289732e-04,   2.21559783e-03,
         2.09284731e-03,   8.11451232e-03,   1.17255914e-02,
         6.74361385e-04,  -3.52431074e-03,  -1.65104436e-03,
        -5.73142903e-03,   0.00000000e+00,   0.00000000e+00,
         5.59679589e-03,   3.57324618e-02,  -3.35832314e-06,
        -5.50605866e-06,   1.35450005e-04,  -1.06499490e-03,
         6.87013531e-03,   4.94504800e-04,  -5.12282698e-04,
         2.38689260e-03,   0.00000000e+00,   0.00000000e+00,
         2.35592392e-03,  -1.08252007e-02,   1.19200694e-02,
         1.98384646e-03,   1.06238547e-03,  -4.53260805e-03,
         3.55034481e-03,  -2.20052535e-02,  -1.81601775e-03,
         7.60183283e-03,   7.28266893e-03,   3.97793865e-03,
         0.00000000e+00,   0.00000000e+00,   5.32207287e-03,
        -4.18888474e-02,  -5.48708156e-03,   2.31248894e-02,
         1.36142860e-02,   1.25545162e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.87715574e-03,   4.44337113e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.19913200e-02,   1.61988162e-03,  -1.22173552e-04,
         4.88694210e-04,  -5.84577473e-04,   2.34144813e-03,
         1.91522148e-04,  -7.66120118e-04,   1.90848198e-04,
        -7.76507222e-04,   0.00000000e+00,   0.00000000e+00,
        -7.51764325e-04,   4.52616118e-03,   4.79932266e-04,
        -1.92796990e-03,  -4.61799192e-04,  -2.91483687e-03,
         0.00000000e+00,   0.00000000e+00,   3.06676702e-02,
         6.30912640e-04,  -7.72912693e-04,   3.09181297e-03,
        -3.61394359e-03,   1.48139874e-02,   1.20995611e-03,
        -4.85074312e-03,   9.75677242e-04,  -4.90300752e-03,
         0.00000000e+00,   0.00000000e+00,  -4.45942757e-03,
         2.79119739e-02,   2.98887172e-03,  -1.22516482e-02,
        -2.47113233e-03,  -1.65951317e-02,   0.00000000e+00,
         0.00000000e+00,   6.09007492e-03,   1.73257717e-03,
         2.53881285e-02,   1.10801337e-02,   2.22790363e-06,
        -8.91230931e-06,   8.61116808e-05,  -3.57108419e-04,
        -2.12577375e-04,   1.00355958e-03,  -7.59567105e-05,
         3.40670259e-04,   0.00000000e+00,   0.00000000e+00,
         3.78194352e-04,  -2.03945790e-03,   4.43289623e-04,
         3.02359609e-03,  -4.13100968e-04,   3.02517525e-03,
         0.00000000e+00,   0.00000000e+00,  -1.52669394e-04,
        -2.26083026e-04,  -6.94814286e-04,  -1.45228793e-03,
         2.62785580e-02,   2.96696106e-03,  -5.78326540e-03,
         2.31337860e-02,  -2.78714975e-02,   1.12282101e-01,
         9.96302620e-03,  -3.98749245e-02,   2.24460137e-03,
        -1.10629504e-02,   0.00000000e+00,   0.00000000e+00,
        -5.02678087e-02,   2.12878302e-01,   3.21344983e-02,
        -1.28893114e-01,   9.36014502e-04,  -3.12666375e-02,
         0.00000000e+00,   0.00000000e+00,  -7.18736486e-04,
         1.69897654e-02,  -3.20120613e-03,   6.57220347e-02,
         2.89276969e-03,  -1.49959201e-02,   1.50146056e-02,
         6.00584226e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.92677428e-04,   9.23274225e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.55066371e-04,
         2.55156551e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.62484115e-02,   2.84637494e-03,  -6.12327281e-04,
         2.94186441e-03,  -2.27583614e-03,   1.44558483e-02,
         1.12166114e-03,  -4.63178244e-03,  -6.09609177e-04,
        -5.55454129e-03,   0.00000000e+00,   0.00000000e+00,
        -1.93778834e-03,   3.04094252e-02,   2.72418087e-03,
        -1.18319910e-02,  -5.08924184e-03,  -2.41889124e-02,
         0.00000000e+00,   0.00000000e+00,   5.06036650e-03,
         2.20481920e-03,   1.60341412e-02,   1.47528920e-02,
        -4.23951885e-04,  -1.71213134e-03,  -1.66620039e-02,
         1.06202348e-01,   0.00000000e+00,   0.00000000e+00,
         1.78599533e-02,   1.84436258e-02,   1.89097160e-06,
        -8.65118222e-06,   1.10608015e-04,  -5.53854848e-04,
         5.35161377e-04,   9.73536728e-04,  -1.68259797e-04,
         8.67351514e-04,   0.00000000e+00,   0.00000000e+00,
         8.63660696e-04,  -4.51726674e-03,   3.41604687e-03,
         3.16389365e-03,  -1.59516179e-03,   8.57797470e-03,
         0.00000000e+00,   0.00000000e+00,   1.17144407e-04,
        -5.82926484e-04,   4.35824444e-04,  -3.79621428e-03,
         1.10490941e-02,   2.91395232e-03,   1.14860475e-02,
        -4.77862181e-02,   0.00000000e+00,   0.00000000e+00,
         1.19622492e-04,  -3.97135680e-03,   1.68949797e-02,
         3.32533566e-03,  -2.45503084e-03,   1.15675695e-02,
        -1.07133025e-02,   5.67470804e-02,   4.87924717e-03,
        -1.98636722e-02,  -2.52607095e-03,  -7.68951025e-03,
         0.00000000e+00,   0.00000000e+00,  -1.97078596e-02,
         1.12677540e-01,   1.56160670e-02,  -6.37531144e-02,
        -4.77392990e-03,  -3.13516813e-02,   0.00000000e+00,
         0.00000000e+00,  -1.53334244e-03,   7.97211504e-03,
        -4.59746295e-03,   4.11763706e-02,   1.44091209e-03,
        -7.60567640e-03,  -1.36727813e-02,   1.08162204e-01,
         0.00000000e+00,   0.00000000e+00,  -7.09987319e-03,
         6.18521770e-02,   5.31575865e-03,  -2.38253346e-02,
        -3.39623169e-03,   9.30965464e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.53904086e-04,   8.92150204e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.52591187e-03,   2.64607372e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.10766748e-02,   2.64994934e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.69263508e-02,   2.93463461e-03,   3.24520489e-04,
         2.25321875e-05,   1.74434028e-03,   1.39527459e-03,
        -2.43091614e-03,  -1.16179817e-04,   1.29340425e-03,
        -3.18062620e-03,   0.00000000e+00,   0.00000000e+00,
         5.01353267e-04,   1.42445122e-02,  -5.42726237e-03,
        -7.44822102e-04,   9.08532189e-03,  -3.08516706e-02,
         0.00000000e+00,   0.00000000e+00,  -6.09799709e-04,
         2.44005601e-03,  -3.84859591e-03,   1.54372967e-02,
         3.72780935e-04,  -1.52919767e-03,  -4.39726920e-02,
         1.75970434e-01,   0.00000000e+00,   0.00000000e+00,
        -3.44926818e-03,   1.47230877e-02,   5.21166763e-05,
        -1.45368006e-03,  -2.10726835e-02,   8.67524007e-02,
         0.00000000e+00,   0.00000000e+00,   9.57422298e-03,
         2.74220030e-04,   6.76810545e-04,   9.08189722e-04,
         2.77789391e-03,   6.31001443e-03,  -1.17156487e-03,
        -1.68871263e-03,   6.66927762e-04,  -5.47338763e-03,
         0.00000000e+00,   0.00000000e+00,   5.08987664e-04,
         2.93412406e-02,  -3.34093602e-03,  -5.62612618e-03,
         1.07748607e-02,  -4.84769005e-02,   0.00000000e+00,
         0.00000000e+00,  -7.37070320e-04,   3.94832120e-03,
        -4.71996977e-03,   2.47017541e-02,   1.82368295e-04,
        -2.58932134e-03,  -3.34060904e-02,   1.36413238e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.15280386e-05,
         4.13451402e-05,   6.11641571e-04,   2.20034709e-04,
         2.92901543e-06,  -6.71855167e-05,  -2.25780193e-04,
        -9.19468123e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.43519127e-04,
         7.72308302e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.67330237e-05,
        -1.98141304e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.47018361e-05,  -1.13794919e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.37221813e-04,   1.00653605e-03,  -8.25425030e-04,
         4.91476336e-03,   4.18900038e-04,  -1.72680936e-03,
        -8.04146077e-05,  -5.97483418e-04,   0.00000000e+00,
         0.00000000e+00,  -1.37349718e-03,   1.01983845e-02,
         1.33109613e-03,  -5.54065500e-03,   3.36664159e-05,
        -4.03355719e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.26556816e-04,
         5.06428997e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.38675290e-04,   1.84464269e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.92702406e-04,   3.20329381e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.39340704e-03,   1.11476119e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.66747761e-05,
        -6.84653238e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.00633314e-04,  -9.32103247e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.20226855e-04,
         9.45313766e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.53614529e-04,   3.43851023e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.55607208e-03,
         2.22242902e-02,  -2.69702681e-02,   1.07919093e-01,
         9.64697230e-03,  -3.85896554e-02,   2.08268620e-03,
        -8.44548579e-03,   0.00000000e+00,   0.00000000e+00,
        -5.04512596e-02,   2.04772064e-01,   3.15948129e-02,
        -1.26508822e-01,   3.76901392e-03,  -2.35859919e-02,
         0.00000000e+00,   0.00000000e+00,  -1.01223524e-03,
         1.65551329e-02,  -4.53694946e-03,   6.29300888e-02,
         2.95072478e-03,  -1.47640997e-02,  -5.67261070e-03,
         2.83831927e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.76246133e-04,
         3.11964329e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.20617611e-03,   1.26337015e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.74770287e-02,
         1.02910867e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.35183321e-05,
        -1.08524807e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.04135656e-04,  -2.30564002e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.14330250e-02,
        -4.72786865e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.64246737e-08,   9.96325200e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.94053705e-04,   6.17152913e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.19793796e-02,   9.08907482e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.67904701e-03,   1.07194159e-02,  -1.29463974e-02,
         5.21036449e-02,   4.65663814e-03,  -1.86410040e-02,
         8.26613383e-04,  -3.85593871e-03,   0.00000000e+00,
         0.00000000e+00,  -2.38312867e-02,   9.96528193e-02,
         1.52628170e-02,  -6.13403654e-02,   6.17398027e-04,
        -1.24721688e-02,   0.00000000e+00,   0.00000000e+00,
        -1.30813858e-03,   6.85147003e-03,  -3.75961375e-03,
         3.38783515e-02,   1.38788960e-03,  -7.09814479e-03,
        -2.66814358e-03,   1.36458040e-02,   0.00000000e+00,
         0.00000000e+00,  -6.86990534e-03,   5.42174558e-02,
         5.25544938e-03,  -2.30742327e-02,  -1.01033206e-02,
         4.43589793e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.37303255e-05,
         2.60197563e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.72685221e-03,   7.48337120e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.32560406e-02,
         1.73030633e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.09724919e-02,   8.39577785e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.64998998e-05,   6.48400949e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.33521710e-03,   1.22266636e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.32307937e-02,   1.33924322e-01,
         7.07739442e-02,   2.61510015e-03,   1.31097388e-02,
         7.00816725e-03,   6.13556260e-02,   3.31240985e-02,
        -2.79326194e-04,  -9.42118287e-04,  -1.50759119e-03,
        -6.36782849e-03,   6.69495904e-02,   6.50838674e-03,
        -8.61741927e-04,  -4.33287611e-03,  -6.59414705e-03,
        -2.04598335e-02,  -7.05922463e-04,   6.33118869e-03,
         6.95886609e-02,   8.27383786e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.68249276e-02,   6.07855852e-03,
         1.00845473e-02,   1.18034456e-02,   3.56231470e-02,
         6.12519419e-02,   8.71029661e-04,  -1.46804306e-02,
        -2.54697583e-03,  -3.21081939e-02,   0.00000000e+00,
         0.00000000e+00,   3.34751903e-02,   1.26029716e-01,
         3.76244404e-04,  -1.79421808e-03,   1.77548044e-03,
        -1.41054324e-02,   3.08070249e-02,   8.54871347e-03,
        -3.17117817e-03,   1.55200267e-02,   0.00000000e+00,
         0.00000000e+00,   6.02934265e-03,  -4.10788497e-02,
         5.30953570e-02,   2.04491297e-02,   2.67202342e-03,
        -1.17807520e-02,   7.97836454e-03,  -5.83704886e-02,
        -4.49948428e-03,   2.08332512e-02,   3.29535516e-02,
         9.92297571e-03,   0.00000000e+00,   0.00000000e+00,
         1.09977220e-02,  -1.08065949e-01,  -1.37277810e-02,
         6.38642066e-02,   6.05590226e-02,   2.20463653e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.08748436e-02,
         7.52689519e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.34956462e-02,   1.64779790e-02,
        -1.03974562e-03,   4.15898248e-03,  -5.07399908e-03,
         2.03034920e-02,   1.79260978e-03,  -7.17051404e-03,
         4.96886185e-04,  -2.01923161e-03,   0.00000000e+00,
         0.00000000e+00,  -8.65215429e-03,   3.91464521e-02,
         5.85057130e-03,  -2.34328424e-02,  -1.85375132e-03,
        -7.05838893e-03,   0.00000000e+00,   0.00000000e+00,
         9.88724500e-02,   8.98802690e-03,  -4.16059378e-03,
         1.66430938e-02,  -2.01412343e-02,   8.15608694e-02,
         7.14637839e-03,  -2.86261922e-02,   1.55283344e-03,
        -8.90049991e-03,   0.00000000e+00,   0.00000000e+00,
        -3.23988600e-02,   1.57928745e-01,   2.31259174e-02,
        -9.36684470e-02,  -1.13840495e-02,  -3.09923405e-02,
         0.00000000e+00,   0.00000000e+00,   1.65935477e-02,
         1.93014688e-02,   7.75518959e-02,   7.20121039e-02,
         1.84871525e-05,  -7.39565742e-05,   3.49685028e-04,
        -1.44567184e-03,  -7.33747321e-04,   3.40155869e-03,
        -2.41105086e-04,   1.09257015e-03,   0.00000000e+00,
         0.00000000e+00,   1.15003744e-03,  -6.65777198e-03,
         8.18704238e-04,   1.20992837e-02,  -5.24275049e-04,
         7.70503298e-03,   0.00000000e+00,   0.00000000e+00,
        -2.18587552e-04,  -3.07781460e-03,  -2.38607361e-03,
        -1.24375503e-02,   9.07606695e-02,   1.73877309e-02,
        -7.65243187e-04,   3.06419713e-03,  -3.22490851e-03,
         1.52151062e-02,   1.13790981e-03,  -4.64478138e-03,
         6.49884665e-05,  -6.09421941e-03,   0.00000000e+00,
         0.00000000e+00,   2.56561687e-05,   2.88386696e-02,
         2.65940381e-03,  -1.17801693e-02,  -1.13387269e-02,
        -1.91893243e-02,   0.00000000e+00,   0.00000000e+00,
         4.20222888e-04,   5.91693409e-03,   4.58709901e-03,
         2.39105258e-02,  -4.34154258e-04,  -1.70396944e-03,
         9.13694736e-02,   1.97771664e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.61119136e-04,   3.10754169e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.36344472e-03,   9.77800480e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.05348353e-02,   1.65013762e-02,
        -5.19569874e-03,   2.30992722e-02,  -2.32404492e-02,
         1.14419370e-01,   9.50941200e-03,  -3.93310242e-02,
        -3.36450798e-03,  -1.59938836e-02,   0.00000000e+00,
         0.00000000e+00,  -3.62750825e-02,   2.23835713e-01,
         3.05979818e-02,  -1.28808169e-01,  -2.34395464e-02,
        -5.54255116e-02,   0.00000000e+00,   0.00000000e+00,
         1.17690258e-02,   2.65884597e-02,   4.15149788e-02,
         1.07631233e-01,  -6.75516681e-04,  -1.64855936e-02,
         1.29864472e-03,   3.16926726e-02,   0.00000000e+00,
         0.00000000e+00,   4.23919217e-02,   1.69567687e-01,
         8.75296399e-05,  -3.65806107e-04,   9.48922362e-04,
        -4.77170133e-03,   1.46411770e-03,   7.43481466e-03,
        -7.91244277e-04,   4.53950688e-03,   0.00000000e+00,
         0.00000000e+00,   2.97875607e-03,  -1.92049724e-02,
         1.06103444e-02,   2.56862731e-02,  -2.79263533e-03,
         2.52621893e-02,   0.00000000e+00,   0.00000000e+00,
         2.08925477e-03,  -8.89974852e-03,   6.21750960e-03,
        -3.66769931e-02,   3.90554131e-02,   1.94932044e-02,
         3.83701681e-04,  -4.18262015e-03,   0.00000000e+00,
         0.00000000e+00,   6.34785851e-03,  -5.24063956e-02,
         6.65393019e-02,   3.57873640e-02,   3.15336575e-04,
         6.97434857e-03,   5.42793784e-03,   3.61518584e-02,
         1.61929728e-03,  -9.92366991e-03,  -1.24562713e-02,
        -1.83134223e-02,   0.00000000e+00,   0.00000000e+00,
         1.33654570e-02,   7.05230992e-02,   3.86320953e-03,
        -2.52774848e-02,  -2.77676876e-02,  -5.66512084e-02,
         0.00000000e+00,   0.00000000e+00,  -4.01648065e-03,
         1.71092909e-02,  -1.19528299e-02,   7.05095592e-02,
         3.83701681e-04,  -4.18262015e-03,   3.85173574e-02,
         2.53583925e-02,   0.00000000e+00,   0.00000000e+00,
        -1.22034188e-02,   1.00748495e-01,   8.29000930e-04,
        -1.12386986e-02,   6.53768138e-02,   5.15471219e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.61222859e-03,
         6.73214746e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.16388741e-02,   2.04848591e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.92550034e-02,
         1.73175287e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.69705238e-02,   2.99413245e-02,
         7.65925117e-04,   3.30023750e-03,   5.06802932e-03,
         2.13299787e-02,  -1.12740359e-02,  -4.87550480e-03,
         7.97688732e-03,  -2.10058990e-02,   0.00000000e+00,
         0.00000000e+00,   6.64018796e-03,   5.61134735e-02,
        -2.60743946e-02,  -1.20474154e-02,   2.83414914e-02,
        -8.44333883e-02,   0.00000000e+00,   0.00000000e+00,
        -8.00851478e-03,   3.20363075e-02,  -3.19386837e-02,
         1.27880595e-01,   1.90558080e-03,  -7.74761455e-03,
        -3.66337727e-03,   1.48943749e-02,   0.00000000e+00,
         0.00000000e+00,  -4.27537387e-02,   1.75299662e-01,
         2.57846105e-03,  -1.64298195e-02,  -4.95695358e-03,
         3.15854499e-02,   0.00000000e+00,   0.00000000e+00,
         4.76141005e-02,   1.08519809e-02,   2.30962876e-03,
         8.01719148e-03,   8.81417238e-03,   4.66061853e-02,
        -5.49316190e-03,  -1.14619889e-02,   6.24572937e-03,
        -3.25247246e-02,   0.00000000e+00,   0.00000000e+00,
         8.61076361e-03,   1.12294140e-01,  -1.61678401e-02,
        -3.41063995e-02,   2.99990768e-02,  -1.30837929e-01,
         0.00000000e+00,   0.00000000e+00,  -1.17805688e-02,
         5.02220006e-02,  -4.59041218e-02,   2.01357881e-01,
         1.60508367e-03,  -1.31144738e-02,  -3.08568758e-03,
         2.52118751e-02,   0.00000000e+00,   0.00000000e+00,
        -2.89604199e-02,   1.40013295e-01,  -3.83200641e-02,
        -1.35478007e-05,  -7.99904045e-03,  -6.68429021e-05,
        -3.78722358e-02,  -1.29314435e-03,   7.06417797e-04,
         2.51053328e-03,   5.01463864e-03,   1.23984860e-02,
        -3.67195786e-02,  -7.33239788e-03,   7.21376073e-04,
         2.78031438e-05,   4.51259956e-03,   7.42113554e-04,
        -1.58740465e-03,  -2.53157773e-03,  -3.83411731e-02,
        -6.16220628e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.73625194e-02,  -3.51558131e-04,  -6.99187736e-03,
        -9.44319963e-05,  -2.74708956e-02,  -2.78877389e-03,
         2.22439563e-03,   2.05920989e-02,   3.96916194e-03,
         1.77042660e-03,   0.00000000e+00,   0.00000000e+00,
        -3.46849496e-02,  -9.59610047e-03,  -1.48097153e-03,
         6.67407663e-03,  -4.02881538e-03,   3.45900642e-02,
        -1.40099307e-02,  -2.06083773e-02,  -6.25799113e-04,
        -4.76299538e-03,   0.00000000e+00,   0.00000000e+00,
        -5.76158449e-03,   6.87118806e-02,  -1.81462431e-02,
        -7.32525769e-02,   8.87926138e-05,   5.67718792e-05,
         2.25587558e-03,   2.12250066e-03,  -3.64679544e-04,
        -5.80747366e-03,  -1.88448360e-02,  -1.38865137e-03,
         0.00000000e+00,   0.00000000e+00,   5.41621456e-03,
         8.81317638e-03,  -1.21152626e-03,  -1.88245029e-02,
        -3.52850416e-02,  -7.62682827e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.81059230e-02,  -6.37264949e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.29166802e-02,  -2.65147730e-03,   1.66418725e-07,
        -6.65674900e-07,   4.96329664e-06,  -2.33487791e-05,
        -5.51297579e-05,   2.20707179e-04,   9.34011027e-07,
         1.10589128e-05,   0.00000000e+00,   0.00000000e+00,
        -5.11170995e-04,  -1.15161035e-04,  -2.80202260e-04,
         1.19785444e-03,   1.69852033e-03,   1.03918102e-04,
         0.00000000e+00,   0.00000000e+00,  -4.80906097e-02,
        -3.68611355e-05,   4.46234537e-06,  -1.82143010e-05,
         4.26094317e-05,  -6.45779216e-04,  -7.22404162e-04,
         2.99313352e-03,   2.40524153e-04,   3.18372128e-04,
         0.00000000e+00,   0.00000000e+00,  -2.71897991e-03,
        -3.14802435e-03,  -2.40757407e-03,   1.26257132e-02,
         8.82353145e-03,   2.77247558e-03,   0.00000000e+00,
         0.00000000e+00,  -1.02816812e-02,  -1.60986236e-04,
        -4.71574778e-02,  -2.55475310e-03,  -2.68008645e-03,
         1.07203661e-02,  -1.30154100e-02,   5.21810588e-02,
         4.69831837e-03,  -1.90342521e-02,   9.05005936e-04,
        -3.94597458e-03,   0.00000000e+00,   0.00000000e+00,
        -2.36468277e-02,   9.98724027e-02,   1.39151119e-02,
        -6.39836657e-02,  -5.32614603e-04,  -1.22815288e-02,
         0.00000000e+00,   0.00000000e+00,   1.22024814e-03,
         5.08323376e-03,   7.34666747e-03,   2.67866428e-02,
        -4.55431172e-02,  -1.37992881e-02,   1.71781514e-06,
        -8.51265705e-06,  -2.00950315e-04,  -3.04608183e-04,
        -3.63916660e-04,   1.69279916e-03,   6.40654312e-04,
         2.20220227e-04,   0.00000000e+00,   0.00000000e+00,
        -3.16117180e-03,  -1.29740074e-03,  -9.28062359e-04,
         6.63918103e-03,   7.38535267e-03,   1.39356313e-03,
         0.00000000e+00,   0.00000000e+00,  -5.70243725e-04,
        -3.30159778e-05,  -3.39671895e-03,  -7.30179571e-04,
        -1.00760251e-03,   1.25593096e-02,  -4.70954576e-02,
        -9.21014013e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.21289392e-05,  -5.60069899e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.79640207e-03,
        -4.65209838e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.66987166e-02,  -7.73293203e-04,  -2.91905532e-04,
        -6.22579693e-05,  -2.23282037e-03,  -2.22630715e-03,
        -1.63831289e-03,   9.91675913e-03,   3.43590016e-03,
         1.15779134e-03,   0.00000000e+00,   0.00000000e+00,
        -7.90273813e-03,  -1.04997770e-02,  -5.36085715e-03,
         3.84632344e-02,   1.76256989e-02,   8.92752190e-03,
         0.00000000e+00,   0.00000000e+00,  -8.77543433e-03,
        -2.07997239e-04,  -3.35801333e-02,  -4.83887880e-03,
        -4.12324382e-04,   5.10673944e-02,  -2.92561093e-03,
        -1.53517007e-03,   0.00000000e+00,   0.00000000e+00,
        -4.22757850e-02,  -1.35074808e-02,  -5.22196890e-03,
         2.09283931e-02,  -2.50006339e-02,   1.02541534e-01,
         7.87614329e-03,  -3.90173761e-02,   6.47910600e-04,
        -6.14905766e-03,   0.00000000e+00,   0.00000000e+00,
        -4.48771183e-02,   1.98845885e-01,   2.34952878e-02,
        -1.36177834e-01,  -3.96295006e-03,  -2.15014528e-02,
         0.00000000e+00,   0.00000000e+00,  -1.14587820e-03,
         5.95373068e-03,  -1.96424469e-03,   3.83309843e-02,
        -1.53925968e-02,  -3.41860265e-02,  -3.18457754e-03,
         1.93889815e-02,   0.00000000e+00,   0.00000000e+00,
        -5.45127424e-03,   9.33798249e-02,  -2.30734363e-02,
        -9.22937454e-02,  -1.08176450e-03,  -5.47551027e-05,
        -7.12332839e-03,  -1.90577351e-03,  -2.54756958e-04,
         9.99895865e-03,   8.31803322e-03,   1.33687433e-03,
         0.00000000e+00,   0.00000000e+00,  -1.48188571e-02,
        -7.44427573e-03,  -2.04040027e-03,   3.42490243e-02,
         2.03957696e-02,   7.24702752e-03,   0.00000000e+00,
         0.00000000e+00,  -5.96554866e-05,  -8.27687596e-05,
        -1.47620068e-03,  -2.36584699e-03,  -9.37226739e-03,
         4.41397409e-02,  -2.22416832e-02,  -1.77938112e-03,
         0.00000000e+00,   0.00000000e+00,  -3.71934354e-03,
        -7.60002301e-03,  -1.61188210e-02,   8.50868860e-02,
        -4.07736874e-02,  -7.49909019e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.66365230e-03,  -3.34377687e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.61739502e-03,  -2.47950976e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.19918865e-02,  -1.27636397e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.00408076e-02,  -4.56757101e-03,  -6.93152203e-04,
        -8.31983226e-04,  -5.61471897e-03,  -6.22047207e-03,
         5.53726047e-03,   1.52766710e-02,  -2.29390918e-03,
         1.96279089e-03,   0.00000000e+00,   0.00000000e+00,
        -1.18462371e-02,  -1.62559151e-02,   9.54379405e-03,
         5.72987611e-02,  -7.91437438e-03,   1.15897495e-02,
         0.00000000e+00,   0.00000000e+00,   5.90781556e-05,
        -2.37446648e-04,   1.27532011e-03,  -5.18449229e-03,
        -2.11922034e-02,   8.48680215e-02,   3.91719064e-04,
        -1.72536197e-03,   0.00000000e+00,   0.00000000e+00,
         3.41090333e-03,  -1.70957733e-02,  -4.19302230e-02,
         1.73161947e-01,   2.24459861e-04,  -1.02748808e-02,
         0.00000000e+00,   0.00000000e+00,  -3.70147568e-02,
        -1.74425508e-02,  -1.74749590e-03,  -2.41149852e-03,
        -8.59754761e-03,  -1.45044386e-02,   1.20474836e-03,
         2.50316699e-02,  -8.93691630e-06,   2.96111600e-03,
         0.00000000e+00,   0.00000000e+00,  -1.57036262e-02,
        -3.51962971e-02,  -1.44339739e-03,   9.62715956e-02,
        -2.48162883e-03,   1.79112500e-02,   0.00000000e+00,
         0.00000000e+00,  -2.14757877e-04,  -6.42750546e-04,
        -3.20882223e-05,  -9.60995574e-03,  -3.14327811e-02,
         1.32301259e-01,  -7.84970174e-04,  -3.62909657e-03,
         0.00000000e+00,   0.00000000e+00,  -2.62706434e-04,
        -3.05620701e-02,  -2.99181413e-02,   1.35848367e-01,
         1.19108997e-01,   9.44527494e-03,   1.94627630e-02,
         2.26120171e-02,   9.11610517e-02,   9.64655977e-02,
        -3.49934959e-04,  -3.36337358e-03,  -2.17461920e-03,
        -1.87228035e-02,   1.08736962e-01,   2.05109510e-02,
        -7.05746402e-04,  -1.06055233e-02,  -6.65675277e-03,
        -4.94794192e-02,  -2.14185486e-03,   1.54040989e-02,
         1.12345504e-01,   2.17741274e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.08482787e-01,   1.91730882e-02,
         1.46972530e-02,   2.95578717e-02,   4.80836889e-02,
         1.41474959e-01,   1.53309668e-03,  -3.02191376e-02,
         1.99668057e-03,  -7.41605109e-02,   0.00000000e+00,
         0.00000000e+00,   4.35682735e-02,   2.34242096e-01,
         1.42816192e-03,  -6.37883814e-03,   6.14978374e-03,
        -3.95584504e-02,   4.78427764e-02,   2.28396290e-02,
        -7.89080328e-03,   3.67610094e-02,   0.00000000e+00,
         0.00000000e+00,   1.07550296e-02,  -7.57653494e-02,
         7.83975962e-02,   4.30405187e-02,   3.26530593e-03,
        -1.49367347e-02,   8.85270453e-03,  -7.63980282e-02,
        -5.66082257e-03,   2.78410866e-02,   5.18200817e-02,
         1.84648111e-02,   0.00000000e+00,   0.00000000e+00,
         1.26882222e-02,  -1.36856311e-01,  -1.66348207e-02,
         8.02093180e-02,   8.86396654e-02,   2.88581642e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.80908370e-02,
         2.00310643e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.91868949e-02,   3.48740400e-02,
        -3.77214875e-05,   1.50885950e-04,  -2.33670333e-04,
         9.42201593e-04,   2.69390100e-05,  -1.07814438e-04,
         2.06207544e-04,  -8.56463463e-04,   0.00000000e+00,
         0.00000000e+00,   5.40719528e-04,   2.10041765e-03,
         6.35976841e-05,  -2.73893262e-04,  -2.76299695e-03,
        -2.49338330e-03,   0.00000000e+00,   0.00000000e+00,
         9.24516273e-02,   7.08635632e-05,  -5.93405950e-04,
         2.37482581e-03,  -2.84636729e-03,   1.27327833e-02,
         7.27178093e-04,  -2.96696343e-03,   9.99326760e-04,
        -7.55128947e-03,   0.00000000e+00,   0.00000000e+00,
         1.69738412e-03,   2.44059964e-02,   1.61305094e-03,
        -7.55531782e-03,  -1.56427065e-02,  -1.94475263e-02,
         0.00000000e+00,   0.00000000e+00,   1.97659827e-02,
         3.09487436e-04,   9.06577310e-02,   4.91137630e-03,
         4.23558160e-05,  -1.69440418e-04,   3.53175637e-04,
        -1.47968426e-03,  -1.38190787e-04,   1.18105609e-03,
        -3.65101001e-04,   1.63549007e-03,   0.00000000e+00,
         0.00000000e+00,   5.16501282e-04,  -3.97546747e-03,
         3.30031236e-03,   3.55710611e-03,  -5.31063258e-05,
         5.10118282e-03,   0.00000000e+00,   0.00000000e+00,
        -5.70243725e-04,  -3.30159778e-05,  -3.39671895e-03,
        -7.30179571e-04,   8.99821601e-02,   1.56345487e-03,
        -2.99942020e-03,   1.20030810e-02,  -1.40471585e-02,
         5.94141653e-02,   4.94355605e-03,  -1.99151194e-02,
         5.50107038e-04,  -1.01504526e-02,   0.00000000e+00,
         0.00000000e+00,  -1.91852706e-02,   1.12259468e-01,
         1.55889384e-02,  -6.37314116e-02,  -1.36032869e-02,
        -2.42881958e-02,   0.00000000e+00,   0.00000000e+00,
         2.01988727e-03,   5.12953128e-03,   1.21098051e-02,
         2.78105562e-02,   2.34733235e-04,  -6.64073331e-03,
         8.81105495e-02,   2.67355393e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.16601499e-04,   1.08956926e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.39317976e-03,   3.06174235e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.97757871e-02,   1.48661486e-03,
        -1.03216917e-03,   8.05235317e-03,  -2.09183458e-03,
         4.21676764e-02,   1.91824447e-03,  -1.01628277e-02,
        -5.20758704e-03,  -2.41123698e-02,   0.00000000e+00,
         0.00000000e+00,   7.20946040e-03,   7.54478965e-02,
         4.16551572e-03,  -2.55193298e-02,  -3.27219722e-02,
        -5.26877807e-02,   0.00000000e+00,   0.00000000e+00,
         1.68703036e-02,   3.99863576e-04,   6.45560117e-02,
         9.30248591e-03,  -2.92561093e-03,  -1.53517007e-03,
         3.69018977e-03,   5.32201266e-02,   0.00000000e+00,
         0.00000000e+00,   8.12729375e-02,   2.59674099e-02,
         2.76406860e-04,  -1.14129219e-03,   1.79393549e-03,
        -9.03958461e-03,   3.44993651e-03,   7.03520388e-03,
        -1.73617310e-03,   9.38023939e-03,   0.00000000e+00,
         0.00000000e+00,   2.88624706e-03,  -2.16083591e-02,
         1.78399152e-02,   1.83447719e-02,  -2.03315480e-03,
         2.51901671e-02,   0.00000000e+00,   0.00000000e+00,
        -5.96554866e-05,  -8.27687596e-05,  -1.47620068e-03,
        -2.36584699e-03,   4.24081634e-02,   2.71539621e-03,
         4.69296973e-03,  -2.33271034e-02,   0.00000000e+00,
         0.00000000e+00,  -3.71934354e-03,  -7.60002301e-03,
         7.73575353e-02,   1.03058010e-02,  -3.79180674e-03,
         2.91199343e-02,  -1.31158205e-02,   1.44876105e-01,
         9.45556666e-03,  -4.46675397e-02,  -1.66893416e-02,
        -3.90351989e-02,   0.00000000e+00,   0.00000000e+00,
        -2.07964599e-02,   2.63333573e-01,   3.01961990e-02,
        -1.36742372e-01,  -3.92995195e-02,  -7.49041325e-02,
         0.00000000e+00,   0.00000000e+00,  -1.06222474e-03,
         6.06979533e-03,   1.05796183e-04,   4.16485549e-02,
         1.47431597e-03,  -1.04524884e-02,   2.99417287e-02,
         6.64261781e-02,   0.00000000e+00,   0.00000000e+00,
        -2.35727850e-04,   1.04037155e-01,   7.84995616e-03,
        -4.63980050e-02,   4.53851481e-02,   1.81540593e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.57528160e-03,
         6.30475519e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.82793310e-02,   1.50597210e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.22782266e-02,
         2.45374152e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.69763128e-02,   8.78091118e-03,
        -1.73756518e-04,   1.15180043e-02,   1.82914098e-03,
         6.19377126e-02,  -1.70254807e-02,  -1.50985200e-02,
         1.69238831e-02,  -4.98091286e-02,   0.00000000e+00,
         0.00000000e+00,   5.94284162e-03,   1.09314011e-01,
        -3.87538485e-02,  -2.99981413e-02,   3.76255186e-02,
        -1.04379034e-01,   0.00000000e+00,   0.00000000e+00,
        -1.13574597e-04,   4.56478493e-04,  -2.45173476e-03,
         9.96690937e-03,   3.91719064e-04,  -1.72536197e-03,
        -2.17415016e-02,   8.72874553e-02,   0.00000000e+00,
         0.00000000e+00,  -6.55727937e-03,   3.28657105e-02,
         2.24459861e-04,  -1.02748808e-02,  -4.22449777e-02,
         1.87570167e-01,   0.00000000e+00,   0.00000000e+00,
         7.11588919e-02,   3.35323717e-02,   2.16579198e-03,
         2.05986102e-02,   6.53781378e-03,   1.08319459e-01,
        -8.29683735e-03,  -2.35128089e-02,   1.60829706e-02,
        -7.56494710e-02,   0.00000000e+00,   0.00000000e+00,
         8.81682513e-03,   1.93433107e-01,  -2.39347659e-02,
        -5.74698927e-02,   3.78465035e-02,  -1.59721281e-01,
         0.00000000e+00,   0.00000000e+00,   4.12860541e-04,
         1.23565358e-03,   6.16878926e-05,   1.84746264e-02,
        -7.84970174e-04,  -3.62909657e-03,  -3.03320362e-02,
         1.37390254e-01,   0.00000000e+00,   0.00000000e+00,
         5.05039081e-04,   5.87539465e-02,  -4.94990822e-03,
        -1.99421338e-02,  -2.64475724e-02,   1.49830555e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.15363374e-04,
         2.50356164e-03,   3.82413630e-03,   1.21858798e-02,
         3.55119676e-04,  -3.47859011e-03,  -1.34898873e-03,
        -2.37893386e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.20136460e-03,
         2.00128192e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.71438681e-03,
        -8.52123765e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.61786759e-04,  -5.23774492e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.50507023e-03,   6.66142508e-03,  -4.61766858e-03,
         3.39949891e-02,   2.42710028e-03,  -1.13720915e-02,
        -5.13769021e-04,  -4.22981587e-03,   0.00000000e+00,
         0.00000000e+00,  -7.04469537e-03,   6.57764029e-02,
         7.44168833e-03,  -3.50201952e-02,  -1.18572529e-03,
        -1.51029276e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.34778401e-05,
         2.14077400e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.69440303e-04,   1.14549577e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.80456591e-04,   2.81199657e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.15178807e-03,   1.11890533e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.07102028e-05,
        -3.30608517e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.45587860e-04,  -2.09781788e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.52753186e-04,
         1.61747602e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.16926076e-04,   6.20034407e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.68005020e-03,
         1.07202185e-02,  -1.30132800e-02,   5.21571510e-02,
         4.65872682e-03,  -1.86426750e-02,   9.09557830e-04,
        -3.92229427e-03,   0.00000000e+00,   0.00000000e+00,
        -2.37583646e-02,   9.95944815e-02,   1.52545767e-02,
        -6.13337731e-02,  -1.41425065e-04,  -1.18651103e-02,
         0.00000000e+00,   0.00000000e+00,   9.23624177e-04,
         5.06605982e-03,   5.57979446e-03,   2.64068249e-02,
         6.31474237e-04,  -6.49301250e-03,  -1.21397548e-03,
         1.24824696e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.61092844e-03,
         9.31067308e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.86669143e-03,   3.36893115e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.93414090e-03,
         5.02688442e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.44053920e-04,
        -2.02054267e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.17602364e-03,  -1.11142447e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.94276638e-03,
        -2.28240863e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.76670987e-04,   9.54631726e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.47043956e-03,   3.16595375e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.50220424e-03,   4.38780862e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.22292352e-03,   2.09264679e-02,  -2.50471471e-02,
         1.02352063e-01,   9.09599744e-03,  -3.66283168e-02,
         7.27593533e-04,  -5.95722223e-03,   0.00000000e+00,
         0.00000000e+00,  -4.52325078e-02,   1.97089277e-01,
         2.99090397e-02,  -1.22046309e-01,  -3.05316383e-03,
        -1.90235619e-02,   0.00000000e+00,   0.00000000e+00,
        -1.17690923e-03,   5.91067681e-03,  -2.73212075e-03,
         3.71003404e-02,   1.72411263e-03,  -9.94947125e-03,
        -3.31451439e-03,   1.91273268e-02,   0.00000000e+00,
         0.00000000e+00,  -7.38596705e-03,   8.94265171e-02,
         8.58283595e-03,  -4.34664858e-02,  -1.65000435e-02,
         8.35619962e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.14135725e-03,
         1.21957790e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.02604945e-02,   4.75888403e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.09884427e-02,
         8.39705391e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.18134656e-02,   1.67817257e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.30913343e-03,   1.96257676e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.30291782e-02,   7.66722071e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.18410994e-02,   1.30413510e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.12055394e-02,   1.30661712e-01,   3.50326745e-01,
         7.67615135e-03,   6.84478746e-02,   1.99680623e-02,
         3.21359505e-01,   9.84707999e-02,  -6.98462075e-03,
        -1.54418211e-02,  -4.49985791e-02,  -8.42252577e-02,
         3.40852674e-01,   7.59644826e-02,   2.46943635e-03,
         5.45950821e-03,   1.59094002e-02,   2.97781254e-02,
        -3.00802362e-03,  -2.06128032e-02,   3.33408195e-01,
         2.49503973e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.32344698e-01,   1.76626709e-02,   5.75111381e-02,
         2.73985505e-02,   2.14781834e-01,   1.54894830e-01,
        -2.53834619e-02,  -1.37707547e-01,   8.97440901e-03,
         4.86869703e-02,   0.00000000e+00,   0.00000000e+00,
         2.51133568e-01,   2.91456989e-01,   4.81920740e-03,
        -2.53781989e-02,   1.73933785e-03,  -1.56785570e-01,
         1.44845301e-01,   1.39683742e-01,   4.07071060e-03,
        -4.25453811e-02,   0.00000000e+00,   0.00000000e+00,
        -7.42708921e-03,  -3.27695165e-01,   2.40108188e-01,
         3.84305425e-01,  -1.70384712e-03,   8.97254826e-03,
        -6.14948795e-04,   5.54320700e-02,   4.07071060e-03,
        -4.25453811e-02,   1.54919795e-01,   3.43892955e-02,
         0.00000000e+00,   0.00000000e+00,   2.62587257e-03,
         1.15857737e-01,   1.11756832e-02,  -1.22365305e-01,
         2.67766593e-01,   8.14667464e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.56359009e-01,   1.93472318e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.71717794e-01,   3.82040780e-02,  -1.59480991e-05,
         6.37923964e-05,  -1.00628307e-04,   4.15405655e-04,
         1.22635427e-04,  -4.90643892e-04,  -4.32456558e-05,
         1.18492155e-04,   0.00000000e+00,   0.00000000e+00,
         1.75169577e-03,   8.42072018e-04,   2.86151415e-04,
        -1.18461782e-03,  -6.34191868e-03,   3.15908303e-04,
         0.00000000e+00,   0.00000000e+00,   1.74266986e-01,
         2.38687137e-07,  -1.02763890e-04,   4.13754375e-04,
        -1.32044933e-04,   2.67676650e-03,   7.54456407e-04,
        -3.13577017e-03,  -1.58084515e-03,   7.05299206e-04,
         0.00000000e+00,   0.00000000e+00,   1.20391321e-02,
         5.37464213e-03,   1.32831087e-03,  -7.48953100e-03,
        -3.63223256e-02,   1.90597195e-03,   0.00000000e+00,
         0.00000000e+00,   3.74169156e-02,   2.33177725e-06,
         1.74260305e-01,   2.49516682e-05,   3.41019103e-05,
        -1.36493286e-04,   2.09459238e-04,  -9.73138464e-04,
        -3.29583671e-05,   1.18371825e-03,   1.39142584e-04,
        -2.19412166e-04,   0.00000000e+00,   0.00000000e+00,
        -4.24771168e-04,  -2.07184582e-03,   6.83902047e-03,
         2.96847226e-03,   2.61457616e-03,  -6.19801259e-04,
         0.00000000e+00,   0.00000000e+00,  -1.26698963e-03,
        -1.89360362e-06,  -8.01417949e-03,  -1.71419550e-05,
         1.73816223e-01,   1.31379437e-05,  -8.43411614e-05,
         3.49621508e-04,   7.53905862e-04,   2.18762213e-03,
         5.49607561e-04,  -2.50059878e-03,  -3.28320708e-03,
         4.80662866e-04,   0.00000000e+00,   0.00000000e+00,
         1.30206029e-02,   4.22911256e-03,   7.98049995e-04,
        -5.72507199e-03,  -3.11603045e-02,   1.34483047e-03,
         0.00000000e+00,   0.00000000e+00,   2.43571986e-03,
         3.64035176e-06,   1.54068318e-02,   3.29544925e-05,
        -1.51491995e-03,  -1.90369661e-05,   1.75940559e-01,
         3.98330254e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.37206747e-04,   8.14164256e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.43982710e-03,
         1.50027756e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.73028207e-01,   3.23547544e-06,   2.13088191e-03,
         2.20827207e-03,   1.50531180e-02,   1.33419078e-02,
         3.94272959e-04,  -1.42101519e-02,  -2.16091668e-02,
         2.66294430e-03,   0.00000000e+00,   0.00000000e+00,
         4.46043038e-02,   2.57421808e-02,   4.50648017e-04,
        -3.32674494e-02,  -8.64741064e-02,   7.41908994e-03,
         0.00000000e+00,   0.00000000e+00,   3.19814264e-02,
         4.43545348e-05,   1.27517047e-01,   3.16010752e-04,
        -7.58925707e-03,  -1.51744248e-04,   1.45899412e-02,
         2.91720207e-04,   0.00000000e+00,   0.00000000e+00,
         1.73692897e-01,   2.14235331e-03,   3.46003989e-04,
        -1.66330818e-03,   4.70826746e-04,  -1.10889086e-02,
         9.81523419e-03,   1.18542921e-02,   2.43304234e-03,
        -1.81877033e-03,   0.00000000e+00,   0.00000000e+00,
        -3.13017419e-03,  -2.32287654e-02,   4.29655614e-02,
         3.05613473e-02,   1.32692065e-02,  -5.35711516e-03,
         0.00000000e+00,   0.00000000e+00,  -1.60831552e-04,
        -6.15188821e-05,  -4.68423227e-03,  -4.16850386e-04,
         8.46382166e-02,   2.03685489e-04,  -1.32632744e-03,
        -3.50924769e-04,   0.00000000e+00,   0.00000000e+00,
        -1.49687710e-02,  -2.39203381e-03,   1.71121552e-01,
         2.72052761e-03,   8.48695959e-03,   4.58943141e-03,
         4.64731862e-02,   2.62224764e-02,  -3.26779542e-03,
        -2.61046682e-02,  -5.10640079e-02,   4.58118420e-03,
         0.00000000e+00,   0.00000000e+00,   8.19874679e-02,
         4.84783098e-02,  -2.67597615e-03,  -5.88604392e-02,
        -1.08727764e-01,   1.27035923e-02,   0.00000000e+00,
         0.00000000e+00,   3.09190064e-04,   1.18266763e-04,
         9.00518622e-03,   8.01372592e-04,  -1.32632744e-03,
        -3.50924769e-04,   8.64980938e-02,   6.95778890e-04,
         0.00000000e+00,   0.00000000e+00,   2.87766624e-02,
         4.59855716e-03,  -6.75849029e-03,  -4.68852068e-03,
         1.80598821e-01,   9.29512789e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.15197801e-02,   1.26686908e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.63128973e-02,   2.33012693e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.39483002e-02,   2.11447742e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.67605984e-01,   2.81697435e-04,  -2.17432285e-03,
         4.22924324e-02,   1.12431335e-02,   2.56986256e-01,
        -4.69702104e-02,  -2.20099206e-01,   1.66064771e-02,
         7.78168204e-02,   0.00000000e+00,   0.00000000e+00,
         5.04066238e-02,   5.61385846e-01,  -1.31751909e-01,
        -6.66975226e-01,   4.65813340e-02,   2.35811353e-01,
         0.00000000e+00,   0.00000000e+00,  -5.18588508e-04,
         2.07821660e-03,  -3.18981388e-03,   1.30301974e-02,
         1.20048174e-03,  -5.08720929e-03,  -2.30786199e-03,
         9.77988801e-03,   0.00000000e+00,   0.00000000e+00,
        -8.51228110e-03,   5.57530862e-02,   3.80289208e-03,
        -5.00966699e-02,  -7.31085681e-03,   9.63081707e-02,
         0.00000000e+00,   0.00000000e+00,   3.05700943e-01,
         1.22280377e+00,   1.34090248e-02,   3.28598533e-02,
         6.23277712e-02,   2.02137071e-01,  -2.34772065e-02,
        -1.83335732e-01,   8.30044596e-03,   6.48189697e-02,
         0.00000000e+00,   0.00000000e+00,   1.16693573e-01,
         4.38360653e-01,  -8.15959456e-02,  -5.36789069e-01,
         2.88485232e-02,   1.89783595e-01,   0.00000000e+00,
         0.00000000e+00,   1.00589627e-03,   1.34318236e-03,
         6.25356810e-03,   8.47353211e-03,  -2.40283145e-03,
        -3.34509309e-03,   4.61931506e-03,   6.43076271e-03,
         0.00000000e+00,   0.00000000e+00,   2.24920654e-02,
         3.90523854e-02,  -1.70480867e-02,  -3.68965940e-02,
         3.27740357e-02,   7.09317302e-02,   0.00000000e+00,
         0.00000000e+00,   5.11355987e-02,   4.85760642e-01,
         4.78450147e-01,   2.09028612e-02,   8.91305846e-02,
         4.55428729e-02,   4.24365884e-01,   1.81494368e-01,
        -5.54802977e-03,  -1.48038881e-02,  -3.79708769e-02,
        -7.26109780e-02,   4.57870502e-01,   7.02369119e-02,
         1.96152474e-03,   5.23396484e-03,   1.34247323e-02,
         2.56718575e-02,  -1.23502164e-03,  -9.44735498e-03,
         4.54813979e-01,   4.68559012e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.54377333e-01,   4.35157568e-02,
         7.38616718e-02,   5.73837000e-02,   2.78363504e-01,
         2.60338240e-01,  -2.24416743e-02,  -1.14524041e-01,
         7.93433004e-03,   4.04903630e-02,   0.00000000e+00,
         0.00000000e+00,   3.29163413e-01,   4.39922237e-01,
         5.70656335e-03,  -2.80249067e-02,   5.82339486e-03,
        -1.51283665e-01,   2.04805093e-01,   1.10939519e-01,
         2.58345945e-03,  -2.23546641e-02,   0.00000000e+00,
         0.00000000e+00,  -5.12420851e-03,  -3.02621191e-01,
         3.54041104e-01,   3.06573547e-01,  -2.01757482e-03,
         9.90830079e-03,  -2.05888100e-03,   5.34868526e-02,
         2.58345945e-03,  -2.23546641e-02,   2.11198829e-01,
         5.56145481e-02,   0.00000000e+00,   0.00000000e+00,
         1.81168129e-03,   1.06992748e-01,   7.73309633e-03,
        -7.35999913e-02,   3.73179541e-01,   1.24422861e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.12112220e-01,
         4.77109808e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.75913603e-01,   9.84013348e-02,
        -8.69575068e-05,   3.47830027e-04,  -4.17009273e-04,
         1.68793099e-03,   1.51258769e-04,  -6.05187659e-04,
         1.56687806e-05,  -1.46767380e-04,   0.00000000e+00,
         0.00000000e+00,   2.23521462e-03,   3.18636631e-03,
         4.77766094e-04,  -1.97155609e-03,  -9.58234269e-03,
        -3.80531559e-04,   0.00000000e+00,   0.00000000e+00,
         2.69285459e-01,   3.71105067e-04,  -5.51153320e-04,
         2.20843413e-03,  -1.86946362e-03,   1.07207688e-02,
         9.49174969e-04,  -3.94872963e-03,  -1.83846369e-03,
        -1.15609837e-03,   0.00000000e+00,   0.00000000e+00,
         1.55525827e-02,   2.00149381e-02,   2.35722987e-03,
        -1.25732733e-02,  -5.44857300e-02,  -2.61534577e-03,
         0.00000000e+00,   0.00000000e+00,   5.75960453e-02,
         9.22736927e-04,   2.67994894e-01,   4.42083243e-03,
         1.70266897e-04,  -6.81149954e-04,   8.21243435e-04,
        -3.45959026e-03,  -4.99028013e-05,   1.77901528e-03,
         1.69105575e-05,   3.76996801e-04,   0.00000000e+00,
         0.00000000e+00,   3.67341682e-04,  -6.92956713e-03,
         1.02001987e-02,   5.73217049e-03,   3.28968172e-03,
         1.24003940e-03,   0.00000000e+00,   0.00000000e+00,
        -1.85872851e-03,  -2.60095635e-04,  -1.17134860e-02,
        -1.51418384e-03,   2.68081883e-01,   1.48486640e-03,
        -4.47597241e-04,   1.80771595e-03,  -2.23081847e-04,
         8.71079503e-03,   7.01901909e-04,  -3.18748606e-03,
        -4.42125891e-03,  -1.40283829e-03,   0.00000000e+00,
         0.00000000e+00,   1.75747939e-02,   1.56885956e-02,
         1.49507517e-03,  -9.49493513e-03,  -4.64603539e-02,
        -2.68872876e-03,   0.00000000e+00,   0.00000000e+00,
         3.57330623e-03,   5.00019959e-04,   2.25185510e-02,
         2.91093751e-03,  -1.89187828e-03,  -9.29924080e-04,
         2.70734819e-01,   2.78887667e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.60500743e-04,   5.17200274e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.11444904e-02,   1.44289760e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.67097784e-01,   1.00114732e-03,
         1.54630153e-03,   8.62785326e-03,   1.59076073e-02,
         4.09314374e-02,   1.07599980e-03,  -1.67173182e-02,
        -2.96965470e-02,  -3.77090357e-03,   0.00000000e+00,
         0.00000000e+00,   5.72676920e-02,   7.33685972e-02,
         2.93526041e-03,  -4.93888799e-02,  -1.26772321e-01,
        -5.42081106e-03,   0.00000000e+00,   0.00000000e+00,
         4.90596037e-02,   1.54986262e-03,   1.94704859e-01,
         8.87069716e-03,  -1.06041716e-02,  -3.34706957e-03,
         2.03859533e-02,   6.43456238e-03,   0.00000000e+00,
         0.00000000e+00,   2.61897878e-01,   2.41716151e-02,
         1.11405728e-03,  -4.70074106e-03,   3.83104728e-03,
        -2.44473145e-02,   1.38376711e-02,   1.49253316e-02,
         1.86410287e-03,   1.46268417e-03,   0.00000000e+00,
         0.00000000e+00,   1.55775363e-03,  -4.90054010e-02,
         6.23348433e-02,   4.52490030e-02,   1.49169745e-02,
         3.99236735e-03,   0.00000000e+00,   0.00000000e+00,
        -7.95822766e-05,  -7.50891026e-04,  -5.95809000e-03,
        -4.86915431e-03,   1.29837458e-01,   3.28506722e-03,
        -1.09073010e-03,  -3.38448863e-03,   0.00000000e+00,
         0.00000000e+00,  -1.87072341e-02,  -1.58064479e-02,
         2.59564882e-01,   1.61758015e-02,   9.62544343e-03,
         1.46308891e-02,   5.78929410e-02,   6.72353569e-02,
        -2.25024952e-03,  -2.83500791e-02,  -7.14053753e-02,
        -5.65879426e-03,   0.00000000e+00,   0.00000000e+00,
         1.07670454e-01,   1.14350204e-01,  -1.65340418e-05,
        -7.66044782e-02,  -1.56595556e-01,  -4.16763373e-03,
         0.00000000e+00,   0.00000000e+00,   1.52992674e-04,
         1.44354787e-03,   1.14541096e-02,   9.36068897e-03,
        -1.09073010e-03,  -3.38448863e-03,   1.31366963e-01,
         8.03105459e-03,   0.00000000e+00,   0.00000000e+00,
         3.59636579e-02,   3.03870514e-02,  -5.03897132e-03,
        -1.98708833e-02,   2.66630911e-01,   4.40402654e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.57298049e-02,
         5.19461692e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.74638967e-02,   1.22777472e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.29270093e-01,
         1.52455605e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.56943758e-01,   5.83955406e-03,
         4.23871054e-04,   4.32479763e-02,   3.28440125e-02,
         2.25724078e-01,  -7.93690229e-02,  -1.38622279e-01,
         2.80611871e-02,   4.90103768e-02,   0.00000000e+00,
         0.00000000e+00,   9.89350492e-02,   4.52567472e-01,
        -2.13099250e-01,  -4.31586426e-01,   7.53419623e-02,
         1.52588844e-01,   0.00000000e+00,   0.00000000e+00,
        -6.69355431e-04,   2.68338372e-03,  -4.08439457e-03,
         1.67439022e-02,   1.51356400e-03,  -6.47820945e-03,
        -2.90974590e-03,   1.24540115e-02,   0.00000000e+00,
         0.00000000e+00,  -9.33035727e-03,   6.45103236e-02,
         2.51175887e-03,  -5.25444705e-02,  -4.82872220e-03,
         1.01013937e-01,   0.00000000e+00,   0.00000000e+00,
         4.53794006e-01,   6.90303037e-01,   1.47378787e-02,
         5.89515149e-02,   7.37518112e-02,   2.95007245e-01,
        -3.81210120e-02,  -1.52484048e-01,   1.34778131e-02,
         5.39112522e-02,   0.00000000e+00,   0.00000000e+00,
         1.45207759e-01,   5.80831037e-01,  -1.24563207e-01,
        -4.98252826e-01,   4.40397440e-02,   1.76158976e-01,
         0.00000000e+00,   0.00000000e+00,   1.03659533e-03,
         4.14638132e-03,   6.43412991e-03,   2.57365197e-02,
        -2.46719353e-03,  -9.86877411e-03,   4.74304771e-03,
         1.89721908e-02,   0.00000000e+00,   0.00000000e+00,
         2.37193561e-02,   9.48774243e-02,  -1.85452173e-02,
        -7.41808692e-02,   3.56521892e-02,   1.42608757e-01,
         0.00000000e+00,   0.00000000e+00,   1.90164284e-01,
         7.60657137e-01,   1.20739069e-01,   4.82956275e-01])
    arr = arr.reshape((nt,n))
  elif name == "AA MO 2E INTEGRALS":
    dimens = (norbtt,nrorb,noa)
    arr = np.array([  6.55742111e-01,   1.66819914e-02,   5.98050522e-01,
         2.30921180e-02,  -6.87908643e-03,   5.80333645e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.01650739e-01,  -7.17702459e-02,   2.57370402e-02,
        -1.14126951e-02,   0.00000000e+00,   5.97834840e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.16762315e-03,   0.00000000e+00,   6.14895487e-01,
         1.12400346e-02,  -1.34567699e-02,   1.97223647e-02,
         0.00000000e+00,   8.54098860e-03,   0.00000000e+00,
         6.05398906e-01,   1.55451299e-02,   8.60900372e-02,
         5.05370505e-03,   0.00000000e+00,   1.31783632e-02,
         0.00000000e+00,  -9.49729656e-03,   6.14342356e-01,
        -4.25719920e-02,   1.79732284e-02,   6.70968272e-02,
         0.00000000e+00,  -9.51276662e-03,   0.00000000e+00,
        -2.17291438e-02,  -7.84626324e-02,   3.77144724e-01,
        -8.21339103e-03,   2.06735096e-02,   2.73048568e-02,
         0.00000000e+00,   1.55884997e-02,   0.00000000e+00,
        -3.46077260e-02,   3.66622777e-02,   7.00382354e-02,
         4.15128655e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.05134324e-01,   0.00000000e+00,
         3.26603250e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.41467069e-01,
         6.72978960e-03,   2.17083165e-02,  -4.08638950e-02,
         0.00000000e+00,  -8.03463689e-02,   0.00000000e+00,
         2.64613694e-02,  -5.48069954e-02,  -9.17805268e-03,
        -8.96394047e-03,   0.00000000e+00,   5.26143880e-01,
         1.47634630e-02,   2.85301248e-02,   7.28856346e-02,
         0.00000000e+00,  -2.85884312e-02,   0.00000000e+00,
         8.12925039e-03,  -4.18500309e-02,   5.99700887e-02,
         2.01733511e-02,   0.00000000e+00,  -1.02208476e-02,
         5.38589069e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.12370095e-02,   0.00000000e+00,
        -1.10435004e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.24223398e-02,
         0.00000000e+00,   0.00000000e+00,   5.62782873e-01,
         9.58175729e-03,  -3.05793983e-03,  -9.47867624e-03,
         0.00000000e+00,  -2.47166851e-02,   0.00000000e+00,
        -1.05700869e-01,  -1.02865176e-02,   2.32640433e-03,
         3.19705941e-02,   0.00000000e+00,   2.56700513e-02,
        -1.48580799e-02,   0.00000000e+00,   5.52657573e-01,
        -4.67323525e-03,   2.49509738e-02,  -2.42454689e-02,
         0.00000000e+00,   4.49538916e-02,   0.00000000e+00,
        -6.56224336e-03,  -8.56769086e-02,   3.55498162e-02,
        -1.08729676e-02,   0.00000000e+00,  -2.40176538e-02,
        -2.60284548e-02,   0.00000000e+00,  -3.51115571e-03,
         5.79623659e-01,  -7.26074407e-02,   2.61303758e-02,
        -9.95815296e-03,   0.00000000e+00,  -2.43194546e-02,
         0.00000000e+00,  -2.11818502e-03,   4.55028961e-02,
         5.40245260e-02,   4.44432511e-03,   0.00000000e+00,
        -4.17521010e-02,  -3.24708848e-02,   0.00000000e+00,
        -5.06853728e-03,   4.67365719e-02,   5.71105983e-01,
        -3.13054789e-02,  -6.76751744e-02,   2.54249564e-02,
         0.00000000e+00,  -2.80897453e-02,   0.00000000e+00,
         2.03415726e-03,  -3.75739539e-02,   6.61753314e-03,
        -1.36487804e-02,   0.00000000e+00,  -6.04728829e-03,
        -1.11298981e-02,   0.00000000e+00,  -6.26450302e-03,
         4.36647182e-02,   1.66019370e-02,   6.14326663e-01,
         1.66819914e-02,   2.13686012e-01,   1.02684005e-02,
        -9.45346880e-03,  -6.66290845e-02,  -1.03135352e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.18400745e-01,   2.60243672e-02,   9.38297698e-02,
        -2.65362697e-03,   0.00000000e+00,  -5.75145615e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.74985722e-01,   0.00000000e+00,   1.72632304e-01,
        -1.09824668e-02,  -3.73153872e-03,   1.35418254e-01,
         0.00000000e+00,   1.20894210e-01,   0.00000000e+00,
         1.55733120e-01,   6.20285226e-02,  -1.20478516e-02,
         5.93431616e-02,   0.00000000e+00,  -1.36196420e-01,
         0.00000000e+00,   3.28969533e-02,   1.33552198e-01,
         4.85107045e-03,  -3.69978770e-02,  -4.24617298e-02,
         0.00000000e+00,   3.95304062e-02,   0.00000000e+00,
        -2.54354474e-03,  -5.99832347e-02,  -8.01723524e-02,
         1.25106174e-02,  -8.35487911e-04,  -7.16679943e-03,
         0.00000000e+00,  -1.17901904e-02,   0.00000000e+00,
        -2.04603749e-02,  -1.30665307e-03,  -4.78818217e-02,
        -1.28405113e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.94033576e-02,   0.00000000e+00,
        -6.56989396e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.47805370e-01,
         5.54738381e-04,   4.53257827e-03,   1.72343066e-02,
         0.00000000e+00,   4.74578546e-02,   0.00000000e+00,
        -6.19060014e-02,   2.14933238e-02,  -2.89926651e-03,
         2.66091683e-02,   0.00000000e+00,  -1.41402210e-01,
         2.77463654e-03,  -1.51573181e-04,  -4.92298993e-02,
         0.00000000e+00,   3.60835913e-02,   0.00000000e+00,
         3.97615061e-02,   1.16225086e-02,  -4.91489022e-02,
        -2.76601652e-02,   0.00000000e+00,  -1.78627372e-02,
        -1.21411141e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.72079706e-02,   0.00000000e+00,
        -8.59602969e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.89644952e-02,
         0.00000000e+00,   0.00000000e+00,   2.06828200e-01,
        -1.38498625e-03,   8.25560224e-03,  -3.64521869e-02,
         0.00000000e+00,  -2.90875993e-02,   0.00000000e+00,
        -7.37370590e-02,  -5.94875924e-04,  -2.71665340e-03,
         3.11431235e-02,   0.00000000e+00,   6.87437598e-02,
        -6.75931307e-02,   0.00000000e+00,   1.85029530e-01,
         8.67552910e-03,  -2.16714696e-03,  -6.43911695e-03,
         0.00000000e+00,   1.72678714e-02,   0.00000000e+00,
        -2.02906849e-04,  -1.00579402e-01,   2.61280891e-02,
        -1.27054605e-02,   0.00000000e+00,   3.10339716e-02,
         3.37753561e-02,   0.00000000e+00,   9.20416406e-03,
         2.15177661e-01,   1.88176559e-02,  -7.11843921e-02,
         1.21361545e-02,   0.00000000e+00,  -1.38536078e-02,
         0.00000000e+00,  -1.60614150e-03,  -4.16920787e-02,
        -1.84304067e-02,  -1.27066676e-02,   0.00000000e+00,
        -2.12551565e-02,  -5.73363148e-02,   0.00000000e+00,
         2.47014210e-02,  -5.45501948e-02,  -1.16374943e-01,
        -5.50166320e-02,  -4.55673937e-02,   1.29968833e-02,
         0.00000000e+00,  -2.60579431e-02,   0.00000000e+00,
         5.90293232e-03,  -2.85724070e-02,   2.49927667e-02,
        -1.18293062e-02,   0.00000000e+00,  -1.92431695e-02,
        -2.52367973e-02,   0.00000000e+00,  -9.98406829e-03,
         2.72887947e-03,   1.20821904e-01,   1.75035542e-01,
         2.30921180e-02,  -9.45346880e-03,  -1.62842301e-02,
         8.80854177e-02,  -3.75049011e-02,   5.21324614e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.57535161e-02,  -9.28478876e-03,  -5.53965385e-03,
         4.40815095e-03,   0.00000000e+00,   3.27669023e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.80074514e-02,   0.00000000e+00,  -6.68700866e-03,
         1.13468026e-02,   5.67923118e-02,  -2.78003651e-02,
         0.00000000e+00,  -1.53083336e-02,   0.00000000e+00,
        -4.99735296e-03,  -6.34531921e-04,   2.67967346e-02,
        -2.10037997e-02,   0.00000000e+00,   2.56210582e-02,
         0.00000000e+00,   7.66922092e-03,   2.25030822e-03,
         1.23268124e-02,  -1.23385857e-02,   3.67638183e-02,
         0.00000000e+00,  -7.18736771e-03,   0.00000000e+00,
        -1.21291704e-02,  -1.80636290e-02,  -2.41444183e-02,
         2.28668925e-03,   5.09962009e-03,   4.74568739e-02,
         0.00000000e+00,  -1.50368894e-03,   0.00000000e+00,
        -1.55983930e-02,  -1.02690204e-02,  -5.70328304e-03,
        -5.87247751e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.72982555e-02,   0.00000000e+00,
         1.69001161e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.45530320e-02,
        -2.23479058e-03,   3.13414506e-03,  -3.71368565e-03,
         0.00000000e+00,  -2.03058665e-02,   0.00000000e+00,
         1.70853760e-02,  -4.86599343e-03,   6.72141062e-03,
        -1.40577762e-02,   0.00000000e+00,   4.05768839e-02,
         8.82101585e-03,  -9.41707285e-03,   7.59701246e-03,
         0.00000000e+00,  -1.18931914e-02,   0.00000000e+00,
        -5.71648522e-03,  -2.15561332e-02,  -2.58723143e-03,
        -2.29261890e-03,   0.00000000e+00,  -1.58170290e-02,
         6.30389751e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.91291287e-03,   0.00000000e+00,
         9.88672860e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.65992633e-03,
         0.00000000e+00,   0.00000000e+00,  -1.48414736e-02,
         1.87332843e-03,  -5.18534779e-03,   7.39123491e-03,
         0.00000000e+00,  -2.42890237e-03,   0.00000000e+00,
         1.15666918e-02,  -5.63725022e-03,   3.19832613e-03,
         5.08317915e-03,   0.00000000e+00,  -2.10377317e-02,
         1.55215524e-02,   0.00000000e+00,  -1.07377116e-02,
        -3.17763701e-03,  -1.16430936e-03,   8.07160734e-05,
         0.00000000e+00,  -4.99036870e-03,   0.00000000e+00,
         6.94429458e-03,   1.31863860e-02,  -3.72379371e-03,
        -2.69409966e-03,   0.00000000e+00,  -1.69391047e-03,
        -2.65467219e-02,   0.00000000e+00,  -5.83932625e-03,
        -1.65000163e-02,  -8.66503140e-03,   1.34628737e-02,
        -1.86036145e-02,   0.00000000e+00,   4.33780451e-03,
         0.00000000e+00,   3.61272055e-03,   1.26364596e-02,
        -4.56711535e-03,  -8.16679330e-03,   0.00000000e+00,
         3.04555735e-02,  -5.43822059e-02,   0.00000000e+00,
        -4.63899674e-03,   2.16638300e-02,   1.83778742e-02,
         1.28300028e-02,   6.84340862e-03,   1.44305871e-03,
         0.00000000e+00,  -4.31014203e-03,   0.00000000e+00,
         2.21081379e-03,  -4.28317824e-03,  -1.07215360e-03,
         1.43677316e-03,   0.00000000e+00,  -2.27878295e-03,
         1.30688571e-02,   0.00000000e+00,   4.64013048e-02,
         1.66729495e-02,  -8.96386373e-03,  -1.78222843e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.79348395e-02,  -4.50502769e-02,   1.85487857e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.51437276e-03,   0.00000000e+00,
         7.29141757e-03,   7.01235441e-02,  -1.52860391e-02,
         0.00000000e+00,   6.55854803e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.60997659e-03,   0.00000000e+00,   2.69585484e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.91975015e-02,   0.00000000e+00,
         2.14176731e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.52995895e-03,   0.00000000e+00,   8.24546942e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.84069807e-02,   0.00000000e+00,   9.52829031e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.06850005e-02,   1.05560452e-02,
        -3.86665700e-03,   0.00000000e+00,  -3.34885413e-03,
         0.00000000e+00,   2.18854004e-03,   1.69354078e-02,
         1.86271724e-02,  -5.39630367e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.90616003e-03,   0.00000000e+00,   5.47656085e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.77102747e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.59318127e-04,   0.00000000e+00,   9.12151851e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.07655043e-02,   0.00000000e+00,
         0.00000000e+00,   5.15737533e-04,  -3.17051309e-03,
         4.81513055e-03,   0.00000000e+00,  -9.26981352e-03,
         0.00000000e+00,   1.70974536e-03,  -5.63364363e-03,
         1.17974567e-03,  -7.37297061e-04,   0.00000000e+00,
        -8.04931133e-03,  -8.53320591e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.19098008e-03,   0.00000000e+00,  -2.52343211e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.90961271e-03,   0.00000000e+00,
         0.00000000e+00,  -7.40408846e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.08966153e-03,   0.00000000e+00,   8.64166217e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.69419185e-02,   0.00000000e+00,
         0.00000000e+00,  -1.37591460e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.56793911e-03,   0.00000000e+00,
         2.90481448e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.96535099e-02,
         0.00000000e+00,   0.00000000e+00,   5.84966906e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.87477656e-03,   0.00000000e+00,   3.16044712e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.82944778e-02,   0.00000000e+00,
         0.00000000e+00,   5.27699656e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.17702459e-02,   2.60243672e-02,  -7.26689057e-03,
        -9.28478876e-03,  -5.05386446e-03,  -4.14634835e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.62826113e-02,   9.09802634e-02,  -1.28186757e-02,
         9.83036118e-03,   0.00000000e+00,  -2.18712504e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.15590394e-02,   0.00000000e+00,   3.05223935e-03,
         2.39256508e-03,   4.23601485e-02,   4.92145292e-03,
         0.00000000e+00,   1.63439008e-02,   0.00000000e+00,
         3.76508456e-03,   4.03828313e-03,  -5.90042653e-02,
         1.88495005e-02,   0.00000000e+00,  -3.28573498e-02,
         0.00000000e+00,   1.37315339e-02,  -2.59895793e-02,
         5.04879844e-03,   1.03460532e-02,  -1.24066117e-02,
         0.00000000e+00,  -5.40864878e-03,   0.00000000e+00,
         3.26222639e-03,  -4.01464964e-03,  -1.93495811e-02,
         6.94890555e-03,  -6.14714726e-03,  -6.06752615e-03,
         0.00000000e+00,  -1.98068212e-02,   0.00000000e+00,
         3.80450676e-03,  -1.09415746e-02,  -5.75000072e-03,
        -2.59931235e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.25355798e-02,   0.00000000e+00,
        -1.76858968e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.36281698e-02,
        -7.47116451e-03,   8.18524796e-03,  -3.85706431e-03,
         0.00000000e+00,   9.05213171e-03,   0.00000000e+00,
        -1.15773928e-02,   2.23124085e-02,   1.21668619e-02,
        -4.43888017e-04,   0.00000000e+00,  -2.97299196e-02,
        -6.04301255e-03,   6.54977999e-03,  -1.75327628e-02,
         0.00000000e+00,   2.26617164e-02,   0.00000000e+00,
         9.75113722e-03,   1.90221547e-02,  -8.37091255e-03,
        -7.36898102e-03,   0.00000000e+00,   4.17936339e-03,
        -3.00406357e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.38293155e-02,   0.00000000e+00,
        -1.02282325e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.26724494e-03,
         0.00000000e+00,   0.00000000e+00,   8.79910438e-03,
        -3.00434516e-03,  -3.49493195e-03,  -1.05391159e-02,
         0.00000000e+00,  -5.02971329e-03,   0.00000000e+00,
        -8.69135728e-03,   3.32717003e-05,  -1.05995766e-03,
        -2.68830455e-03,   0.00000000e+00,  -5.12691066e-03,
        -1.14000430e-02,   0.00000000e+00,   7.37781736e-03,
         4.39535796e-03,   2.79959023e-03,  -3.91692521e-03,
         0.00000000e+00,   1.05480702e-02,   0.00000000e+00,
         1.42286389e-03,  -1.35414770e-02,  -1.61704097e-03,
        -5.52858456e-05,   0.00000000e+00,   2.25117797e-02,
         1.94770806e-02,   0.00000000e+00,   1.88541316e-03,
         1.17115402e-02,   4.41327776e-03,  -1.35455128e-02,
         5.71064756e-03,   0.00000000e+00,  -1.27529713e-02,
         0.00000000e+00,   1.29041042e-03,  -2.14453825e-02,
        -1.30513777e-03,  -3.29333682e-03,   0.00000000e+00,
         5.42644501e-02,   1.70934305e-02,   0.00000000e+00,
         1.41623471e-02,  -4.22851078e-02,  -4.73910378e-02,
        -1.35515864e-02,  -1.22145335e-02,  -6.11278720e-03,
         0.00000000e+00,   7.03668517e-03,   0.00000000e+00,
        -4.19804609e-03,   1.16842060e-02,  -1.88089669e-03,
         3.24815104e-03,   0.00000000e+00,  -9.78622926e-03,
        -1.41002262e-02,   0.00000000e+00,   2.96519317e-02,
        -3.16362026e-02,   2.17345563e-02,  -1.94264369e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.29141757e-03,   5.33702431e-02,  -1.06487948e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.79314951e-03,   0.00000000e+00,
         7.32494870e-02,   5.56344985e-02,  -1.13738691e-02,
         0.00000000e+00,   2.37435923e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.25972353e-03,   0.00000000e+00,  -4.12121333e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.49363285e-02,   0.00000000e+00,
         5.98142461e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.28593496e-03,   0.00000000e+00,  -8.05446186e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.81982907e-03,   0.00000000e+00,  -9.22678567e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.40920476e-03,  -1.51841843e-02,
         6.77826846e-03,   0.00000000e+00,  -6.20050628e-03,
         0.00000000e+00,  -7.37944227e-05,  -4.42817619e-03,
        -4.31996159e-03,  -1.59309262e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.28909823e-03,   0.00000000e+00,   4.32390182e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.41181769e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.95344460e-04,   0.00000000e+00,   8.32826272e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.69016063e-03,   0.00000000e+00,
         0.00000000e+00,  -1.35326939e-02,  -1.68835143e-02,
         3.45897736e-03,   0.00000000e+00,  -4.95369240e-03,
         0.00000000e+00,   6.24445577e-04,  -7.41167780e-03,
         6.50682676e-03,  -4.20484057e-03,   0.00000000e+00,
        -6.21793467e-03,  -1.00445545e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.16750591e-03,   0.00000000e+00,   2.75627509e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.08153515e-03,   0.00000000e+00,
         0.00000000e+00,  -3.13803646e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.90943805e-03,   0.00000000e+00,   4.19447026e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.32231201e-03,   0.00000000e+00,
         0.00000000e+00,  -1.05989599e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.92165274e-03,   0.00000000e+00,
        -1.79686572e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.70396764e-02,
         0.00000000e+00,   0.00000000e+00,   3.35728598e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.81060207e-03,   0.00000000e+00,  -1.41108904e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.18794152e-02,   0.00000000e+00,
         0.00000000e+00,   7.15295248e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.12400346e-02,  -1.09824668e-02,   5.26779107e-03,
         1.13468026e-02,   4.26804792e-02,  -5.18683454e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.29706484e-03,   2.39256508e-03,   3.37702024e-02,
        -5.94982366e-03,   0.00000000e+00,   1.13126800e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.34233548e-03,   0.00000000e+00,  -3.27898210e-03,
         7.14205380e-02,   5.10853740e-02,  -1.33027834e-02,
         0.00000000e+00,   2.19307578e-02,   0.00000000e+00,
        -9.64790728e-03,  -2.46663138e-03,   1.33835698e-02,
         5.12323985e-03,   0.00000000e+00,   1.19030819e-02,
         0.00000000e+00,   7.07737159e-03,   5.05727867e-03,
        -4.93152537e-03,   3.98384727e-04,  -2.63971252e-03,
         0.00000000e+00,   3.79856252e-04,   0.00000000e+00,
        -4.29742925e-03,   6.11644840e-03,   8.61870392e-03,
        -5.05749161e-03,  -6.36579971e-03,  -8.06886178e-03,
         0.00000000e+00,   2.39080920e-03,   0.00000000e+00,
         5.83946591e-03,   7.45913165e-03,   8.99665961e-03,
         2.27687279e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.21577704e-04,   0.00000000e+00,
         2.13777071e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.57023207e-03,
         3.47743951e-03,  -1.41615721e-02,   6.99599699e-03,
         0.00000000e+00,  -3.22226945e-03,   0.00000000e+00,
         7.11282492e-03,  -4.60214869e-03,  -1.96585467e-03,
        -8.99168712e-04,   0.00000000e+00,  -1.01752753e-02,
        -1.70476777e-04,   9.11267673e-03,  -1.24105091e-03,
         0.00000000e+00,   3.29314211e-03,   0.00000000e+00,
         5.12471938e-03,  -1.48510352e-03,   1.63557748e-03,
         1.16377121e-03,   0.00000000e+00,  -2.81232233e-05,
         1.11751656e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.59568323e-03,   0.00000000e+00,
         2.60114720e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.26918302e-04,
         0.00000000e+00,   0.00000000e+00,  -3.46018323e-03,
        -1.31075367e-02,  -1.40790499e-02,   5.92907515e-03,
         0.00000000e+00,  -3.72424588e-03,   0.00000000e+00,
         4.43274191e-03,  -8.35350389e-03,   6.84518132e-03,
        -7.22708807e-03,   0.00000000e+00,  -3.71113969e-03,
        -9.32823169e-03,   0.00000000e+00,  -9.52895319e-03,
        -1.23466985e-03,   4.05777119e-04,   6.52516192e-03,
         0.00000000e+00,   7.38640331e-04,   0.00000000e+00,
         1.34881989e-03,   3.74108294e-03,   2.02771279e-03,
         2.85074394e-03,   0.00000000e+00,  -4.54970450e-03,
        -2.30616664e-03,   0.00000000e+00,  -1.14754106e-02,
        -3.37127746e-03,  -2.27485926e-03,   3.22839678e-03,
         2.58355664e-03,   0.00000000e+00,   2.66404124e-03,
         0.00000000e+00,  -1.80276302e-02,   3.01066796e-03,
         5.12222542e-03,   9.88063249e-03,   0.00000000e+00,
        -1.50813354e-02,  -1.88982164e-03,   0.00000000e+00,
         2.97802384e-02,   5.17296135e-03,   1.41631267e-02,
         2.78470868e-03,   2.80210200e-03,  -2.14667294e-03,
         0.00000000e+00,  -5.77719393e-03,   0.00000000e+00,
        -1.18656082e-02,  -1.14757242e-03,  -2.21452717e-04,
         8.34436704e-03,   0.00000000e+00,   2.15995558e-02,
        -1.77889789e-02,   0.00000000e+00,   6.71694849e-02,
         4.94166352e-03,   1.14256087e-03,  -7.88817653e-04,
         1.55451299e-02,   6.20285226e-02,   4.36766172e-03,
        -6.34531921e-04,   3.90115329e-03,  -3.05671976e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.55320050e-02,   4.03828313e-03,  -1.78175861e-02,
         8.89126244e-03,   0.00000000e+00,  -2.39924967e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.93519128e-02,   0.00000000e+00,   4.08759573e-02,
        -2.46663138e-03,   7.91540389e-03,   3.37209385e-02,
         0.00000000e+00,   3.19051522e-02,   0.00000000e+00,
         3.93814931e-02,   8.29017139e-02,   3.85060674e-02,
         7.04313084e-03,   0.00000000e+00,  -2.43346146e-02,
         0.00000000e+00,   9.03477954e-03,   3.27665499e-02,
        -1.39639375e-02,  -2.36420224e-02,  -1.76827054e-02,
         0.00000000e+00,   3.12158543e-03,   0.00000000e+00,
         5.62455973e-03,  -1.52115584e-02,  -2.72945394e-03,
         1.02497226e-02,  -2.68908021e-03,  -1.27455079e-02,
         0.00000000e+00,  -8.49747459e-03,   0.00000000e+00,
         3.38055411e-03,   8.06402519e-04,  -1.02780496e-02,
        -6.25037194e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.25518381e-02,   0.00000000e+00,
        -2.25053749e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.13539109e-02,
        -8.12373129e-03,   4.59909708e-03,   6.92130979e-03,
         0.00000000e+00,   2.64579456e-02,   0.00000000e+00,
        -2.04188688e-02,   1.33311270e-02,   4.49599177e-03,
         1.19363808e-02,   0.00000000e+00,  -3.25909978e-02,
        -6.10844646e-03,   3.51415734e-04,  -2.87196361e-02,
         0.00000000e+00,   2.00405884e-02,   0.00000000e+00,
         1.02646880e-02,   1.09483443e-02,  -1.62977605e-02,
        -1.14848213e-02,   0.00000000e+00,  -1.63293783e-03,
        -3.15400962e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.59356790e-02,   0.00000000e+00,
        -2.94759546e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.99846960e-02,
         0.00000000e+00,   0.00000000e+00,   5.04187265e-02,
        -2.40554785e-03,   2.07941171e-03,  -1.52886041e-02,
         0.00000000e+00,  -9.35976401e-03,   0.00000000e+00,
        -2.73301093e-02,   9.92730391e-04,  -1.90058192e-03,
         4.62281983e-03,   0.00000000e+00,   1.70499617e-02,
        -2.10601002e-02,   0.00000000e+00,   4.43230309e-02,
        -8.40673956e-03,  -2.30055396e-02,   3.55731413e-03,
         0.00000000e+00,  -2.60704618e-03,   0.00000000e+00,
         1.41006178e-03,  -4.70291650e-02,   1.37087707e-02,
        -5.86143739e-03,   0.00000000e+00,   1.89239160e-03,
        -4.96579703e-04,   0.00000000e+00,  -2.11642554e-04,
         2.70784101e-02,   1.58045635e-02,  -3.06048343e-02,
         7.61390672e-03,   0.00000000e+00,  -1.49716988e-02,
         0.00000000e+00,  -4.80188566e-05,  -2.49436976e-02,
        -3.94879112e-03,  -7.76130008e-03,   0.00000000e+00,
         1.17769719e-02,   2.96429245e-03,   0.00000000e+00,
         7.73948893e-03,   1.04559536e-02,  -3.56427044e-02,
        -2.39208567e-02,  -1.76988672e-02,  -1.43882594e-03,
         0.00000000e+00,   4.59791987e-03,   0.00000000e+00,
        -5.86944324e-05,  -3.02160531e-02,   1.43210959e-02,
        -4.49955252e-03,   0.00000000e+00,  -6.50250806e-03,
        -9.15272346e-03,   0.00000000e+00,  -6.91012033e-04,
         5.74389919e-02,   3.63331431e-02,   6.73863346e-02,
        -4.25719920e-02,   4.85107045e-03,  -4.36475324e-02,
         1.23268124e-02,  -1.51479624e-02,  -1.77534352e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.90319273e-02,   5.04879844e-03,   1.01715906e-02,
        -1.17973232e-03,   0.00000000e+00,  -3.88121089e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.39370272e-03,   0.00000000e+00,  -3.59107430e-02,
        -4.93152537e-03,   2.67536127e-03,  -3.86766606e-03,
         0.00000000e+00,   2.14458079e-03,   0.00000000e+00,
        -3.23484078e-02,  -1.39639375e-02,  -1.86929197e-02,
        -5.95270817e-03,   0.00000000e+00,  -7.73281035e-03,
         0.00000000e+00,   6.49261928e-03,  -3.46734474e-02,
         2.03522374e-02,  -1.34519720e-02,  -1.19610450e-02,
         0.00000000e+00,   5.92091987e-03,   0.00000000e+00,
         2.94840960e-03,   9.05614540e-03,  -7.49876848e-03,
         9.41137518e-03,  -1.32331930e-02,  -6.45273074e-03,
         0.00000000e+00,   1.14123635e-03,   0.00000000e+00,
         5.46181205e-03,  -4.39857379e-03,  -2.99864826e-03,
        -7.55006649e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.94818769e-02,   0.00000000e+00,
        -7.06557593e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.20390995e-02,
        -2.27970548e-03,  -1.77749374e-03,   6.66431124e-03,
         0.00000000e+00,   1.42601016e-02,   0.00000000e+00,
        -5.27791299e-03,   8.81193883e-03,  -1.34644267e-04,
         4.29559491e-03,   0.00000000e+00,  -3.07717347e-02,
         5.21654585e-03,  -1.25879704e-02,  -1.31440293e-02,
         0.00000000e+00,   3.41044012e-03,   0.00000000e+00,
        -3.31515783e-04,  -4.78727203e-05,  -1.38714163e-02,
        -5.11782794e-03,   0.00000000e+00,  -5.41351053e-03,
        -2.49358488e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.74027844e-03,   0.00000000e+00,
         1.58171588e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.32451514e-03,
         0.00000000e+00,   0.00000000e+00,  -2.83388398e-02,
        -3.90344217e-04,   8.64375368e-04,   3.22486433e-03,
         0.00000000e+00,   1.87673889e-03,   0.00000000e+00,
         1.58646541e-02,  -1.31897115e-04,  -9.83124024e-04,
        -5.20976553e-03,   0.00000000e+00,  -3.05822039e-03,
         4.60772419e-03,   0.00000000e+00,  -2.47279326e-02,
         6.58136486e-03,   2.63450580e-03,   3.31522636e-04,
         0.00000000e+00,  -6.25598177e-03,   0.00000000e+00,
         2.77818557e-03,   1.36690857e-02,  -6.10934577e-03,
         1.20192178e-03,   0.00000000e+00,   6.03806257e-03,
         6.41976713e-04,   0.00000000e+00,   9.69600610e-04,
        -2.50206917e-02,   1.47903937e-02,  -9.91216396e-03,
        -8.29128269e-03,   0.00000000e+00,   5.64905429e-03,
         0.00000000e+00,   4.07698968e-03,  -3.14924397e-03,
        -1.62786759e-02,  -7.01324198e-03,   0.00000000e+00,
         3.19858568e-03,  -1.74422736e-02,   0.00000000e+00,
        -1.92056043e-03,  -9.02130419e-03,  -3.79474071e-02,
         5.71450904e-03,   1.36378149e-02,  -4.07663745e-04,
         0.00000000e+00,  -1.66571592e-03,   0.00000000e+00,
         8.32470147e-04,   1.17084689e-02,  -6.51122995e-04,
         4.81676344e-03,   0.00000000e+00,   3.97126642e-04,
         6.91298349e-03,   0.00000000e+00,   1.46980053e-03,
        -1.58070952e-02,  -9.97325279e-04,  -3.69170579e-02,
        -8.21339103e-03,   1.25106174e-02,  -5.56173372e-03,
         2.28668925e-03,  -2.47946765e-03,   1.04128658e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.04736740e-02,   6.94890555e-03,  -1.27952280e-03,
        -1.00301278e-03,   0.00000000e+00,  -1.75374175e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.27103224e-02,   0.00000000e+00,   4.27119652e-04,
        -5.05749161e-03,  -2.46825652e-03,  -2.88298977e-04,
         0.00000000e+00,   7.02375029e-03,   0.00000000e+00,
         4.76788581e-03,   1.02497226e-02,  -4.04723050e-03,
        -4.45941450e-03,   0.00000000e+00,  -1.01991904e-02,
         0.00000000e+00,   7.34761505e-03,   6.23342316e-04,
         9.41137518e-03,  -1.39352102e-02,  -1.12573099e-02,
         0.00000000e+00,   3.77820166e-03,   0.00000000e+00,
         4.39201118e-03,   1.48550072e-03,   1.05765070e-02,
         1.79231245e-02,  -1.95012125e-02,  -2.16048190e-02,
         0.00000000e+00,   1.81209711e-04,   0.00000000e+00,
         8.96108700e-03,   3.25787767e-03,   1.29200559e-02,
         4.51327596e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.78061532e-03,   0.00000000e+00,
        -7.34976616e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.09037117e-02,
        -1.37666581e-03,   2.49682526e-03,  -1.12038831e-03,
         0.00000000e+00,   7.67545115e-03,   0.00000000e+00,
        -5.77050164e-03,   7.29495148e-03,   2.37058386e-03,
         6.92747624e-03,   0.00000000e+00,  -1.59414320e-02,
         1.76313772e-03,  -6.24510105e-03,  -8.45715587e-03,
         0.00000000e+00,   4.76259463e-03,   0.00000000e+00,
         1.87447310e-03,   5.30192547e-04,  -7.25151583e-03,
        -1.23687528e-03,   0.00000000e+00,  -5.42884794e-03,
        -6.92003027e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.95035690e-03,   0.00000000e+00,
        -5.46259722e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.23784859e-03,
         0.00000000e+00,   0.00000000e+00,   4.39907592e-03,
         2.82001688e-03,   4.80810095e-03,  -1.55406533e-03,
         0.00000000e+00,  -2.79122722e-03,   0.00000000e+00,
        -5.80523197e-03,   1.94074826e-04,  -2.26554701e-03,
        -5.73186360e-03,   0.00000000e+00,   1.31193583e-03,
        -7.89321945e-04,   0.00000000e+00,   6.17881810e-03,
         2.08237493e-05,  -2.64528346e-03,  -1.64273539e-03,
         0.00000000e+00,  -5.34955193e-05,   0.00000000e+00,
         1.71552720e-03,  -7.79666537e-03,   1.05549007e-03,
         6.52910995e-04,   0.00000000e+00,   5.90484580e-03,
        -4.41275589e-04,   0.00000000e+00,   1.80978836e-03,
         4.43275735e-03,   5.65794555e-03,  -1.00189115e-02,
        -4.42526090e-03,   0.00000000e+00,  -1.24192049e-03,
         0.00000000e+00,   5.33979887e-03,  -6.77749713e-03,
        -9.87102657e-03,  -3.99472840e-03,   0.00000000e+00,
         7.23301148e-03,  -8.48565984e-03,   0.00000000e+00,
        -8.86984747e-04,  -3.80929014e-03,  -1.86904074e-02,
        -5.68473980e-03,  -2.92817296e-03,   1.47375830e-03,
         0.00000000e+00,   1.49508859e-03,   0.00000000e+00,
         4.81918459e-03,  -2.14130474e-03,   4.38192157e-03,
         2.93774897e-03,   0.00000000e+00,  -3.01287198e-03,
         1.89699573e-03,   0.00000000e+00,  -1.96117534e-03,
         2.86231730e-03,   7.71694583e-03,   3.91702008e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.06850005e-02,   1.08590667e-02,  -3.26489029e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.92921822e-03,   0.00000000e+00,
         5.40920476e-03,  -8.58666148e-03,   3.62724485e-03,
         0.00000000e+00,  -2.53656619e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.55883482e-03,   0.00000000e+00,  -3.98202808e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.81432240e-03,   0.00000000e+00,
        -1.97181982e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.59567407e-03,   0.00000000e+00,  -3.07310149e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.17500388e-04,   0.00000000e+00,  -1.22086390e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.24472989e-02,  -1.75742252e-02,
         5.37807858e-03,   0.00000000e+00,  -1.76622938e-04,
         0.00000000e+00,  -1.56784394e-03,  -6.39111962e-03,
         2.93573660e-04,  -7.56458713e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.50391303e-04,   0.00000000e+00,  -2.67517204e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.01838517e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.73403713e-03,   0.00000000e+00,  -8.66188069e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.26144503e-04,   0.00000000e+00,
         0.00000000e+00,   3.50926567e-03,   8.84287333e-03,
        -1.15034060e-03,   0.00000000e+00,   1.32055980e-04,
         0.00000000e+00,   2.16097753e-04,   2.76818053e-03,
        -6.14237929e-04,   1.15503198e-03,   0.00000000e+00,
        -9.56968824e-04,  -1.29654338e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.58455658e-03,   0.00000000e+00,   1.21895767e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.27432224e-03,   0.00000000e+00,
         0.00000000e+00,  -4.40134556e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.76005146e-03,   0.00000000e+00,  -2.40066185e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.80874669e-03,   0.00000000e+00,
         0.00000000e+00,   4.25352827e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.88404362e-02,   0.00000000e+00,
        -9.50756460e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.26397817e-03,
         0.00000000e+00,   0.00000000e+00,   5.36386986e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.51294986e-03,   0.00000000e+00,   1.22582995e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.15335818e-04,   0.00000000e+00,
         0.00000000e+00,   3.77310133e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.72978960e-03,   5.54738381e-04,   4.77561636e-03,
        -2.23479058e-03,   1.50274748e-03,   2.68832728e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.50051276e-04,  -7.47116451e-03,   9.57776361e-03,
        -6.04749155e-03,   0.00000000e+00,   2.71017297e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.98485207e-03,   0.00000000e+00,   7.04013806e-03,
         3.47743951e-03,  -8.08894628e-03,   5.47301554e-03,
         0.00000000e+00,   3.73560100e-04,   0.00000000e+00,
         6.67615501e-03,  -8.12373129e-03,   3.51939075e-03,
         1.27020707e-03,   0.00000000e+00,   6.45117575e-03,
         0.00000000e+00,  -1.27145712e-03,   9.92123355e-03,
        -2.27970548e-03,   2.06731577e-03,   4.63749432e-03,
         0.00000000e+00,   4.03414899e-03,   0.00000000e+00,
        -2.82554832e-03,   5.09889012e-05,  -3.25116975e-03,
        -1.37666581e-03,   4.17561138e-03,  -5.74006356e-04,
         0.00000000e+00,  -1.25949431e-04,   0.00000000e+00,
        -2.66837027e-03,   3.17409291e-03,   2.53245194e-03,
        -5.35538199e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.30605235e-03,   0.00000000e+00,
        -1.42909348e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.47763451e-04,
         2.08193596e-02,  -1.39149648e-02,   1.66298512e-03,
         0.00000000e+00,  -1.37037920e-03,   0.00000000e+00,
        -5.01054787e-03,  -4.44884695e-03,   6.91638118e-04,
        -5.86016728e-03,   0.00000000e+00,   1.00198703e-03,
         1.23418046e-04,  -4.41510282e-04,  -1.14670772e-04,
         0.00000000e+00,  -8.90933019e-04,   0.00000000e+00,
         1.24308391e-03,  -1.22799172e-03,   8.06424678e-04,
        -2.33449156e-03,   0.00000000e+00,   2.61980939e-03,
         1.15286270e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.84368695e-03,   0.00000000e+00,
        -8.97344751e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.76999579e-05,
         0.00000000e+00,   0.00000000e+00,   6.12338279e-03,
         4.78382673e-03,   7.91793959e-03,  -5.53065027e-03,
         0.00000000e+00,  -4.84551651e-03,   0.00000000e+00,
        -6.96021138e-03,   9.01042004e-04,  -1.94724501e-04,
         3.07857361e-04,   0.00000000e+00,   1.26434836e-03,
         1.07201007e-03,   0.00000000e+00,   6.52198965e-03,
        -3.78705308e-03,   4.50397655e-03,  -2.40070777e-04,
         0.00000000e+00,   8.72141516e-03,   0.00000000e+00,
        -2.46597263e-03,  -4.56234897e-03,   2.95796483e-03,
         2.68299936e-03,   0.00000000e+00,  -9.25600238e-06,
        -1.13991458e-03,   0.00000000e+00,   2.86135669e-03,
         6.68739106e-03,  -1.17288569e-02,   1.80301233e-03,
         9.46483494e-03,   0.00000000e+00,   2.01262763e-02,
         0.00000000e+00,  -7.82232745e-03,   1.12017697e-02,
         1.88255109e-03,   5.96044219e-03,   0.00000000e+00,
        -8.43747659e-03,  -1.16049142e-03,   0.00000000e+00,
         4.94015685e-04,   7.77540922e-04,   2.81197370e-03,
        -2.10510294e-03,  -7.55610372e-03,   1.34536832e-03,
         0.00000000e+00,  -4.36385015e-03,   0.00000000e+00,
         1.15168551e-02,  -4.30292661e-03,   1.11403500e-03,
        -2.68279216e-03,   0.00000000e+00,   2.37419500e-03,
         2.07829491e-03,   0.00000000e+00,  -6.50607219e-04,
        -3.22760186e-03,   2.83704059e-03,   4.13398348e-03,
         1.47634630e-02,   2.77463654e-03,   8.90573160e-03,
         8.82101585e-03,  -9.07739068e-03,   1.36666287e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.25787759e-02,  -6.04301255e-03,   7.38335044e-03,
        -3.07321590e-03,   0.00000000e+00,   1.98345372e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.36608410e-04,   0.00000000e+00,   1.64383482e-02,
        -1.70476777e-04,   4.11278732e-03,  -7.39843507e-04,
         0.00000000e+00,   2.26879301e-03,   0.00000000e+00,
         1.52144838e-02,  -6.10844646e-03,   1.86771110e-03,
        -8.48492652e-03,   0.00000000e+00,   5.59367959e-03,
         0.00000000e+00,  -8.99714630e-04,   1.80759720e-02,
         5.21654585e-03,  -7.27396776e-03,  -3.09552964e-03,
         0.00000000e+00,   8.49816770e-04,   0.00000000e+00,
         4.69337847e-04,  -2.77636946e-03,   7.01472954e-03,
         1.76313772e-03,  -3.77828486e-03,  -9.11903520e-04,
         0.00000000e+00,   8.41129347e-04,   0.00000000e+00,
        -1.48421792e-03,  -5.27565005e-04,  -7.17063927e-05,
         1.23412202e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.02229781e-02,   0.00000000e+00,
         7.44978467e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.06793466e-02,
         1.23418046e-04,  -4.59448463e-04,  -6.45410388e-03,
         0.00000000e+00,  -4.85017162e-03,   0.00000000e+00,
         1.99174044e-03,  -2.56350555e-03,  -2.10495755e-03,
        -3.63392810e-03,   0.00000000e+00,   1.40388883e-02,
         2.28798567e-02,  -1.15597607e-02,   1.60561022e-02,
         0.00000000e+00,   1.80376919e-05,   0.00000000e+00,
         1.86100496e-03,  -7.77543249e-03,   4.73338186e-03,
         1.09723448e-03,   0.00000000e+00,   6.92691917e-03,
         7.83139672e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.61779499e-03,   0.00000000e+00,
        -1.28946655e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.24783129e-04,
         0.00000000e+00,   0.00000000e+00,   1.30943825e-02,
        -1.60548920e-03,  -7.88281292e-03,   2.16650547e-03,
         0.00000000e+00,  -5.16796250e-03,   0.00000000e+00,
        -1.29281149e-02,  -4.06972359e-03,   2.93575543e-03,
         1.90365637e-03,   0.00000000e+00,   2.55706041e-03,
        -2.31498887e-04,   0.00000000e+00,   1.19314684e-02,
        -3.23994852e-03,   4.11553105e-03,  -9.14282406e-03,
         0.00000000e+00,   7.99621554e-03,   0.00000000e+00,
         2.64509726e-05,  -7.87389457e-03,   2.44367474e-04,
        -2.14748982e-03,   0.00000000e+00,  -1.53312441e-03,
        -8.61908534e-04,   0.00000000e+00,  -3.23947510e-03,
         1.41107630e-02,  -8.43062498e-03,  -6.05886604e-03,
        -2.03537808e-02,   0.00000000e+00,   6.43316669e-03,
         0.00000000e+00,  -6.65163413e-04,   8.66854557e-03,
        -1.02894637e-02,  -6.35882069e-03,   0.00000000e+00,
        -1.51012864e-03,  -1.17265102e-02,   0.00000000e+00,
        -5.63190087e-04,   2.26262788e-03,   1.19402228e-02,
        -4.33862325e-03,  -8.33860270e-03,   4.83688523e-03,
         0.00000000e+00,  -7.87727873e-03,   0.00000000e+00,
        -9.14897355e-03,  -5.13401317e-03,   4.65885784e-03,
         1.95250161e-03,   0.00000000e+00,   2.31554594e-03,
         3.04759511e-03,   0.00000000e+00,   5.35296739e-04,
        -3.03537785e-03,   2.06730751e-03,   1.23287681e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.15737533e-04,  -8.29882484e-03,   4.17282019e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.56394842e-03,   0.00000000e+00,
        -1.35326939e-02,  -1.25652281e-02,   2.19644145e-03,
         0.00000000e+00,  -3.87437812e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.29702009e-04,   0.00000000e+00,   5.48490007e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.14737790e-03,   0.00000000e+00,
        -2.75627025e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.36904276e-03,   0.00000000e+00,   2.81935005e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.52212687e-03,   0.00000000e+00,  -1.46805923e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.50926567e-03,   7.02076342e-03,
        -7.56018466e-04,   0.00000000e+00,  -1.05753060e-04,
         0.00000000e+00,   2.37278144e-04,   2.77773693e-03,
         4.92867453e-04,   3.82132224e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.91625584e-03,   0.00000000e+00,  -2.97513283e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.85827223e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.20475810e-03,   0.00000000e+00,  -4.61276651e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.05269488e-03,   0.00000000e+00,
         0.00000000e+00,   2.23016599e-02,   2.18657140e-02,
        -4.09163011e-03,   0.00000000e+00,   6.11492588e-03,
         0.00000000e+00,  -8.17958902e-04,   4.03760292e-03,
        -1.57317718e-03,   4.05286628e-04,   0.00000000e+00,
         1.39255715e-03,   1.99886779e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.91919477e-04,   0.00000000e+00,  -1.51299708e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.88635673e-04,   0.00000000e+00,
         0.00000000e+00,   6.09852293e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.13447199e-04,   0.00000000e+00,  -2.83645541e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.12618984e-03,   0.00000000e+00,
         0.00000000e+00,   7.60854167e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.66075326e-03,   0.00000000e+00,
         1.40365884e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.43351796e-03,
         0.00000000e+00,   0.00000000e+00,  -5.79478233e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.41586628e-02,   0.00000000e+00,   2.97454802e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.44031607e-03,   0.00000000e+00,
         0.00000000e+00,  -1.20058375e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.58175729e-03,  -1.38498625e-03,   9.12066598e-03,
         1.87332843e-03,  -7.96715102e-03,   1.44608366e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.38948040e-02,  -3.00434516e-03,  -6.20803679e-03,
        -2.54394783e-03,   0.00000000e+00,   8.05056973e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.67616403e-03,   0.00000000e+00,   9.38534380e-03,
        -1.31075367e-02,  -1.08655326e-02,   1.91078263e-03,
         0.00000000e+00,  -5.52880179e-03,   0.00000000e+00,
         9.49331508e-03,  -2.40554785e-03,   8.61930215e-04,
        -3.60930043e-03,   0.00000000e+00,   9.90165490e-04,
         0.00000000e+00,  -4.50135538e-03,   8.30076405e-03,
        -3.90344217e-04,   1.67589107e-03,   6.45412985e-03,
         0.00000000e+00,  -1.12668763e-03,   0.00000000e+00,
         1.82785309e-03,  -3.63451539e-03,   7.44300142e-04,
         2.82001688e-03,   4.60258544e-03,   3.97487415e-03,
         0.00000000e+00,  -1.29027568e-03,   0.00000000e+00,
        -4.50969347e-03,   2.07951559e-04,   9.87686012e-04,
        -2.81950086e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.44022594e-03,   0.00000000e+00,
         3.54044258e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.26539701e-02,
         4.78382673e-03,   7.49198378e-03,  -6.85431523e-03,
         0.00000000e+00,  -8.46564190e-03,   0.00000000e+00,
         5.41424698e-04,  -1.13182657e-03,   5.86240375e-04,
        -2.67819607e-03,   0.00000000e+00,   9.59924532e-03,
        -1.60548920e-03,  -5.42860885e-03,   6.08135541e-03,
         0.00000000e+00,  -4.84047897e-03,   0.00000000e+00,
        -4.79850616e-03,  -5.12262120e-03,   4.69655022e-03,
         1.88430069e-03,   0.00000000e+00,   7.45914715e-04,
         1.31951909e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.76298746e-04,   0.00000000e+00,
        -5.23818457e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.22834135e-04,
         0.00000000e+00,   0.00000000e+00,   6.73349714e-03,
         2.11957586e-02,   1.92989582e-02,  -4.02972450e-03,
         0.00000000e+00,   4.90062274e-03,   0.00000000e+00,
        -7.50172505e-03,   3.03639082e-03,  -1.33397844e-04,
         2.42841009e-03,   0.00000000e+00,   1.25340064e-03,
         2.59931412e-03,   0.00000000e+00,   7.56471615e-03,
        -1.34749836e-03,   2.09663804e-03,  -2.73326741e-03,
         0.00000000e+00,   2.76858608e-03,   0.00000000e+00,
        -3.33521280e-03,  -2.77950527e-03,   7.67750369e-04,
         4.69476466e-04,   0.00000000e+00,   1.74625496e-03,
        -3.84765380e-03,   0.00000000e+00,  -7.88602662e-04,
         7.81522598e-03,  -5.40991155e-03,   4.96063460e-03,
        -3.22013818e-04,   0.00000000e+00,   4.29619911e-03,
         0.00000000e+00,   1.28337525e-02,   3.62310260e-03,
         7.12134959e-04,  -1.25445960e-03,   0.00000000e+00,
         2.54088229e-03,  -1.61395904e-03,   0.00000000e+00,
        -6.89017073e-03,   4.22096783e-04,   9.30958342e-03,
        -1.82458594e-03,  -4.68077970e-03,   1.25446275e-02,
         0.00000000e+00,   9.14200088e-03,   0.00000000e+00,
         2.72732653e-02,  -9.46653169e-04,  -1.10290202e-04,
        -2.68385534e-03,   0.00000000e+00,  -4.50029506e-03,
         3.85445846e-03,   0.00000000e+00,  -1.11023725e-02,
        -4.50132788e-04,  -1.44487854e-03,   7.20737049e-03,
        -4.67323525e-03,   8.67552910e-03,  -3.05825011e-03,
        -3.17763701e-03,  -4.00473065e-03,  -6.63966527e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.12313211e-02,   4.39535796e-03,   8.28962813e-03,
        -3.01919037e-03,   0.00000000e+00,  -1.12485641e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.11094493e-02,   0.00000000e+00,   3.12068213e-03,
        -1.23466985e-03,  -1.31615558e-03,   8.13437086e-03,
         0.00000000e+00,   5.72685861e-03,   0.00000000e+00,
         3.13285873e-03,  -8.40673956e-03,  -1.83656785e-02,
         5.10742937e-03,   0.00000000e+00,  -1.07869707e-02,
         0.00000000e+00,   2.51539950e-03,  -8.68950283e-03,
         6.58136486e-03,   5.79099080e-04,  -6.21383289e-03,
         0.00000000e+00,   1.69758786e-03,   0.00000000e+00,
         1.89543231e-03,   3.26899705e-03,  -2.45553743e-03,
         2.08237493e-05,  -3.19419168e-03,  -3.90759891e-03,
         0.00000000e+00,  -4.98520945e-04,   0.00000000e+00,
         2.26817174e-03,  -2.53831553e-03,  -2.55110993e-03,
        -3.20960856e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.67930463e-02,   0.00000000e+00,
        -7.55190308e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.19386702e-02,
        -3.78705308e-03,   2.19130184e-03,   5.29933408e-03,
         0.00000000e+00,   1.36936025e-02,   0.00000000e+00,
        -6.83806657e-03,   2.33914906e-03,   1.37226884e-03,
         5.71573663e-03,   0.00000000e+00,  -9.93568111e-03,
        -3.23994852e-03,   4.52462334e-04,  -1.47149564e-02,
         0.00000000e+00,   7.37214682e-03,   0.00000000e+00,
         2.07927784e-03,   2.81255863e-05,  -6.64380841e-03,
        -4.94024599e-03,   0.00000000e+00,  -9.88726098e-04,
        -8.90685823e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.93453363e-04,   0.00000000e+00,
         4.41821929e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.46008423e-03,
         0.00000000e+00,   0.00000000e+00,   5.06851782e-03,
        -1.34749836e-03,   1.45165541e-03,  -2.69174031e-03,
         0.00000000e+00,   6.91814836e-04,   0.00000000e+00,
         2.48849405e-04,  -4.56617231e-04,  -6.86253509e-04,
         1.08582558e-04,   0.00000000e+00,   4.44828685e-03,
        -4.34685618e-03,   0.00000000e+00,   3.49581746e-03,
         2.57475596e-02,   1.95504256e-02,  -2.46364780e-03,
         0.00000000e+00,   3.52762302e-03,   0.00000000e+00,
        -2.15832867e-04,  -4.88537953e-03,   1.64688380e-04,
         3.97564351e-04,   0.00000000e+00,   1.44735606e-03,
         2.24469528e-03,   0.00000000e+00,   9.34562942e-04,
         4.49961710e-03,   1.36274574e-02,  -1.08309906e-02,
         5.48957471e-03,   0.00000000e+00,  -1.06244676e-02,
         0.00000000e+00,   1.66429565e-03,   4.56408727e-03,
        -5.02089682e-03,  -2.55428484e-03,   0.00000000e+00,
        -1.52468074e-03,  -1.45352216e-03,   0.00000000e+00,
         5.94711940e-04,  -8.19792635e-03,  -9.58608116e-03,
         5.81033216e-03,   5.58903907e-03,   4.01684493e-03,
         0.00000000e+00,  -9.27657506e-03,   0.00000000e+00,
         1.19844305e-03,   2.83857107e-02,  -6.85662048e-03,
         2.16045216e-03,   0.00000000e+00,  -1.64788778e-03,
        -2.52988293e-03,   0.00000000e+00,  -1.42823155e-03,
        -2.04396159e-02,   4.99222251e-03,  -1.55557260e-03,
        -7.26074407e-02,   1.88176559e-02,  -7.48439207e-02,
        -8.66503140e-03,   2.34657539e-03,  -7.97560719e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.65811123e-02,   4.41327776e-03,   2.30013494e-03,
         2.33164553e-03,   0.00000000e+00,  -8.34729675e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.99658445e-02,   0.00000000e+00,  -6.58040423e-02,
        -2.27485926e-03,  -3.02510853e-03,   1.10844674e-02,
         0.00000000e+00,   1.28959404e-02,   0.00000000e+00,
        -6.53856615e-02,   1.58045635e-02,  -1.59034229e-02,
         4.53439961e-03,   0.00000000e+00,  -2.18748089e-02,
         0.00000000e+00,   5.76737447e-03,  -6.58842440e-02,
         1.47903937e-02,  -1.83447183e-02,  -3.08799244e-02,
         0.00000000e+00,   9.78126803e-03,   0.00000000e+00,
         9.26793350e-03,   1.47370686e-02,  -2.82410925e-02,
         5.65794555e-03,  -1.15370897e-02,  -2.03618803e-02,
         0.00000000e+00,  -2.38751874e-03,   0.00000000e+00,
         1.61293788e-02,  -7.15538119e-03,  -1.81086408e-02,
        -2.13645783e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.43339065e-02,   0.00000000e+00,
        -2.75084412e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.04659680e-02,
        -1.17288569e-02,  -6.90319307e-03,   2.80538052e-02,
         0.00000000e+00,   5.69762716e-02,   0.00000000e+00,
        -2.39691672e-02,   2.65513983e-02,   1.48189813e-04,
         1.59565464e-02,   0.00000000e+00,  -8.00675415e-02,
        -8.43062498e-03,  -1.75258438e-02,  -5.39195966e-02,
         0.00000000e+00,   2.13326743e-02,   0.00000000e+00,
         1.58980231e-03,   2.04082150e-02,  -3.32489520e-02,
        -1.88168230e-02,   0.00000000e+00,  -3.28646719e-04,
        -8.34634294e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.53850693e-03,   0.00000000e+00,
         4.05497893e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.89260338e-03,
         0.00000000e+00,   0.00000000e+00,  -4.81075558e-02,
        -5.40991155e-03,   3.66965304e-03,  -1.42772740e-03,
         0.00000000e+00,   9.12701680e-03,   0.00000000e+00,
         3.87386555e-02,   3.53334394e-03,  -3.91491553e-03,
        -9.38230923e-03,   0.00000000e+00,   3.52642797e-03,
        -3.72688239e-03,   0.00000000e+00,  -4.91059526e-02,
         1.36274574e-02,  -1.25372527e-02,   1.35412544e-02,
         0.00000000e+00,  -2.70417144e-02,   0.00000000e+00,
         3.67557540e-03,   2.08220949e-02,  -7.29113157e-03,
         4.04115304e-04,   0.00000000e+00,   6.04307469e-03,
         8.32978654e-03,   0.00000000e+00,  -1.15889975e-04,
        -5.55963062e-02,   5.82581917e-02,  -3.62557276e-02,
         3.00034092e-03,   0.00000000e+00,   7.13335512e-04,
         0.00000000e+00,   3.89186675e-03,  -2.33923157e-02,
        -1.82648882e-02,  -1.33414458e-02,   0.00000000e+00,
        -2.71534401e-03,   9.44648889e-04,   0.00000000e+00,
         4.13160165e-03,  -1.03873509e-02,  -8.18286303e-02,
         7.28753989e-03,   3.61373891e-02,  -5.96283348e-03,
         0.00000000e+00,   7.66687416e-03,   0.00000000e+00,
         4.11661905e-04,   1.63895825e-02,  -5.47705215e-04,
         5.56673741e-03,   0.00000000e+00,   3.79257526e-03,
         2.15681219e-03,   0.00000000e+00,  -4.08318470e-03,
         1.40845939e-03,   5.28879721e-03,  -5.26752262e-02,
        -3.13054789e-02,  -5.50166320e-02,  -4.01538138e-02,
         1.28300028e-02,   1.19564000e-02,   1.92502086e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.46738852e-05,  -1.35515864e-02,  -2.26874664e-02,
        -3.13525061e-03,   0.00000000e+00,  -8.47349685e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.39153921e-02,   0.00000000e+00,  -8.03824142e-02,
         2.78470868e-03,   3.66145138e-03,  -3.38294326e-02,
         0.00000000e+00,  -3.33768876e-02,   0.00000000e+00,
        -7.46197803e-02,  -2.39208567e-02,  -3.54973767e-03,
        -1.80264557e-02,   0.00000000e+00,   3.82267333e-02,
         0.00000000e+00,  -7.69605241e-03,  -7.25347412e-02,
         5.71450904e-03,   1.04001814e-02,   1.12797416e-02,
         0.00000000e+00,  -1.09668212e-02,   0.00000000e+00,
         3.56766593e-04,   2.12626225e-02,  -5.54715954e-04,
        -5.68473980e-03,  -9.33575985e-04,   9.13112871e-03,
         0.00000000e+00,   5.72232680e-03,   0.00000000e+00,
         9.20796279e-03,  -4.84490103e-03,   6.39714837e-03,
         2.86474168e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.13728715e-02,   0.00000000e+00,
         2.83891530e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.28067130e-02,
        -2.10510294e-03,  -5.42751184e-03,   1.40622680e-03,
         0.00000000e+00,  -1.16283197e-02,   0.00000000e+00,
         2.78048247e-02,  -5.01871136e-03,   4.75737783e-04,
        -7.39795926e-03,   0.00000000e+00,   1.47041573e-02,
        -4.33862325e-03,  -6.15929627e-03,   9.96973167e-03,
         0.00000000e+00,  -1.82826787e-02,   0.00000000e+00,
        -2.20278994e-02,  -4.66111924e-03,   9.52797781e-03,
         7.63595498e-03,   0.00000000e+00,   6.13458131e-03,
         1.46044419e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.78604346e-02,   0.00000000e+00,
         7.82682682e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.05873673e-02,
         0.00000000e+00,   0.00000000e+00,  -9.01557761e-02,
        -1.82458594e-03,  -3.52462263e-03,   3.09739347e-02,
         0.00000000e+00,   2.61970709e-02,   0.00000000e+00,
         7.23384814e-02,   1.77403359e-03,  -7.90653974e-06,
        -1.02163219e-02,   0.00000000e+00,  -2.17716455e-02,
         2.25127513e-02,   0.00000000e+00,  -8.26173314e-02,
         5.81033216e-03,  -3.71832147e-03,   1.34636323e-02,
         0.00000000e+00,  -2.76467847e-02,   0.00000000e+00,
         3.41675326e-03,   7.68669702e-02,  -2.05126843e-02,
         5.53909358e-03,   0.00000000e+00,  -9.76200302e-03,
        -1.31605084e-02,   0.00000000e+00,  -2.70272289e-03,
        -1.03845134e-01,   7.28753989e-03,   3.64831713e-02,
        -4.38509243e-03,   0.00000000e+00,   1.10610267e-02,
         0.00000000e+00,   4.42973321e-03,   1.27404124e-02,
         4.45554255e-04,   4.02142154e-03,   0.00000000e+00,
         4.61972367e-03,   7.73003620e-03,   0.00000000e+00,
        -7.75594569e-03,   1.44520398e-02,   1.76515321e-03,
         5.87496650e-02,   4.99883595e-02,  -7.89378953e-03,
         0.00000000e+00,   9.86880543e-03,   0.00000000e+00,
        -2.14866987e-03,   2.68575200e-02,  -1.20829092e-02,
         4.38970950e-03,   0.00000000e+00,   6.21392086e-03,
         1.03404613e-02,   0.00000000e+00,   4.74625605e-03,
        -9.51394569e-03,  -3.66040197e-02,  -8.57413653e-02,
         1.66819914e-02,   2.13686012e-01,   1.02684005e-02,
        -9.45346880e-03,  -6.66290845e-02,  -1.03135352e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.18400745e-01,   2.60243672e-02,   9.38297698e-02,
        -2.65362697e-03,   0.00000000e+00,  -5.75145615e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.74985722e-01,   0.00000000e+00,   1.72632304e-01,
        -1.09824668e-02,  -3.73153872e-03,   1.35418254e-01,
         0.00000000e+00,   1.20894210e-01,   0.00000000e+00,
         1.55733120e-01,   6.20285226e-02,  -1.20478516e-02,
         5.93431616e-02,   0.00000000e+00,  -1.36196420e-01,
         0.00000000e+00,   3.28969533e-02,   1.33552198e-01,
         4.85107045e-03,  -3.69978770e-02,  -4.24617298e-02,
         0.00000000e+00,   3.95304062e-02,   0.00000000e+00,
        -2.54354474e-03,  -5.99832347e-02,  -8.01723524e-02,
         1.25106174e-02,  -8.35487911e-04,  -7.16679943e-03,
         0.00000000e+00,  -1.17901904e-02,   0.00000000e+00,
        -2.04603749e-02,  -1.30665307e-03,  -4.78818217e-02,
        -1.28405113e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.94033576e-02,   0.00000000e+00,
        -6.56989396e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.47805370e-01,
         5.54738381e-04,   4.53257827e-03,   1.72343066e-02,
         0.00000000e+00,   4.74578546e-02,   0.00000000e+00,
        -6.19060014e-02,   2.14933238e-02,  -2.89926651e-03,
         2.66091683e-02,   0.00000000e+00,  -1.41402210e-01,
         2.77463654e-03,  -1.51573181e-04,  -4.92298993e-02,
         0.00000000e+00,   3.60835913e-02,   0.00000000e+00,
         3.97615061e-02,   1.16225086e-02,  -4.91489022e-02,
        -2.76601652e-02,   0.00000000e+00,  -1.78627372e-02,
        -1.21411141e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.72079706e-02,   0.00000000e+00,
        -8.59602969e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.89644952e-02,
         0.00000000e+00,   0.00000000e+00,   2.06828200e-01,
        -1.38498625e-03,   8.25560224e-03,  -3.64521869e-02,
         0.00000000e+00,  -2.90875993e-02,   0.00000000e+00,
        -7.37370590e-02,  -5.94875924e-04,  -2.71665340e-03,
         3.11431235e-02,   0.00000000e+00,   6.87437598e-02,
        -6.75931307e-02,   0.00000000e+00,   1.85029530e-01,
         8.67552910e-03,  -2.16714696e-03,  -6.43911695e-03,
         0.00000000e+00,   1.72678714e-02,   0.00000000e+00,
        -2.02906849e-04,  -1.00579402e-01,   2.61280891e-02,
        -1.27054605e-02,   0.00000000e+00,   3.10339716e-02,
         3.37753561e-02,   0.00000000e+00,   9.20416406e-03,
         2.15177661e-01,   1.88176559e-02,  -7.11843921e-02,
         1.21361545e-02,   0.00000000e+00,  -1.38536078e-02,
         0.00000000e+00,  -1.60614150e-03,  -4.16920787e-02,
        -1.84304067e-02,  -1.27066676e-02,   0.00000000e+00,
        -2.12551565e-02,  -5.73363148e-02,   0.00000000e+00,
         2.47014210e-02,  -5.45501948e-02,  -1.16374943e-01,
        -5.50166320e-02,  -4.55673937e-02,   1.29968833e-02,
         0.00000000e+00,  -2.60579431e-02,   0.00000000e+00,
         5.90293232e-03,  -2.85724070e-02,   2.49927667e-02,
        -1.18293062e-02,   0.00000000e+00,  -1.92431695e-02,
        -2.52367973e-02,   0.00000000e+00,  -9.98406829e-03,
         2.72887947e-03,   1.20821904e-01,   1.75035542e-01,
         5.98050522e-01,   1.02684005e-02,   6.03898961e-01,
        -1.62842301e-02,   8.05989496e-03,   5.52377179e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.73210013e-01,  -7.26689057e-03,   7.59124793e-03,
        -7.67668166e-03,   0.00000000e+00,   5.83640015e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.38145887e-03,   0.00000000e+00,   6.04004264e-01,
         5.26779107e-03,  -9.27878519e-03,   1.71175864e-02,
         0.00000000e+00,   8.24793789e-03,   0.00000000e+00,
         5.96671101e-01,   4.36766172e-03,   3.29095555e-02,
         1.78951789e-02,   0.00000000e+00,  -1.50251994e-03,
         0.00000000e+00,  -7.53488001e-03,   5.84221650e-01,
        -4.36475324e-02,   3.68168158e-02,   5.27590984e-02,
         0.00000000e+00,  -1.63712951e-02,   0.00000000e+00,
        -1.51489371e-02,  -6.86497023e-02,   3.84306921e-01,
        -5.56173372e-03,   1.55464577e-02,   7.76333159e-03,
         0.00000000e+00,   3.60596163e-03,   0.00000000e+00,
        -2.53901687e-02,   3.31606626e-02,   7.55608709e-02,
         4.35959117e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.04302698e-01,   0.00000000e+00,
         2.38543121e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.18694502e-01,
         4.77561636e-03,   2.68551198e-02,  -4.69853696e-02,
         0.00000000e+00,  -7.85065218e-02,   0.00000000e+00,
         2.08882570e-02,  -4.24928640e-02,  -2.69591463e-03,
        -8.85865663e-03,   0.00000000e+00,   5.13952154e-01,
         8.90573160e-03,   3.71116037e-02,   7.01977429e-02,
         0.00000000e+00,  -1.62143568e-02,   0.00000000e+00,
         1.21550099e-02,  -2.44510632e-02,   6.45890125e-02,
         2.12363387e-02,   0.00000000e+00,   1.87366016e-03,
         5.16229440e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.10778471e-02,   0.00000000e+00,
        -1.14593749e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.82997461e-02,
         0.00000000e+00,   0.00000000e+00,   5.53324453e-01,
         9.12066598e-03,  -3.55419821e-03,  -1.53564833e-02,
         0.00000000e+00,  -2.46886304e-02,   0.00000000e+00,
        -1.10852291e-01,  -7.73278857e-03,   6.57077676e-04,
         2.53763822e-02,   0.00000000e+00,   2.15490199e-02,
        -1.88209626e-02,   0.00000000e+00,   5.44003747e-01,
        -3.05825011e-03,   2.98248658e-02,  -2.86358602e-02,
         0.00000000e+00,   5.61021119e-02,   0.00000000e+00,
        -8.73777823e-03,  -8.91409439e-02,   3.26658995e-02,
        -8.18164007e-03,   0.00000000e+00,  -1.08125681e-02,
        -6.57359385e-03,   0.00000000e+00,   2.43804312e-04,
         5.74363900e-01,  -7.48439207e-02,   2.33709711e-02,
        -1.61746572e-03,   0.00000000e+00,  -3.11945241e-02,
         0.00000000e+00,  -1.49050528e-03,   3.35631280e-02,
         5.79047582e-02,   7.62911758e-03,   0.00000000e+00,
        -1.24108514e-02,   6.18077309e-03,   0.00000000e+00,
         1.22186854e-03,   1.38985318e-02,   5.51405706e-01,
        -4.01538138e-02,  -7.67718308e-02,   2.01369223e-02,
         0.00000000e+00,  -1.88498231e-02,   0.00000000e+00,
        -1.00366496e-03,  -2.50855516e-02,   2.53081055e-03,
        -1.12439742e-02,   0.00000000e+00,  -1.09604332e-02,
        -2.13193811e-02,   0.00000000e+00,  -6.33057733e-03,
         1.00756805e-02,   1.90218288e-02,   5.82310605e-01,
        -6.87908643e-03,  -6.66290845e-02,   8.05989496e-03,
        -3.75049011e-02,   8.01635503e-02,   4.44416069e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.12561344e-03,  -5.05386446e-03,  -2.03948099e-02,
        -9.34561286e-03,   0.00000000e+00,  -1.46791456e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.77852958e-02,   0.00000000e+00,  -5.75241382e-02,
         4.26804792e-02,   1.82489787e-03,  -3.51227288e-02,
         0.00000000e+00,  -1.19709049e-02,   0.00000000e+00,
        -5.61780293e-02,   3.90115329e-03,   1.21368928e-02,
        -1.10930295e-02,   0.00000000e+00,   3.99100388e-02,
         0.00000000e+00,  -8.78535415e-03,  -4.28021300e-02,
        -1.51479624e-02,   1.27502597e-02,  -9.94331829e-03,
         0.00000000e+00,  -1.20955932e-02,   0.00000000e+00,
         7.92536674e-03,   3.36142222e-02,   5.51007367e-02,
        -2.47946765e-03,  -1.05017014e-02,  -3.60367504e-02,
         0.00000000e+00,   2.99574143e-03,   0.00000000e+00,
         2.43188896e-02,   1.12126252e-02,   2.78767763e-02,
         1.06460670e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.26357470e-03,   0.00000000e+00,
         1.07330068e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.88837793e-02,
         1.50274748e-03,  -1.18351955e-02,   3.01124746e-03,
         0.00000000e+00,   1.02247618e-03,   0.00000000e+00,
         1.23290057e-02,  -3.24132527e-03,  -1.56158336e-03,
         2.80387735e-03,   0.00000000e+00,   8.88657109e-03,
        -9.07739068e-03,   1.06684763e-02,   5.79287030e-03,
         0.00000000e+00,  -9.47735384e-04,   0.00000000e+00,
        -7.59113915e-03,   8.30033739e-03,   1.84688432e-02,
         1.05356598e-02,   0.00000000e+00,   1.63129415e-02,
         1.68109746e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.32318452e-03,   0.00000000e+00,
         2.34582022e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.63532021e-02,
         0.00000000e+00,   0.00000000e+00,  -6.27778455e-02,
        -7.96715102e-03,  -7.23033325e-03,   1.11116004e-02,
         0.00000000e+00,   7.99703842e-03,   0.00000000e+00,
         1.89371143e-02,  -7.43917788e-04,   2.95378929e-03,
        -1.97174327e-02,   0.00000000e+00,  -1.10411212e-02,
         6.54097530e-03,   0.00000000e+00,  -6.16758585e-02,
        -4.00473065e-03,  -6.72646524e-03,   9.07569148e-03,
         0.00000000e+00,  -6.09692527e-03,   0.00000000e+00,
        -1.07808074e-03,   2.24571997e-02,  -3.42015824e-03,
         6.85027546e-03,   0.00000000e+00,  -1.35873972e-02,
        -2.93731837e-03,   0.00000000e+00,  -8.14374023e-03,
        -7.43366088e-02,   2.34657539e-03,   1.35667734e-02,
         1.04927157e-02,   0.00000000e+00,   7.06418301e-04,
         0.00000000e+00,  -1.18711340e-02,   3.58388441e-03,
         1.07225162e-02,   1.39036347e-02,   0.00000000e+00,
        -1.51323865e-02,   5.31571344e-02,   0.00000000e+00,
         1.42846359e-02,   1.80692909e-02,   3.12632679e-02,
         1.19564000e-02,   1.19374533e-02,  -7.52449432e-03,
         0.00000000e+00,   1.09737720e-02,   0.00000000e+00,
        -8.72860912e-03,   3.88854700e-03,  -4.56485077e-03,
         8.16869641e-03,   0.00000000e+00,   2.08431172e-02,
        -1.10473876e-02,   0.00000000e+00,   1.94654965e-02,
         1.37361240e-02,  -3.04704285e-02,  -4.87794538e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.50502769e-02,   7.14509378e-02,  -1.45537593e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.44012777e-03,   0.00000000e+00,
         5.33702431e-02,   4.38177532e-04,  -1.72438422e-03,
         0.00000000e+00,   1.85069084e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.28393771e-03,   0.00000000e+00,  -5.12990925e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.91254897e-02,   0.00000000e+00,
        -6.94304870e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.01955659e-02,   0.00000000e+00,  -8.06956923e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.77585036e-02,   0.00000000e+00,  -7.41153915e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.08590667e-02,  -1.81718752e-02,
         6.63516569e-03,   0.00000000e+00,  -8.07029463e-04,
         0.00000000e+00,  -1.80357445e-03,  -1.15932217e-02,
        -1.67168675e-02,   1.91092956e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.06788751e-02,   0.00000000e+00,  -1.10841167e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.21131385e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.74044770e-03,   0.00000000e+00,   4.53910915e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.23111926e-03,   0.00000000e+00,
         0.00000000e+00,  -8.29882484e-03,  -1.06546837e-02,
         3.04252564e-04,   0.00000000e+00,   9.56351924e-04,
         0.00000000e+00,  -4.38556514e-04,  -1.42950617e-03,
         4.47965044e-03,  -3.07431891e-03,   0.00000000e+00,
         4.49215038e-04,  -2.15801357e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.00350629e-03,   0.00000000e+00,   3.65069560e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.42994178e-03,   0.00000000e+00,
         0.00000000e+00,  -1.60158742e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.10894172e-03,   0.00000000e+00,  -3.29340423e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.97204124e-03,   0.00000000e+00,
         0.00000000e+00,  -7.87926159e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.92744496e-03,   0.00000000e+00,
        -1.47147857e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.13931534e-02,
         0.00000000e+00,   0.00000000e+00,   2.40143305e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.67923197e-03,   0.00000000e+00,  -1.07931668e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.82702655e-02,   0.00000000e+00,
         0.00000000e+00,   2.51157822e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.57370402e-02,   9.38297698e-02,   7.59124793e-03,
        -5.53965385e-03,  -2.03948099e-02,  -4.39340757e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.60238450e-02,  -1.28186757e-02,   1.08972511e-01,
        -1.18173568e-02,   0.00000000e+00,  -2.59491831e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.22032357e-02,   0.00000000e+00,   8.94995975e-02,
         3.37702024e-02,   1.69745932e-04,   6.21208205e-02,
         0.00000000e+00,   7.63802740e-02,   0.00000000e+00,
         7.42111784e-02,  -1.78175861e-02,  -8.62638533e-03,
         3.49262853e-02,   0.00000000e+00,  -6.97382648e-02,
         0.00000000e+00,   1.58636745e-02,   8.05872445e-02,
         1.01715906e-02,  -1.59851175e-02,  -2.02873973e-02,
         0.00000000e+00,   3.31074810e-02,   0.00000000e+00,
        -8.58496843e-03,  -2.28166313e-02,  -3.94646901e-02,
        -1.27952280e-03,  -4.32198937e-03,  -5.69696544e-03,
         0.00000000e+00,   7.53292892e-03,   0.00000000e+00,
        -1.30595025e-02,   8.66910391e-03,  -1.82293031e-02,
        -5.27911245e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.94192428e-02,   0.00000000e+00,
        -2.71559802e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.40324255e-02,
         9.57776361e-03,  -1.20402661e-02,   1.27524897e-02,
         0.00000000e+00,   1.84005213e-02,   0.00000000e+00,
        -2.60053027e-02,  -6.19518079e-04,  -1.39178295e-02,
         1.28873688e-02,   0.00000000e+00,  -8.53883576e-02,
         7.38335044e-03,   2.66521126e-03,  -1.26142776e-02,
         0.00000000e+00,   1.08292918e-02,   0.00000000e+00,
         2.13520008e-02,  -3.17457765e-03,  -2.23834283e-02,
        -8.13826489e-03,   0.00000000e+00,  -1.87024445e-02,
        -5.92456273e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.20335669e-02,   0.00000000e+00,
        -3.82683554e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.39199785e-02,
         0.00000000e+00,   0.00000000e+00,   1.06489693e-01,
        -6.20803679e-03,  -1.53212143e-03,  -1.01037430e-02,
         0.00000000e+00,  -1.60842390e-02,   0.00000000e+00,
        -3.04848975e-02,  -5.12979962e-03,   3.18290544e-03,
         1.41719403e-02,   0.00000000e+00,   3.81889590e-02,
        -3.55997841e-02,   0.00000000e+00,   9.27727360e-02,
         8.28962813e-03,   1.45037080e-02,  -2.86743751e-03,
         0.00000000e+00,   1.19275422e-02,   0.00000000e+00,
        -2.97004598e-04,  -3.70000873e-02,   1.22913022e-02,
        -3.17465513e-03,   0.00000000e+00,   1.19013003e-02,
         2.05254102e-02,   0.00000000e+00,  -2.00923718e-03,
         1.29527943e-01,   2.30013494e-03,  -2.80443413e-02,
         3.12976826e-03,   0.00000000e+00,   6.61978252e-03,
         0.00000000e+00,  -1.22208084e-02,  -5.80010516e-03,
        -8.56603573e-03,   3.09129905e-03,   0.00000000e+00,
        -5.63912532e-02,  -4.77451285e-02,   0.00000000e+00,
         2.55501130e-02,  -3.14525712e-02,  -3.84757778e-02,
        -2.26874664e-02,  -1.43590094e-02,   1.05589808e-02,
         0.00000000e+00,  -2.70857854e-02,   0.00000000e+00,
        -1.26672918e-03,  -4.65179184e-03,   9.17032624e-03,
        -6.82107335e-04,   0.00000000e+00,   7.75153283e-03,
        -1.72830501e-02,   0.00000000e+00,   1.79151366e-02,
        -2.61669123e-02,   5.37790602e-02,   8.25088303e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.01235441e-02,   4.38177532e-04,   2.40236305e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.38514683e-02,   0.00000000e+00,
         5.56344985e-02,   9.58261100e-02,  -2.04900369e-02,
         0.00000000e+00,   2.34295766e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.96136681e-03,   0.00000000e+00,  -1.27892618e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.73422332e-03,   0.00000000e+00,
         1.17466032e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.08481491e-03,   0.00000000e+00,  -1.83043488e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.01919028e-02,   0.00000000e+00,   7.12821152e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.58666148e-03,  -1.65565359e-03,
         1.52749057e-03,   0.00000000e+00,  -7.54622827e-03,
         0.00000000e+00,   1.88667160e-03,   9.68796471e-03,
         1.22008718e-02,  -4.20344309e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.51185562e-03,   0.00000000e+00,   8.56807249e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.79995425e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.06172057e-04,   0.00000000e+00,   8.01058165e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.67245883e-03,   0.00000000e+00,
         0.00000000e+00,  -1.25652281e-02,  -1.62228729e-02,
         5.96823650e-03,   0.00000000e+00,  -1.04355851e-02,
         0.00000000e+00,   1.51720943e-03,  -8.84836811e-03,
         4.84502001e-03,  -2.93876923e-03,   0.00000000e+00,
        -1.07647424e-02,  -1.42891717e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.09699736e-03,   0.00000000e+00,  -1.39007933e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.98124881e-03,   0.00000000e+00,
         0.00000000e+00,  -2.31636488e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.30378832e-03,   0.00000000e+00,   8.48663520e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.63039452e-03,   0.00000000e+00,
         0.00000000e+00,  -1.69212124e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.92545676e-03,   0.00000000e+00,
        -1.07446711e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.88387242e-02,
         0.00000000e+00,   0.00000000e+00,   2.75188156e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.17564103e-03,   0.00000000e+00,  -1.15779028e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.03536500e-04,   0.00000000e+00,
         0.00000000e+00,   8.94677298e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.34567699e-02,  -3.73153872e-03,  -9.27878519e-03,
         5.67923118e-02,   1.82489787e-03,   2.03282810e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.15924451e-02,   4.23601485e-02,   1.69745932e-04,
         1.08039585e-02,   0.00000000e+00,   2.99633386e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.25897406e-02,   0.00000000e+00,  -8.10398733e-03,
         5.10853740e-02,   9.52341815e-02,  -2.77851313e-02,
         0.00000000e+00,   9.10670466e-03,   0.00000000e+00,
        -8.89524869e-03,   7.91540389e-03,  -7.87266935e-04,
        -3.08047215e-03,   0.00000000e+00,   1.10355667e-02,
         0.00000000e+00,   6.27519405e-03,  -1.19154984e-02,
         2.67536127e-03,  -6.79076276e-04,   1.53235001e-02,
         0.00000000e+00,  -9.92472322e-03,   0.00000000e+00,
        -5.90088916e-03,  -9.57071805e-03,  -1.95669398e-02,
        -2.46825652e-03,  -3.90834309e-04,   2.46716392e-02,
         0.00000000e+00,  -1.01981449e-02,   0.00000000e+00,
        -4.80024745e-03,  -8.24854373e-03,  -3.94507189e-03,
        -4.11862051e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.40392225e-03,   0.00000000e+00,
         4.60883281e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.32310632e-02,
        -8.08894628e-03,  -5.15486450e-04,   9.63441599e-05,
         0.00000000e+00,  -1.16396731e-02,   0.00000000e+00,
         1.21143689e-02,   5.03625043e-03,   1.01708808e-02,
        -1.08112961e-02,   0.00000000e+00,   1.85094965e-02,
         4.11278732e-03,   4.07916036e-03,  -3.86686144e-03,
         0.00000000e+00,   6.55816642e-03,   0.00000000e+00,
         4.88232249e-03,  -3.85647750e-03,  -3.32794865e-03,
        -5.13031265e-03,   0.00000000e+00,  -3.69272094e-03,
         2.95393529e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.06750090e-03,   0.00000000e+00,
         3.99010371e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.98339128e-03,
         0.00000000e+00,   0.00000000e+00,  -1.16072881e-02,
        -1.08655326e-02,  -1.64756174e-02,   3.06057129e-03,
         0.00000000e+00,  -5.28824816e-03,   0.00000000e+00,
         6.40847941e-03,  -7.68780802e-03,   5.30659522e-03,
        -1.64257667e-03,   0.00000000e+00,  -2.07261338e-02,
        -2.47641851e-03,   0.00000000e+00,  -1.25792325e-02,
        -1.31615558e-03,  -2.22006286e-03,   2.35726416e-03,
         0.00000000e+00,   1.59395230e-03,   0.00000000e+00,
         7.30714833e-03,   3.86989779e-03,  -2.32069785e-03,
        -2.02932670e-03,   0.00000000e+00,   2.71356327e-03,
        -6.66418546e-03,   0.00000000e+00,  -1.76718122e-02,
        -1.46436118e-02,  -3.02510853e-03,   4.26249959e-03,
        -8.99261686e-03,   0.00000000e+00,  -6.82112780e-03,
         0.00000000e+00,  -8.37176643e-03,  -2.31290394e-03,
         1.10636217e-03,  -2.50328983e-03,   0.00000000e+00,
         4.25833658e-02,  -2.03619127e-02,   0.00000000e+00,
         2.25026832e-02,  -1.03670651e-03,   1.33353369e-03,
         3.66145138e-03,  -2.69984493e-04,  -5.18586282e-03,
         0.00000000e+00,  -8.14777761e-04,   0.00000000e+00,
        -1.26536304e-02,   9.20183718e-04,  -2.11634589e-03,
         6.95082285e-03,   0.00000000e+00,   6.00077527e-03,
        -9.95189724e-03,   0.00000000e+00,   8.62288149e-02,
         4.22047019e-03,   3.95906050e-03,  -1.22769730e-02,
         8.60900372e-02,  -1.20478516e-02,   3.29095555e-02,
         2.67967346e-02,   1.21368928e-02,   5.50095629e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.97853100e-02,  -5.90042653e-02,  -8.62638533e-03,
         6.30665086e-03,   0.00000000e+00,   3.46130315e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.62540899e-02,   0.00000000e+00,   3.42298326e-02,
         1.33835698e-02,  -7.87266935e-04,  -8.37720163e-03,
         0.00000000e+00,  -4.68885975e-03,   0.00000000e+00,
         3.16411011e-02,   3.85060674e-02,   8.37869465e-02,
        -1.79099256e-02,   0.00000000e+00,   3.71097840e-02,
         0.00000000e+00,  -6.42058448e-03,   3.80365363e-02,
        -1.86929197e-02,  -1.28635064e-02,   2.32872094e-02,
         0.00000000e+00,  -3.05466733e-03,   0.00000000e+00,
        -7.21454771e-03,  -7.62657572e-03,   1.77840827e-02,
        -4.04723050e-03,   9.57868022e-03,   1.57026396e-02,
         0.00000000e+00,   1.01308754e-02,   0.00000000e+00,
        -8.56704369e-03,   8.99931087e-03,   6.33820646e-03,
         1.52192343e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.10460682e-02,   0.00000000e+00,
         1.61747510e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.19264325e-02,
         3.51939075e-03,  -1.60070948e-03,  -3.72697595e-03,
         0.00000000e+00,  -1.51851162e-02,   0.00000000e+00,
         1.19255679e-02,  -1.72141057e-02,  -5.93032151e-03,
        -4.11698252e-03,   0.00000000e+00,   4.64803057e-02,
         1.86771110e-03,   3.95154166e-03,   1.58507635e-02,
         0.00000000e+00,  -1.24939292e-02,   0.00000000e+00,
        -4.68353619e-03,  -1.49841695e-02,   9.98231747e-03,
         6.24943275e-03,   0.00000000e+00,  -1.07508177e-02,
         5.25309856e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.07662102e-03,   0.00000000e+00,
        -1.37773015e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.19425581e-04,
         0.00000000e+00,   0.00000000e+00,   2.25679122e-02,
         8.61930215e-04,  -1.11081498e-03,   1.97708718e-03,
         0.00000000e+00,  -4.13623168e-03,   0.00000000e+00,
        -1.32859092e-02,  -2.77515784e-03,   2.48142482e-03,
         5.83054094e-03,   0.00000000e+00,   9.74502036e-05,
         3.77379724e-03,   0.00000000e+00,   2.14758555e-02,
        -1.83656785e-02,  -1.39922039e-02,   3.11702969e-03,
         0.00000000e+00,  -4.01427087e-03,   0.00000000e+00,
         2.12127094e-04,  -1.15547065e-02,   9.21990333e-03,
        -2.41032998e-03,   0.00000000e+00,  -1.99267767e-02,
        -2.51507885e-02,   0.00000000e+00,  -5.50344980e-03,
        -8.27392475e-03,  -1.59034229e-02,   9.98331263e-03,
        -3.42715878e-03,   0.00000000e+00,   2.01016111e-03,
         0.00000000e+00,  -4.40798872e-03,   1.12464563e-02,
         1.03314450e-02,   3.22422379e-03,   0.00000000e+00,
        -2.16151086e-02,  -1.41909684e-02,   0.00000000e+00,
        -3.36130199e-03,   5.01133854e-02,   5.63833601e-02,
        -3.54973767e-03,  -5.24332659e-03,   2.10916793e-03,
         0.00000000e+00,  -2.03039877e-04,   0.00000000e+00,
         8.81079420e-04,  -3.26530951e-02,   7.24451190e-03,
        -4.66052520e-03,   0.00000000e+00,   6.70750573e-03,
         5.03903591e-03,   0.00000000e+00,   4.44530689e-03,
         6.30460077e-02,  -9.53460002e-03,   5.92426395e-02,
         1.79732284e-02,  -3.69978770e-02,   3.68168158e-02,
        -1.23385857e-02,   1.27502597e-02,   2.77299570e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.72725816e-02,   1.03460532e-02,  -1.59851175e-02,
        -3.58777128e-03,   0.00000000e+00,   4.75755328e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.93343692e-02,   0.00000000e+00,   4.54288923e-03,
         3.98384727e-04,  -6.79076276e-04,  -1.42048913e-02,
         0.00000000e+00,  -2.17256410e-02,   0.00000000e+00,
         4.25221873e-03,  -2.36420224e-02,  -1.28635064e-02,
         3.75676084e-03,   0.00000000e+00,   1.70592740e-02,
         0.00000000e+00,  -9.22633274e-03,   5.43550266e-03,
        -1.34519720e-02,   3.11109022e-02,   2.36560859e-02,
         0.00000000e+00,  -1.36946701e-02,   0.00000000e+00,
        -4.89956014e-03,  -3.64463365e-03,   2.71957244e-03,
        -1.39352102e-02,   1.59044541e-02,   1.64322167e-02,
         0.00000000e+00,  -2.76815442e-03,   0.00000000e+00,
        -5.51635639e-03,  -9.45847344e-04,   6.04037514e-03,
        -8.07702835e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.18008499e-02,   0.00000000e+00,
         1.77265151e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.59228311e-02,
         2.06731577e-03,   3.37020621e-03,  -9.20373202e-03,
         0.00000000e+00,  -2.57486908e-02,   0.00000000e+00,
         1.55626469e-02,  -1.07721018e-02,   1.71068761e-03,
        -1.01294158e-02,   0.00000000e+00,   4.55748135e-02,
        -7.27396776e-03,   1.43141712e-02,   2.38596938e-02,
         0.00000000e+00,  -1.23178386e-02,   0.00000000e+00,
        -6.44477598e-03,  -1.97799061e-03,   2.27849510e-02,
         1.00458132e-02,   0.00000000e+00,   9.17768684e-03,
         4.19040112e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.87009676e-03,   0.00000000e+00,
         6.49552497e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.96994175e-03,
         0.00000000e+00,   0.00000000e+00,  -6.01985446e-03,
         1.67589107e-03,  -2.12146672e-03,   5.30921195e-03,
         0.00000000e+00,   5.67253809e-03,   0.00000000e+00,
         5.08069427e-03,   8.78237228e-04,   9.05089651e-04,
         2.65195675e-03,   0.00000000e+00,  -8.52826745e-03,
         6.99687879e-03,   0.00000000e+00,  -4.53643871e-03,
         5.79099080e-04,   7.24591427e-03,  -8.63628127e-04,
         0.00000000e+00,   5.57211839e-03,   0.00000000e+00,
        -2.55825146e-03,   1.41354709e-02,  -3.05530918e-03,
         1.43203737e-03,   0.00000000e+00,  -3.51480848e-03,
         5.35390547e-04,   0.00000000e+00,   6.97051916e-04,
         3.56553232e-03,  -1.83447183e-02,   2.65583497e-02,
         6.99904278e-03,   0.00000000e+00,  -3.36716488e-03,
         0.00000000e+00,  -1.02407886e-03,   1.11157385e-02,
         2.08234225e-02,   1.00280696e-02,   0.00000000e+00,
         6.73188154e-03,   2.34571964e-02,   0.00000000e+00,
        -2.70357102e-03,  -1.98607327e-03,   4.69038160e-02,
         1.04001814e-02,  -1.92525000e-03,  -1.24715968e-03,
         0.00000000e+00,   3.67233697e-03,   0.00000000e+00,
        -1.16502048e-03,   8.76988334e-03,  -9.14050236e-03,
        -3.02368553e-03,   0.00000000e+00,  -1.16262073e-03,
        -3.31219883e-03,   0.00000000e+00,  -2.60806717e-04,
        -1.63381410e-02,  -1.72292370e-02,  -8.49535802e-03,
         2.06735096e-02,  -8.35487911e-04,   1.55464577e-02,
         5.09962009e-03,  -1.05017014e-02,  -2.47363032e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.04782725e-02,  -6.14714726e-03,  -4.32198937e-03,
         4.61380305e-04,   0.00000000e+00,   2.51853549e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.59042583e-03,   0.00000000e+00,   1.95541052e-02,
        -6.36579971e-03,  -3.90834309e-04,   9.38484845e-03,
         0.00000000e+00,  -7.61722169e-03,   0.00000000e+00,
         1.36968179e-02,  -2.68908021e-03,   9.57868022e-03,
         6.47692794e-03,   0.00000000e+00,   6.48839106e-03,
         0.00000000e+00,  -5.87241506e-03,   1.67554206e-02,
        -1.32331930e-02,   1.59044541e-02,   2.17348318e-02,
         0.00000000e+00,  -5.44273281e-03,   0.00000000e+00,
        -7.35915057e-03,  -1.27478574e-02,  -1.98310358e-02,
        -1.95012125e-02,   2.96812578e-02,   3.67400910e-02,
         0.00000000e+00,  -4.88394941e-03,   0.00000000e+00,
        -1.75456881e-02,  -7.02216432e-03,  -2.07377634e-02,
        -7.74573211e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.47976590e-02,   0.00000000e+00,
         6.63671730e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.78433579e-02,
         4.17561138e-03,   1.47894462e-03,  -1.52210922e-03,
         0.00000000e+00,  -1.14539602e-02,   0.00000000e+00,
         2.57756996e-03,  -7.51845240e-03,  -7.63364660e-04,
        -1.08395810e-02,   0.00000000e+00,   2.21369631e-02,
        -3.77828486e-03,   6.81853005e-03,   1.11767702e-02,
         0.00000000e+00,  -5.97531635e-03,   0.00000000e+00,
        -1.88714103e-03,  -2.57614254e-03,   8.96373982e-03,
         1.01401231e-04,   0.00000000e+00,   4.38844981e-03,
         1.92621707e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.92309151e-04,   0.00000000e+00,
        -6.62971360e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.46690078e-03,
         0.00000000e+00,   0.00000000e+00,   1.41680284e-02,
         4.60258544e-03,   1.13646517e-03,  -4.40802513e-03,
         0.00000000e+00,   2.54751128e-04,   0.00000000e+00,
        -5.54635263e-03,   1.28452863e-03,   2.43596239e-03,
         1.23060492e-02,   0.00000000e+00,   1.34812037e-03,
         2.98952628e-04,   0.00000000e+00,   1.14178011e-02,
        -3.19419168e-03,   1.47699767e-03,  -1.21955240e-05,
         0.00000000e+00,   3.80156387e-03,   0.00000000e+00,
        -2.70292510e-03,  -3.16234160e-03,   1.90390005e-03,
        -2.28305446e-03,   0.00000000e+00,  -3.27340453e-03,
        -2.30878097e-03,   0.00000000e+00,   1.73814068e-03,
         1.45895762e-02,  -1.15370897e-02,   1.00922111e-02,
         6.60487448e-03,   0.00000000e+00,   1.51126703e-03,
         0.00000000e+00,  -1.70369849e-03,   6.81829736e-03,
         1.34182929e-02,   3.30581172e-03,   0.00000000e+00,
        -2.68831342e-04,   4.28960656e-03,   0.00000000e+00,
        -3.43686671e-03,   4.46610698e-03,   2.27065509e-02,
        -9.33575985e-04,  -6.06681357e-03,   2.40802644e-03,
         0.00000000e+00,   1.33232886e-04,   0.00000000e+00,
         3.96393767e-03,  -5.14324840e-03,  -3.06733425e-03,
        -7.72497652e-03,   0.00000000e+00,  -2.70586141e-03,
        -3.93623065e-04,   0.00000000e+00,  -4.15600722e-03,
         3.20330586e-03,  -1.63759858e-03,   1.60439924e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.05560452e-02,  -1.81718752e-02,   5.23669220e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.45250449e-04,   0.00000000e+00,
        -1.51841843e-02,  -1.65565359e-03,   2.37788412e-04,
         0.00000000e+00,  -4.66020260e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.66599044e-03,   0.00000000e+00,   1.49459271e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.34586740e-03,   0.00000000e+00,
         3.92495714e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.52297249e-03,   0.00000000e+00,   4.27330252e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.22210013e-03,   0.00000000e+00,   9.14325081e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.75742252e-02,   2.13593070e-02,
        -2.97225077e-03,   0.00000000e+00,  -3.77610641e-03,
         0.00000000e+00,   2.29515657e-03,   5.05556608e-03,
         1.96146208e-03,   7.71507459e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.64249479e-03,   0.00000000e+00,   2.08037039e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.43055142e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.60592554e-03,   0.00000000e+00,  -5.96646965e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.47131730e-04,   0.00000000e+00,
         0.00000000e+00,   7.02076342e-03,   1.28461630e-03,
        -7.23765003e-04,   0.00000000e+00,   2.57401352e-03,
         0.00000000e+00,  -4.18688499e-04,   1.83362506e-04,
        -5.04446250e-04,  -9.79647025e-04,   0.00000000e+00,
         1.52977941e-03,   2.28429773e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.95371375e-03,   0.00000000e+00,  -1.70223579e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.68662939e-03,   0.00000000e+00,
         0.00000000e+00,   9.53135905e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.14999187e-03,   0.00000000e+00,   7.19654518e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.47192356e-03,   0.00000000e+00,
         0.00000000e+00,   2.10726579e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.43514403e-02,   0.00000000e+00,
         1.57204688e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.15447406e-02,
         0.00000000e+00,   0.00000000e+00,  -4.93534632e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.88879450e-03,   0.00000000e+00,   1.66151885e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.30638788e-03,   0.00000000e+00,
         0.00000000e+00,  -9.77698900e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.17083165e-02,   4.53257827e-03,   2.68551198e-02,
         3.13414506e-03,  -1.18351955e-02,   2.56872912e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.92789369e-02,   8.18524796e-03,  -1.20402661e-02,
         4.69914716e-03,   0.00000000e+00,   2.69922827e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.46379802e-04,   0.00000000e+00,   3.11039748e-02,
        -1.41615721e-02,  -5.15486450e-04,   2.14308009e-03,
         0.00000000e+00,  -4.93977632e-03,   0.00000000e+00,
         3.19169474e-02,   4.59909708e-03,  -1.60070948e-03,
         4.45306964e-04,   0.00000000e+00,  -3.74375644e-03,
         0.00000000e+00,   1.13424140e-03,   1.98089876e-02,
        -1.77749374e-03,   3.37020621e-03,   5.00836445e-03,
         0.00000000e+00,  -7.47130158e-03,   0.00000000e+00,
         1.16567608e-03,  -9.40310729e-03,   8.71933231e-03,
         2.49682526e-03,   1.47894462e-03,   6.66197083e-03,
         0.00000000e+00,  -5.34003032e-04,   0.00000000e+00,
        -5.29048555e-03,  -8.81634033e-04,   1.68276591e-03,
         1.04519345e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.67631100e-02,   0.00000000e+00,
         5.67300893e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.41733890e-02,
        -1.39149648e-02,   2.32146739e-02,  -1.13263190e-02,
         0.00000000e+00,  -2.15669054e-02,   0.00000000e+00,
         8.76693612e-03,  -5.36700686e-03,   1.75412901e-03,
         2.10169403e-03,   0.00000000e+00,   2.54459911e-02,
        -4.59448463e-04,   4.83609786e-03,   1.16022393e-02,
         0.00000000e+00,  -7.57365623e-03,   0.00000000e+00,
         3.87472188e-04,  -7.26595775e-03,   7.33854150e-03,
         6.11332920e-03,   0.00000000e+00,  -2.28405592e-03,
         1.58103048e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.26841356e-03,   0.00000000e+00,
        -1.27014003e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.58505906e-03,
         0.00000000e+00,   0.00000000e+00,   2.62427465e-02,
         7.49198378e-03,   1.57582388e-03,  -4.28712085e-04,
         0.00000000e+00,   2.32625252e-03,   0.00000000e+00,
        -1.42942289e-02,   2.92379673e-04,  -2.55872152e-05,
         5.13572793e-03,   0.00000000e+00,   1.70006353e-03,
        -2.12211158e-03,   0.00000000e+00,   2.58981067e-02,
         2.19130184e-03,   2.69812199e-03,  -5.93058971e-03,
         0.00000000e+00,   4.57980304e-03,   0.00000000e+00,
        -1.14972952e-03,  -1.14291490e-02,   1.70861166e-03,
        -2.35857886e-03,   0.00000000e+00,   1.12724058e-03,
        -2.69644252e-03,   0.00000000e+00,   1.99290687e-03,
         2.50202871e-02,  -6.90319307e-03,   5.49681475e-03,
        -7.35404712e-03,   0.00000000e+00,  -2.17475960e-02,
         0.00000000e+00,   1.40575411e-02,  -5.01841109e-03,
         4.20400456e-03,  -2.72452037e-03,   0.00000000e+00,
         1.18759308e-02,  -1.87252482e-03,   0.00000000e+00,
        -5.73546653e-03,  -1.48160409e-03,   2.11655075e-02,
        -5.42751184e-03,  -8.36483647e-03,   7.14954158e-03,
         0.00000000e+00,   4.96953761e-03,   0.00000000e+00,
         2.57219700e-03,   3.13119069e-04,  -1.03224022e-03,
        -1.26011006e-03,   0.00000000e+00,  -8.41787304e-03,
        -1.68848247e-03,   0.00000000e+00,  -8.19041037e-03,
         1.38224951e-04,   1.78801250e-04,   2.78459139e-02,
         2.85301248e-02,  -1.51573181e-04,   3.71116037e-02,
        -9.41707285e-03,   1.06684763e-02,   2.03364011e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.81334316e-02,   6.54977999e-03,   2.66521126e-03,
         1.37195144e-03,   0.00000000e+00,   2.92429148e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.22313271e-03,   0.00000000e+00,   3.53363045e-02,
         9.11267673e-03,   4.07916036e-03,   1.64339319e-03,
         0.00000000e+00,   5.68999691e-03,   0.00000000e+00,
         3.28667750e-02,   3.51415734e-04,   3.95154166e-03,
         8.00778439e-03,   0.00000000e+00,  -2.62764093e-03,
         0.00000000e+00,  -2.36529480e-03,   2.51820370e-02,
        -1.25879704e-02,   1.43141712e-02,   1.27855816e-02,
         0.00000000e+00,  -5.34634702e-03,   0.00000000e+00,
        -4.32354465e-03,  -7.16139244e-03,   9.82246311e-03,
        -6.24510105e-03,   6.81853005e-03,   6.69755208e-03,
         0.00000000e+00,  -2.14826233e-04,   0.00000000e+00,
        -5.92198287e-03,   4.23220756e-03,   7.01044508e-03,
         1.97663105e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.95545145e-02,   0.00000000e+00,
         5.55172622e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.42683829e-02,
        -4.41510282e-04,   4.83609786e-03,  -3.01889919e-03,
         0.00000000e+00,  -1.76380789e-02,   0.00000000e+00,
         4.95860102e-03,  -1.04802031e-02,   1.13933529e-03,
         5.71755454e-04,   0.00000000e+00,   2.13165691e-02,
        -1.15597607e-02,   2.47505669e-02,   1.38254320e-02,
         0.00000000e+00,  -9.09712950e-03,   0.00000000e+00,
         4.47165195e-03,  -3.56776405e-03,   1.21621353e-02,
         8.52323619e-03,   0.00000000e+00,  -4.89926936e-03,
         2.58652929e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.78433885e-03,   0.00000000e+00,
        -1.76733070e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.47654353e-03,
         0.00000000e+00,   0.00000000e+00,   3.05356522e-02,
        -5.42860885e-03,  -3.75508839e-03,  -3.10184597e-03,
         0.00000000e+00,  -5.39291290e-03,   0.00000000e+00,
        -1.55549631e-02,  -8.40917416e-04,   1.23868991e-04,
         4.41497863e-03,   0.00000000e+00,   9.57334151e-04,
        -4.79793110e-03,   0.00000000e+00,   2.86387195e-02,
         4.52462334e-04,   5.47696712e-03,  -1.83617735e-03,
         0.00000000e+00,   1.00685800e-02,   0.00000000e+00,
        -8.66769615e-04,  -1.45025500e-02,   5.33332317e-03,
        -6.88352056e-04,   0.00000000e+00,  -3.09131611e-03,
         1.88585245e-03,   0.00000000e+00,  -1.46736492e-03,
         3.00162735e-02,  -1.75258438e-02,   1.36602214e-02,
         1.52192309e-02,   0.00000000e+00,  -1.50672728e-02,
         0.00000000e+00,  -6.31519876e-03,   1.17777050e-04,
         1.73631667e-02,   1.09241071e-02,   0.00000000e+00,
        -2.53878790e-03,   1.07135163e-02,   0.00000000e+00,
         4.75937448e-03,  -1.18997509e-03,   2.96808980e-02,
        -6.15929627e-03,  -1.36000395e-02,  -3.79231806e-03,
         0.00000000e+00,  -3.62857910e-03,   0.00000000e+00,
        -5.66361784e-03,  -2.13807896e-03,  -3.37719441e-03,
        -3.04071660e-03,   0.00000000e+00,  -2.02642121e-03,
        -8.90842260e-03,   0.00000000e+00,   6.91088156e-03,
        -8.31608441e-04,   2.04123565e-03,   3.11232608e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.17051309e-03,  -1.06546837e-02,   2.20416135e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.62951670e-03,   0.00000000e+00,
        -1.68835143e-02,  -1.62228729e-02,   3.86366354e-03,
         0.00000000e+00,  -6.94176139e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.40484362e-04,   0.00000000e+00,   9.55044034e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.65952114e-03,   0.00000000e+00,
        -4.38597270e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.31451489e-03,   0.00000000e+00,   2.61259433e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.44068260e-03,   0.00000000e+00,  -9.82221393e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.84287333e-03,   1.28461630e-03,
        -5.39664047e-04,   0.00000000e+00,   2.19240961e-03,
         0.00000000e+00,  -4.44356108e-04,   7.31024358e-04,
         1.72927469e-03,  -2.50257273e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.69603122e-03,   0.00000000e+00,  -3.95213662e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.74386439e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.61485492e-03,   0.00000000e+00,  -5.71184053e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.69812053e-04,   0.00000000e+00,
         0.00000000e+00,   2.18657140e-02,   2.61644235e-02,
        -5.54585479e-03,   0.00000000e+00,   8.37812560e-03,
         0.00000000e+00,  -6.24691792e-04,   1.50846052e-03,
        -1.57466124e-03,   1.44291174e-03,   0.00000000e+00,
         1.41735113e-03,   2.20359278e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.58193946e-04,   0.00000000e+00,  -1.05852708e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.28501288e-05,   0.00000000e+00,
         0.00000000e+00,   6.96640491e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.97327081e-03,   0.00000000e+00,  -7.42815295e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.33471700e-03,   0.00000000e+00,
         0.00000000e+00,   1.58898200e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.20841963e-02,   0.00000000e+00,
         1.13429487e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.05843632e-03,
         0.00000000e+00,   0.00000000e+00,  -9.00388599e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.14769660e-02,   0.00000000e+00,   3.33509723e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.04335557e-03,   0.00000000e+00,
         0.00000000e+00,  -1.59036109e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.05793983e-03,   8.25560224e-03,  -3.55419821e-03,
        -5.18534779e-03,  -7.23033325e-03,  -2.34636288e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.00205864e-02,  -3.49493195e-03,  -1.53212143e-03,
         1.48708494e-04,   0.00000000e+00,  -1.12523550e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.61095098e-03,   0.00000000e+00,   2.09399181e-03,
        -1.40790499e-02,  -1.64756174e-02,   7.45519548e-03,
         0.00000000e+00,  -3.29101740e-04,   0.00000000e+00,
         3.71697021e-03,   2.07941171e-03,  -1.11081498e-03,
         1.24184065e-03,   0.00000000e+00,  -7.13327363e-03,
         0.00000000e+00,  -2.96280936e-03,   5.94330249e-05,
         8.64375368e-04,  -2.12146672e-03,   1.27935318e-04,
         0.00000000e+00,   4.12808057e-03,   0.00000000e+00,
         2.40072812e-03,  -1.14926615e-03,  -5.95112377e-03,
         4.80810095e-03,   1.13646517e-03,  -4.07302141e-03,
         0.00000000e+00,   6.28421667e-05,   0.00000000e+00,
        -1.29787969e-03,   1.35215406e-03,   1.02234562e-03,
        -1.65168354e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.84215163e-03,   0.00000000e+00,
        -4.68846903e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.02805470e-02,
         7.91793959e-03,   1.57582388e-03,   1.38197192e-03,
         0.00000000e+00,   6.84353831e-03,   0.00000000e+00,
        -8.84026627e-03,   2.58751311e-03,   1.02816976e-03,
         1.92113938e-03,   0.00000000e+00,  -7.51473390e-03,
        -7.88281292e-03,  -3.75508839e-03,  -7.57096290e-03,
         0.00000000e+00,  -1.28493760e-03,   0.00000000e+00,
        -2.51958921e-03,   1.03309465e-03,  -4.12206829e-03,
        -2.27609281e-03,   0.00000000e+00,  -3.39684713e-03,
        -5.91177444e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.25373128e-03,   0.00000000e+00,
        -3.11854930e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.72527999e-03,
         0.00000000e+00,   0.00000000e+00,   4.59033636e-03,
         1.92989582e-02,   2.50926456e-02,  -9.05133332e-03,
         0.00000000e+00,   5.61623378e-03,   0.00000000e+00,
        -3.64348374e-03,   1.24517067e-03,  -1.91786110e-03,
         5.31668485e-04,   0.00000000e+00,   3.19729611e-03,
         7.40842990e-04,   0.00000000e+00,   6.09675313e-03,
         1.45165541e-03,   7.51913850e-04,  -1.47868327e-03,
         0.00000000e+00,  -1.43331124e-03,   0.00000000e+00,
        -7.00745527e-03,  -4.67120109e-03,   1.81097246e-03,
         1.13238803e-03,   0.00000000e+00,   3.05151669e-03,
        -2.18905166e-04,   0.00000000e+00,   7.83689629e-04,
         4.40149627e-03,   3.66965304e-03,  -2.22890104e-03,
         9.13224100e-03,   0.00000000e+00,   7.00226453e-03,
         0.00000000e+00,   1.02733529e-02,  -9.99271514e-04,
        -4.93730867e-04,  -9.48373162e-04,   0.00000000e+00,
        -2.40060180e-03,  -5.16652308e-04,   0.00000000e+00,
        -6.26631069e-03,  -2.80261607e-03,  -1.03784750e-02,
        -3.52462263e-03,  -1.59683951e-03,   9.30801123e-03,
         0.00000000e+00,   8.73032152e-03,   0.00000000e+00,
         3.13357001e-02,   7.63006263e-04,  -7.76474536e-05,
        -3.40656078e-03,   0.00000000e+00,  -5.26899838e-03,
         4.49838575e-03,   0.00000000e+00,  -1.43464738e-02,
         1.81079313e-05,   4.00296120e-03,   3.42562777e-03,
         2.49509738e-02,  -2.16714696e-03,   2.98248658e-02,
        -1.16430936e-03,  -6.72646524e-03,   2.93772228e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.12707966e-02,   2.79959023e-03,   1.45037080e-02,
        -2.87023939e-03,   0.00000000e+00,   3.16059718e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.30047946e-03,   0.00000000e+00,   3.21706140e-02,
         4.05777119e-04,  -2.22006286e-03,   8.43662005e-04,
         0.00000000e+00,   5.31976359e-04,   0.00000000e+00,
         3.07112332e-02,  -2.30055396e-02,  -1.39922039e-02,
         3.95054579e-03,   0.00000000e+00,  -3.71661407e-03,
         0.00000000e+00,  -3.16717247e-04,   2.27643779e-02,
         2.63450580e-03,   7.24591427e-03,   5.90529800e-03,
         0.00000000e+00,   1.36667996e-03,   0.00000000e+00,
        -2.94998392e-03,  -1.66645058e-03,   1.03402756e-02,
        -2.64528346e-03,   1.47699767e-03,   4.09046379e-03,
         0.00000000e+00,   1.32676573e-03,   0.00000000e+00,
        -5.70275299e-03,   1.27913272e-03,   4.41393445e-03,
         1.12527862e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.38919136e-02,   0.00000000e+00,
         1.89892907e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.78829784e-02,
         4.50397655e-03,   2.69812199e-03,  -6.97109632e-03,
         0.00000000e+00,  -7.42773528e-03,   0.00000000e+00,
         3.74530501e-04,  -8.94175172e-03,  -6.58085919e-04,
        -2.62074072e-03,   0.00000000e+00,   2.37827388e-02,
         4.11553105e-03,   5.47696712e-03,   8.16921911e-03,
         0.00000000e+00,   1.32415368e-03,   0.00000000e+00,
         2.45305789e-03,  -9.39122885e-03,   6.61486329e-03,
         2.20782329e-03,   0.00000000e+00,  -3.01284617e-03,
         2.54541355e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.03505729e-03,   0.00000000e+00,
        -2.22634379e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.35026911e-03,
         0.00000000e+00,   0.00000000e+00,   2.62739792e-02,
         2.09663804e-03,   7.51913850e-04,  -4.97983481e-03,
         0.00000000e+00,  -6.00401704e-03,   0.00000000e+00,
        -2.09541549e-02,  -2.40474170e-03,   1.44931485e-03,
         3.82991769e-03,   0.00000000e+00,   2.51038780e-03,
        -1.59932740e-03,   0.00000000e+00,   2.50067963e-02,
         1.95504256e-02,   3.11805381e-02,  -1.25736228e-02,
         0.00000000e+00,   2.28120306e-02,   0.00000000e+00,
        -2.56905701e-03,  -2.37273862e-02,   5.84709239e-03,
         3.84442692e-04,   0.00000000e+00,  -2.11940439e-05,
         5.36738077e-04,   0.00000000e+00,   7.13750364e-04,
         3.54696999e-02,  -1.25372527e-02,  -7.54930139e-04,
         2.11066528e-03,   0.00000000e+00,  -6.12727612e-03,
         0.00000000e+00,  -1.32713349e-03,   1.89520070e-02,
         3.53908129e-04,   2.38916401e-03,   0.00000000e+00,
        -4.23602171e-03,  -4.37694658e-03,   0.00000000e+00,
        -9.73613934e-04,  -6.20895822e-03,   2.76839851e-02,
        -3.71832147e-03,  -1.19724212e-02,   8.38837584e-03,
         0.00000000e+00,  -1.51275898e-02,   0.00000000e+00,
         2.32259368e-03,   2.29507556e-02,  -6.73268835e-03,
         5.75650952e-04,   0.00000000e+00,  -1.35612844e-03,
        -2.02415693e-03,   0.00000000e+00,   1.16502583e-04,
        -2.71547295e-02,   8.08245885e-04,   2.08120973e-02,
         2.61303758e-02,  -7.11843921e-02,   2.33709711e-02,
         1.34628737e-02,   1.35667734e-02,   6.33697180e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.18729593e-02,  -1.35455128e-02,  -2.80443413e-02,
        -1.49272259e-03,   0.00000000e+00,   5.54552336e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.26354747e-02,   0.00000000e+00,  -2.89657751e-02,
         3.22839678e-03,   4.26249959e-03,  -4.50813645e-02,
         0.00000000e+00,  -4.44140177e-02,   0.00000000e+00,
        -2.42629520e-02,  -3.06048343e-02,   9.98331263e-03,
        -1.71802762e-02,   0.00000000e+00,   4.76001467e-02,
         0.00000000e+00,  -1.37654965e-02,  -1.24677792e-02,
        -9.91216396e-03,   2.65583497e-02,   3.53507729e-02,
         0.00000000e+00,  -1.80228394e-02,   0.00000000e+00,
        -5.92297559e-03,   7.01461719e-03,   2.52914204e-02,
        -1.00189115e-02,   1.00922111e-02,   2.40708983e-02,
         0.00000000e+00,   7.21324868e-03,   0.00000000e+00,
        -4.73424240e-03,   2.79447205e-03,   2.11833787e-02,
         2.09257864e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.72717377e-02,   0.00000000e+00,
         4.65911024e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.90884205e-02,
         1.80301233e-03,   5.49681475e-03,  -2.05889055e-02,
         0.00000000e+00,  -5.63614266e-02,   0.00000000e+00,
         4.33588463e-02,  -2.37356500e-02,   6.97930741e-04,
        -1.68045150e-02,   0.00000000e+00,   7.76374715e-02,
        -6.05886604e-03,   1.36602214e-02,   4.93857596e-02,
         0.00000000e+00,  -3.45139340e-02,   0.00000000e+00,
        -2.02204577e-02,  -1.63911921e-02,   3.48358843e-02,
         2.32488939e-02,   0.00000000e+00,   2.73785984e-03,
         7.65234371e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.66291632e-02,   0.00000000e+00,
         3.42622435e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.24628604e-02,
         0.00000000e+00,   0.00000000e+00,  -4.90882813e-02,
         4.96063460e-03,  -2.22890104e-03,   2.44879515e-02,
         0.00000000e+00,   1.67626619e-02,   0.00000000e+00,
         2.98672753e-02,  -4.38604631e-05,   2.38421376e-03,
        -2.83909142e-03,   0.00000000e+00,  -2.46673096e-02,
         2.42877343e-02,   0.00000000e+00,  -4.13429720e-02,
        -1.08309906e-02,  -7.54930139e-04,   3.36978103e-03,
         0.00000000e+00,  -6.85995978e-03,   0.00000000e+00,
        -7.62114114e-04,   4.93389588e-02,  -1.14062920e-02,
         4.12654250e-03,   0.00000000e+00,  -1.30288514e-02,
        -1.59738107e-02,   0.00000000e+00,  -3.58048994e-03,
        -4.49313563e-02,  -3.62557276e-02,   6.27202416e-02,
        -1.37465988e-03,   0.00000000e+00,   1.68471924e-03,
         0.00000000e+00,   3.64281874e-03,   2.04865162e-02,
         2.05131655e-02,   1.49758020e-02,   0.00000000e+00,
         7.03172066e-03,   1.30067382e-02,   0.00000000e+00,
        -1.10268651e-02,   2.04099290e-02,   6.99039128e-02,
         3.64831713e-02,   1.18042435e-02,  -3.35094337e-03,
         0.00000000e+00,   1.01844129e-02,   0.00000000e+00,
         1.66209333e-03,   3.59237654e-03,  -1.01505270e-02,
        -9.94040055e-04,   0.00000000e+00,   1.16528867e-03,
         6.33438908e-03,   0.00000000e+00,   6.14644826e-03,
        -3.23465657e-03,  -4.08222963e-02,  -3.89724292e-02,
        -6.76751744e-02,  -4.55673937e-02,  -7.67718308e-02,
         6.84340862e-03,   1.19374533e-02,  -3.71977000e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.66382994e-02,  -1.22145335e-02,  -1.43590094e-02,
         3.24209167e-03,   0.00000000e+00,  -6.04513178e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.58641078e-02,   0.00000000e+00,  -1.07908018e-01,
         2.80210200e-03,  -2.69984493e-04,  -2.93653133e-02,
         0.00000000e+00,  -2.38522864e-02,   0.00000000e+00,
        -1.03676924e-01,  -1.76988672e-02,  -5.24332659e-03,
        -1.47272628e-02,   0.00000000e+00,   2.55040774e-02,
         0.00000000e+00,  -3.82373440e-03,  -1.04871365e-01,
         1.36378149e-02,  -1.92525000e-03,  -3.89066623e-03,
         0.00000000e+00,  -2.85858824e-03,   0.00000000e+00,
         3.12709071e-03,   2.89216877e-02,  -1.59249836e-02,
        -2.92817296e-03,  -6.06681357e-03,  -2.71175275e-04,
         0.00000000e+00,   6.09557490e-03,   0.00000000e+00,
         1.47588750e-02,  -7.15429618e-03,  -4.65333684e-03,
        -1.10442864e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.92208707e-02,   0.00000000e+00,
         1.04688333e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.26473805e-02,
        -7.55610372e-03,  -8.36483647e-03,   1.72866901e-02,
         0.00000000e+00,   1.93364957e-02,   0.00000000e+00,
         1.15222539e-02,   9.09279654e-03,  -2.53041634e-03,
         1.32638888e-03,   0.00000000e+00,  -3.01326257e-02,
        -8.33860270e-03,  -1.36000395e-02,  -1.86840779e-02,
         0.00000000e+00,  -6.46513395e-03,   0.00000000e+00,
        -1.81494793e-02,   6.61854813e-03,  -1.01694014e-02,
        -2.05108087e-03,   0.00000000e+00,  -9.94210460e-04,
        -3.24801583e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.50641551e-02,   0.00000000e+00,
         9.13063634e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.01517010e-02,
         0.00000000e+00,   0.00000000e+00,  -1.09149832e-01,
        -4.68077970e-03,  -1.59683951e-03,   2.57044714e-02,
         0.00000000e+00,   2.65921899e-02,   0.00000000e+00,
         8.54927932e-02,   3.47388488e-03,  -2.05574513e-03,
        -1.43838542e-02,   0.00000000e+00,  -1.99695280e-02,
         2.08535022e-02,   0.00000000e+00,  -1.02138503e-01,
         5.58903907e-03,  -1.19724212e-02,   1.88850844e-02,
         0.00000000e+00,  -3.83912843e-02,   0.00000000e+00,
         5.04709241e-03,   7.95006307e-02,  -2.15641372e-02,
         5.54000442e-03,   0.00000000e+00,  -5.76740374e-03,
        -7.84233399e-03,   0.00000000e+00,  -2.14109101e-03,
        -1.29510146e-01,   3.61373891e-02,   1.18042435e-02,
        -3.92311007e-03,   0.00000000e+00,   1.30502975e-02,
         0.00000000e+00,   5.34330230e-03,  -2.37146273e-03,
        -7.77999047e-03,  -2.93715216e-03,   0.00000000e+00,
        -2.32316978e-03,   4.49059874e-03,   0.00000000e+00,
        -4.78527744e-03,   9.20219655e-03,  -3.83314777e-02,
         4.99883595e-02,   6.59212415e-02,  -1.15789177e-02,
         0.00000000e+00,   1.49616406e-02,   0.00000000e+00,
        -2.50273464e-03,   2.73128926e-02,  -1.07105923e-02,
         7.17939386e-03,   0.00000000e+00,   9.99632065e-03,
         1.23766451e-02,   0.00000000e+00,   2.65226660e-03,
        -6.25859207e-03,  -3.60529753e-02,  -1.05830419e-01,
         2.30921180e-02,  -9.45346880e-03,  -1.62842301e-02,
         8.80854177e-02,  -3.75049011e-02,   5.21324614e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.57535161e-02,  -9.28478876e-03,  -5.53965385e-03,
         4.40815095e-03,   0.00000000e+00,   3.27669023e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.80074514e-02,   0.00000000e+00,  -6.68700866e-03,
         1.13468026e-02,   5.67923118e-02,  -2.78003651e-02,
         0.00000000e+00,  -1.53083336e-02,   0.00000000e+00,
        -4.99735296e-03,  -6.34531921e-04,   2.67967346e-02,
        -2.10037997e-02,   0.00000000e+00,   2.56210582e-02,
         0.00000000e+00,   7.66922092e-03,   2.25030822e-03,
         1.23268124e-02,  -1.23385857e-02,   3.67638183e-02,
         0.00000000e+00,  -7.18736771e-03,   0.00000000e+00,
        -1.21291704e-02,  -1.80636290e-02,  -2.41444183e-02,
         2.28668925e-03,   5.09962009e-03,   4.74568739e-02,
         0.00000000e+00,  -1.50368894e-03,   0.00000000e+00,
        -1.55983930e-02,  -1.02690204e-02,  -5.70328304e-03,
        -5.87247751e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.72982555e-02,   0.00000000e+00,
         1.69001161e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.45530320e-02,
        -2.23479058e-03,   3.13414506e-03,  -3.71368565e-03,
         0.00000000e+00,  -2.03058665e-02,   0.00000000e+00,
         1.70853760e-02,  -4.86599343e-03,   6.72141062e-03,
        -1.40577762e-02,   0.00000000e+00,   4.05768839e-02,
         8.82101585e-03,  -9.41707285e-03,   7.59701246e-03,
         0.00000000e+00,  -1.18931914e-02,   0.00000000e+00,
        -5.71648522e-03,  -2.15561332e-02,  -2.58723143e-03,
        -2.29261890e-03,   0.00000000e+00,  -1.58170290e-02,
         6.30389751e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.91291287e-03,   0.00000000e+00,
         9.88672860e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.65992633e-03,
         0.00000000e+00,   0.00000000e+00,  -1.48414736e-02,
         1.87332843e-03,  -5.18534779e-03,   7.39123491e-03,
         0.00000000e+00,  -2.42890237e-03,   0.00000000e+00,
         1.15666918e-02,  -5.63725022e-03,   3.19832613e-03,
         5.08317915e-03,   0.00000000e+00,  -2.10377317e-02,
         1.55215524e-02,   0.00000000e+00,  -1.07377116e-02,
        -3.17763701e-03,  -1.16430936e-03,   8.07160734e-05,
         0.00000000e+00,  -4.99036870e-03,   0.00000000e+00,
         6.94429458e-03,   1.31863860e-02,  -3.72379371e-03,
        -2.69409966e-03,   0.00000000e+00,  -1.69391047e-03,
        -2.65467219e-02,   0.00000000e+00,  -5.83932625e-03,
        -1.65000163e-02,  -8.66503140e-03,   1.34628737e-02,
        -1.86036145e-02,   0.00000000e+00,   4.33780451e-03,
         0.00000000e+00,   3.61272055e-03,   1.26364596e-02,
        -4.56711535e-03,  -8.16679330e-03,   0.00000000e+00,
         3.04555735e-02,  -5.43822059e-02,   0.00000000e+00,
        -4.63899674e-03,   2.16638300e-02,   1.83778742e-02,
         1.28300028e-02,   6.84340862e-03,   1.44305871e-03,
         0.00000000e+00,  -4.31014203e-03,   0.00000000e+00,
         2.21081379e-03,  -4.28317824e-03,  -1.07215360e-03,
         1.43677316e-03,   0.00000000e+00,  -2.27878295e-03,
         1.30688571e-02,   0.00000000e+00,   4.64013048e-02,
         1.66729495e-02,  -8.96386373e-03,  -1.78222843e-03,
        -6.87908643e-03,  -6.66290845e-02,   8.05989496e-03,
        -3.75049011e-02,   8.01635503e-02,   4.44416069e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.12561344e-03,  -5.05386446e-03,  -2.03948099e-02,
        -9.34561286e-03,   0.00000000e+00,  -1.46791456e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.77852958e-02,   0.00000000e+00,  -5.75241382e-02,
         4.26804792e-02,   1.82489787e-03,  -3.51227288e-02,
         0.00000000e+00,  -1.19709049e-02,   0.00000000e+00,
        -5.61780293e-02,   3.90115329e-03,   1.21368928e-02,
        -1.10930295e-02,   0.00000000e+00,   3.99100388e-02,
         0.00000000e+00,  -8.78535415e-03,  -4.28021300e-02,
        -1.51479624e-02,   1.27502597e-02,  -9.94331829e-03,
         0.00000000e+00,  -1.20955932e-02,   0.00000000e+00,
         7.92536674e-03,   3.36142222e-02,   5.51007367e-02,
        -2.47946765e-03,  -1.05017014e-02,  -3.60367504e-02,
         0.00000000e+00,   2.99574143e-03,   0.00000000e+00,
         2.43188896e-02,   1.12126252e-02,   2.78767763e-02,
         1.06460670e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.26357470e-03,   0.00000000e+00,
         1.07330068e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.88837793e-02,
         1.50274748e-03,  -1.18351955e-02,   3.01124746e-03,
         0.00000000e+00,   1.02247618e-03,   0.00000000e+00,
         1.23290057e-02,  -3.24132527e-03,  -1.56158336e-03,
         2.80387735e-03,   0.00000000e+00,   8.88657109e-03,
        -9.07739068e-03,   1.06684763e-02,   5.79287030e-03,
         0.00000000e+00,  -9.47735384e-04,   0.00000000e+00,
        -7.59113915e-03,   8.30033739e-03,   1.84688432e-02,
         1.05356598e-02,   0.00000000e+00,   1.63129415e-02,
         1.68109746e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.32318452e-03,   0.00000000e+00,
         2.34582022e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.63532021e-02,
         0.00000000e+00,   0.00000000e+00,  -6.27778455e-02,
        -7.96715102e-03,  -7.23033325e-03,   1.11116004e-02,
         0.00000000e+00,   7.99703842e-03,   0.00000000e+00,
         1.89371143e-02,  -7.43917788e-04,   2.95378929e-03,
        -1.97174327e-02,   0.00000000e+00,  -1.10411212e-02,
         6.54097530e-03,   0.00000000e+00,  -6.16758585e-02,
        -4.00473065e-03,  -6.72646524e-03,   9.07569148e-03,
         0.00000000e+00,  -6.09692527e-03,   0.00000000e+00,
        -1.07808074e-03,   2.24571997e-02,  -3.42015824e-03,
         6.85027546e-03,   0.00000000e+00,  -1.35873972e-02,
        -2.93731837e-03,   0.00000000e+00,  -8.14374023e-03,
        -7.43366088e-02,   2.34657539e-03,   1.35667734e-02,
         1.04927157e-02,   0.00000000e+00,   7.06418301e-04,
         0.00000000e+00,  -1.18711340e-02,   3.58388441e-03,
         1.07225162e-02,   1.39036347e-02,   0.00000000e+00,
        -1.51323865e-02,   5.31571344e-02,   0.00000000e+00,
         1.42846359e-02,   1.80692909e-02,   3.12632679e-02,
         1.19564000e-02,   1.19374533e-02,  -7.52449432e-03,
         0.00000000e+00,   1.09737720e-02,   0.00000000e+00,
        -8.72860912e-03,   3.88854700e-03,  -4.56485077e-03,
         8.16869641e-03,   0.00000000e+00,   2.08431172e-02,
        -1.10473876e-02,   0.00000000e+00,   1.94654965e-02,
         1.37361240e-02,  -3.04704285e-02,  -4.87794538e-02,
         5.80333645e-01,  -1.03135352e-01,   5.52377179e-01,
         5.21324614e-02,   4.44416069e-03,   6.66027594e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.19721035e-01,  -4.14634835e-02,  -4.39340757e-02,
        -1.79020155e-03,   0.00000000e+00,   5.86454241e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.41025878e-02,   0.00000000e+00,   4.72842983e-01,
        -5.18683454e-03,   2.03282810e-03,  -8.00876644e-02,
         0.00000000e+00,  -6.73198779e-02,   0.00000000e+00,
         4.97347951e-01,  -3.05671976e-02,   5.50095629e-02,
        -3.93692822e-02,   0.00000000e+00,   7.95669593e-02,
         0.00000000e+00,  -1.05951649e-02,   4.89757747e-01,
        -1.77534352e-02,   2.77299570e-02,   9.62791679e-02,
         0.00000000e+00,  -3.17685067e-02,   0.00000000e+00,
        -2.24337714e-02,  -3.92035804e-02,   4.21657290e-01,
         1.04128658e-02,  -2.47363032e-03,   3.30845848e-02,
         0.00000000e+00,   1.67859213e-02,   0.00000000e+00,
        -2.00227137e-02,   2.64907343e-02,   1.06346421e-01,
         5.00230789e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.29313312e-01,   0.00000000e+00,
         6.40143158e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.89863614e-01,
         2.68832728e-03,   2.56872912e-02,  -6.08984970e-02,
         0.00000000e+00,  -1.01848428e-01,   0.00000000e+00,
         6.07560021e-02,  -5.06430567e-02,  -1.99694045e-03,
        -2.60803256e-02,   0.00000000e+00,   5.94020316e-01,
         1.36666287e-02,   2.03364011e-02,   9.83594187e-02,
         0.00000000e+00,  -4.36039716e-02,   0.00000000e+00,
        -1.98858441e-02,  -4.70709333e-02,   8.09180301e-02,
         3.74734371e-02,   0.00000000e+00,  -2.09405387e-02,
         6.18319210e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.71205105e-04,   0.00000000e+00,
        -5.13369465e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.14924593e-02,
         0.00000000e+00,   0.00000000e+00,   4.08705466e-01,
         1.44608366e-02,  -2.34636288e-03,   1.29666340e-02,
         0.00000000e+00,  -9.02966345e-03,   0.00000000e+00,
        -5.55457371e-02,  -9.90429339e-03,   1.80464646e-03,
         8.32692403e-03,   0.00000000e+00,  -2.93230153e-02,
         3.88351855e-02,   0.00000000e+00,   4.29978230e-01,
        -6.63966527e-03,   2.93772228e-02,  -2.67664226e-02,
         0.00000000e+00,   3.45773823e-02,   0.00000000e+00,
        -2.59946694e-03,  -1.89291354e-02,   1.25927419e-02,
        -2.14840861e-03,   0.00000000e+00,  -2.36802247e-02,
        -4.77729671e-02,   0.00000000e+00,  -4.19347976e-04,
         4.27040106e-01,  -7.97560719e-02,   6.33697180e-02,
        -2.67567553e-02,   0.00000000e+00,  -1.64576479e-02,
         0.00000000e+00,   1.07140311e-02,   6.16757427e-02,
         4.86050925e-02,   4.12789026e-03,   0.00000000e+00,
         1.37414009e-02,  -1.72942836e-02,   0.00000000e+00,
        -2.73224216e-02,   5.90759898e-02,   5.92307556e-01,
         1.92502086e-03,  -3.71977000e-02,   1.42635844e-02,
         0.00000000e+00,  -8.27805484e-03,   0.00000000e+00,
         4.68259380e-03,  -8.72092996e-03,  -9.38988833e-03,
        -2.85964124e-03,   0.00000000e+00,  -7.18830929e-03,
         1.46317621e-02,   0.00000000e+00,   5.13149622e-03,
         1.83202911e-02,  -5.26588391e-02,   4.67245588e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.85487857e-02,  -1.45537593e-02,   3.31267103e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.95092685e-04,   0.00000000e+00,
        -1.06487948e-02,   2.40236305e-03,  -1.02995214e-02,
         0.00000000e+00,  -2.83116595e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.74431433e-03,   0.00000000e+00,   1.23172086e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.61874294e-03,   0.00000000e+00,
         8.26075866e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.40495180e-03,   0.00000000e+00,  -4.23361239e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.91335760e-03,   0.00000000e+00,  -2.35608130e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.26489029e-03,   5.23669220e-03,
        -7.59005582e-03,   0.00000000e+00,   3.14748278e-04,
         0.00000000e+00,   3.11803113e-03,   4.42735292e-03,
        -2.55977150e-03,  -4.43829463e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.85852512e-03,   0.00000000e+00,   1.68057724e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.31497987e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.27215462e-03,   0.00000000e+00,  -4.57733490e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.27228480e-02,   0.00000000e+00,
         0.00000000e+00,   4.17282019e-03,   2.20416135e-03,
         5.01739154e-04,   0.00000000e+00,  -1.48390086e-03,
         0.00000000e+00,  -1.92433087e-04,  -3.77850032e-04,
         4.42179281e-04,   1.61073975e-03,   0.00000000e+00,
        -1.19671332e-03,   1.82229975e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.81955033e-04,   0.00000000e+00,  -1.64113598e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.44171363e-03,   0.00000000e+00,
         0.00000000e+00,   7.59730123e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.86887670e-03,   0.00000000e+00,   1.53427073e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.82780548e-03,   0.00000000e+00,
         0.00000000e+00,   5.06628804e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.43517350e-03,   0.00000000e+00,
         4.97759041e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.85686336e-02,
         0.00000000e+00,   0.00000000e+00,  -3.39073753e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.01888094e-04,   0.00000000e+00,   4.06273853e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.63730640e-03,   0.00000000e+00,
         0.00000000e+00,  -7.34881207e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.14126951e-02,  -2.65362697e-03,  -7.67668166e-03,
         4.40815095e-03,  -9.34561286e-03,  -1.79020155e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.45852574e-03,   9.83036118e-03,  -1.18173568e-02,
         2.93047658e-02,   0.00000000e+00,  -3.98669875e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.52344523e-03,   0.00000000e+00,  -9.43080549e-03,
        -5.94982366e-03,   1.08039585e-02,  -1.26408676e-02,
         0.00000000e+00,  -9.44771587e-03,   0.00000000e+00,
         7.06109208e-03,   8.89126244e-03,   6.30665086e-03,
         3.61791771e-03,   0.00000000e+00,   3.90646022e-03,
         0.00000000e+00,  -5.78233574e-03,  -1.95088322e-02,
        -1.17973232e-03,  -3.58777128e-03,   1.59212735e-03,
         0.00000000e+00,   3.00281968e-03,   0.00000000e+00,
        -1.69910146e-03,   3.51154715e-03,  -9.13970020e-03,
        -1.00301278e-03,   4.61380305e-04,   7.89268045e-03,
         0.00000000e+00,   3.71959890e-03,   0.00000000e+00,
        -4.97604854e-03,  -1.17184862e-03,  -3.77059817e-03,
        -1.37539986e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.53245150e-03,   0.00000000e+00,
         2.11540729e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.13110296e-03,
        -6.04749155e-03,   4.69914716e-03,  -5.42850568e-03,
         0.00000000e+00,  -1.25079961e-03,   0.00000000e+00,
         3.63229215e-03,   1.94992470e-03,  -2.20595674e-03,
        -5.47675898e-03,   0.00000000e+00,   2.40055892e-02,
        -3.07321590e-03,   1.37195144e-03,  -5.63610889e-03,
         0.00000000e+00,   7.78174504e-03,   0.00000000e+00,
        -7.41959009e-04,   5.46941431e-03,  -6.46205729e-03,
        -2.21906531e-03,   0.00000000e+00,  -1.36772614e-02,
        -1.10934461e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.10134334e-03,   0.00000000e+00,
         2.06541486e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.55925478e-03,
         0.00000000e+00,   0.00000000e+00,  -9.68937909e-03,
        -2.54394783e-03,   1.48708494e-04,  -2.84029203e-03,
         0.00000000e+00,   2.04106190e-04,   0.00000000e+00,
         5.57578136e-04,   1.09432815e-03,  -1.57320617e-03,
         2.12238155e-03,   0.00000000e+00,  -9.52951538e-03,
         9.76086458e-04,   0.00000000e+00,   1.15039564e-03,
        -3.01919037e-03,  -2.87023939e-03,   8.86497585e-04,
         0.00000000e+00,  -2.88152703e-03,   0.00000000e+00,
         9.58238970e-04,   8.48748026e-04,   4.55227464e-05,
        -1.10031548e-03,   0.00000000e+00,  -1.54662583e-03,
         1.24068670e-03,   0.00000000e+00,  -3.25268937e-03,
        -2.11267782e-02,   2.33164553e-03,  -1.49272259e-03,
        -1.75398927e-03,   0.00000000e+00,  -6.12144326e-03,
         0.00000000e+00,   2.12276278e-03,  -4.67229951e-03,
         9.94745905e-04,  -2.87811645e-03,   0.00000000e+00,
         1.39143951e-02,  -9.34757878e-04,   0.00000000e+00,
        -2.48548488e-03,   2.89483437e-03,  -4.85568823e-03,
        -3.13525061e-03,   3.24209167e-03,  -2.50732592e-03,
         0.00000000e+00,   4.92137674e-03,   0.00000000e+00,
        -2.64423801e-03,  -1.30897869e-03,  -8.83586081e-04,
        -1.04820003e-03,   0.00000000e+00,  -3.84648959e-03,
         2.24334783e-03,   0.00000000e+00,   2.98285071e-03,
         6.60102504e-03,  -2.91585163e-03,  -4.71852791e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.52860391e-02,  -1.72438422e-03,  -1.02995214e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.49912214e-03,   0.00000000e+00,
        -1.13738691e-02,  -2.04900369e-02,   1.58790138e-02,
         0.00000000e+00,  -3.55292973e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.10157327e-02,   0.00000000e+00,   9.19255226e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.85559763e-03,   0.00000000e+00,
         2.64057699e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.93580993e-03,   0.00000000e+00,   1.05865507e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.18717427e-03,   0.00000000e+00,  -2.13176592e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.62724485e-03,   2.37788412e-04,
         3.22959890e-03,   0.00000000e+00,   1.11665463e-03,
         0.00000000e+00,  -3.26186709e-03,  -3.16594137e-03,
         1.36816377e-03,   3.18069925e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.10515977e-03,   0.00000000e+00,  -4.18515259e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.78112937e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.41513736e-03,   0.00000000e+00,   1.34706081e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.00621784e-02,   0.00000000e+00,
         0.00000000e+00,   2.19644145e-03,   3.86366354e-03,
        -2.47048591e-03,   0.00000000e+00,   1.73885510e-03,
         0.00000000e+00,  -3.72549352e-03,   2.89965805e-04,
        -1.10654219e-03,   1.38517698e-03,   0.00000000e+00,
         5.49132868e-03,  -5.97384254e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.96707510e-03,   0.00000000e+00,  -3.07847984e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.93446668e-03,   0.00000000e+00,
         0.00000000e+00,   9.81538552e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.22367239e-05,   0.00000000e+00,  -4.31931793e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.42640470e-03,   0.00000000e+00,
         0.00000000e+00,   9.27820748e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.26035633e-03,   0.00000000e+00,
         1.30430914e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.89313882e-03,
         0.00000000e+00,   0.00000000e+00,  -5.79022204e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.85783480e-03,   0.00000000e+00,   2.72190724e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.88810255e-04,   0.00000000e+00,
         0.00000000e+00,  -1.89409182e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.97223647e-02,   1.35418254e-01,   1.71175864e-02,
        -2.78003651e-02,  -3.51227288e-02,  -8.00876644e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.01168657e-02,   4.92145292e-03,   6.21208205e-02,
        -1.26408676e-02,   0.00000000e+00,  -3.62384491e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.09184928e-01,   0.00000000e+00,   1.11302867e-01,
        -1.33027834e-02,  -2.77851313e-02,   1.11548513e-01,
         0.00000000e+00,   8.12913535e-02,   0.00000000e+00,
         1.15679500e-01,   3.37209385e-02,  -8.37720163e-03,
         4.33465222e-02,   0.00000000e+00,  -8.28142473e-02,
         0.00000000e+00,   2.31996210e-02,   8.99533429e-02,
        -3.86766606e-03,  -1.42048913e-02,  -3.18218803e-02,
         0.00000000e+00,   2.16107017e-02,   0.00000000e+00,
        -5.05612595e-04,  -3.68548669e-02,  -5.12076129e-02,
        -2.88298977e-04,   9.38484845e-03,  -9.92920398e-03,
         0.00000000e+00,  -8.82710877e-03,   0.00000000e+00,
        -1.28596699e-02,   1.38057424e-04,  -3.47265035e-02,
        -8.67598685e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.63504915e-02,   0.00000000e+00,
        -4.10067699e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.13122355e-02,
         5.47301554e-03,   2.14308009e-03,   1.61616159e-02,
         0.00000000e+00,   3.14228273e-02,   0.00000000e+00,
        -4.62820924e-02,   9.15484128e-03,  -2.32562948e-03,
         2.12543765e-02,   0.00000000e+00,  -1.00513119e-01,
        -7.39843507e-04,   1.64339319e-03,  -3.15801947e-02,
         0.00000000e+00,   1.92274398e-02,   0.00000000e+00,
         2.82942157e-02,   9.08473611e-03,  -2.80283096e-02,
        -1.87018804e-02,   0.00000000e+00,   1.28667191e-03,
        -8.55099418e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.32634969e-02,   0.00000000e+00,
        -5.50114367e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.43360236e-02,
         0.00000000e+00,   0.00000000e+00,   1.35241015e-01,
         1.91078263e-03,   7.45519548e-03,  -2.64965342e-02,
         0.00000000e+00,  -1.76077084e-02,   0.00000000e+00,
        -5.35598568e-02,   6.39352909e-05,  -1.97963883e-03,
         2.32153515e-02,   0.00000000e+00,   5.81031906e-02,
        -5.04932272e-02,   0.00000000e+00,   1.37326325e-01,
         8.13437086e-03,   8.43662005e-04,  -3.31958782e-03,
         0.00000000e+00,   1.15295285e-02,   0.00000000e+00,
        -5.33746230e-03,  -6.33450940e-02,   1.76359723e-02,
        -6.41549654e-03,   0.00000000e+00,   1.82861267e-02,
         2.30397063e-02,   0.00000000e+00,   1.56591579e-02,
         1.44624459e-01,   1.10844674e-02,  -4.50813645e-02,
         1.50813900e-02,   0.00000000e+00,  -6.26952537e-03,
         0.00000000e+00,  -2.47414469e-03,  -2.37423253e-02,
        -6.44401545e-03,  -4.39394875e-03,   0.00000000e+00,
        -3.01894380e-02,  -2.29343263e-02,   0.00000000e+00,
         1.46966550e-02,  -3.49885241e-02,  -6.73663307e-02,
        -3.38294326e-02,  -2.93653133e-02,   1.02847351e-02,
         0.00000000e+00,  -1.68857531e-02,   0.00000000e+00,
         6.35136338e-03,  -1.65591014e-02,   1.52036562e-02,
        -1.01749706e-02,   0.00000000e+00,  -1.04973582e-02,
        -1.86686185e-02,   0.00000000e+00,  -2.68288898e-02,
        -2.05035679e-03,   7.66164800e-02,   1.19959935e-01,
         5.05370505e-03,   5.93431616e-02,   1.78951789e-02,
        -2.10037997e-02,  -1.10930295e-02,  -3.93692822e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.19311105e-02,   1.88495005e-02,   3.49262853e-02,
         3.61791771e-03,   0.00000000e+00,  -7.77607962e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.10973723e-02,   0.00000000e+00,   5.59488603e-02,
         5.12323985e-03,  -3.08047215e-03,   4.33465222e-02,
         0.00000000e+00,   2.87596858e-02,   0.00000000e+00,
         5.29613305e-02,   7.04313084e-03,  -1.79099256e-02,
         3.95765841e-02,   0.00000000e+00,  -4.67382924e-02,
         0.00000000e+00,   1.62066524e-02,   5.18187547e-02,
        -5.95270817e-03,   3.75676084e-03,  -1.35331344e-02,
         0.00000000e+00,   1.32909512e-02,   0.00000000e+00,
        -5.54993485e-03,  -2.03267052e-02,  -3.23814381e-02,
        -4.45941450e-03,   6.47692794e-03,  -1.64725072e-03,
         0.00000000e+00,  -2.37769242e-03,   0.00000000e+00,
        -7.58170865e-03,   1.56958975e-03,  -1.48753138e-02,
        -4.87592104e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.49327009e-02,   0.00000000e+00,
        -1.95340599e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.21703017e-02,
         1.27020707e-03,   4.45306964e-04,   4.12920543e-03,
         0.00000000e+00,   1.07057592e-02,   0.00000000e+00,
        -1.73816429e-02,   3.30981643e-03,  -2.87945879e-03,
         4.72833678e-03,   0.00000000e+00,  -3.49307988e-02,
        -8.48492652e-03,   8.00778439e-03,  -1.62210333e-02,
         0.00000000e+00,   1.37691713e-02,   0.00000000e+00,
         1.26657084e-02,   1.13869211e-02,  -1.26434229e-02,
        -7.82403169e-03,   0.00000000e+00,  -5.11058217e-03,
        -4.52174550e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.15991965e-02,   0.00000000e+00,
        -2.49878100e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.02306832e-02,
         0.00000000e+00,   0.00000000e+00,   6.66196704e-02,
        -3.60930043e-03,   1.24184065e-03,  -1.29026162e-02,
         0.00000000e+00,  -6.53273890e-03,   0.00000000e+00,
        -2.13530267e-02,  -2.14451346e-03,  -6.22961194e-05,
         1.02094641e-02,   0.00000000e+00,   2.03046056e-02,
        -2.39843997e-02,   0.00000000e+00,   5.95935426e-02,
         5.10742937e-03,   3.95054579e-03,  -9.55285885e-04,
         0.00000000e+00,   7.58668332e-03,   0.00000000e+00,
        -5.79832453e-03,  -3.17366568e-02,   9.70742865e-03,
        -1.71496139e-03,   0.00000000e+00,   1.31230082e-02,
         1.78819222e-02,   0.00000000e+00,   1.31947477e-02,
         8.73533669e-02,   4.53439961e-03,  -1.71802762e-02,
         1.26462803e-02,   0.00000000e+00,  -7.26813232e-03,
         0.00000000e+00,  -4.26071482e-03,  -1.34379847e-02,
         5.65649609e-03,   2.24443003e-03,   0.00000000e+00,
        -1.05911506e-02,  -3.33687952e-03,   0.00000000e+00,
         1.10552300e-02,  -2.68991227e-02,  -2.66988374e-02,
        -1.80264557e-02,  -1.47272628e-02,   3.87744243e-03,
         0.00000000e+00,  -7.45989337e-03,   0.00000000e+00,
        -4.57916465e-04,  -2.62201422e-03,   3.41701215e-03,
        -4.32574096e-03,   0.00000000e+00,  -4.01712955e-03,
        -1.60103525e-02,   0.00000000e+00,  -1.35728983e-04,
        -1.25836719e-02,   3.63159722e-02,   5.21807542e-02,
         6.70968272e-02,  -4.24617298e-02,   5.27590984e-02,
         3.67638183e-02,  -9.94331829e-03,   9.62791679e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.78277162e-02,  -1.24066117e-02,  -2.02873973e-02,
         1.59212735e-03,   0.00000000e+00,   8.07552551e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.29694062e-02,   0.00000000e+00,   2.85817318e-02,
        -2.63971252e-03,   1.53235001e-02,  -3.18218803e-02,
         0.00000000e+00,  -2.95461624e-02,   0.00000000e+00,
         3.04051608e-02,  -1.76827054e-02,   2.32872094e-02,
        -1.35331344e-02,   0.00000000e+00,   3.47182421e-02,
         0.00000000e+00,  -1.10410009e-02,   2.83061555e-02,
        -1.19610450e-02,   2.36560859e-02,   6.27204046e-02,
         0.00000000e+00,  -1.61133811e-02,   0.00000000e+00,
        -1.72461720e-02,  -2.23645230e-02,  -1.08683630e-02,
        -1.12573099e-02,   2.17348318e-02,   5.17475821e-02,
         0.00000000e+00,   3.03312325e-05,   0.00000000e+00,
        -2.13683309e-02,  -3.79955863e-03,   8.44354088e-03,
        -3.55308060e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.79486599e-02,   0.00000000e+00,
         2.88045840e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.35754122e-02,
         4.63749432e-03,   5.00836445e-03,  -1.59872276e-02,
         0.00000000e+00,  -3.98063083e-02,   0.00000000e+00,
         2.51391404e-02,  -1.79647943e-02,   1.53176975e-03,
        -2.01988527e-02,   0.00000000e+00,   9.12084671e-02,
        -3.09552964e-03,   1.27855816e-02,   3.76413403e-02,
         0.00000000e+00,  -2.32677241e-02,   0.00000000e+00,
        -1.18624323e-02,  -1.79837127e-02,   2.96171009e-02,
         1.30426798e-02,   0.00000000e+00,  -1.06465731e-02,
         1.09237303e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.28921055e-03,   0.00000000e+00,
        -2.90314810e-06,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.21409331e-02,
         0.00000000e+00,   0.00000000e+00,   9.89505845e-03,
         6.45412985e-03,   1.27935318e-04,   6.50556218e-03,
         0.00000000e+00,   8.95675105e-04,   0.00000000e+00,
         1.16650969e-04,  -8.75722911e-04,   1.86269600e-03,
         1.09316953e-02,   0.00000000e+00,  -1.87818123e-02,
         2.01494773e-02,   0.00000000e+00,   1.45083572e-02,
        -6.21383289e-03,   5.90529800e-03,  -3.35503921e-03,
         0.00000000e+00,   5.36808544e-03,   0.00000000e+00,
         1.59534061e-03,   1.30825168e-02,  -9.66703995e-04,
        -2.06176910e-03,   0.00000000e+00,  -9.02430308e-03,
        -1.97301358e-02,   0.00000000e+00,  -4.60018843e-03,
         9.18626561e-03,  -3.08799244e-02,   3.53507729e-02,
        -3.55484521e-03,   0.00000000e+00,   5.82325411e-04,
         0.00000000e+00,   2.37891561e-03,   2.41227203e-02,
         2.69452535e-02,   6.82193614e-03,   0.00000000e+00,
         1.50846660e-02,  -1.17783618e-02,   0.00000000e+00,
        -1.10731586e-02,   2.12959397e-02,   8.15282645e-02,
         1.12797416e-02,  -3.89066623e-03,   1.09872059e-03,
         0.00000000e+00,   2.67283928e-04,   0.00000000e+00,
         4.97258184e-03,  -3.31120649e-03,  -8.77479979e-03,
        -7.02260793e-03,   0.00000000e+00,  -5.20561994e-03,
         9.30627019e-03,   0.00000000e+00,   1.31699918e-02,
         5.80449654e-03,  -2.34521642e-02,   2.29391372e-02,
         2.73048568e-02,  -7.16679943e-03,   7.76333159e-03,
         4.74568739e-02,  -3.60367504e-02,   3.30845848e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.94385859e-02,  -6.06752615e-03,  -5.69696544e-03,
         7.89268045e-03,   0.00000000e+00,   4.13063625e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.08066754e-02,   0.00000000e+00,   1.54973148e-02,
        -8.06886178e-03,   2.46716392e-02,  -9.92920398e-03,
         0.00000000e+00,  -1.81026804e-02,   0.00000000e+00,
         1.32099878e-02,  -1.27455079e-02,   1.57026396e-02,
        -1.64725072e-03,   0.00000000e+00,   1.40063409e-02,
         0.00000000e+00,  -4.34219558e-03,   1.39576403e-02,
        -6.45273074e-03,   1.64322167e-02,   5.17475821e-02,
         0.00000000e+00,  -8.48184365e-03,   0.00000000e+00,
        -1.85588527e-02,  -2.41550946e-02,  -3.80199209e-02,
        -2.16048190e-02,   3.67400910e-02,   7.75084259e-02,
         0.00000000e+00,  -4.09831592e-03,   0.00000000e+00,
        -3.30830231e-02,  -1.66915163e-02,  -3.16036791e-02,
        -1.35333720e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.10677272e-02,   0.00000000e+00,
         1.86118869e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.77170393e-02,
        -5.74006356e-04,   6.66197083e-03,  -9.35083027e-03,
         0.00000000e+00,  -2.84810106e-02,   0.00000000e+00,
         1.74182147e-02,  -1.21893065e-02,  -1.40353811e-03,
        -2.21157482e-02,   0.00000000e+00,   4.89391854e-02,
        -9.11903520e-04,   6.69755208e-03,   2.45313443e-02,
         0.00000000e+00,  -1.47706813e-02,   0.00000000e+00,
        -8.44607842e-03,  -1.40600056e-02,   1.27246684e-02,
         4.53026826e-03,   0.00000000e+00,  -1.22835766e-02,
         5.71215802e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.46783948e-03,   0.00000000e+00,
         1.67359615e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.20895406e-03,
         0.00000000e+00,   0.00000000e+00,   5.95567319e-03,
         3.97487415e-03,  -4.07302141e-03,   2.88448396e-03,
         0.00000000e+00,   1.73284519e-03,   0.00000000e+00,
         5.59080301e-03,  -3.03430612e-04,   4.91178776e-03,
         2.00156023e-02,   0.00000000e+00,  -1.15823890e-02,
         1.19533598e-02,   0.00000000e+00,   7.05481568e-03,
        -3.90759891e-03,   4.09046379e-03,  -1.50175564e-03,
         0.00000000e+00,   1.45427995e-03,   0.00000000e+00,
         1.68462432e-03,   8.42142799e-03,  -2.14703916e-03,
        -4.95806015e-03,   0.00000000e+00,  -3.26886473e-03,
        -1.34008538e-02,   0.00000000e+00,  -1.33665336e-03,
         8.79294708e-03,  -2.03618803e-02,   2.40708983e-02,
        -4.79978104e-03,   0.00000000e+00,  -4.65091873e-04,
         0.00000000e+00,   2.54524977e-03,   1.40929841e-02,
         1.47056093e-02,   2.54172329e-03,   0.00000000e+00,
         1.64856252e-02,  -2.34217545e-02,   0.00000000e+00,
        -8.74615495e-03,   1.08240064e-02,   3.27924816e-02,
         9.13112871e-03,  -2.71175275e-04,   1.87123902e-03,
         0.00000000e+00,  -2.82564386e-03,   0.00000000e+00,
         8.31148800e-04,  -3.27029894e-03,  -6.92055086e-03,
        -1.00599997e-02,   0.00000000e+00,  -7.53399371e-03,
         7.66861069e-03,   0.00000000e+00,   1.40343511e-02,
         1.93437868e-03,  -8.01882052e-03,   1.04486932e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.86665700e-03,   6.63516569e-03,  -7.59005582e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.40782936e-04,   0.00000000e+00,
         6.77826846e-03,   1.52749057e-03,   3.22959890e-03,
         0.00000000e+00,   1.32971594e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.04261461e-03,   0.00000000e+00,  -2.32080770e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.42326262e-03,   0.00000000e+00,
        -1.45878824e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.27054660e-03,   0.00000000e+00,   1.60526660e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.04621726e-03,   0.00000000e+00,   1.57660185e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.37807858e-03,  -2.97225077e-03,
         1.56486296e-02,   0.00000000e+00,   2.90960456e-04,
         0.00000000e+00,  -5.21870860e-03,  -3.74015621e-03,
         2.96732572e-03,   3.81805255e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.61722442e-03,   0.00000000e+00,  -2.94307001e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.35550793e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.31189795e-02,   0.00000000e+00,   5.73052831e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.17659796e-03,   0.00000000e+00,
         0.00000000e+00,  -7.56018466e-04,  -5.39664047e-04,
        -1.26403146e-03,   0.00000000e+00,  -1.81992724e-04,
         0.00000000e+00,   2.86459388e-03,   1.31002552e-03,
        -1.19195467e-04,  -6.97747568e-04,   0.00000000e+00,
        -5.88972666e-04,  -1.50988104e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.69301032e-03,   0.00000000e+00,   3.97912171e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.31843363e-04,   0.00000000e+00,
         0.00000000e+00,   3.07472136e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.65938377e-03,   0.00000000e+00,  -6.10340077e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.67741074e-03,   0.00000000e+00,
         0.00000000e+00,  -3.68687681e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.18938780e-03,   0.00000000e+00,
        -3.39176281e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.12253456e-03,
         0.00000000e+00,   0.00000000e+00,   3.09506325e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.91596830e-03,   0.00000000e+00,   6.55873601e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.25982395e-03,   0.00000000e+00,
         0.00000000e+00,   4.47242988e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.08638950e-02,   1.72343066e-02,  -4.69853696e-02,
        -3.71368565e-03,   3.01124746e-03,  -6.08984970e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.72539398e-02,  -3.85706431e-03,   1.27524897e-02,
        -5.42850568e-03,   0.00000000e+00,  -5.13901112e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.74162434e-02,   0.00000000e+00,  -3.47335639e-02,
         6.99599699e-03,   9.63441599e-05,   1.61616159e-02,
         0.00000000e+00,   1.54829521e-02,   0.00000000e+00,
        -4.01161394e-02,   6.92130979e-03,  -3.72697595e-03,
         4.12920543e-03,   0.00000000e+00,  -1.22469164e-02,
         0.00000000e+00,   3.07583191e-03,  -3.34202927e-02,
         6.66431124e-03,  -9.20373202e-03,  -1.59872276e-02,
         0.00000000e+00,   4.03419100e-03,   0.00000000e+00,
         4.48124598e-03,   4.51207781e-03,  -2.44636319e-02,
        -1.12038831e-03,  -1.52210922e-03,  -9.35083027e-03,
         0.00000000e+00,  -3.89096480e-03,   0.00000000e+00,
         8.45211695e-03,  -4.25300619e-03,  -1.52497081e-02,
        -3.42287522e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.07692536e-02,   0.00000000e+00,
        -1.72253403e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.43500078e-02,
         1.66298512e-03,  -1.13263190e-02,   3.61376791e-02,
         0.00000000e+00,   3.87502724e-02,   0.00000000e+00,
        -2.40225492e-02,   1.20478706e-02,   2.79480149e-03,
         1.29214082e-02,   0.00000000e+00,  -5.75533093e-02,
        -6.45410388e-03,  -3.01889919e-03,  -3.56665052e-02,
         0.00000000e+00,   1.53859759e-03,   0.00000000e+00,
         8.49167810e-03,   6.66872919e-03,  -2.24512489e-02,
        -1.40525309e-02,   0.00000000e+00,   2.46367257e-03,
        -4.96607988e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.96084376e-04,   0.00000000e+00,
         1.65726551e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.89848060e-03,
         0.00000000e+00,   0.00000000e+00,  -2.32744689e-02,
        -6.85431523e-03,   1.38197192e-03,  -5.81663235e-03,
         0.00000000e+00,  -1.55092173e-03,   0.00000000e+00,
         2.39098868e-02,   1.34654167e-03,  -3.43918255e-03,
        -4.11424212e-03,   0.00000000e+00,   4.43186121e-03,
        -4.65646068e-03,   0.00000000e+00,  -2.43478713e-02,
         5.29933408e-03,  -6.97109632e-03,   8.61547197e-03,
         0.00000000e+00,  -1.09722959e-02,   0.00000000e+00,
         2.57256498e-03,   7.97769010e-03,  -2.21334430e-03,
         1.84739650e-05,   0.00000000e+00,   1.55322405e-03,
         4.67402195e-03,   0.00000000e+00,  -8.05251723e-04,
        -2.70432949e-02,   2.80538052e-02,  -2.05889055e-02,
         9.40045183e-03,   0.00000000e+00,   7.36741356e-03,
         0.00000000e+00,  -6.32298301e-03,  -1.08231522e-02,
        -6.25135856e-03,  -1.52877407e-03,   0.00000000e+00,
        -1.11819213e-02,  -4.09220744e-03,   0.00000000e+00,
         5.26878655e-03,  -5.93166806e-03,  -5.26716790e-02,
         1.40622680e-03,   1.72866901e-02,  -5.52009914e-03,
         0.00000000e+00,  -1.11976015e-03,   0.00000000e+00,
        -7.56769233e-04,   4.23465709e-03,  -9.17460725e-04,
         3.06989129e-04,   0.00000000e+00,   5.13051861e-03,
         1.49516530e-04,   0.00000000e+00,   3.39505409e-03,
         2.01774995e-03,   6.73365629e-03,  -2.58322074e-02,
         7.28856346e-02,  -4.92298993e-02,   7.01977429e-02,
         7.59701246e-03,   5.79287030e-03,   9.83594187e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.01530066e-01,  -1.75327628e-02,  -1.26142776e-02,
        -5.63610889e-03,   0.00000000e+00,   9.11477411e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.45012805e-02,   0.00000000e+00,   3.70734336e-02,
        -1.24105091e-03,  -3.86686144e-03,  -3.15801947e-02,
         0.00000000e+00,  -2.86691366e-02,   0.00000000e+00,
         4.01907129e-02,  -2.87196361e-02,   1.58507635e-02,
        -1.62210333e-02,   0.00000000e+00,   3.69683025e-02,
         0.00000000e+00,  -1.14131059e-02,   4.76859551e-02,
        -1.31440293e-02,   2.38596938e-02,   3.76413403e-02,
         0.00000000e+00,  -1.67935800e-02,   0.00000000e+00,
        -8.89927658e-03,  -8.13033994e-03,   4.20678602e-02,
        -8.45715587e-03,   1.11767702e-02,   2.45313443e-02,
         0.00000000e+00,   5.45224657e-03,   0.00000000e+00,
        -1.32769789e-02,   4.72016817e-03,   2.31629095e-02,
         3.95180806e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.00441469e-02,   0.00000000e+00,
         3.94815483e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.01435351e-01,
        -1.14670772e-04,   1.16022393e-02,  -3.56665052e-02,
         0.00000000e+00,  -6.15940177e-02,   0.00000000e+00,
         3.73762000e-02,  -2.76768286e-02,  -7.45493449e-03,
        -1.92485508e-02,   0.00000000e+00,   9.88134917e-02,
         1.60561022e-02,   1.38254320e-02,   8.76959350e-02,
         0.00000000e+00,  -3.29687496e-02,   0.00000000e+00,
        -1.57447220e-02,  -2.72896976e-02,   5.10642164e-02,
         3.23609975e-02,   0.00000000e+00,   5.03207859e-03,
         9.65590306e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.78766443e-03,   0.00000000e+00,
        -1.24671336e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.35053517e-02,
         0.00000000e+00,   0.00000000e+00,   1.52401842e-02,
         6.08135541e-03,  -7.57096290e-03,   1.83663581e-02,
         0.00000000e+00,   7.95356396e-04,   0.00000000e+00,
        -1.98270041e-02,  -5.32430920e-03,   7.51842623e-03,
         7.70197673e-03,   0.00000000e+00,  -1.03700488e-02,
         1.48408425e-02,   0.00000000e+00,   1.85260987e-02,
        -1.47149564e-02,   8.16921911e-03,  -1.38656712e-02,
         0.00000000e+00,   1.39639914e-02,   0.00000000e+00,
        -2.90412392e-03,   9.14456206e-03,  -2.79975833e-03,
        -1.25975928e-03,   0.00000000e+00,  -1.19414827e-02,
        -1.26767968e-02,   0.00000000e+00,  -3.74742887e-03,
         2.48059732e-02,  -5.39195966e-02,   4.93857596e-02,
        -1.66294268e-02,   0.00000000e+00,  -3.08047957e-03,
         0.00000000e+00,   2.35494619e-03,   2.60316180e-02,
         1.63852758e-02,   8.98825774e-03,   0.00000000e+00,
        -2.88847843e-03,   6.93054160e-03,   0.00000000e+00,
        -1.01225012e-02,   1.81639669e-02,   1.02501974e-01,
         9.96973167e-03,  -1.86840779e-02,   8.29614713e-03,
         0.00000000e+00,  -1.55544578e-03,   0.00000000e+00,
        -6.31058959e-03,  -1.06181379e-02,  -2.21150337e-03,
        -1.77145402e-03,   0.00000000e+00,   6.77867035e-04,
         1.38638295e-03,   0.00000000e+00,  -4.62467129e-03,
        -4.05446015e-03,  -2.66762971e-02,   2.37656305e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.81513055e-03,   3.04252564e-04,   5.01739154e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.26749043e-04,   0.00000000e+00,
         3.45897736e-03,   5.96823650e-03,  -2.47048591e-03,
         0.00000000e+00,   1.23243934e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.11590321e-03,   0.00000000e+00,  -2.96857331e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.65187025e-04,   0.00000000e+00,
         5.31996008e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.22061884e-04,   0.00000000e+00,  -5.71463902e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.73657646e-04,   0.00000000e+00,   1.00973880e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.15034060e-03,  -7.23765003e-04,
        -1.26403146e-03,   0.00000000e+00,  -3.98237088e-04,
         0.00000000e+00,   2.33963779e-03,   1.57694196e-03,
         9.11851186e-05,  -6.09273561e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.14049019e-04,   0.00000000e+00,   2.89605709e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.22390476e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.40877607e-03,   0.00000000e+00,  -1.11703772e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.31808057e-03,   0.00000000e+00,
         0.00000000e+00,  -4.09163011e-03,  -5.54585479e-03,
         5.09152713e-03,   0.00000000e+00,  -1.34812590e-03,
         0.00000000e+00,   6.49170972e-03,   2.64560586e-03,
        -5.63614923e-04,  -4.53754945e-04,   0.00000000e+00,
        -1.20150321e-03,  -5.98146059e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.87501100e-03,   0.00000000e+00,   6.08402481e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.85465949e-04,   0.00000000e+00,
         0.00000000e+00,  -2.31312656e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.07180037e-03,   0.00000000e+00,   5.36743403e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.95582776e-04,   0.00000000e+00,
         0.00000000e+00,  -1.30038066e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.43144060e-03,   0.00000000e+00,
        -2.29073750e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.30109680e-03,
         0.00000000e+00,   0.00000000e+00,   1.86325910e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.41776242e-03,   0.00000000e+00,  -6.18944882e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.03234894e-04,   0.00000000e+00,
         0.00000000e+00,   5.22842648e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.47867624e-03,  -3.64521869e-02,  -1.53564833e-02,
         7.39123491e-03,   1.11116004e-02,   1.29666340e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.08102939e-02,  -1.05391159e-02,  -1.01037430e-02,
        -2.84029203e-03,   0.00000000e+00,   7.88148934e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.96575756e-02,   0.00000000e+00,  -4.11541543e-02,
         5.92907515e-03,   3.06057129e-03,  -2.64965342e-02,
         0.00000000e+00,  -1.99693548e-02,   0.00000000e+00,
        -4.35021922e-02,  -1.52886041e-02,   1.97708718e-03,
        -1.29026162e-02,   0.00000000e+00,   2.29806566e-02,
         0.00000000e+00,  -4.96813594e-03,  -3.17786188e-02,
         3.22486433e-03,   5.30921195e-03,   6.50556218e-03,
         0.00000000e+00,  -6.77924636e-03,   0.00000000e+00,
         5.39190573e-05,   1.16811072e-02,   8.99596368e-03,
        -1.55406533e-03,  -4.40802513e-03,   2.88448396e-03,
         0.00000000e+00,   5.81914232e-03,   0.00000000e+00,
         7.30377898e-03,   4.27284683e-04,   9.70029562e-03,
         2.10387079e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.59248156e-02,   0.00000000e+00,
         1.98249043e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.77266128e-02,
        -5.53065027e-03,  -4.28712085e-04,  -5.81663235e-03,
         0.00000000e+00,  -1.48280957e-02,   0.00000000e+00,
         2.51960117e-02,  -4.70111363e-03,  -3.51521689e-03,
        -4.97731520e-03,   0.00000000e+00,   1.42706042e-02,
         2.16650547e-03,  -3.10184597e-03,   1.83663581e-02,
         0.00000000e+00,  -1.25533386e-02,   0.00000000e+00,
        -1.65246182e-02,  -6.41368921e-03,   1.17397110e-02,
         1.01049574e-02,   0.00000000e+00,   2.88372139e-03,
         1.52667409e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.06656195e-02,   0.00000000e+00,
         3.92948236e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.28694126e-02,
         0.00000000e+00,   0.00000000e+00,  -4.86998342e-02,
        -4.02972450e-03,  -9.05133332e-03,   2.76967342e-02,
         0.00000000e+00,   1.59577703e-02,   0.00000000e+00,
         4.63977191e-02,   3.02375390e-03,   5.51868798e-04,
        -6.84940662e-03,   0.00000000e+00,  -1.34525792e-02,
         1.40126243e-02,   0.00000000e+00,  -4.88234939e-02,
        -2.69174031e-03,  -4.97983481e-03,   7.41756960e-03,
         0.00000000e+00,  -1.32080877e-02,   0.00000000e+00,
         6.74864555e-03,   4.23529559e-02,  -1.11609057e-02,
         2.29934124e-03,   0.00000000e+00,  -6.97905910e-03,
        -8.08778872e-03,   0.00000000e+00,  -3.65600777e-03,
        -5.20869696e-02,  -1.42772740e-03,   2.44879515e-02,
        -9.63292302e-03,   0.00000000e+00,   3.48738684e-03,
         0.00000000e+00,   2.73431755e-03,   6.87508901e-03,
         8.54494580e-05,   1.81687405e-03,   0.00000000e+00,
        -7.87557244e-04,   3.32247580e-03,   0.00000000e+00,
        -3.20260417e-03,   1.07931300e-02,   1.25129438e-02,
         3.09739347e-02,   2.57044714e-02,  -4.62417990e-03,
         0.00000000e+00,   5.88717457e-03,   0.00000000e+00,
        -9.40263003e-03,   8.62623365e-03,  -4.00832150e-03,
         4.61943271e-03,   0.00000000e+00,   6.31259858e-03,
         4.09712429e-03,   0.00000000e+00,   4.21547322e-03,
        -2.47866250e-03,  -2.39084135e-02,  -4.34875553e-02,
        -2.42454689e-02,  -6.43911695e-03,  -2.86358602e-02,
         8.07160734e-05,   9.07569148e-03,  -2.67664226e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.40539895e-02,  -3.91692521e-03,  -2.86743751e-03,
         8.86497585e-04,   0.00000000e+00,  -2.64988818e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.46810117e-03,   0.00000000e+00,  -3.45795682e-02,
         6.52516192e-03,   2.35726416e-03,  -3.31958782e-03,
         0.00000000e+00,  -9.72692128e-04,   0.00000000e+00,
        -3.43462503e-02,   3.55731413e-03,   3.11702969e-03,
        -9.55285885e-04,   0.00000000e+00,   4.05148495e-03,
         0.00000000e+00,  -3.46659341e-03,  -3.30733406e-02,
         3.31522636e-04,  -8.63628127e-04,  -3.35503921e-03,
         0.00000000e+00,   5.08555110e-04,   0.00000000e+00,
         2.13204983e-03,   8.26303504e-03,  -1.08924268e-02,
        -1.64273539e-03,  -1.21955240e-05,  -1.50175564e-03,
         0.00000000e+00,   3.24256334e-04,   0.00000000e+00,
         4.69703226e-03,  -5.68511285e-04,  -4.15690351e-03,
        -1.31214985e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.41231271e-02,   0.00000000e+00,
         2.18428880e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.05140246e-02,
        -2.40070777e-04,  -5.93058971e-03,   8.61547197e-03,
         0.00000000e+00,   6.86307954e-03,   0.00000000e+00,
         1.71613493e-03,   6.01640512e-03,  -6.20895632e-04,
         1.17752722e-03,   0.00000000e+00,  -2.25467925e-02,
        -9.14282406e-03,  -1.83617735e-03,  -1.38656712e-02,
         0.00000000e+00,   1.52033233e-03,   0.00000000e+00,
        -3.26887554e-03,   6.17904305e-03,  -7.23075353e-03,
        -3.36952867e-03,   0.00000000e+00,   2.60077622e-04,
        -2.00420523e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.01400534e-02,   0.00000000e+00,
         2.69938235e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.22213624e-03,
         0.00000000e+00,   0.00000000e+00,  -3.18463572e-02,
        -2.73326741e-03,  -1.47868327e-03,   7.41756960e-03,
         0.00000000e+00,   4.69560341e-03,   0.00000000e+00,
         2.63979471e-02,   7.95126476e-03,  -2.37873943e-03,
        -4.16818506e-03,   0.00000000e+00,  -3.98873918e-03,
         1.74599749e-03,   0.00000000e+00,  -3.13425277e-02,
        -2.46364780e-03,  -1.25736228e-02,   1.54690402e-02,
         0.00000000e+00,  -1.62608104e-02,   0.00000000e+00,
         8.73522503e-03,   3.02816864e-02,  -6.93063173e-03,
         1.82860836e-03,   0.00000000e+00,  -1.72843588e-03,
        -4.01771857e-05,   0.00000000e+00,  -3.36742070e-03,
        -4.11033041e-02,   1.35412544e-02,   3.36978103e-03,
         5.23676053e-03,   0.00000000e+00,   4.79233253e-03,
         0.00000000e+00,  -2.10516830e-03,  -7.30326928e-03,
         6.44017197e-04,   1.90611075e-03,   0.00000000e+00,
        -2.21354762e-03,   3.72182491e-03,   0.00000000e+00,
         2.61250665e-03,   2.37745320e-03,  -2.16707507e-02,
         1.34636323e-02,   1.88850844e-02,  -5.64307007e-03,
         0.00000000e+00,   6.86656378e-03,   0.00000000e+00,
        -4.04196219e-04,   6.28277407e-04,  -1.01190805e-03,
         1.25261589e-03,   0.00000000e+00,   3.97954773e-03,
        -2.36085657e-04,   0.00000000e+00,   4.10045736e-03,
         6.39464644e-03,  -5.43122274e-03,  -3.13780519e-02,
        -9.95815296e-03,   1.21361545e-02,  -1.61746572e-03,
        -1.86036145e-02,   1.04927157e-02,  -2.67567553e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.03900231e-02,   5.71064756e-03,   3.12976826e-03,
        -1.75398927e-03,   0.00000000e+00,  -1.82113755e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.45374889e-02,   0.00000000e+00,   2.67108030e-03,
         2.58355664e-03,  -8.99261686e-03,   1.50813900e-02,
         0.00000000e+00,   9.28128614e-03,   0.00000000e+00,
        -3.60623801e-05,   7.61390672e-03,  -3.42715878e-03,
         1.26462803e-02,   0.00000000e+00,  -1.16307074e-02,
         0.00000000e+00,   1.22960843e-04,  -3.63052578e-03,
        -8.29128269e-03,   6.99904278e-03,  -3.55484521e-03,
         0.00000000e+00,   2.70662819e-03,   0.00000000e+00,
         5.93901003e-04,   2.83307689e-03,  -2.70056793e-03,
        -4.42526090e-03,   6.60487448e-03,  -4.79978104e-03,
         0.00000000e+00,  -2.94855422e-03,   0.00000000e+00,
         7.50452954e-04,   2.42252435e-03,  -1.89295077e-03,
        -1.05841458e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.39325800e-02,   0.00000000e+00,
        -8.89865833e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.05609779e-02,
         9.46483494e-03,  -7.35404712e-03,   9.40045183e-03,
         0.00000000e+00,   1.15176909e-02,   0.00000000e+00,
        -1.16722312e-02,   1.29013186e-03,   2.76342921e-03,
         4.62567092e-03,   0.00000000e+00,  -2.40590443e-02,
        -2.03537808e-02,   1.52192309e-02,  -1.66294268e-02,
         0.00000000e+00,   4.05501689e-03,   0.00000000e+00,
         3.96922482e-03,   8.72348218e-03,  -5.70113356e-03,
        -3.69457392e-03,   0.00000000e+00,  -8.58177542e-04,
        -1.57787878e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.32164352e-03,   0.00000000e+00,
        -5.55483117e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.64516218e-03,
         0.00000000e+00,   0.00000000e+00,   7.35323594e-03,
        -3.22013818e-04,   9.13224100e-03,  -9.63292302e-03,
         0.00000000e+00,  -1.66105710e-03,   0.00000000e+00,
        -2.42757581e-03,   2.75167595e-03,  -2.50018383e-03,
        -3.57139911e-04,   0.00000000e+00,   5.42776049e-03,
        -6.91980132e-03,   0.00000000e+00,   5.02904397e-03,
         5.48957471e-03,   2.11066528e-03,   5.23676053e-03,
         0.00000000e+00,   2.30583106e-03,   0.00000000e+00,
        -2.80966190e-03,  -1.07310613e-02,   4.69936925e-03,
         2.08363644e-03,   0.00000000e+00,   1.52918937e-03,
         5.92830183e-03,   0.00000000e+00,   3.24847822e-03,
         5.28806216e-03,   3.00034092e-03,  -1.37465988e-03,
         2.97092502e-02,   0.00000000e+00,  -1.06499526e-03,
         0.00000000e+00,  -7.71523142e-03,  -5.35979144e-03,
         8.26168848e-03,   8.32937860e-03,   0.00000000e+00,
        -6.47365519e-03,   1.65795001e-02,   0.00000000e+00,
         4.47761522e-03,  -6.35832268e-03,  -1.55921710e-02,
        -4.38509243e-03,  -3.92311007e-03,  -5.10088903e-03,
         0.00000000e+00,   1.38257309e-04,   0.00000000e+00,
         9.76494677e-03,   3.38643828e-03,  -2.37183985e-03,
        -3.26032341e-03,   0.00000000e+00,  -1.36022077e-03,
        -6.46471752e-03,   0.00000000e+00,  -3.59838405e-03,
        -4.68335584e-04,   8.70677794e-03,   4.08942369e-03,
         2.54249564e-02,   1.29968833e-02,   2.01369223e-02,
         1.44305871e-03,  -7.52449432e-03,   1.42635844e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.36582680e-02,  -6.11278720e-03,   1.05589808e-02,
        -2.50732592e-03,   0.00000000e+00,   1.86878943e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.00477404e-02,   0.00000000e+00,   3.14580674e-02,
        -2.14667294e-03,  -5.18586282e-03,   1.02847351e-02,
         0.00000000e+00,   5.18836941e-03,   0.00000000e+00,
         3.03061235e-02,  -1.43882594e-03,   2.10916793e-03,
         3.87744243e-03,   0.00000000e+00,  -7.06798771e-03,
         0.00000000e+00,   2.25905158e-04,   3.04970808e-02,
        -4.07663745e-04,  -1.24715968e-03,   1.09872059e-03,
         0.00000000e+00,   2.06918312e-03,   0.00000000e+00,
        -1.23787787e-04,  -8.51883046e-03,   7.87098591e-04,
         1.47375830e-03,   2.40802644e-03,   1.87123902e-03,
         0.00000000e+00,   3.23075307e-04,   0.00000000e+00,
        -5.62128117e-03,   1.66448108e-03,  -1.35152013e-03,
        -2.17114289e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.12641782e-03,   0.00000000e+00,
        -8.72748272e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.18346319e-03,
         1.34536832e-03,   7.14954158e-03,  -5.52009914e-03,
         0.00000000e+00,  -6.32136854e-03,   0.00000000e+00,
        -1.92088932e-03,  -3.60143899e-03,  -2.72312073e-03,
        -8.82445632e-04,   0.00000000e+00,   9.48205524e-03,
         4.83688523e-03,  -3.79231806e-03,   8.29614713e-03,
         0.00000000e+00,  -9.69171314e-04,   0.00000000e+00,
         6.29905508e-04,  -7.70486307e-03,   3.47444717e-03,
         1.30160840e-03,   0.00000000e+00,  -4.88188362e-04,
         7.88357792e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.85654536e-03,   0.00000000e+00,
        -1.98137886e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.07729271e-03,
         0.00000000e+00,   0.00000000e+00,   3.09325698e-02,
         1.25446275e-02,   9.30801123e-03,  -4.62417990e-03,
         0.00000000e+00,  -2.09034835e-03,   0.00000000e+00,
        -1.99015309e-02,   3.94640028e-05,   1.66088082e-03,
         5.74831737e-03,   0.00000000e+00,   7.73893811e-03,
        -5.61402293e-03,   0.00000000e+00,   2.85319840e-02,
         4.01684493e-03,   8.38837584e-03,  -5.64307007e-03,
         0.00000000e+00,   8.77698485e-03,   0.00000000e+00,
        -2.25927017e-03,  -1.63555697e-02,   4.47655524e-03,
        -1.20135447e-03,   0.00000000e+00,   1.45172148e-03,
        -1.11497785e-03,   0.00000000e+00,   1.97322333e-04,
         3.70287993e-02,  -5.96283348e-03,  -3.35094337e-03,
        -5.10088903e-03,   0.00000000e+00,  -1.91350667e-03,
         0.00000000e+00,   7.43735405e-03,   5.18755236e-03,
        -1.22738290e-03,  -1.68316871e-03,   0.00000000e+00,
        -6.27154442e-03,  -8.48030578e-03,   0.00000000e+00,
        -1.34455467e-03,  -1.64762139e-03,   1.32614531e-02,
        -7.89378953e-03,  -1.15789177e-02,   1.48041110e-02,
         0.00000000e+00,  -1.63889321e-03,   0.00000000e+00,
         1.43065930e-02,   4.99726580e-05,   1.37887250e-03,
        -1.62014082e-03,   0.00000000e+00,  -1.65271330e-03,
        -2.31403735e-03,   0.00000000e+00,  -4.86943953e-03,
        -2.85213876e-03,   8.17278761e-03,   3.01724884e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.79348395e-02,  -4.50502769e-02,   1.85487857e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.51437276e-03,   0.00000000e+00,
         7.29141757e-03,   7.01235441e-02,  -1.52860391e-02,
         0.00000000e+00,   6.55854803e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.60997659e-03,   0.00000000e+00,   2.69585484e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.91975015e-02,   0.00000000e+00,
         2.14176731e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.52995895e-03,   0.00000000e+00,   8.24546942e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.84069807e-02,   0.00000000e+00,   9.52829031e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.06850005e-02,   1.05560452e-02,
        -3.86665700e-03,   0.00000000e+00,  -3.34885413e-03,
         0.00000000e+00,   2.18854004e-03,   1.69354078e-02,
         1.86271724e-02,  -5.39630367e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.90616003e-03,   0.00000000e+00,   5.47656085e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.77102747e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.59318127e-04,   0.00000000e+00,   9.12151851e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.07655043e-02,   0.00000000e+00,
         0.00000000e+00,   5.15737533e-04,  -3.17051309e-03,
         4.81513055e-03,   0.00000000e+00,  -9.26981352e-03,
         0.00000000e+00,   1.70974536e-03,  -5.63364363e-03,
         1.17974567e-03,  -7.37297061e-04,   0.00000000e+00,
        -8.04931133e-03,  -8.53320591e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.19098008e-03,   0.00000000e+00,  -2.52343211e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.90961271e-03,   0.00000000e+00,
         0.00000000e+00,  -7.40408846e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.08966153e-03,   0.00000000e+00,   8.64166217e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.69419185e-02,   0.00000000e+00,
         0.00000000e+00,  -1.37591460e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.56793911e-03,   0.00000000e+00,
         2.90481448e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.96535099e-02,
         0.00000000e+00,   0.00000000e+00,   5.84966906e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.87477656e-03,   0.00000000e+00,   3.16044712e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.82944778e-02,   0.00000000e+00,
         0.00000000e+00,   5.27699656e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.50502769e-02,   7.14509378e-02,  -1.45537593e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.44012777e-03,   0.00000000e+00,
         5.33702431e-02,   4.38177532e-04,  -1.72438422e-03,
         0.00000000e+00,   1.85069084e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.28393771e-03,   0.00000000e+00,  -5.12990925e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.91254897e-02,   0.00000000e+00,
        -6.94304870e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.01955659e-02,   0.00000000e+00,  -8.06956923e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.77585036e-02,   0.00000000e+00,  -7.41153915e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.08590667e-02,  -1.81718752e-02,
         6.63516569e-03,   0.00000000e+00,  -8.07029463e-04,
         0.00000000e+00,  -1.80357445e-03,  -1.15932217e-02,
        -1.67168675e-02,   1.91092956e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.06788751e-02,   0.00000000e+00,  -1.10841167e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.21131385e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.74044770e-03,   0.00000000e+00,   4.53910915e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.23111926e-03,   0.00000000e+00,
         0.00000000e+00,  -8.29882484e-03,  -1.06546837e-02,
         3.04252564e-04,   0.00000000e+00,   9.56351924e-04,
         0.00000000e+00,  -4.38556514e-04,  -1.42950617e-03,
         4.47965044e-03,  -3.07431891e-03,   0.00000000e+00,
         4.49215038e-04,  -2.15801357e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.00350629e-03,   0.00000000e+00,   3.65069560e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.42994178e-03,   0.00000000e+00,
         0.00000000e+00,  -1.60158742e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.10894172e-03,   0.00000000e+00,  -3.29340423e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.97204124e-03,   0.00000000e+00,
         0.00000000e+00,  -7.87926159e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.92744496e-03,   0.00000000e+00,
        -1.47147857e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.13931534e-02,
         0.00000000e+00,   0.00000000e+00,   2.40143305e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.67923197e-03,   0.00000000e+00,  -1.07931668e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.82702655e-02,   0.00000000e+00,
         0.00000000e+00,   2.51157822e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.85487857e-02,  -1.45537593e-02,   3.31267103e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.95092685e-04,   0.00000000e+00,
        -1.06487948e-02,   2.40236305e-03,  -1.02995214e-02,
         0.00000000e+00,  -2.83116595e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.74431433e-03,   0.00000000e+00,   1.23172086e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.61874294e-03,   0.00000000e+00,
         8.26075866e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.40495180e-03,   0.00000000e+00,  -4.23361239e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.91335760e-03,   0.00000000e+00,  -2.35608130e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.26489029e-03,   5.23669220e-03,
        -7.59005582e-03,   0.00000000e+00,   3.14748278e-04,
         0.00000000e+00,   3.11803113e-03,   4.42735292e-03,
        -2.55977150e-03,  -4.43829463e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.85852512e-03,   0.00000000e+00,   1.68057724e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.31497987e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.27215462e-03,   0.00000000e+00,  -4.57733490e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.27228480e-02,   0.00000000e+00,
         0.00000000e+00,   4.17282019e-03,   2.20416135e-03,
         5.01739154e-04,   0.00000000e+00,  -1.48390086e-03,
         0.00000000e+00,  -1.92433087e-04,  -3.77850032e-04,
         4.42179281e-04,   1.61073975e-03,   0.00000000e+00,
        -1.19671332e-03,   1.82229975e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.81955033e-04,   0.00000000e+00,  -1.64113598e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.44171363e-03,   0.00000000e+00,
         0.00000000e+00,   7.59730123e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.86887670e-03,   0.00000000e+00,   1.53427073e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.82780548e-03,   0.00000000e+00,
         0.00000000e+00,   5.06628804e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.43517350e-03,   0.00000000e+00,
         4.97759041e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.85686336e-02,
         0.00000000e+00,   0.00000000e+00,  -3.39073753e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.01888094e-04,   0.00000000e+00,   4.06273853e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.63730640e-03,   0.00000000e+00,
         0.00000000e+00,  -7.34881207e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.01650739e-01,  -1.18400745e-01,   5.73210013e-01,
         4.57535161e-02,   7.12561344e-03,   6.19721035e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.09606607e-01,  -4.62826113e-02,  -4.60238450e-02,
        -1.45852574e-03,   0.00000000e+00,   6.12816660e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.27305567e-01,   0.00000000e+00,   5.11922900e-01,
         3.29706484e-03,   1.15924451e-02,  -7.01168657e-02,
         0.00000000e+00,  -7.31936171e-02,   0.00000000e+00,
         4.86579757e-01,  -3.55320050e-02,   6.97853100e-02,
        -3.19311105e-02,   0.00000000e+00,   9.09050713e-02,
         0.00000000e+00,  -2.52179758e-02,   4.96282754e-01,
        -3.90319273e-02,   4.72725816e-02,   9.78277162e-02,
         0.00000000e+00,  -3.93767952e-02,   0.00000000e+00,
        -2.09176649e-02,  -4.29021834e-02,   3.99883990e-01,
        -2.04736740e-02,   3.04782725e-02,   4.94385859e-02,
         0.00000000e+00,   1.31347902e-02,   0.00000000e+00,
        -2.77843765e-02,   2.69054919e-02,   8.71640443e-02,
         4.41568085e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.62075298e-01,   0.00000000e+00,
         8.21172470e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.70387833e-01,
        -2.50051276e-04,   2.92789369e-02,  -5.72539398e-02,
         0.00000000e+00,  -1.14757305e-01,   0.00000000e+00,
         6.61336525e-02,  -5.94224804e-02,  -5.84397449e-04,
        -3.12565280e-02,   0.00000000e+00,   6.09611851e-01,
         1.25787759e-02,   2.81334316e-02,   1.01530066e-01,
         0.00000000e+00,  -4.70566641e-02,   0.00000000e+00,
        -1.64047656e-02,  -4.62153769e-02,   8.72687879e-02,
         3.49771219e-02,   0.00000000e+00,   1.34433675e-04,
         6.05942523e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.39221706e-04,   0.00000000e+00,
        -5.54719411e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.04312156e-02,
         0.00000000e+00,   0.00000000e+00,   4.30451990e-01,
         1.38948040e-02,  -1.00205864e-02,   1.08102939e-02,
         0.00000000e+00,  -6.13984681e-03,   0.00000000e+00,
        -5.56835678e-02,  -9.35056615e-03,   3.42174523e-03,
         1.40750282e-02,   0.00000000e+00,  -2.80772557e-02,
         3.23020874e-02,   0.00000000e+00,   4.20188033e-01,
        -1.12313211e-02,   3.12707966e-02,  -2.40539895e-02,
         0.00000000e+00,   3.72469966e-02,   0.00000000e+00,
        -4.59474827e-03,  -1.70351767e-02,   1.48325166e-02,
        -2.99523391e-03,   0.00000000e+00,  -3.35044051e-02,
        -4.46840904e-02,   0.00000000e+00,  -7.85157318e-03,
         4.27449995e-01,  -8.65811123e-02,   7.18729593e-02,
        -2.03900231e-02,   0.00000000e+00,  -1.93264668e-02,
         0.00000000e+00,   4.50722555e-03,   6.66832924e-02,
         6.51052983e-02,   5.70272451e-03,   0.00000000e+00,
         6.05534211e-03,  -1.80126480e-03,   0.00000000e+00,
        -2.40978757e-02,   6.58008399e-02,   6.30905088e-01,
        -5.46738852e-05,  -3.66382994e-02,   1.36582680e-02,
         0.00000000e+00,  -7.29356941e-03,   0.00000000e+00,
        -8.25331854e-04,  -1.11335661e-02,  -1.26700989e-02,
        -4.21822833e-03,   0.00000000e+00,  -2.53269332e-03,
         7.24975223e-03,   0.00000000e+00,   9.41103970e-03,
         2.26049014e-02,  -6.40157748e-02,   4.79550527e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.51437276e-03,  -6.44012777e-03,   5.95092685e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.98642936e-02,   0.00000000e+00,
         3.79314951e-03,   1.38514683e-02,  -2.49912214e-03,
         0.00000000e+00,  -4.03997834e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.53464788e-03,   0.00000000e+00,   1.00356663e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.91649310e-03,   0.00000000e+00,
        -1.06761228e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.50118195e-03,   0.00000000e+00,   3.57666520e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.41709482e-04,   0.00000000e+00,   4.72127977e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.92921822e-03,   1.45250449e-04,
         2.40782936e-04,   0.00000000e+00,  -7.97449300e-03,
         0.00000000e+00,   2.92636754e-03,  -3.40930390e-03,
         3.86770098e-03,  -2.09023917e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.62383106e-03,   0.00000000e+00,   5.13633127e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.23662841e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.59741779e-03,   0.00000000e+00,   3.53089979e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.17020611e-03,   0.00000000e+00,
         0.00000000e+00,  -5.56394842e-03,  -1.62951670e-03,
        -5.26749043e-04,   0.00000000e+00,  -5.75500404e-04,
         0.00000000e+00,  -1.01656667e-03,   3.42655118e-04,
        -3.73390497e-04,   1.82750219e-03,   0.00000000e+00,
        -3.25162324e-03,  -4.04822590e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.51458899e-04,   0.00000000e+00,  -1.14330713e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.45409636e-03,   0.00000000e+00,
         0.00000000e+00,   5.28658506e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.03235452e-04,   0.00000000e+00,   1.03270713e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.28870492e-03,   0.00000000e+00,
         0.00000000e+00,  -8.81698140e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.02164760e-03,   0.00000000e+00,
        -2.38567883e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.50226097e-03,
         0.00000000e+00,   0.00000000e+00,   9.97183998e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.84413260e-04,   0.00000000e+00,  -4.29709326e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.78037919e-04,   0.00000000e+00,
         0.00000000e+00,   7.21523388e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.16762315e-03,   1.74985722e-01,   7.38145887e-03,
        -2.80074514e-02,  -3.77852958e-02,  -9.41025878e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.27305567e-01,   2.15590394e-02,   8.22032357e-02,
        -5.52344523e-03,   0.00000000e+00,  -5.69144395e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.67855360e-01,   0.00000000e+00,   1.51088562e-01,
        -2.34233548e-03,  -1.25897406e-02,   1.09184928e-01,
         0.00000000e+00,   1.00132955e-01,   0.00000000e+00,
         1.14295382e-01,   4.93519128e-02,  -1.62540899e-02,
         5.10973723e-02,   0.00000000e+00,  -1.11013717e-01,
         0.00000000e+00,   2.50679374e-02,   9.83630987e-02,
         3.39370272e-03,  -2.93343692e-02,  -4.29694062e-02,
         0.00000000e+00,   3.35975119e-02,   0.00000000e+00,
         6.61125503e-04,  -4.08451338e-02,  -5.74658820e-02,
         1.27103224e-02,  -7.59042583e-03,  -2.08066754e-02,
         0.00000000e+00,  -7.41353147e-03,   0.00000000e+00,
        -9.77175262e-03,   1.87975639e-03,  -3.40796069e-02,
        -8.06369211e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.49203576e-02,   0.00000000e+00,
        -6.56715191e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.52939840e-01,
         2.98485207e-03,  -5.46379802e-04,   1.74162434e-02,
         0.00000000e+00,   4.66710730e-02,   0.00000000e+00,
        -5.37155576e-02,   1.87601571e-02,  -4.59706995e-03,
         2.55922972e-02,   0.00000000e+00,  -1.29090059e-01,
         4.36608410e-04,   2.22313271e-03,  -4.45012805e-02,
         0.00000000e+00,   3.28566137e-02,   0.00000000e+00,
         3.29064042e-02,   1.44424573e-02,  -4.06411114e-02,
        -2.20026309e-02,   0.00000000e+00,  -1.12749291e-02,
        -1.13537455e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.43035047e-02,   0.00000000e+00,
        -7.56782881e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.53161247e-02,
         0.00000000e+00,   0.00000000e+00,   1.86653954e-01,
        -3.67616403e-03,   7.61095098e-03,  -2.96575756e-02,
         0.00000000e+00,  -2.27226945e-02,   0.00000000e+00,
        -5.78586842e-02,   1.55092835e-04,  -2.49957071e-03,
         2.13677788e-02,   0.00000000e+00,   5.91301410e-02,
        -5.76358843e-02,   0.00000000e+00,   1.42762095e-01,
         1.11094493e-02,  -1.30047946e-03,  -3.46810117e-03,
         0.00000000e+00,   1.34778755e-02,   0.00000000e+00,
        -1.27259645e-03,  -8.05088524e-02,   2.09557189e-02,
        -9.08301489e-03,   0.00000000e+00,   2.46768279e-02,
         3.26382903e-02,   0.00000000e+00,   7.65579390e-03,
         1.70502989e-01,   1.99658445e-02,  -6.26354747e-02,
         1.45374889e-02,   0.00000000e+00,  -1.11318613e-02,
         0.00000000e+00,  -4.03568401e-03,  -3.60260870e-02,
        -1.56572778e-02,  -7.05935841e-03,   0.00000000e+00,
        -2.78932802e-02,  -3.51931197e-02,   0.00000000e+00,
         2.40997464e-02,  -4.85747095e-02,  -1.05323077e-01,
        -4.39153921e-02,  -3.58641078e-02,   1.00477404e-02,
         0.00000000e+00,  -2.08114811e-02,   0.00000000e+00,
         3.40727318e-03,  -1.96377912e-02,   2.00311560e-02,
        -9.05219352e-03,   0.00000000e+00,  -1.20049702e-02,
        -2.45634985e-02,   0.00000000e+00,  -1.16860279e-02,
        -2.42473636e-03,   1.02454621e-01,   1.39426299e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.60997659e-03,   7.28393771e-03,  -8.74431433e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.53464788e-03,   0.00000000e+00,
         2.25972353e-03,  -4.96136681e-03,   1.10157327e-02,
         0.00000000e+00,   9.72784878e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.46539978e-02,   0.00000000e+00,   9.68080935e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.85702880e-04,   0.00000000e+00,
         1.46174685e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.15427018e-03,   0.00000000e+00,   1.82524432e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.56671145e-03,   0.00000000e+00,  -6.31365786e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.55883482e-03,  -1.66599044e-03,
         3.04261461e-03,   0.00000000e+00,   2.79822561e-03,
         0.00000000e+00,  -4.35311480e-03,   5.09007339e-05,
        -1.33509616e-04,   3.57350019e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.90456021e-03,   0.00000000e+00,  -4.54913012e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.20306889e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.13769208e-03,   0.00000000e+00,   2.36660581e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.98196565e-03,   0.00000000e+00,
         0.00000000e+00,   6.29702009e-04,  -2.40484362e-04,
        -1.11590321e-03,   0.00000000e+00,  -9.06028379e-04,
         0.00000000e+00,  -4.21255174e-03,  -6.86800575e-05,
        -8.95592129e-05,   6.69281774e-04,   0.00000000e+00,
         5.10894564e-03,  -3.09893400e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.17644093e-03,   0.00000000e+00,  -3.44982958e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.12813409e-03,   0.00000000e+00,
         0.00000000e+00,   1.15002292e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.17408454e-04,   0.00000000e+00,  -6.71767929e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.60709833e-04,   0.00000000e+00,
         0.00000000e+00,   9.96762504e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.88102276e-03,   0.00000000e+00,
        -9.76918647e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.13043100e-03,
         0.00000000e+00,   0.00000000e+00,   2.46507305e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.21291931e-04,   0.00000000e+00,   1.04365528e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.93046796e-03,   0.00000000e+00,
         0.00000000e+00,  -1.79562974e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.91975015e-02,   1.91254897e-02,  -7.61874294e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.91649310e-03,   0.00000000e+00,
         1.49363285e-02,  -5.73422332e-03,   5.85559763e-03,
         0.00000000e+00,  -7.62731436e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.85702880e-04,   0.00000000e+00,   1.16869919e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.93963314e-02,   0.00000000e+00,
         6.42866782e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.33619221e-04,   0.00000000e+00,  -4.35946196e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.89645085e-03,   0.00000000e+00,  -1.43848000e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.81432240e-03,  -7.34586740e-03,
         3.42326262e-03,   0.00000000e+00,  -3.74009386e-03,
         0.00000000e+00,   5.06388916e-04,  -8.62781916e-03,
        -2.16815995e-03,  -1.28918271e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.70065923e-05,   0.00000000e+00,   6.89675327e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.62923317e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.36388877e-03,   0.00000000e+00,   2.10381234e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.18632667e-03,   0.00000000e+00,
         0.00000000e+00,  -4.14737790e-03,  -1.65952114e-03,
        -9.65187025e-04,   0.00000000e+00,   1.99036878e-03,
         0.00000000e+00,  -4.34994534e-04,  -3.46354446e-03,
         1.77882860e-03,  -5.32358730e-04,   0.00000000e+00,
        -2.84955179e-04,  -8.39736810e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.96672992e-03,   0.00000000e+00,   9.96220966e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.75381296e-03,   0.00000000e+00,
         0.00000000e+00,   4.98850689e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.11379224e-03,   0.00000000e+00,  -7.31978239e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.53004036e-03,   0.00000000e+00,
         0.00000000e+00,   1.12497600e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.57561582e-03,   0.00000000e+00,
        -6.59794890e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.03432357e-02,
         0.00000000e+00,   0.00000000e+00,   3.64476255e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.00364288e-03,   0.00000000e+00,  -3.00240333e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.27614718e-03,   0.00000000e+00,
         0.00000000e+00,   3.44552036e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.52995895e-03,   1.01955659e-02,   7.40495180e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.50118195e-03,   0.00000000e+00,
         2.28593496e-03,  -7.08481491e-03,  -3.93580993e-03,
         0.00000000e+00,   3.23365869e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.15427018e-03,   0.00000000e+00,   2.79672381e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.33619221e-04,   0.00000000e+00,
        -3.92858671e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.56137900e-03,   0.00000000e+00,  -3.38424860e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.63029503e-03,   0.00000000e+00,  -3.20132032e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.59567407e-03,  -7.52297249e-03,
        -3.27054660e-03,   0.00000000e+00,   2.55997305e-03,
         0.00000000e+00,   6.93440133e-04,  -5.16739577e-04,
        -3.80014886e-03,  -4.03658805e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.27352056e-03,   0.00000000e+00,  -9.77749390e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.00038254e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.94350634e-03,   0.00000000e+00,  -2.93464369e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.43275059e-03,   0.00000000e+00,
         0.00000000e+00,   1.36904276e-03,   2.31451489e-03,
         3.22061884e-04,   0.00000000e+00,  -1.78712927e-05,
         0.00000000e+00,  -3.77490302e-05,   1.68571713e-03,
        -2.77900400e-04,   5.65623856e-04,   0.00000000e+00,
        -6.91139014e-05,   1.23748373e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.44686158e-04,   0.00000000e+00,   4.64118309e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.53197831e-04,   0.00000000e+00,
         0.00000000e+00,   6.88355913e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.68059853e-03,   0.00000000e+00,   6.86469785e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.86413032e-04,   0.00000000e+00,
         0.00000000e+00,  -2.42937072e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.08612812e-03,   0.00000000e+00,
        -2.81070403e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.07315476e-03,
         0.00000000e+00,   0.00000000e+00,   1.06575445e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.22946512e-03,   0.00000000e+00,   3.08541705e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.24531418e-04,   0.00000000e+00,
         0.00000000e+00,  -1.66211385e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.84069807e-02,   1.77585036e-02,   3.91335760e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.41709482e-04,   0.00000000e+00,
         6.81982907e-03,  -1.01919028e-02,  -2.18717427e-03,
         0.00000000e+00,   8.62874022e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.56671145e-03,   0.00000000e+00,  -1.36342039e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.89645085e-03,   0.00000000e+00,
        -2.48679249e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.63029503e-03,   0.00000000e+00,  -3.18243026e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.06486911e-02,   0.00000000e+00,  -4.58824623e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.17500388e-04,  -2.22210013e-03,
        -2.04621726e-03,   0.00000000e+00,  -7.77282810e-04,
         0.00000000e+00,   2.08362412e-03,  -4.11917616e-03,
        -7.99503395e-03,   2.35206751e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.48521840e-04,   0.00000000e+00,   1.02108296e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.29973984e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.98543297e-03,   0.00000000e+00,  -9.02404205e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.58293503e-03,   0.00000000e+00,
         0.00000000e+00,  -1.52212687e-03,  -2.44068260e-03,
         4.73657646e-04,   0.00000000e+00,   2.20623441e-03,
         0.00000000e+00,   6.87084318e-04,   1.23187950e-04,
         1.03583762e-03,  -9.44938448e-04,   0.00000000e+00,
         8.69055957e-04,   2.33566412e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.86735078e-04,   0.00000000e+00,   1.93961514e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.45380831e-04,   0.00000000e+00,
         0.00000000e+00,   1.20081362e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.17691839e-03,   0.00000000e+00,  -1.78006391e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.04091197e-03,   0.00000000e+00,
         0.00000000e+00,  -1.42106535e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.40380666e-03,   0.00000000e+00,
        -1.10645603e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.22855886e-02,
         0.00000000e+00,   0.00000000e+00,   3.30531028e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.15343901e-03,   0.00000000e+00,  -3.64652248e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.65190168e-03,   0.00000000e+00,
         0.00000000e+00,  -4.08972844e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.05134324e-01,   5.94033576e-02,  -1.04302698e-01,
        -1.72982555e-02,  -1.26357470e-03,  -1.29313312e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.62075298e-01,   1.25355798e-02,   1.94192428e-02,
         1.53245150e-03,   0.00000000e+00,  -1.30569488e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.49203576e-02,   0.00000000e+00,  -7.15817129e-02,
        -2.21577704e-04,  -5.40392225e-03,   3.63504915e-02,
         0.00000000e+00,   3.81679716e-02,   0.00000000e+00,
        -6.64670950e-02,   3.25518381e-02,  -2.10460682e-02,
         1.49327009e-02,   0.00000000e+00,  -4.54077634e-02,
         0.00000000e+00,   1.35733657e-02,  -7.31389371e-02,
         1.94818769e-02,  -3.18008499e-02,  -4.79486599e-02,
         0.00000000e+00,   2.03181254e-02,   0.00000000e+00,
         1.09446260e-02,   1.37337286e-02,  -4.79800609e-02,
         9.78061532e-03,  -1.47976590e-02,  -3.10677272e-02,
         0.00000000e+00,  -6.94922379e-03,   0.00000000e+00,
         1.75574489e-02,  -9.18000885e-03,  -3.26497552e-02,
        -4.59301475e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.37534615e-01,   0.00000000e+00,
        -6.50425252e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.53397580e-01,
        -4.30605235e-03,  -1.67631100e-02,   4.07692536e-02,
         0.00000000e+00,   8.52954110e-02,   0.00000000e+00,
        -4.80072895e-02,   3.71921117e-02,   2.39996074e-04,
         2.36600643e-02,   0.00000000e+00,  -1.38882958e-01,
        -1.02229781e-02,  -1.95545145e-02,  -8.00441469e-02,
         0.00000000e+00,   3.78231941e-02,   0.00000000e+00,
         1.28404451e-02,   3.00577426e-02,  -5.23914521e-02,
        -3.11537367e-02,   0.00000000e+00,  -2.51885584e-03,
        -1.33974404e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.07340305e-02,   0.00000000e+00,
         2.87032255e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.65855699e-02,
         0.00000000e+00,   0.00000000e+00,  -3.48094120e-02,
        -9.44022594e-03,   6.84215163e-03,  -1.59248156e-02,
         0.00000000e+00,  -1.40294199e-03,   0.00000000e+00,
         2.41842132e-02,   4.34686129e-03,  -4.84856619e-03,
        -8.70800147e-03,   0.00000000e+00,   1.60777629e-02,
        -1.64031899e-02,   0.00000000e+00,  -3.91369157e-02,
         1.67930463e-02,  -1.38919136e-02,   1.41231271e-02,
         0.00000000e+00,  -2.20583957e-02,   0.00000000e+00,
         3.42469974e-03,  -4.80263170e-03,  -1.23926251e-03,
        -5.73856532e-04,   0.00000000e+00,   1.31994495e-02,
         1.70492616e-02,   0.00000000e+00,   3.19673786e-03,
        -4.63597313e-02,   7.43339065e-02,  -6.72717377e-02,
         1.39325800e-02,   0.00000000e+00,   6.44803064e-03,
         0.00000000e+00,  -3.93735441e-03,  -3.51115221e-02,
        -2.77876378e-02,  -1.87012573e-02,   0.00000000e+00,
        -8.91997422e-03,  -4.32526204e-03,   0.00000000e+00,
         1.24189985e-02,  -2.27605180e-02,  -1.35328221e-01,
        -1.13728715e-02,   2.92208707e-02,  -8.12641782e-03,
         0.00000000e+00,   1.43201711e-03,   0.00000000e+00,
         1.91791058e-03,   1.19431248e-02,   4.58805713e-03,
         6.00557051e-03,   0.00000000e+00,   4.04031480e-03,
        -1.54721942e-03,   0.00000000e+00,  -4.43638445e-03,
         4.02888849e-03,   2.73078680e-02,  -4.50895917e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.90616003e-03,   1.06788751e-02,  -5.85852512e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.62383106e-03,   0.00000000e+00,
         4.28909823e-03,  -4.51185562e-03,   2.10515977e-03,
         0.00000000e+00,   5.00683952e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.90456021e-03,   0.00000000e+00,  -3.77305542e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.70065923e-05,   0.00000000e+00,
        -1.00289251e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.27352056e-03,   0.00000000e+00,  -8.03680954e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.48521840e-04,   0.00000000e+00,   5.57636873e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.50391303e-04,  -5.64249479e-03,
         7.61722442e-03,   0.00000000e+00,   1.32796782e-02,
         0.00000000e+00,  -7.25609744e-03,   2.52804419e-03,
        -2.48352248e-03,   3.03337521e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.76576158e-02,   0.00000000e+00,  -7.01584472e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.88866642e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.26650190e-04,   0.00000000e+00,   2.02070486e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.68864074e-04,   0.00000000e+00,
         0.00000000e+00,  -2.91625584e-03,  -1.69603122e-03,
        -2.14049019e-04,   0.00000000e+00,  -1.00215724e-03,
         0.00000000e+00,   3.25511809e-03,  -7.42745053e-04,
         6.27627469e-05,  -1.44567030e-04,   0.00000000e+00,
         9.52150051e-04,   4.37371950e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.49439787e-03,   0.00000000e+00,   4.03948015e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.58223402e-03,   0.00000000e+00,
         0.00000000e+00,  -1.53886556e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.62640704e-04,   0.00000000e+00,   9.03700253e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.80762140e-03,   0.00000000e+00,
         0.00000000e+00,  -1.74023803e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.51115755e-03,   0.00000000e+00,
        -3.80027691e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.15295522e-02,
         0.00000000e+00,   0.00000000e+00,   7.65923599e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.62118289e-04,   0.00000000e+00,  -3.07343397e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.45961998e-03,   0.00000000e+00,
         0.00000000e+00,  -1.26599009e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.59318127e-04,   1.74044770e-03,   4.27215462e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.59741779e-03,   0.00000000e+00,
         1.95344460e-04,   6.06172057e-04,  -3.41513736e-03,
         0.00000000e+00,   2.85638966e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.13769208e-03,   0.00000000e+00,   1.31749979e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.36388877e-03,   0.00000000e+00,
         1.51029221e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.94350634e-03,   0.00000000e+00,  -2.36684721e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.98543297e-03,   0.00000000e+00,  -1.24320212e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.73403713e-03,  -2.60592554e-03,
        -1.31189795e-02,   0.00000000e+00,   5.57706485e-03,
         0.00000000e+00,   1.74574939e-03,   4.43264266e-03,
        -5.96062008e-03,  -4.73033704e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.26650190e-04,   0.00000000e+00,   7.25657431e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.97148626e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.60881414e-02,   0.00000000e+00,  -5.36382009e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.54779949e-03,   0.00000000e+00,
         0.00000000e+00,  -3.20475810e-03,  -2.61485492e-03,
         1.40877607e-03,   0.00000000e+00,  -2.34948009e-03,
         0.00000000e+00,  -2.65914583e-03,  -1.32830251e-03,
         6.42461422e-04,   1.02146327e-03,   0.00000000e+00,
         3.01172530e-04,   7.43811793e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.15964444e-03,   0.00000000e+00,  -3.48568326e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.65492699e-04,   0.00000000e+00,
         0.00000000e+00,   2.50282487e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.67711690e-03,   0.00000000e+00,   1.50863335e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.50992388e-05,   0.00000000e+00,
         0.00000000e+00,  -2.18948509e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.63881128e-03,   0.00000000e+00,
        -1.85826400e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.25694948e-03,
         0.00000000e+00,   0.00000000e+00,  -6.18533635e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.04039293e-04,   0.00000000e+00,  -4.71161949e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.29871378e-03,   0.00000000e+00,
         0.00000000e+00,  -3.82860366e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.12370095e-02,  -3.72079706e-02,  -3.10778471e-02,
         9.91291287e-03,   7.32318452e-03,  -7.71205105e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.39221706e-04,  -1.38293155e-02,  -1.20335669e-02,
        -1.10134334e-03,   0.00000000e+00,  -1.11330467e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.43035047e-02,   0.00000000e+00,  -6.35015968e-02,
         2.59568323e-03,   1.06750090e-03,  -2.32634969e-02,
         0.00000000e+00,  -2.17198624e-02,   0.00000000e+00,
        -5.32391590e-02,  -1.59356790e-02,   2.07662102e-03,
        -1.15991965e-02,   0.00000000e+00,   2.37916903e-02,
         0.00000000e+00,  -5.17326390e-03,  -4.67446234e-02,
         3.74027844e-03,   5.87009676e-03,   8.28921055e-03,
         0.00000000e+00,  -6.05555193e-03,   0.00000000e+00,
        -4.84800766e-04,   1.27032612e-02,  -3.82657868e-03,
        -3.95035690e-03,  -4.92309151e-04,   7.46783948e-03,
         0.00000000e+00,   5.65231233e-03,   0.00000000e+00,
         4.81261979e-03,  -2.20206927e-03,   3.47428428e-03,
        -3.62394232e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.07340305e-02,   0.00000000e+00,
         2.50568464e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.92316842e-03,
        -3.84368695e-03,  -2.26841356e-03,   9.96084376e-04,
         0.00000000e+00,  -9.32007808e-03,   0.00000000e+00,
         1.91723693e-02,  -3.82965940e-03,  -1.40122882e-03,
        -3.94596499e-03,   0.00000000e+00,   6.21382185e-03,
        -4.61779499e-03,  -3.78433885e-03,   7.78766443e-03,
         0.00000000e+00,  -1.41029014e-02,   0.00000000e+00,
        -1.44660320e-02,  -3.50386194e-03,   5.59590789e-03,
         6.49162817e-03,   0.00000000e+00,   1.36237978e-03,
         6.11102826e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.39667708e-02,   0.00000000e+00,
         6.73976977e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.50791166e-02,
         0.00000000e+00,   0.00000000e+00,  -6.82447914e-02,
        -8.76298746e-04,  -2.25373128e-03,   2.06656195e-02,
         0.00000000e+00,   1.73826874e-02,   0.00000000e+00,
         4.75099849e-02,   1.22091895e-03,  -8.89668387e-06,
        -6.24868284e-03,   0.00000000e+00,  -1.43919970e-02,
         1.54774089e-02,   0.00000000e+00,  -5.77414884e-02,
        -6.93453363e-04,  -7.03505729e-03,   1.01400534e-02,
         0.00000000e+00,  -2.10029549e-02,   0.00000000e+00,
         2.45992760e-03,   5.18811190e-02,  -1.32415263e-02,
         3.17788381e-03,   0.00000000e+00,  -7.11982627e-03,
        -9.39233891e-03,   0.00000000e+00,  -2.21228709e-03,
        -6.81843959e-02,   5.53850693e-03,   2.66291632e-02,
        -4.32164352e-03,   0.00000000e+00,   6.40826319e-03,
         0.00000000e+00,   4.03095646e-03,   5.59173917e-03,
         1.56484733e-03,   3.36333073e-03,   0.00000000e+00,
        -1.19413623e-03,   1.80148225e-03,   0.00000000e+00,
        -5.51911744e-03,   1.16936922e-02,  -1.62896488e-04,
         3.78604346e-02,   3.50641551e-02,  -5.85654536e-03,
         0.00000000e+00,   9.64653511e-03,   0.00000000e+00,
        -1.49613173e-03,   1.25267265e-02,  -6.93933752e-03,
         2.40624401e-03,   0.00000000e+00,   5.05324820e-03,
         7.72879540e-03,   0.00000000e+00,   2.83982152e-03,
        -2.04625595e-03,  -2.55723913e-02,  -5.73574065e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.19098008e-03,  -5.00350629e-03,   9.81955033e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.51458899e-04,   0.00000000e+00,
        -2.16750591e-03,   3.09699736e-03,  -1.96707510e-03,
         0.00000000e+00,  -1.47716461e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.17644093e-03,   0.00000000e+00,  -3.08349230e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.96672992e-03,   0.00000000e+00,
         7.65141056e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.44686158e-04,   0.00000000e+00,   4.48435224e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.86735078e-04,   0.00000000e+00,   1.45060229e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.58455658e-03,   2.95371375e-03,
        -3.69301032e-03,   0.00000000e+00,  -6.16359608e-04,
         0.00000000e+00,   3.55039766e-03,   1.79874504e-03,
         4.27003876e-04,  -7.20805551e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.49439787e-03,   0.00000000e+00,   3.45467085e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.57743471e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.15964444e-03,   0.00000000e+00,  -3.00989578e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.81131706e-04,   0.00000000e+00,
         0.00000000e+00,  -2.91919477e-04,  -7.58193946e-04,
         3.87501100e-03,   0.00000000e+00,   2.67030504e-03,
         0.00000000e+00,   7.19598738e-03,  -1.12573979e-04,
        -1.94498099e-04,  -3.01542061e-04,   0.00000000e+00,
        -6.84148490e-04,   5.30412922e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.47749620e-03,   0.00000000e+00,   6.50131751e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.80458549e-04,   0.00000000e+00,
         0.00000000e+00,  -2.74848356e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.24291877e-03,   0.00000000e+00,   8.85603859e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.90299963e-04,   0.00000000e+00,
         0.00000000e+00,  -4.24960564e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.97962386e-03,   0.00000000e+00,
         2.43500195e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.46230062e-03,
         0.00000000e+00,   0.00000000e+00,  -9.47241370e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.90846213e-04,   0.00000000e+00,  -1.23664956e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.41596796e-03,   0.00000000e+00,
         0.00000000e+00,   6.19125051e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.08966153e-03,   9.10894172e-03,  -2.86887670e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.03235452e-04,   0.00000000e+00,
         7.90943805e-03,   1.30378832e-03,  -8.22367239e-05,
         0.00000000e+00,   2.44518054e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.17408454e-04,   0.00000000e+00,  -6.38301631e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.11379224e-03,   0.00000000e+00,
        -4.92793318e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.68059853e-03,   0.00000000e+00,   7.56292310e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.17691839e-03,   0.00000000e+00,  -1.01185753e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.76005146e-03,  -5.14999187e-03,
         3.65938377e-03,   0.00000000e+00,  -3.59839211e-03,
         0.00000000e+00,   1.10212070e-04,  -1.89532518e-03,
        -8.38589419e-04,  -1.08245465e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.62640704e-04,   0.00000000e+00,   7.24227202e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.42305244e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.67711690e-03,   0.00000000e+00,   2.03937585e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.26434628e-05,   0.00000000e+00,
         0.00000000e+00,  -4.13447199e-04,  -1.97327081e-03,
         2.07180037e-03,   0.00000000e+00,  -4.19274895e-03,
         0.00000000e+00,   5.47224688e-04,   7.91273128e-03,
        -1.44052157e-03,   1.32193521e-06,   0.00000000e+00,
        -1.13406488e-03,  -1.79084690e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.24291877e-03,   0.00000000e+00,   8.82825232e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.37276457e-04,   0.00000000e+00,
         0.00000000e+00,  -4.88795364e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.61755253e-03,   0.00000000e+00,   7.98823027e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.04076579e-03,   0.00000000e+00,
         0.00000000e+00,  -3.67195324e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.00326941e-03,   0.00000000e+00,
        -4.92107729e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.69372121e-03,
         0.00000000e+00,   0.00000000e+00,   3.94985578e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.63019481e-04,   0.00000000e+00,   1.71984151e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.64237637e-03,   0.00000000e+00,
         0.00000000e+00,   4.48281494e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.56793911e-03,   8.92744496e-03,  -3.43517350e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.02164760e-03,   0.00000000e+00,
         4.92165274e-03,  -6.92545676e-03,   3.26035633e-03,
         0.00000000e+00,  -1.56779576e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.88102276e-03,   0.00000000e+00,  -9.59653854e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.57561582e-03,   0.00000000e+00,
        -2.92776043e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.08612812e-03,   0.00000000e+00,  -3.34088698e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.40380666e-03,   0.00000000e+00,  -3.24913254e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.88404362e-02,  -2.43514403e-02,
         6.18938780e-03,   0.00000000e+00,   2.47697754e-03,
         0.00000000e+00,  -2.77410632e-03,  -6.95185089e-03,
         2.58727210e-04,  -1.11448522e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.51115755e-03,   0.00000000e+00,  -3.91634023e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.88977206e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.63881128e-03,   0.00000000e+00,  -2.17022114e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.57381277e-04,   0.00000000e+00,
         0.00000000e+00,   3.66075326e-03,   1.20841963e-02,
        -1.43144060e-03,   0.00000000e+00,   2.24117651e-04,
         0.00000000e+00,   1.13697676e-03,   1.97132741e-03,
        -4.33762472e-04,   1.94180801e-03,   0.00000000e+00,
        -1.44135612e-03,  -1.79887820e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.97962386e-03,   0.00000000e+00,   2.09978631e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.70699198e-03,   0.00000000e+00,
         0.00000000e+00,  -8.33290983e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.00326941e-03,   0.00000000e+00,  -3.75726896e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.00394118e-03,   0.00000000e+00,
         0.00000000e+00,   3.40200964e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.01905488e-02,   0.00000000e+00,
        -1.36538617e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.82405647e-03,
         0.00000000e+00,   0.00000000e+00,  -1.24771913e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.70493653e-03,   0.00000000e+00,   1.64926252e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.23557460e-03,   0.00000000e+00,
         0.00000000e+00,   1.84853627e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.87477656e-03,   2.67923197e-03,  -3.01888094e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.84413260e-04,   0.00000000e+00,
        -2.81060207e-03,  -8.17564103e-03,   1.85783480e-03,
         0.00000000e+00,  -2.15677101e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.21291931e-04,   0.00000000e+00,   1.30898908e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.00364288e-03,   0.00000000e+00,
        -1.95926024e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.22946512e-03,   0.00000000e+00,   1.95788619e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.15343901e-03,   0.00000000e+00,  -2.00328427e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.51294986e-03,   9.88879450e-03,
        -1.91596830e-03,   0.00000000e+00,  -6.11790718e-04,
         0.00000000e+00,   9.11305066e-04,   2.27659933e-03,
        -2.49889826e-03,   3.97475158e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.62118289e-04,   0.00000000e+00,  -1.20121627e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.28168754e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.04039293e-04,   0.00000000e+00,  -2.47169677e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.45853598e-04,   0.00000000e+00,
         0.00000000e+00,   1.41586628e-02,   1.14769660e-02,
        -2.41776242e-03,   0.00000000e+00,   4.79093640e-03,
         0.00000000e+00,  -6.94364068e-04,   2.26530138e-03,
        -4.84202213e-04,  -5.86420067e-04,   0.00000000e+00,
         1.40498454e-03,   1.56135818e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.90846213e-04,   0.00000000e+00,  -9.53290496e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.21497859e-04,   0.00000000e+00,
         0.00000000e+00,   3.56202248e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.63019481e-04,   0.00000000e+00,  -1.92748246e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.48513523e-03,   0.00000000e+00,
         0.00000000e+00,   2.42385073e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.70493653e-03,   0.00000000e+00,
         1.24814291e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.25210588e-03,
         0.00000000e+00,   0.00000000e+00,  -1.49279206e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.55851047e-02,   0.00000000e+00,   1.57349841e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.12692506e-03,   0.00000000e+00,
         0.00000000e+00,  -7.43044609e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.17702459e-02,   2.60243672e-02,  -7.26689057e-03,
        -9.28478876e-03,  -5.05386446e-03,  -4.14634835e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.62826113e-02,   9.09802634e-02,  -1.28186757e-02,
         9.83036118e-03,   0.00000000e+00,  -2.18712504e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.15590394e-02,   0.00000000e+00,   3.05223935e-03,
         2.39256508e-03,   4.23601485e-02,   4.92145292e-03,
         0.00000000e+00,   1.63439008e-02,   0.00000000e+00,
         3.76508456e-03,   4.03828313e-03,  -5.90042653e-02,
         1.88495005e-02,   0.00000000e+00,  -3.28573498e-02,
         0.00000000e+00,   1.37315339e-02,  -2.59895793e-02,
         5.04879844e-03,   1.03460532e-02,  -1.24066117e-02,
         0.00000000e+00,  -5.40864878e-03,   0.00000000e+00,
         3.26222639e-03,  -4.01464964e-03,  -1.93495811e-02,
         6.94890555e-03,  -6.14714726e-03,  -6.06752615e-03,
         0.00000000e+00,  -1.98068212e-02,   0.00000000e+00,
         3.80450676e-03,  -1.09415746e-02,  -5.75000072e-03,
        -2.59931235e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.25355798e-02,   0.00000000e+00,
        -1.76858968e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.36281698e-02,
        -7.47116451e-03,   8.18524796e-03,  -3.85706431e-03,
         0.00000000e+00,   9.05213171e-03,   0.00000000e+00,
        -1.15773928e-02,   2.23124085e-02,   1.21668619e-02,
        -4.43888017e-04,   0.00000000e+00,  -2.97299196e-02,
        -6.04301255e-03,   6.54977999e-03,  -1.75327628e-02,
         0.00000000e+00,   2.26617164e-02,   0.00000000e+00,
         9.75113722e-03,   1.90221547e-02,  -8.37091255e-03,
        -7.36898102e-03,   0.00000000e+00,   4.17936339e-03,
        -3.00406357e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.38293155e-02,   0.00000000e+00,
        -1.02282325e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.26724494e-03,
         0.00000000e+00,   0.00000000e+00,   8.79910438e-03,
        -3.00434516e-03,  -3.49493195e-03,  -1.05391159e-02,
         0.00000000e+00,  -5.02971329e-03,   0.00000000e+00,
        -8.69135728e-03,   3.32717003e-05,  -1.05995766e-03,
        -2.68830455e-03,   0.00000000e+00,  -5.12691066e-03,
        -1.14000430e-02,   0.00000000e+00,   7.37781736e-03,
         4.39535796e-03,   2.79959023e-03,  -3.91692521e-03,
         0.00000000e+00,   1.05480702e-02,   0.00000000e+00,
         1.42286389e-03,  -1.35414770e-02,  -1.61704097e-03,
        -5.52858456e-05,   0.00000000e+00,   2.25117797e-02,
         1.94770806e-02,   0.00000000e+00,   1.88541316e-03,
         1.17115402e-02,   4.41327776e-03,  -1.35455128e-02,
         5.71064756e-03,   0.00000000e+00,  -1.27529713e-02,
         0.00000000e+00,   1.29041042e-03,  -2.14453825e-02,
        -1.30513777e-03,  -3.29333682e-03,   0.00000000e+00,
         5.42644501e-02,   1.70934305e-02,   0.00000000e+00,
         1.41623471e-02,  -4.22851078e-02,  -4.73910378e-02,
        -1.35515864e-02,  -1.22145335e-02,  -6.11278720e-03,
         0.00000000e+00,   7.03668517e-03,   0.00000000e+00,
        -4.19804609e-03,   1.16842060e-02,  -1.88089669e-03,
         3.24815104e-03,   0.00000000e+00,  -9.78622926e-03,
        -1.41002262e-02,   0.00000000e+00,   2.96519317e-02,
        -3.16362026e-02,   2.17345563e-02,  -1.94264369e-02,
         2.57370402e-02,   9.38297698e-02,   7.59124793e-03,
        -5.53965385e-03,  -2.03948099e-02,  -4.39340757e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.60238450e-02,  -1.28186757e-02,   1.08972511e-01,
        -1.18173568e-02,   0.00000000e+00,  -2.59491831e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.22032357e-02,   0.00000000e+00,   8.94995975e-02,
         3.37702024e-02,   1.69745932e-04,   6.21208205e-02,
         0.00000000e+00,   7.63802740e-02,   0.00000000e+00,
         7.42111784e-02,  -1.78175861e-02,  -8.62638533e-03,
         3.49262853e-02,   0.00000000e+00,  -6.97382648e-02,
         0.00000000e+00,   1.58636745e-02,   8.05872445e-02,
         1.01715906e-02,  -1.59851175e-02,  -2.02873973e-02,
         0.00000000e+00,   3.31074810e-02,   0.00000000e+00,
        -8.58496843e-03,  -2.28166313e-02,  -3.94646901e-02,
        -1.27952280e-03,  -4.32198937e-03,  -5.69696544e-03,
         0.00000000e+00,   7.53292892e-03,   0.00000000e+00,
        -1.30595025e-02,   8.66910391e-03,  -1.82293031e-02,
        -5.27911245e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.94192428e-02,   0.00000000e+00,
        -2.71559802e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.40324255e-02,
         9.57776361e-03,  -1.20402661e-02,   1.27524897e-02,
         0.00000000e+00,   1.84005213e-02,   0.00000000e+00,
        -2.60053027e-02,  -6.19518079e-04,  -1.39178295e-02,
         1.28873688e-02,   0.00000000e+00,  -8.53883576e-02,
         7.38335044e-03,   2.66521126e-03,  -1.26142776e-02,
         0.00000000e+00,   1.08292918e-02,   0.00000000e+00,
         2.13520008e-02,  -3.17457765e-03,  -2.23834283e-02,
        -8.13826489e-03,   0.00000000e+00,  -1.87024445e-02,
        -5.92456273e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.20335669e-02,   0.00000000e+00,
        -3.82683554e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.39199785e-02,
         0.00000000e+00,   0.00000000e+00,   1.06489693e-01,
        -6.20803679e-03,  -1.53212143e-03,  -1.01037430e-02,
         0.00000000e+00,  -1.60842390e-02,   0.00000000e+00,
        -3.04848975e-02,  -5.12979962e-03,   3.18290544e-03,
         1.41719403e-02,   0.00000000e+00,   3.81889590e-02,
        -3.55997841e-02,   0.00000000e+00,   9.27727360e-02,
         8.28962813e-03,   1.45037080e-02,  -2.86743751e-03,
         0.00000000e+00,   1.19275422e-02,   0.00000000e+00,
        -2.97004598e-04,  -3.70000873e-02,   1.22913022e-02,
        -3.17465513e-03,   0.00000000e+00,   1.19013003e-02,
         2.05254102e-02,   0.00000000e+00,  -2.00923718e-03,
         1.29527943e-01,   2.30013494e-03,  -2.80443413e-02,
         3.12976826e-03,   0.00000000e+00,   6.61978252e-03,
         0.00000000e+00,  -1.22208084e-02,  -5.80010516e-03,
        -8.56603573e-03,   3.09129905e-03,   0.00000000e+00,
        -5.63912532e-02,  -4.77451285e-02,   0.00000000e+00,
         2.55501130e-02,  -3.14525712e-02,  -3.84757778e-02,
        -2.26874664e-02,  -1.43590094e-02,   1.05589808e-02,
         0.00000000e+00,  -2.70857854e-02,   0.00000000e+00,
        -1.26672918e-03,  -4.65179184e-03,   9.17032624e-03,
        -6.82107335e-04,   0.00000000e+00,   7.75153283e-03,
        -1.72830501e-02,   0.00000000e+00,   1.79151366e-02,
        -2.61669123e-02,   5.37790602e-02,   8.25088303e-02,
        -1.14126951e-02,  -2.65362697e-03,  -7.67668166e-03,
         4.40815095e-03,  -9.34561286e-03,  -1.79020155e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.45852574e-03,   9.83036118e-03,  -1.18173568e-02,
         2.93047658e-02,   0.00000000e+00,  -3.98669875e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.52344523e-03,   0.00000000e+00,  -9.43080549e-03,
        -5.94982366e-03,   1.08039585e-02,  -1.26408676e-02,
         0.00000000e+00,  -9.44771587e-03,   0.00000000e+00,
         7.06109208e-03,   8.89126244e-03,   6.30665086e-03,
         3.61791771e-03,   0.00000000e+00,   3.90646022e-03,
         0.00000000e+00,  -5.78233574e-03,  -1.95088322e-02,
        -1.17973232e-03,  -3.58777128e-03,   1.59212735e-03,
         0.00000000e+00,   3.00281968e-03,   0.00000000e+00,
        -1.69910146e-03,   3.51154715e-03,  -9.13970020e-03,
        -1.00301278e-03,   4.61380305e-04,   7.89268045e-03,
         0.00000000e+00,   3.71959890e-03,   0.00000000e+00,
        -4.97604854e-03,  -1.17184862e-03,  -3.77059817e-03,
        -1.37539986e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.53245150e-03,   0.00000000e+00,
         2.11540729e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.13110296e-03,
        -6.04749155e-03,   4.69914716e-03,  -5.42850568e-03,
         0.00000000e+00,  -1.25079961e-03,   0.00000000e+00,
         3.63229215e-03,   1.94992470e-03,  -2.20595674e-03,
        -5.47675898e-03,   0.00000000e+00,   2.40055892e-02,
        -3.07321590e-03,   1.37195144e-03,  -5.63610889e-03,
         0.00000000e+00,   7.78174504e-03,   0.00000000e+00,
        -7.41959009e-04,   5.46941431e-03,  -6.46205729e-03,
        -2.21906531e-03,   0.00000000e+00,  -1.36772614e-02,
        -1.10934461e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.10134334e-03,   0.00000000e+00,
         2.06541486e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.55925478e-03,
         0.00000000e+00,   0.00000000e+00,  -9.68937909e-03,
        -2.54394783e-03,   1.48708494e-04,  -2.84029203e-03,
         0.00000000e+00,   2.04106190e-04,   0.00000000e+00,
         5.57578136e-04,   1.09432815e-03,  -1.57320617e-03,
         2.12238155e-03,   0.00000000e+00,  -9.52951538e-03,
         9.76086458e-04,   0.00000000e+00,   1.15039564e-03,
        -3.01919037e-03,  -2.87023939e-03,   8.86497585e-04,
         0.00000000e+00,  -2.88152703e-03,   0.00000000e+00,
         9.58238970e-04,   8.48748026e-04,   4.55227464e-05,
        -1.10031548e-03,   0.00000000e+00,  -1.54662583e-03,
         1.24068670e-03,   0.00000000e+00,  -3.25268937e-03,
        -2.11267782e-02,   2.33164553e-03,  -1.49272259e-03,
        -1.75398927e-03,   0.00000000e+00,  -6.12144326e-03,
         0.00000000e+00,   2.12276278e-03,  -4.67229951e-03,
         9.94745905e-04,  -2.87811645e-03,   0.00000000e+00,
         1.39143951e-02,  -9.34757878e-04,   0.00000000e+00,
        -2.48548488e-03,   2.89483437e-03,  -4.85568823e-03,
        -3.13525061e-03,   3.24209167e-03,  -2.50732592e-03,
         0.00000000e+00,   4.92137674e-03,   0.00000000e+00,
        -2.64423801e-03,  -1.30897869e-03,  -8.83586081e-04,
        -1.04820003e-03,   0.00000000e+00,  -3.84648959e-03,
         2.24334783e-03,   0.00000000e+00,   2.98285071e-03,
         6.60102504e-03,  -2.91585163e-03,  -4.71852791e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.51437276e-03,  -6.44012777e-03,   5.95092685e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.98642936e-02,   0.00000000e+00,
         3.79314951e-03,   1.38514683e-02,  -2.49912214e-03,
         0.00000000e+00,  -4.03997834e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.53464788e-03,   0.00000000e+00,   1.00356663e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.91649310e-03,   0.00000000e+00,
        -1.06761228e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.50118195e-03,   0.00000000e+00,   3.57666520e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.41709482e-04,   0.00000000e+00,   4.72127977e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.92921822e-03,   1.45250449e-04,
         2.40782936e-04,   0.00000000e+00,  -7.97449300e-03,
         0.00000000e+00,   2.92636754e-03,  -3.40930390e-03,
         3.86770098e-03,  -2.09023917e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.62383106e-03,   0.00000000e+00,   5.13633127e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.23662841e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.59741779e-03,   0.00000000e+00,   3.53089979e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.17020611e-03,   0.00000000e+00,
         0.00000000e+00,  -5.56394842e-03,  -1.62951670e-03,
        -5.26749043e-04,   0.00000000e+00,  -5.75500404e-04,
         0.00000000e+00,  -1.01656667e-03,   3.42655118e-04,
        -3.73390497e-04,   1.82750219e-03,   0.00000000e+00,
        -3.25162324e-03,  -4.04822590e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.51458899e-04,   0.00000000e+00,  -1.14330713e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.45409636e-03,   0.00000000e+00,
         0.00000000e+00,   5.28658506e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.03235452e-04,   0.00000000e+00,   1.03270713e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.28870492e-03,   0.00000000e+00,
         0.00000000e+00,  -8.81698140e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.02164760e-03,   0.00000000e+00,
        -2.38567883e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.50226097e-03,
         0.00000000e+00,   0.00000000e+00,   9.97183998e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.84413260e-04,   0.00000000e+00,  -4.29709326e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.78037919e-04,   0.00000000e+00,
         0.00000000e+00,   7.21523388e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.97834840e-01,  -5.75145615e-02,   5.83640015e-01,
         3.27669023e-02,  -1.46791456e-03,   5.86454241e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.12816660e-01,  -2.18712504e-02,  -2.59491831e-02,
        -3.98669875e-05,   0.00000000e+00,   6.55656410e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.69144395e-02,   0.00000000e+00,   5.32623729e-01,
         1.13126800e-02,   2.99633386e-02,  -3.62384491e-02,
         0.00000000e+00,  -4.52729483e-02,   0.00000000e+00,
         5.45584961e-01,  -2.39924967e-02,   3.46130315e-02,
        -7.77607962e-03,   0.00000000e+00,   5.66463409e-02,
         0.00000000e+00,  -3.14414767e-02,   5.49012050e-01,
        -3.88121089e-02,   4.75755328e-02,   8.07552551e-02,
         0.00000000e+00,  -3.42853383e-02,   0.00000000e+00,
        -1.54537911e-02,  -6.34723458e-02,   3.84084134e-01,
        -1.75374175e-02,   2.51853549e-02,   4.13063625e-02,
         0.00000000e+00,   6.02589753e-03,   0.00000000e+00,
        -3.06744474e-02,   2.58664960e-02,   7.79324525e-02,
         4.17456552e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.30569488e-01,   0.00000000e+00,
         5.30311236e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.72856095e-01,
         2.71017297e-03,   2.69922827e-02,  -5.13901112e-02,
         0.00000000e+00,  -1.14950418e-01,   0.00000000e+00,
         5.41222539e-02,  -5.78248125e-02,   4.87896541e-03,
        -2.96071331e-02,   0.00000000e+00,   6.05039328e-01,
         1.98345372e-02,   2.92429148e-02,   9.11477411e-02,
         0.00000000e+00,  -3.75431355e-02,   0.00000000e+00,
         8.20459520e-05,  -4.21364448e-02,   7.81930890e-02,
         2.39072980e-02,   0.00000000e+00,   1.47671372e-02,
         5.76774960e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.11330467e-02,   0.00000000e+00,
        -7.79481078e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.37269548e-03,
         0.00000000e+00,   0.00000000e+00,   4.72520382e-01,
         8.05056973e-03,  -1.12523550e-02,   7.88148934e-04,
         0.00000000e+00,  -1.45966714e-02,   0.00000000e+00,
        -7.88650035e-02,  -8.30825556e-03,   2.57632480e-03,
         2.23897095e-02,   0.00000000e+00,  -1.22822497e-02,
         6.11329423e-03,   0.00000000e+00,   4.79742387e-01,
        -1.12485641e-03,   3.16059718e-02,  -2.64988818e-02,
         0.00000000e+00,   5.10054060e-02,   0.00000000e+00,
        -4.13386822e-03,  -4.61925103e-02,   1.96671572e-02,
        -8.35799511e-03,   0.00000000e+00,  -2.71715579e-02,
        -2.40824460e-02,   0.00000000e+00,  -1.60536968e-02,
         5.08387513e-01,  -8.34729675e-02,   5.54552336e-02,
        -1.82113755e-02,   0.00000000e+00,  -2.51648766e-02,
         0.00000000e+00,   5.07143860e-05,   5.63002474e-02,
         5.92569094e-02,   5.06698155e-03,   0.00000000e+00,
         1.36839264e-02,  -3.15127843e-03,   0.00000000e+00,
        -9.31717444e-03,   3.54992650e-02,   5.93630090e-01,
        -8.47349685e-03,  -6.04513178e-02,   1.86878943e-02,
         0.00000000e+00,  -1.55498468e-02,   0.00000000e+00,
        -6.34830796e-03,  -1.26152067e-02,  -7.87068170e-03,
        -8.73566504e-03,   0.00000000e+00,  -7.80289466e-03,
        -6.06340215e-03,   0.00000000e+00,   1.96809652e-02,
         7.44501641e-03,  -2.02702608e-02,   5.16053005e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.55854803e-03,   1.85069084e-02,  -2.83116595e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.03997834e-03,   0.00000000e+00,
         2.37435923e-02,   2.34295766e-02,  -3.55292973e-03,
         0.00000000e+00,   2.48054985e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.72784878e-03,   0.00000000e+00,   7.28384472e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.62731436e-03,   0.00000000e+00,
        -7.91976291e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.23365869e-03,   0.00000000e+00,  -3.26647409e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.62874022e-04,   0.00000000e+00,  -1.36911733e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.53656619e-03,  -4.66020260e-03,
         1.32971594e-03,   0.00000000e+00,   1.41660248e-03,
         0.00000000e+00,  -2.89027657e-03,   3.25852374e-03,
        -2.47405649e-03,   1.62365949e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.00683952e-03,   0.00000000e+00,  -1.23900738e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.04174535e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.85638966e-03,   0.00000000e+00,   3.79264423e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.27879269e-03,   0.00000000e+00,
         0.00000000e+00,  -3.87437812e-03,  -6.94176139e-03,
         1.23243934e-03,   0.00000000e+00,  -4.54348935e-03,
         0.00000000e+00,  -3.07228052e-03,   5.42025903e-04,
         1.21610475e-03,  -2.28942108e-04,   0.00000000e+00,
         7.96582340e-04,  -6.15494692e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.47716461e-03,   0.00000000e+00,  -2.35147629e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.00417255e-03,   0.00000000e+00,
         0.00000000e+00,   8.81138523e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.44518054e-03,   0.00000000e+00,   6.22432751e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.30714095e-03,   0.00000000e+00,
         0.00000000e+00,  -1.75730246e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.56779576e-03,   0.00000000e+00,
        -5.11122286e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.38347870e-03,
         0.00000000e+00,   0.00000000e+00,   1.45738557e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.15677101e-03,   0.00000000e+00,  -5.50979498e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.89219249e-03,   0.00000000e+00,
         0.00000000e+00,   2.59986109e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.54098860e-03,   1.20894210e-01,   8.24793789e-03,
        -1.53083336e-02,  -1.19709049e-02,  -6.73198779e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.31936171e-02,   1.63439008e-02,   7.63802740e-02,
        -9.44771587e-03,   0.00000000e+00,  -4.52729483e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.00132955e-01,   0.00000000e+00,   9.28473202e-02,
         2.19307578e-02,   9.10670466e-03,   8.12913535e-02,
         0.00000000e+00,   1.03213108e-01,   0.00000000e+00,
         9.54985583e-02,   3.19051522e-02,  -4.68885975e-03,
         2.87596858e-02,   0.00000000e+00,  -8.54600932e-02,
         0.00000000e+00,   1.28251082e-02,   6.96711838e-02,
         2.14458079e-03,  -2.17256410e-02,  -2.95461624e-02,
         0.00000000e+00,   2.51807427e-02,   0.00000000e+00,
         1.14351114e-03,  -2.65975300e-02,  -3.64576557e-02,
         7.02375029e-03,  -7.61722169e-03,  -1.81026804e-02,
         0.00000000e+00,  -7.39306568e-03,   0.00000000e+00,
        -6.85076357e-03,   4.14542835e-03,  -2.19212241e-02,
        -4.87124676e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.81679716e-02,   0.00000000e+00,
        -3.96273236e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.09996360e-02,
         3.73560100e-04,  -4.93977632e-03,   1.54829521e-02,
         0.00000000e+00,   3.65231944e-02,   0.00000000e+00,
        -4.11780321e-02,   1.60128909e-02,  -5.03311977e-03,
         2.28277902e-02,   0.00000000e+00,  -1.12800639e-01,
         2.26879301e-03,   5.68999691e-03,  -2.86691366e-02,
         0.00000000e+00,   2.50533068e-02,   0.00000000e+00,
         2.82643521e-02,   7.41006907e-03,  -2.65930758e-02,
        -1.40262840e-02,   0.00000000e+00,  -1.16102675e-02,
        -7.41215505e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.17198624e-02,   0.00000000e+00,
        -4.86350897e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.01104197e-02,
         0.00000000e+00,   0.00000000e+00,   1.16368419e-01,
        -5.52880179e-03,  -3.29101740e-04,  -1.99693548e-02,
         0.00000000e+00,  -2.15124998e-02,   0.00000000e+00,
        -4.71978536e-02,  -4.00370187e-04,  -1.63046699e-05,
         1.52552962e-02,   0.00000000e+00,   4.78066410e-02,
        -4.90288792e-02,   0.00000000e+00,   1.18955039e-01,
         5.72685861e-03,   5.31976359e-04,  -9.72692128e-04,
         0.00000000e+00,   1.08264616e-02,   0.00000000e+00,
         4.98619877e-03,  -5.68723556e-02,   1.56859060e-02,
        -7.09087644e-03,   0.00000000e+00,   1.54233189e-02,
         2.47564741e-02,   0.00000000e+00,  -1.10474868e-02,
         1.21568410e-01,   1.28959404e-02,  -4.44140177e-02,
         9.28128614e-03,   0.00000000e+00,  -7.17161058e-03,
         0.00000000e+00,  -8.88652878e-03,  -2.47589802e-02,
        -1.01069756e-02,  -2.39555816e-03,   0.00000000e+00,
        -2.83666562e-02,  -2.88716744e-02,   0.00000000e+00,
         3.15447007e-02,  -3.42032723e-02,  -6.66323082e-02,
        -3.33768876e-02,  -2.38522864e-02,   5.18836941e-03,
         0.00000000e+00,  -1.83915440e-02,   0.00000000e+00,
        -1.63764349e-03,  -1.50689744e-02,   1.49638130e-02,
        -2.60103309e-03,   0.00000000e+00,  -1.16706619e-03,
        -2.29604953e-02,   0.00000000e+00,   1.48191000e-02,
        -1.20750688e-03,   7.19618334e-02,   1.02054976e-01,
         1.31783632e-02,  -1.36196420e-01,  -1.50251994e-03,
         2.56210582e-02,   3.99100388e-02,   7.95669593e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.09050713e-02,  -3.28573498e-02,  -6.97382648e-02,
         3.90646022e-03,   0.00000000e+00,   5.66463409e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.11013717e-01,   0.00000000e+00,  -9.61607320e-02,
         1.19030819e-02,   1.10355667e-02,  -8.28142473e-02,
         0.00000000e+00,  -8.54600932e-02,   0.00000000e+00,
        -8.21885920e-02,  -2.43346146e-02,   3.71097840e-02,
        -4.67382924e-02,   0.00000000e+00,   1.19320220e-01,
         0.00000000e+00,  -1.57230784e-02,  -8.50357590e-02,
        -7.73281035e-03,   1.70592740e-02,   3.47182421e-02,
         0.00000000e+00,  -3.28825401e-02,   0.00000000e+00,
        -1.70710199e-03,   3.67603271e-02,   5.23259826e-02,
        -1.01991904e-02,   6.48839106e-03,   1.40063409e-02,
         0.00000000e+00,   8.19254573e-03,   0.00000000e+00,
         8.89896447e-03,  -6.29606337e-04,   2.91699009e-02,
         7.50406914e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.54077634e-02,   0.00000000e+00,
         4.61409933e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.10228322e-01,
         6.45117575e-03,  -3.74375644e-03,  -1.22469164e-02,
         0.00000000e+00,  -4.15009512e-02,   0.00000000e+00,
         4.45650678e-02,  -2.26152047e-02,   4.93199584e-03,
        -2.28482582e-02,   0.00000000e+00,   1.18352837e-01,
         5.59367959e-03,  -2.62764093e-03,   3.69683025e-02,
         0.00000000e+00,  -2.88609159e-02,   0.00000000e+00,
        -2.50126791e-02,  -1.47070746e-02,   3.39684741e-02,
         1.61175354e-02,   0.00000000e+00,   1.73725053e-02,
         1.01981826e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.37916903e-02,   0.00000000e+00,
         4.75683804e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.31459990e-02,
         0.00000000e+00,   0.00000000e+00,  -1.22870173e-01,
         9.90165490e-04,  -7.13327363e-03,   2.29806566e-02,
         0.00000000e+00,   1.64632053e-02,   0.00000000e+00,
         4.02569695e-02,  -3.76434044e-03,   3.95142538e-03,
        -1.69316470e-02,   0.00000000e+00,  -4.46511633e-02,
         4.41274165e-02,   0.00000000e+00,  -1.08448831e-01,
        -1.07869707e-02,  -3.71661407e-03,   4.05148495e-03,
         0.00000000e+00,  -1.18147686e-02,   0.00000000e+00,
        -3.37536235e-03,   6.57326473e-02,  -1.59946891e-02,
         8.58292846e-03,   0.00000000e+00,  -2.71975054e-02,
        -3.71574805e-02,   0.00000000e+00,   6.14147252e-04,
        -1.60748603e-01,  -2.18748089e-02,   4.76001467e-02,
        -1.16307074e-02,   0.00000000e+00,   1.40138383e-02,
         0.00000000e+00,  -1.88616790e-03,   3.38417471e-02,
         1.15454803e-02,   7.14095292e-03,   0.00000000e+00,
         1.63889104e-02,   2.86291227e-02,   0.00000000e+00,
        -1.77108056e-02,   5.60252991e-02,   8.79881056e-02,
         3.82267333e-02,   2.55040774e-02,  -7.06798771e-03,
         0.00000000e+00,   1.62647078e-02,   0.00000000e+00,
        -4.21403199e-03,   6.94451753e-03,  -1.25191715e-02,
         5.65685270e-03,   0.00000000e+00,   1.48773953e-02,
         1.94256936e-02,   0.00000000e+00,   1.38288012e-02,
         2.00389467e-02,  -7.78006262e-02,  -9.34139121e-02,
        -9.51276662e-03,   3.95304062e-02,  -1.63712951e-02,
        -7.18736771e-03,  -1.20955932e-02,  -3.17685067e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.93767952e-02,  -5.40864878e-03,   3.31074810e-02,
         3.00281968e-03,   0.00000000e+00,  -3.42853383e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.35975119e-02,   0.00000000e+00,   1.48926808e-02,
         3.79856252e-04,  -9.92472322e-03,   2.16107017e-02,
         0.00000000e+00,   2.51807427e-02,   0.00000000e+00,
         1.22300872e-02,   3.12158543e-03,  -3.05466733e-03,
         1.32909512e-02,   0.00000000e+00,  -3.28825401e-02,
         0.00000000e+00,   3.95622206e-03,   1.70485749e-02,
         5.92091987e-03,  -1.36946701e-02,  -1.61133811e-02,
         0.00000000e+00,   1.99602737e-02,   0.00000000e+00,
        -5.90914446e-04,  -2.71026511e-03,  -1.71061730e-02,
         3.77820166e-03,  -5.44273281e-03,  -8.48184365e-03,
         0.00000000e+00,   4.24948957e-03,   0.00000000e+00,
        -2.31102692e-03,   3.33261201e-03,  -9.59855405e-03,
        -1.67185358e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.03181254e-02,   0.00000000e+00,
        -1.58331844e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.29465095e-02,
         4.03414899e-03,  -7.47130158e-03,   4.03419100e-03,
         0.00000000e+00,   1.92476778e-02,   0.00000000e+00,
        -1.46649173e-02,   6.88966045e-03,  -4.71941032e-03,
         5.36490630e-03,   0.00000000e+00,  -4.43062473e-02,
         8.49816770e-04,  -5.34634702e-03,  -1.67935800e-02,
         0.00000000e+00,   1.27591069e-02,   0.00000000e+00,
         6.55088427e-03,   6.07370583e-03,  -1.61472876e-02,
        -7.08396165e-03,   0.00000000e+00,  -1.08723846e-02,
        -4.43095781e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.05555193e-03,   0.00000000e+00,
        -1.06027083e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.22000348e-02,
         0.00000000e+00,   0.00000000e+00,   2.47422567e-02,
        -1.12668763e-03,   4.12808057e-03,  -6.77924636e-03,
         0.00000000e+00,  -5.07425232e-03,   0.00000000e+00,
        -8.32091772e-03,   1.18478223e-03,  -8.66089438e-04,
         2.75643934e-03,   0.00000000e+00,   1.26624846e-02,
        -1.09970880e-02,   0.00000000e+00,   2.09642883e-02,
         1.69758786e-03,   1.36667996e-03,   5.08555110e-04,
         0.00000000e+00,   6.89439846e-04,   0.00000000e+00,
         7.25770044e-04,  -1.62293956e-02,   4.88368563e-03,
        -1.10178549e-03,   0.00000000e+00,   6.26096123e-03,
         1.08492696e-02,   0.00000000e+00,  -1.95515905e-04,
         3.48456145e-02,   9.78126803e-03,  -1.80228394e-02,
         2.70662819e-03,   0.00000000e+00,   5.41304161e-03,
         0.00000000e+00,  -2.63123182e-03,  -6.90781916e-03,
        -9.67344166e-03,  -2.34330748e-03,   0.00000000e+00,
        -1.73798977e-02,  -1.51354518e-02,   0.00000000e+00,
         5.02271215e-03,  -1.21957004e-02,  -3.61146923e-02,
        -1.09668212e-02,  -2.85858824e-03,   2.06918312e-03,
         0.00000000e+00,  -7.41011542e-03,   0.00000000e+00,
         3.30482276e-03,  -3.13823405e-03,   5.90328247e-03,
        -5.10427529e-04,   0.00000000e+00,  -3.03678013e-04,
        -2.22519840e-03,   0.00000000e+00,  -5.35910745e-03,
        -4.09716540e-03,   2.16592640e-02,   1.73755583e-02,
         1.55884997e-02,  -1.17901904e-02,   3.60596163e-03,
        -1.50368894e-03,   2.99574143e-03,   1.67859213e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.31347902e-02,  -1.98068212e-02,   7.53292892e-03,
         3.71959890e-03,   0.00000000e+00,   6.02589753e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.41353147e-03,   0.00000000e+00,  -1.66834128e-03,
         2.39080920e-03,  -1.01981449e-02,  -8.82710877e-03,
         0.00000000e+00,  -7.39306568e-03,   0.00000000e+00,
        -5.23517954e-04,  -8.49747459e-03,   1.01308754e-02,
        -2.37769242e-03,   0.00000000e+00,   8.19254573e-03,
         0.00000000e+00,  -2.23905670e-03,   2.93968152e-03,
         1.14123635e-03,  -2.76815442e-03,   3.03312325e-05,
         0.00000000e+00,   4.24948957e-03,   0.00000000e+00,
        -1.60895187e-03,   5.69987533e-03,   9.96176104e-03,
         1.81209711e-04,  -4.88394941e-03,  -4.09831592e-03,
         0.00000000e+00,   1.15406366e-02,   0.00000000e+00,
         4.26862277e-04,   6.72931641e-03,   8.09148588e-03,
         2.50004729e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.94922379e-03,   0.00000000e+00,
         6.76624280e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.29903138e-02,
        -1.25949431e-04,  -5.34003032e-04,  -3.89096480e-03,
         0.00000000e+00,  -8.30819428e-03,   0.00000000e+00,
         9.23076520e-03,  -8.31001462e-03,  -5.11913032e-03,
         1.75629844e-03,   0.00000000e+00,   1.40034029e-02,
         8.41129347e-04,  -2.14826233e-04,   5.45224657e-03,
         0.00000000e+00,  -6.39538135e-03,   0.00000000e+00,
        -3.18248470e-03,  -3.97714275e-03,   1.79278493e-03,
         5.55265536e-03,   0.00000000e+00,  -7.60405259e-03,
         4.22105828e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.65231233e-03,   0.00000000e+00,
         6.09445283e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.59894209e-03,
         0.00000000e+00,   0.00000000e+00,  -3.85473308e-03,
        -1.29027568e-03,   6.28421667e-05,   5.81914232e-03,
         0.00000000e+00,   4.19667308e-03,   0.00000000e+00,
         6.63543886e-03,  -1.39437350e-03,  -8.71983156e-05,
        -1.72060986e-03,   0.00000000e+00,  -2.02147425e-03,
         4.20053607e-03,   0.00000000e+00,  -3.46255703e-03,
        -4.98520945e-04,   1.32676573e-03,   3.24256334e-04,
         0.00000000e+00,  -3.95311342e-03,   0.00000000e+00,
        -1.66451562e-03,   8.83798638e-03,  -7.46383525e-04,
         1.30924796e-03,   0.00000000e+00,  -5.66958088e-03,
        -3.11354743e-03,   0.00000000e+00,   3.46374756e-04,
        -4.58983991e-03,  -2.38751874e-03,   7.21324868e-03,
        -2.94855422e-03,   0.00000000e+00,   8.45518432e-04,
         0.00000000e+00,   5.47030542e-04,   4.82406991e-03,
         3.73370730e-04,   1.94541678e-03,   0.00000000e+00,
        -1.64184314e-02,  -5.23720022e-03,   0.00000000e+00,
        -3.14228110e-03,   8.36625411e-03,   1.49600743e-02,
         5.72232680e-03,   6.09557490e-03,   3.23075307e-04,
         0.00000000e+00,  -1.61038981e-03,   0.00000000e+00,
        -7.17148882e-04,   8.30861448e-04,  -5.87660073e-04,
         1.70182225e-03,   0.00000000e+00,   3.00045031e-03,
         2.96222642e-03,   0.00000000e+00,  -5.38468004e-03,
         1.43902431e-03,  -8.72086807e-03,   5.45206594e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.34885413e-03,  -8.07029463e-04,   3.14748278e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.97449300e-03,   0.00000000e+00,
        -6.20050628e-03,  -7.54622827e-03,   1.11665463e-03,
         0.00000000e+00,   1.41660248e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.79822561e-03,   0.00000000e+00,  -2.45809194e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.74009386e-03,   0.00000000e+00,
         1.73898290e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.55997305e-03,   0.00000000e+00,  -1.19728267e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.77282810e-04,   0.00000000e+00,   8.05954970e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.76622938e-04,  -3.77610641e-03,
         2.90960456e-04,   0.00000000e+00,   1.41590577e-02,
         0.00000000e+00,  -5.13040468e-03,   5.00832070e-03,
        -2.05651332e-03,  -2.70555346e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.32796782e-02,   0.00000000e+00,  -6.32557289e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.34026157e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.57706485e-03,   0.00000000e+00,  -3.71716434e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.84442696e-03,   0.00000000e+00,
         0.00000000e+00,  -1.05753060e-04,   2.19240961e-03,
        -3.98237088e-04,   0.00000000e+00,  -4.11153792e-05,
         0.00000000e+00,   2.15748890e-03,  -2.06081794e-03,
        -1.61169981e-04,   7.47875066e-04,   0.00000000e+00,
         1.26433646e-03,   1.80958098e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.16359608e-04,   0.00000000e+00,   1.98994159e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.97607384e-04,   0.00000000e+00,
         0.00000000e+00,  -2.16697873e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.59839211e-03,   0.00000000e+00,  -1.41656658e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.96657932e-04,   0.00000000e+00,
         0.00000000e+00,   1.16279842e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.47697754e-03,   0.00000000e+00,
        -7.55243991e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.84316731e-03,
         0.00000000e+00,   0.00000000e+00,  -4.28820558e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.11790718e-04,   0.00000000e+00,   9.27901349e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.22644742e-04,   0.00000000e+00,
         0.00000000e+00,  -7.28835492e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.03463689e-02,   4.74578546e-02,  -7.85065218e-02,
        -2.03058665e-02,   1.02247618e-03,  -1.01848428e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.14757305e-01,   9.05213171e-03,   1.84005213e-02,
        -1.25079961e-03,   0.00000000e+00,  -1.14950418e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.66710730e-02,   0.00000000e+00,  -4.66918921e-02,
        -3.22226945e-03,  -1.16396731e-02,   3.14228273e-02,
         0.00000000e+00,   3.65231944e-02,   0.00000000e+00,
        -5.27788036e-02,   2.64579456e-02,  -1.51851162e-02,
         1.07057592e-02,   0.00000000e+00,  -4.15009512e-02,
         0.00000000e+00,   1.30355100e-02,  -5.60038532e-02,
         1.42601016e-02,  -2.57486908e-02,  -3.98063083e-02,
         0.00000000e+00,   1.92476778e-02,   0.00000000e+00,
         7.81268872e-03,   1.31870528e-02,  -3.40280711e-02,
         7.67545115e-03,  -1.14539602e-02,  -2.84810106e-02,
         0.00000000e+00,  -8.30819428e-03,   0.00000000e+00,
         1.67895444e-02,  -8.45505862e-03,  -2.42103486e-02,
        -2.84676878e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.52954110e-02,   0.00000000e+00,
        -4.28420438e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.12928357e-01,
        -1.37037920e-03,  -2.15669054e-02,   3.87502724e-02,
         0.00000000e+00,   9.53340094e-02,   0.00000000e+00,
        -5.18207584e-02,   3.95074254e-02,  -2.03192253e-03,
         1.98706955e-02,   0.00000000e+00,  -1.17318784e-01,
        -4.85017162e-03,  -1.76380789e-02,  -6.15940177e-02,
         0.00000000e+00,   3.67889905e-02,   0.00000000e+00,
         7.79377461e-03,   2.76679419e-02,  -4.11417641e-02,
        -2.57248472e-02,   0.00000000e+00,  -2.80948745e-03,
        -1.07183626e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.32007808e-03,   0.00000000e+00,
         1.21459152e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.30549431e-02,
         0.00000000e+00,   0.00000000e+00,  -2.32387843e-02,
        -8.46564190e-03,   6.84353831e-03,  -1.48280957e-02,
         0.00000000e+00,  -4.43636051e-03,   0.00000000e+00,
         1.86421994e-02,   5.16398377e-04,  -3.91598176e-03,
        -6.99256473e-03,   0.00000000e+00,   1.53377519e-02,
        -1.26321951e-02,   0.00000000e+00,  -2.75297936e-02,
         1.36936025e-02,  -7.42773528e-03,   6.86307954e-03,
         0.00000000e+00,  -1.67982002e-02,   0.00000000e+00,
         1.50412342e-03,  -1.08144502e-02,   1.08304169e-03,
        -1.22334634e-03,   0.00000000e+00,   1.26382422e-02,
         1.63913254e-02,   0.00000000e+00,   2.87424350e-03,
        -3.34007267e-02,   5.69762716e-02,  -5.63614266e-02,
         1.15176909e-02,   0.00000000e+00,   1.06577850e-02,
         0.00000000e+00,  -6.73830067e-03,  -2.24272638e-02,
        -2.43257749e-02,  -1.42148367e-02,   0.00000000e+00,
        -9.43464863e-03,   2.24317273e-03,   0.00000000e+00,
         8.02561712e-03,  -1.63702551e-02,  -1.07667139e-01,
        -1.16283197e-02,   1.93364957e-02,  -6.32136854e-03,
         0.00000000e+00,  -1.11559989e-03,   0.00000000e+00,
         1.20405627e-03,   9.37315880e-03,   5.04601909e-03,
         2.73561909e-03,   0.00000000e+00,   4.65826444e-03,
        -3.93373835e-04,   0.00000000e+00,  -9.37536525e-03,
         2.20977628e-03,   2.62707480e-02,  -3.34270306e-02,
        -2.85884312e-02,   3.60835913e-02,  -1.62143568e-02,
        -1.18931914e-02,  -9.47735384e-04,  -4.36039716e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.70566641e-02,   2.26617164e-02,   1.08292918e-02,
         7.78174504e-03,   0.00000000e+00,  -3.75431355e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.28566137e-02,   0.00000000e+00,   6.91104023e-03,
         3.29314211e-03,   6.55816642e-03,   1.92274398e-02,
         0.00000000e+00,   2.50533068e-02,   0.00000000e+00,
         7.86265297e-03,   2.00405884e-02,  -1.24939292e-02,
         1.37691713e-02,   0.00000000e+00,  -2.88609159e-02,
         0.00000000e+00,   6.79019318e-03,  -5.02918722e-03,
         3.41044012e-03,  -1.23178386e-02,  -2.32677241e-02,
         0.00000000e+00,   1.27591069e-02,   0.00000000e+00,
         3.45456446e-03,   2.63612632e-03,  -1.31864548e-02,
         4.76259463e-03,  -5.97531635e-03,  -1.47706813e-02,
         0.00000000e+00,  -6.39538135e-03,   0.00000000e+00,
         4.01573566e-03,  -2.31393660e-03,  -1.16334053e-02,
        -7.39473996e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.78231941e-02,   0.00000000e+00,
        -2.55850957e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.04103678e-02,
        -8.90933019e-04,  -7.57365623e-03,   1.53859759e-03,
         0.00000000e+00,   3.67889905e-02,   0.00000000e+00,
        -2.21798869e-02,   2.02427964e-02,  -2.31731316e-03,
         3.32306510e-03,   0.00000000e+00,  -4.61515112e-02,
         1.80376919e-05,  -9.09712950e-03,  -3.29687496e-02,
         0.00000000e+00,   3.67783255e-02,   0.00000000e+00,
         7.66678344e-03,   1.96980758e-02,  -2.12671780e-02,
        -1.55895794e-02,   0.00000000e+00,  -2.10945074e-03,
        -5.11962975e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.41029014e-02,   0.00000000e+00,
        -1.50407066e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.13739938e-02,
         0.00000000e+00,   0.00000000e+00,   1.83158166e-02,
        -4.84047897e-03,  -1.28493760e-03,  -1.25533386e-02,
         0.00000000e+00,  -8.67499840e-03,   0.00000000e+00,
        -1.66850588e-02,   2.62976860e-03,  -8.63112102e-04,
        -2.73303528e-04,   0.00000000e+00,   1.10402364e-02,
        -1.56660499e-02,   0.00000000e+00,   1.48228423e-02,
         7.37214682e-03,   1.32415368e-03,   1.52033233e-03,
         0.00000000e+00,   3.64894816e-03,   0.00000000e+00,
         3.13400522e-03,  -2.66320895e-02,   6.52696175e-03,
        -1.20115146e-03,   0.00000000e+00,   1.00844208e-02,
         1.36809652e-02,   0.00000000e+00,   1.70694230e-05,
         1.48669220e-02,   2.13326743e-02,  -3.45139340e-02,
         4.05501689e-03,   0.00000000e+00,  -5.03349713e-04,
         0.00000000e+00,  -5.08959699e-03,  -1.15611192e-02,
        -1.20432964e-02,  -8.01609750e-03,   0.00000000e+00,
         6.40259279e-03,   3.74596735e-03,   0.00000000e+00,
         1.07153086e-02,  -1.44246929e-02,  -4.52466826e-02,
        -1.82826787e-02,  -6.46513395e-03,  -9.69171314e-04,
         0.00000000e+00,  -3.09801257e-03,   0.00000000e+00,
        -3.23023265e-03,   2.05210849e-03,   5.28722526e-03,
         1.65724060e-03,   0.00000000e+00,   3.28592394e-04,
        -7.14542575e-03,   0.00000000e+00,   4.05502341e-03,
        -9.03790052e-04,   2.50030398e-02,   9.40492891e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.26981352e-03,   9.56351924e-04,  -1.48390086e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.75500404e-04,   0.00000000e+00,
        -4.95369240e-03,  -1.04355851e-02,   1.73885510e-03,
         0.00000000e+00,  -4.54348935e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.06028379e-04,   0.00000000e+00,  -3.01690789e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.99036878e-03,   0.00000000e+00,
        -3.56309092e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.78712927e-05,   0.00000000e+00,   3.43564232e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.20623441e-03,   0.00000000e+00,  -2.98117637e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.32055980e-04,   2.57401352e-03,
        -1.81992724e-04,   0.00000000e+00,  -4.11153792e-05,
         0.00000000e+00,   1.89768245e-03,  -3.00259482e-03,
        -1.16861410e-03,   1.34557897e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.00215724e-03,   0.00000000e+00,   6.67808949e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.05310708e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.34948009e-03,   0.00000000e+00,  -3.03585104e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.75084524e-03,   0.00000000e+00,
         0.00000000e+00,   6.11492588e-03,   8.37812560e-03,
        -1.34812590e-03,   0.00000000e+00,   9.64663717e-03,
         0.00000000e+00,   5.29977826e-03,  -5.21032512e-03,
         1.00759845e-03,  -6.06103260e-04,   0.00000000e+00,
         1.09721425e-03,   2.75429204e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.67030504e-03,   0.00000000e+00,   5.79294722e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.06229554e-05,   0.00000000e+00,
         0.00000000e+00,  -2.07089341e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.19274895e-03,   0.00000000e+00,  -1.01598015e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.94459915e-04,   0.00000000e+00,
         0.00000000e+00,   2.79296047e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.24117651e-04,   0.00000000e+00,
         6.23821790e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.85822776e-03,
         0.00000000e+00,   0.00000000e+00,  -2.84544945e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.79093640e-03,   0.00000000e+00,   8.58787990e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.05355321e-04,   0.00000000e+00,
         0.00000000e+00,  -8.87133780e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.47166851e-02,  -2.90875993e-02,  -2.46886304e-02,
        -2.42890237e-03,   7.99703842e-03,  -9.02966345e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.13984681e-03,  -5.02971329e-03,  -1.60842390e-02,
         2.04106190e-04,   0.00000000e+00,  -1.45966714e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.27226945e-02,   0.00000000e+00,  -4.70958258e-02,
        -3.72424588e-03,  -5.28824816e-03,  -1.76077084e-02,
         0.00000000e+00,  -2.15124998e-02,   0.00000000e+00,
        -4.95296309e-02,  -9.35976401e-03,  -4.13623168e-03,
        -6.53273890e-03,   0.00000000e+00,   1.64632053e-02,
         0.00000000e+00,  -3.48060593e-03,  -4.18913055e-02,
         1.87673889e-03,   5.67253809e-03,   8.95675105e-04,
         0.00000000e+00,  -5.07425232e-03,   0.00000000e+00,
         2.05061635e-03,   1.27875573e-02,  -7.97299230e-05,
        -2.79122722e-03,   2.54751128e-04,   1.73284519e-03,
         0.00000000e+00,   4.19667308e-03,   0.00000000e+00,
         6.99495629e-03,  -2.77949029e-03,   1.37690524e-03,
         1.99324334e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.40294199e-03,   0.00000000e+00,
         1.18811508e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.88770503e-04,
        -4.84551651e-03,   2.32625252e-03,  -1.55092173e-03,
         0.00000000e+00,  -4.43636051e-03,   0.00000000e+00,
         1.58344224e-02,  -1.89005849e-03,  -7.75264778e-04,
        -2.40568122e-03,   0.00000000e+00,   1.52628627e-03,
        -5.16796250e-03,  -5.39291290e-03,   7.95356396e-04,
         0.00000000e+00,  -8.67499840e-03,   0.00000000e+00,
        -1.51700842e-02,   3.05491050e-03,   3.24576396e-03,
         3.96393933e-03,   0.00000000e+00,   4.17098232e-03,
        -5.98076713e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.73826874e-02,   0.00000000e+00,
         3.93438464e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.09861197e-02,
         0.00000000e+00,   0.00000000e+00,  -5.12810871e-02,
         4.90062274e-03,   5.61623378e-03,   1.59577703e-02,
         0.00000000e+00,   2.46025288e-02,   0.00000000e+00,
         4.57566172e-02,  -3.03188743e-03,   8.09458059e-04,
        -6.91919457e-03,   0.00000000e+00,  -1.06050379e-02,
         1.25445309e-02,   0.00000000e+00,  -5.18561496e-02,
         6.91814836e-04,  -6.00401704e-03,   4.69560341e-03,
         0.00000000e+00,  -1.90545685e-02,   0.00000000e+00,
        -7.23861536e-03,   3.72969908e-02,  -9.96828764e-03,
         3.35885127e-03,   0.00000000e+00,  -3.43211744e-03,
        -4.90558637e-03,   0.00000000e+00,   1.02845599e-03,
        -5.63243340e-02,   9.12701680e-03,   1.67626619e-02,
        -1.66105710e-03,   0.00000000e+00,   3.88344386e-03,
         0.00000000e+00,   9.91744846e-03,   1.41679594e-04,
         4.97143695e-04,   2.47523028e-04,   0.00000000e+00,
         1.26452163e-03,   1.12529785e-02,   0.00000000e+00,
        -5.40491307e-03,   5.54612105e-03,  -4.42714033e-03,
         2.61970709e-02,   2.65921899e-02,  -2.09034835e-03,
         0.00000000e+00,   1.26472239e-02,   0.00000000e+00,
         6.22209906e-03,   1.16733286e-02,  -5.60604682e-03,
         1.50283271e-03,   0.00000000e+00,   1.74818103e-03,
         5.73839566e-03,   0.00000000e+00,  -4.50058132e-03,
        -3.03317185e-03,  -1.99422986e-02,  -4.86594297e-02,
         4.49538916e-02,   1.72678714e-02,   5.61021119e-02,
        -4.99036870e-03,  -6.09692527e-03,   3.45773823e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.72469966e-02,   1.05480702e-02,   1.19275422e-02,
        -2.88152703e-03,   0.00000000e+00,   5.10054060e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.34778755e-02,   0.00000000e+00,   6.83051549e-02,
         7.38640331e-04,   1.59395230e-03,   1.15295285e-02,
         0.00000000e+00,   1.08264616e-02,   0.00000000e+00,
         6.54637815e-02,  -2.60704618e-03,  -4.01427087e-03,
         7.58668332e-03,   0.00000000e+00,  -1.18147686e-02,
         0.00000000e+00,  -2.23217823e-03,   6.66758784e-02,
        -6.25598177e-03,   5.57211839e-03,   5.36808544e-03,
         0.00000000e+00,   6.89439846e-04,   0.00000000e+00,
        -1.83822150e-03,  -1.54178249e-02,   1.65301741e-02,
        -5.34955193e-05,   3.80156387e-03,   1.45427995e-03,
         0.00000000e+00,  -3.95311342e-03,   0.00000000e+00,
        -9.34361299e-03,   5.39147606e-03,   5.35279040e-03,
         1.59188358e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.20583957e-02,   0.00000000e+00,
        -3.86624790e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.04306933e-02,
         8.72141516e-03,   4.57980304e-03,  -1.09722959e-02,
         0.00000000e+00,  -1.67982002e-02,   0.00000000e+00,
        -3.67889960e-03,  -1.00699352e-02,   1.68784937e-03,
        -3.68161990e-03,   0.00000000e+00,   3.27869881e-02,
         7.99621554e-03,   1.00685800e-02,   1.39639914e-02,
         0.00000000e+00,   3.64894816e-03,   0.00000000e+00,
         1.10129054e-02,  -1.10769246e-02,   1.04273676e-02,
         2.01432668e-03,   0.00000000e+00,   1.80849492e-03,
         3.48451554e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.10029549e-02,   0.00000000e+00,
        -5.41035201e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.70286178e-03,
         0.00000000e+00,   0.00000000e+00,   6.56752828e-02,
         2.76858608e-03,  -1.43331124e-03,  -1.32080877e-02,
         0.00000000e+00,  -1.90545685e-02,   0.00000000e+00,
        -5.01886477e-02,   2.50448536e-03,   3.66848073e-04,
         8.17255632e-03,   0.00000000e+00,   8.70401212e-03,
        -1.00880792e-02,   0.00000000e+00,   6.18129870e-02,
         3.52762302e-03,   2.28120306e-02,  -1.62608104e-02,
         0.00000000e+00,   4.07387083e-02,   0.00000000e+00,
         2.08371804e-03,  -6.12317120e-02,   1.62195850e-02,
        -3.21436720e-03,   0.00000000e+00,   1.14574467e-03,
         4.24775458e-03,   0.00000000e+00,  -1.93495533e-03,
         8.39857763e-02,  -2.70417144e-02,  -6.85995978e-03,
         2.30583106e-03,   0.00000000e+00,  -7.17717274e-03,
         0.00000000e+00,  -5.49427092e-03,   1.38143578e-02,
         4.22153770e-03,   3.60288575e-03,   0.00000000e+00,
         1.39399880e-03,  -2.06758745e-03,   0.00000000e+00,
         2.97859915e-03,  -7.19625610e-03,   3.61124836e-02,
        -2.76467847e-02,  -3.83912843e-02,   8.77698485e-03,
         0.00000000e+00,  -1.35903918e-02,   0.00000000e+00,
         6.33102908e-04,  -3.88906967e-03,   2.12527777e-03,
        -2.96296000e-03,   0.00000000e+00,  -3.50612127e-03,
        -6.66819940e-03,   0.00000000e+00,   6.81297962e-04,
        -9.21483877e-03,   1.52277773e-02,   6.42474202e-02,
        -2.43194546e-02,  -1.38536078e-02,  -3.11945241e-02,
         4.33780451e-03,   7.06418301e-04,  -1.64576479e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.93264668e-02,  -1.27529713e-02,   6.61978252e-03,
        -6.12144326e-03,   0.00000000e+00,  -2.51648766e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.11318613e-02,   0.00000000e+00,  -3.80443425e-02,
         2.66404124e-03,  -6.82112780e-03,  -6.26952537e-03,
         0.00000000e+00,  -7.17161058e-03,   0.00000000e+00,
        -3.80263132e-02,  -1.49716988e-02,   2.01016111e-03,
        -7.26813232e-03,   0.00000000e+00,   1.40138383e-02,
         0.00000000e+00,  -3.19483433e-03,  -2.42480243e-02,
         5.64905429e-03,  -3.36716488e-03,   5.82325411e-04,
         0.00000000e+00,   5.41304161e-03,   0.00000000e+00,
        -1.24078185e-03,   8.55591911e-03,  -1.29781661e-02,
        -1.24192049e-03,   1.51126703e-03,  -4.65091873e-04,
         0.00000000e+00,   8.45518432e-04,   0.00000000e+00,
         2.65319862e-03,  -9.19525005e-04,  -2.34844262e-03,
        -9.27039219e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.44803064e-03,   0.00000000e+00,
         6.97763159e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.29972217e-02,
         2.01262763e-02,  -2.17475960e-02,   7.36741356e-03,
         0.00000000e+00,   1.06577850e-02,   0.00000000e+00,
        -3.71950892e-03,   2.53752913e-03,  -3.01509814e-03,
        -8.04529357e-03,   0.00000000e+00,  -1.62147070e-02,
         6.43316669e-03,  -1.50672728e-02,  -3.08047957e-03,
         0.00000000e+00,  -5.03349713e-04,   0.00000000e+00,
        -6.20613117e-03,   2.59611105e-03,  -4.77412004e-03,
        -4.81507069e-03,   0.00000000e+00,   5.09610055e-03,
        -7.10022726e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.40826319e-03,   0.00000000e+00,
         2.15607325e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.68148399e-03,
         0.00000000e+00,   0.00000000e+00,  -3.72480807e-02,
         4.29619911e-03,   7.00226453e-03,   3.48738684e-03,
         0.00000000e+00,   3.88344386e-03,   0.00000000e+00,
         2.25566944e-02,  -8.75727909e-05,   3.64939101e-04,
        -4.76524122e-03,   0.00000000e+00,  -5.26521112e-03,
         9.69976973e-03,   0.00000000e+00,  -3.44270647e-02,
        -1.06244676e-02,  -6.12727612e-03,   4.79233253e-03,
         0.00000000e+00,  -7.17717274e-03,   0.00000000e+00,
        -1.99816735e-03,   2.58968481e-02,  -5.82808947e-03,
         3.74155058e-03,   0.00000000e+00,  -1.05522319e-04,
        -2.15817247e-03,   0.00000000e+00,   3.19621529e-04,
        -3.69474036e-02,   7.13335512e-04,   1.68471924e-03,
        -1.06499526e-03,   0.00000000e+00,   3.65058654e-02,
         0.00000000e+00,  -6.54929814e-03,   1.01640328e-02,
        -6.42927618e-03,   9.52908031e-04,   0.00000000e+00,
        -1.00651241e-02,  -5.09332885e-03,   0.00000000e+00,
        -1.46767228e-03,   3.40446739e-03,  -1.68350188e-02,
         1.10610267e-02,   1.30502975e-02,  -1.91350667e-03,
         0.00000000e+00,   1.30716302e-03,   0.00000000e+00,
         1.02275240e-02,  -4.71281595e-03,   1.45777497e-03,
        -1.45761147e-04,   0.00000000e+00,   7.24231456e-03,
         9.55263849e-03,   0.00000000e+00,  -3.88024598e-04,
        -2.58081525e-03,  -8.26190483e-03,  -3.91096626e-02,
        -2.80897453e-02,  -2.60579431e-02,  -1.88498231e-02,
        -4.31014203e-03,   1.09737720e-02,  -8.27805484e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.29356941e-03,   7.03668517e-03,  -2.70857854e-02,
         4.92137674e-03,   0.00000000e+00,  -1.55498468e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.08114811e-02,   0.00000000e+00,  -4.23246923e-02,
        -5.77719393e-03,  -8.14777761e-04,  -1.68857531e-02,
         0.00000000e+00,  -1.83915440e-02,   0.00000000e+00,
        -3.81412982e-02,   4.59791987e-03,  -2.03039877e-04,
        -7.45989337e-03,   0.00000000e+00,   1.62647078e-02,
         0.00000000e+00,  -4.67165722e-03,  -3.95844362e-02,
        -1.66571592e-03,   3.67233697e-03,   2.67283928e-04,
         0.00000000e+00,  -7.41011542e-03,   0.00000000e+00,
         4.51315602e-03,   1.05329195e-02,   3.73985872e-03,
         1.49508859e-03,   1.33232886e-04,  -2.82564386e-03,
         0.00000000e+00,  -1.61038981e-03,   0.00000000e+00,
         6.28225420e-03,  -1.96281151e-03,   3.08659791e-03,
         8.62534959e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.43201711e-03,   0.00000000e+00,
         6.75299833e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.81477894e-04,
        -4.36385015e-03,   4.96953761e-03,  -1.11976015e-03,
         0.00000000e+00,  -1.11559989e-03,   0.00000000e+00,
         6.89223125e-03,   6.01827707e-03,   2.23968022e-03,
        -1.67226078e-03,   0.00000000e+00,   3.94519968e-03,
        -7.87727873e-03,  -3.62857910e-03,  -1.55544578e-03,
         0.00000000e+00,  -3.09801257e-03,   0.00000000e+00,
        -9.13171588e-03,   6.01912071e-03,   2.64265969e-03,
         2.07590778e-03,   0.00000000e+00,   4.88533358e-03,
        -4.17029559e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.64653511e-03,   0.00000000e+00,
         2.76573336e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.05336483e-02,
         0.00000000e+00,   0.00000000e+00,  -4.40500328e-02,
         9.14200088e-03,   8.73032152e-03,   5.88717457e-03,
         0.00000000e+00,   1.26472239e-02,   0.00000000e+00,
         2.38226540e-02,   4.13929587e-03,  -1.43371749e-03,
        -6.70570207e-03,   0.00000000e+00,  -1.09573570e-02,
         9.54876394e-03,   0.00000000e+00,  -3.99312336e-02,
        -9.27657506e-03,  -1.51275898e-02,   6.86656378e-03,
         0.00000000e+00,  -1.35903918e-02,   0.00000000e+00,
        -1.49284477e-04,   2.41755189e-02,  -6.77362765e-03,
         2.02478503e-03,   0.00000000e+00,  -9.00794699e-04,
        -3.35604373e-03,   0.00000000e+00,  -8.10486950e-04,
        -5.32038335e-02,   7.66687416e-03,   1.01844129e-02,
         1.38257309e-04,   0.00000000e+00,   1.30716302e-03,
         0.00000000e+00,   9.59030004e-03,  -8.32732603e-03,
         2.49865154e-03,  -9.46762089e-04,   0.00000000e+00,
         1.32291696e-02,   1.70030264e-02,   0.00000000e+00,
        -4.76147064e-03,   5.13626181e-03,  -6.67692345e-03,
         9.86880543e-03,   1.49616406e-02,  -1.63889321e-03,
         0.00000000e+00,   2.14294028e-02,   0.00000000e+00,
         1.15717032e-02,  -2.91034751e-03,  -1.43103996e-03,
         7.61788001e-04,   0.00000000e+00,   4.42777036e-04,
         4.29436443e-03,   0.00000000e+00,  -3.44908488e-03,
         9.04992882e-03,  -1.66100774e-02,  -3.96635763e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.29141757e-03,   5.33702431e-02,  -1.06487948e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.79314951e-03,   0.00000000e+00,
         7.32494870e-02,   5.56344985e-02,  -1.13738691e-02,
         0.00000000e+00,   2.37435923e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.25972353e-03,   0.00000000e+00,  -4.12121333e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.49363285e-02,   0.00000000e+00,
         5.98142461e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.28593496e-03,   0.00000000e+00,  -8.05446186e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.81982907e-03,   0.00000000e+00,  -9.22678567e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.40920476e-03,  -1.51841843e-02,
         6.77826846e-03,   0.00000000e+00,  -6.20050628e-03,
         0.00000000e+00,  -7.37944227e-05,  -4.42817619e-03,
        -4.31996159e-03,  -1.59309262e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.28909823e-03,   0.00000000e+00,   4.32390182e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.41181769e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.95344460e-04,   0.00000000e+00,   8.32826272e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.69016063e-03,   0.00000000e+00,
         0.00000000e+00,  -1.35326939e-02,  -1.68835143e-02,
         3.45897736e-03,   0.00000000e+00,  -4.95369240e-03,
         0.00000000e+00,   6.24445577e-04,  -7.41167780e-03,
         6.50682676e-03,  -4.20484057e-03,   0.00000000e+00,
        -6.21793467e-03,  -1.00445545e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.16750591e-03,   0.00000000e+00,   2.75627509e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.08153515e-03,   0.00000000e+00,
         0.00000000e+00,  -3.13803646e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.90943805e-03,   0.00000000e+00,   4.19447026e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.32231201e-03,   0.00000000e+00,
         0.00000000e+00,  -1.05989599e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.92165274e-03,   0.00000000e+00,
        -1.79686572e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.70396764e-02,
         0.00000000e+00,   0.00000000e+00,   3.35728598e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.81060207e-03,   0.00000000e+00,  -1.41108904e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.18794152e-02,   0.00000000e+00,
         0.00000000e+00,   7.15295248e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.01235441e-02,   4.38177532e-04,   2.40236305e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.38514683e-02,   0.00000000e+00,
         5.56344985e-02,   9.58261100e-02,  -2.04900369e-02,
         0.00000000e+00,   2.34295766e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.96136681e-03,   0.00000000e+00,  -1.27892618e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.73422332e-03,   0.00000000e+00,
         1.17466032e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.08481491e-03,   0.00000000e+00,  -1.83043488e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.01919028e-02,   0.00000000e+00,   7.12821152e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.58666148e-03,  -1.65565359e-03,
         1.52749057e-03,   0.00000000e+00,  -7.54622827e-03,
         0.00000000e+00,   1.88667160e-03,   9.68796471e-03,
         1.22008718e-02,  -4.20344309e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.51185562e-03,   0.00000000e+00,   8.56807249e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.79995425e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.06172057e-04,   0.00000000e+00,   8.01058165e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.67245883e-03,   0.00000000e+00,
         0.00000000e+00,  -1.25652281e-02,  -1.62228729e-02,
         5.96823650e-03,   0.00000000e+00,  -1.04355851e-02,
         0.00000000e+00,   1.51720943e-03,  -8.84836811e-03,
         4.84502001e-03,  -2.93876923e-03,   0.00000000e+00,
        -1.07647424e-02,  -1.42891717e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.09699736e-03,   0.00000000e+00,  -1.39007933e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.98124881e-03,   0.00000000e+00,
         0.00000000e+00,  -2.31636488e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.30378832e-03,   0.00000000e+00,   8.48663520e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.63039452e-03,   0.00000000e+00,
         0.00000000e+00,  -1.69212124e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.92545676e-03,   0.00000000e+00,
        -1.07446711e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.88387242e-02,
         0.00000000e+00,   0.00000000e+00,   2.75188156e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.17564103e-03,   0.00000000e+00,  -1.15779028e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.03536500e-04,   0.00000000e+00,
         0.00000000e+00,   8.94677298e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.52860391e-02,  -1.72438422e-03,  -1.02995214e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.49912214e-03,   0.00000000e+00,
        -1.13738691e-02,  -2.04900369e-02,   1.58790138e-02,
         0.00000000e+00,  -3.55292973e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.10157327e-02,   0.00000000e+00,   9.19255226e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.85559763e-03,   0.00000000e+00,
         2.64057699e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.93580993e-03,   0.00000000e+00,   1.05865507e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.18717427e-03,   0.00000000e+00,  -2.13176592e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.62724485e-03,   2.37788412e-04,
         3.22959890e-03,   0.00000000e+00,   1.11665463e-03,
         0.00000000e+00,  -3.26186709e-03,  -3.16594137e-03,
         1.36816377e-03,   3.18069925e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.10515977e-03,   0.00000000e+00,  -4.18515259e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.78112937e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.41513736e-03,   0.00000000e+00,   1.34706081e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.00621784e-02,   0.00000000e+00,
         0.00000000e+00,   2.19644145e-03,   3.86366354e-03,
        -2.47048591e-03,   0.00000000e+00,   1.73885510e-03,
         0.00000000e+00,  -3.72549352e-03,   2.89965805e-04,
        -1.10654219e-03,   1.38517698e-03,   0.00000000e+00,
         5.49132868e-03,  -5.97384254e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.96707510e-03,   0.00000000e+00,  -3.07847984e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.93446668e-03,   0.00000000e+00,
         0.00000000e+00,   9.81538552e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.22367239e-05,   0.00000000e+00,  -4.31931793e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.42640470e-03,   0.00000000e+00,
         0.00000000e+00,   9.27820748e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.26035633e-03,   0.00000000e+00,
         1.30430914e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.89313882e-03,
         0.00000000e+00,   0.00000000e+00,  -5.79022204e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.85783480e-03,   0.00000000e+00,   2.72190724e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.88810255e-04,   0.00000000e+00,
         0.00000000e+00,  -1.89409182e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.16762315e-03,   1.74985722e-01,   7.38145887e-03,
        -2.80074514e-02,  -3.77852958e-02,  -9.41025878e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.27305567e-01,   2.15590394e-02,   8.22032357e-02,
        -5.52344523e-03,   0.00000000e+00,  -5.69144395e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.67855360e-01,   0.00000000e+00,   1.51088562e-01,
        -2.34233548e-03,  -1.25897406e-02,   1.09184928e-01,
         0.00000000e+00,   1.00132955e-01,   0.00000000e+00,
         1.14295382e-01,   4.93519128e-02,  -1.62540899e-02,
         5.10973723e-02,   0.00000000e+00,  -1.11013717e-01,
         0.00000000e+00,   2.50679374e-02,   9.83630987e-02,
         3.39370272e-03,  -2.93343692e-02,  -4.29694062e-02,
         0.00000000e+00,   3.35975119e-02,   0.00000000e+00,
         6.61125503e-04,  -4.08451338e-02,  -5.74658820e-02,
         1.27103224e-02,  -7.59042583e-03,  -2.08066754e-02,
         0.00000000e+00,  -7.41353147e-03,   0.00000000e+00,
        -9.77175262e-03,   1.87975639e-03,  -3.40796069e-02,
        -8.06369211e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.49203576e-02,   0.00000000e+00,
        -6.56715191e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.52939840e-01,
         2.98485207e-03,  -5.46379802e-04,   1.74162434e-02,
         0.00000000e+00,   4.66710730e-02,   0.00000000e+00,
        -5.37155576e-02,   1.87601571e-02,  -4.59706995e-03,
         2.55922972e-02,   0.00000000e+00,  -1.29090059e-01,
         4.36608410e-04,   2.22313271e-03,  -4.45012805e-02,
         0.00000000e+00,   3.28566137e-02,   0.00000000e+00,
         3.29064042e-02,   1.44424573e-02,  -4.06411114e-02,
        -2.20026309e-02,   0.00000000e+00,  -1.12749291e-02,
        -1.13537455e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.43035047e-02,   0.00000000e+00,
        -7.56782881e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.53161247e-02,
         0.00000000e+00,   0.00000000e+00,   1.86653954e-01,
        -3.67616403e-03,   7.61095098e-03,  -2.96575756e-02,
         0.00000000e+00,  -2.27226945e-02,   0.00000000e+00,
        -5.78586842e-02,   1.55092835e-04,  -2.49957071e-03,
         2.13677788e-02,   0.00000000e+00,   5.91301410e-02,
        -5.76358843e-02,   0.00000000e+00,   1.42762095e-01,
         1.11094493e-02,  -1.30047946e-03,  -3.46810117e-03,
         0.00000000e+00,   1.34778755e-02,   0.00000000e+00,
        -1.27259645e-03,  -8.05088524e-02,   2.09557189e-02,
        -9.08301489e-03,   0.00000000e+00,   2.46768279e-02,
         3.26382903e-02,   0.00000000e+00,   7.65579390e-03,
         1.70502989e-01,   1.99658445e-02,  -6.26354747e-02,
         1.45374889e-02,   0.00000000e+00,  -1.11318613e-02,
         0.00000000e+00,  -4.03568401e-03,  -3.60260870e-02,
        -1.56572778e-02,  -7.05935841e-03,   0.00000000e+00,
        -2.78932802e-02,  -3.51931197e-02,   0.00000000e+00,
         2.40997464e-02,  -4.85747095e-02,  -1.05323077e-01,
        -4.39153921e-02,  -3.58641078e-02,   1.00477404e-02,
         0.00000000e+00,  -2.08114811e-02,   0.00000000e+00,
         3.40727318e-03,  -1.96377912e-02,   2.00311560e-02,
        -9.05219352e-03,   0.00000000e+00,  -1.20049702e-02,
        -2.45634985e-02,   0.00000000e+00,  -1.16860279e-02,
        -2.42473636e-03,   1.02454621e-01,   1.39426299e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.55854803e-03,   1.85069084e-02,  -2.83116595e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.03997834e-03,   0.00000000e+00,
         2.37435923e-02,   2.34295766e-02,  -3.55292973e-03,
         0.00000000e+00,   2.48054985e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.72784878e-03,   0.00000000e+00,   7.28384472e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.62731436e-03,   0.00000000e+00,
        -7.91976291e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.23365869e-03,   0.00000000e+00,  -3.26647409e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.62874022e-04,   0.00000000e+00,  -1.36911733e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.53656619e-03,  -4.66020260e-03,
         1.32971594e-03,   0.00000000e+00,   1.41660248e-03,
         0.00000000e+00,  -2.89027657e-03,   3.25852374e-03,
        -2.47405649e-03,   1.62365949e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.00683952e-03,   0.00000000e+00,  -1.23900738e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.04174535e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.85638966e-03,   0.00000000e+00,   3.79264423e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.27879269e-03,   0.00000000e+00,
         0.00000000e+00,  -3.87437812e-03,  -6.94176139e-03,
         1.23243934e-03,   0.00000000e+00,  -4.54348935e-03,
         0.00000000e+00,  -3.07228052e-03,   5.42025903e-04,
         1.21610475e-03,  -2.28942108e-04,   0.00000000e+00,
         7.96582340e-04,  -6.15494692e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.47716461e-03,   0.00000000e+00,  -2.35147629e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.00417255e-03,   0.00000000e+00,
         0.00000000e+00,   8.81138523e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.44518054e-03,   0.00000000e+00,   6.22432751e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.30714095e-03,   0.00000000e+00,
         0.00000000e+00,  -1.75730246e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.56779576e-03,   0.00000000e+00,
        -5.11122286e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.38347870e-03,
         0.00000000e+00,   0.00000000e+00,   1.45738557e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.15677101e-03,   0.00000000e+00,  -5.50979498e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.89219249e-03,   0.00000000e+00,
         0.00000000e+00,   2.59986109e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.14895487e-01,   1.72632304e-01,   6.04004264e-01,
        -6.68700866e-03,  -5.75241382e-02,   4.72842983e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.11922900e-01,   3.05223935e-03,   8.94995975e-02,
        -9.43080549e-03,   0.00000000e+00,   5.32623729e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.51088562e-01,   0.00000000e+00,   7.84268487e-01,
        -3.27898210e-03,  -8.10398733e-03,   1.11302867e-01,
         0.00000000e+00,   9.28473202e-02,   0.00000000e+00,
         6.93506882e-01,   4.08759573e-02,   3.42298326e-02,
         5.59488603e-02,   0.00000000e+00,  -9.61607320e-02,
         0.00000000e+00,   1.60907616e-02,   6.72433563e-01,
        -3.59107430e-02,   4.54288923e-03,   2.85817318e-02,
         0.00000000e+00,   1.48926808e-02,   0.00000000e+00,
        -2.04840625e-02,  -1.13873729e-01,   3.09115361e-01,
         4.27119652e-04,   1.95541052e-02,   1.54973148e-02,
         0.00000000e+00,  -1.66834128e-03,   0.00000000e+00,
        -4.65323598e-02,   3.05305543e-02,   3.37146186e-02,
         3.12226690e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.15817129e-02,   0.00000000e+00,
        -2.55808380e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.27474586e-01,
         7.04013806e-03,   3.11039748e-02,  -3.47335639e-02,
         0.00000000e+00,  -4.66918921e-02,   0.00000000e+00,
        -2.18313641e-02,  -2.98512307e-02,  -7.09197073e-03,
         7.87761277e-03,   0.00000000e+00,   4.07309752e-01,
         1.64383482e-02,   3.53363045e-02,   3.70734336e-02,
         0.00000000e+00,   6.91104023e-03,   0.00000000e+00,
         4.02411149e-02,  -2.23745245e-02,   2.57591140e-02,
         9.93983962e-04,   0.00000000e+00,  -1.69387728e-02,
         4.26285228e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.35015968e-02,   0.00000000e+00,
        -1.97673510e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.71370000e-02,
         0.00000000e+00,   0.00000000e+00,   7.57374651e-01,
         9.38534380e-03,   2.09399181e-03,  -4.11541543e-02,
         0.00000000e+00,  -4.70958258e-02,   0.00000000e+00,
        -1.63828868e-01,  -9.42715284e-03,  -3.68853775e-04,
         5.11746598e-02,   0.00000000e+00,   6.99748321e-02,
        -6.47404159e-02,   0.00000000e+00,   6.72024066e-01,
         3.12068213e-03,   3.21706140e-02,  -3.45795682e-02,
         0.00000000e+00,   6.83051549e-02,   0.00000000e+00,
        -7.98645640e-03,  -1.59191163e-01,   5.12034315e-02,
        -1.80971766e-02,   0.00000000e+00,   1.06319397e-02,
         1.38064393e-02,   0.00000000e+00,   5.69798217e-03,
         7.29166778e-01,  -6.58040423e-02,  -2.89657751e-02,
         2.67108030e-03,   0.00000000e+00,  -3.80443425e-02,
         0.00000000e+00,  -2.49105325e-03,   8.11149942e-03,
         4.22252888e-02,  -3.98989505e-03,   0.00000000e+00,
        -3.32088580e-02,  -5.48541772e-02,   0.00000000e+00,
         1.63228741e-02,  -2.21629159e-02,   4.66887195e-01,
        -8.03824142e-02,  -1.07908018e-01,   3.14580674e-02,
         0.00000000e+00,  -4.23246923e-02,   0.00000000e+00,
         4.42944585e-03,  -4.73659051e-02,   2.12888118e-02,
        -2.03039376e-02,   0.00000000e+00,  -2.51579565e-02,
        -3.59985895e-02,   0.00000000e+00,  -1.03308831e-02,
         1.01267369e-02,   1.08754557e-01,   7.20784378e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.69585484e-03,  -5.12990925e-03,   1.23172086e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.00356663e-02,   0.00000000e+00,
        -4.12121333e-03,  -1.27892618e-04,   9.19255226e-03,
         0.00000000e+00,   7.28384472e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.68080935e-03,   0.00000000e+00,   3.41436110e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.16869919e-03,   0.00000000e+00,
         2.10838034e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.79672381e-04,   0.00000000e+00,  -1.02870946e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.36342039e-04,   0.00000000e+00,  -2.98691125e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.98202808e-04,   1.49459271e-03,
        -2.32080770e-03,   0.00000000e+00,  -2.45809194e-03,
         0.00000000e+00,  -2.23394549e-03,  -2.77425102e-04,
         1.49495855e-04,  -3.67605550e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.77305542e-03,   0.00000000e+00,  -2.31942536e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.85973479e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.31749979e-03,   0.00000000e+00,   2.81766319e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.47775855e-03,   0.00000000e+00,
         0.00000000e+00,   5.48490007e-04,   9.55044034e-04,
        -2.96857331e-03,   0.00000000e+00,  -3.01690789e-03,
         0.00000000e+00,  -9.41636977e-03,  -3.97961522e-04,
        -7.87860505e-05,   3.81570971e-03,   0.00000000e+00,
         4.86092559e-03,  -5.74616812e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.08349230e-03,   0.00000000e+00,  -9.36392180e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.92274961e-03,   0.00000000e+00,
         0.00000000e+00,   2.88066031e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.38301631e-04,   0.00000000e+00,  -4.83753921e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.65047901e-04,   0.00000000e+00,
         0.00000000e+00,   2.03264903e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.59653854e-04,   0.00000000e+00,
         7.04377203e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.71588232e-03,
         0.00000000e+00,   0.00000000e+00,   5.86770543e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.30898908e-04,   0.00000000e+00,   7.15184951e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.95764561e-03,   0.00000000e+00,
         0.00000000e+00,  -1.95061126e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.14176731e-02,  -6.94304870e-03,   8.26075866e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.06761228e-02,   0.00000000e+00,
         5.98142461e-03,   1.17466032e-02,   2.64057699e-03,
         0.00000000e+00,  -7.91976291e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.46174685e-03,   0.00000000e+00,   2.10838034e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.42866782e-03,   0.00000000e+00,
         3.41096869e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.92858671e-03,   0.00000000e+00,  -8.14329635e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.48679249e-03,   0.00000000e+00,   2.83193187e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.97181982e-03,   3.92495714e-03,
        -1.45878824e-03,   0.00000000e+00,   1.73898290e-03,
         0.00000000e+00,  -2.86935749e-04,   1.57368249e-03,
         3.26575696e-03,  -5.60119007e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.00289251e-03,   0.00000000e+00,   1.79418709e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.80724244e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.51029221e-04,   0.00000000e+00,  -1.07364821e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.23602526e-03,   0.00000000e+00,
         0.00000000e+00,  -2.75627025e-03,  -4.38597270e-03,
         5.31996008e-04,   0.00000000e+00,  -3.56309092e-04,
         0.00000000e+00,  -6.86638205e-05,  -1.04655168e-02,
         3.40860221e-03,  -1.66533049e-03,   0.00000000e+00,
         4.46250336e-04,   3.25963537e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.65141056e-04,   0.00000000e+00,  -7.78976611e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.72290441e-03,   0.00000000e+00,
         0.00000000e+00,   1.08547112e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.92793318e-03,   0.00000000e+00,  -8.19621896e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.73072628e-03,   0.00000000e+00,
         0.00000000e+00,   2.67413994e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.92776043e-03,   0.00000000e+00,
        -6.75502675e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.57447071e-02,
         0.00000000e+00,   0.00000000e+00,   1.90834594e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.95926024e-03,   0.00000000e+00,  -3.04071918e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.27145118e-03,   0.00000000e+00,
         0.00000000e+00,   1.47683564e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.24546942e-04,  -8.06956923e-03,  -4.23361239e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.57666520e-03,   0.00000000e+00,
        -8.05446186e-03,  -1.83043488e-03,   1.05865507e-03,
         0.00000000e+00,  -3.26647409e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.82524432e-05,   0.00000000e+00,  -1.02870946e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.35946196e-03,   0.00000000e+00,
        -8.14329635e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.38424860e-03,   0.00000000e+00,   4.80480932e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.18243026e-03,   0.00000000e+00,   9.63100808e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.07310149e-03,   4.27330252e-03,
         1.60526660e-03,   0.00000000e+00,  -1.19728267e-03,
         0.00000000e+00,  -2.98735718e-04,   1.16006491e-03,
         1.81337394e-03,   2.11912313e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.03680954e-04,   0.00000000e+00,  -3.58644080e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.78366994e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.36684721e-03,   0.00000000e+00,   5.97409790e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.12858148e-03,   0.00000000e+00,
         0.00000000e+00,   2.81935005e-03,   2.61259433e-03,
        -5.71463902e-04,   0.00000000e+00,   3.43564232e-04,
         0.00000000e+00,   2.53585734e-05,   3.14302723e-03,
        -1.31830838e-03,   3.46186174e-04,   0.00000000e+00,
         1.02355320e-04,  -1.63021393e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.48435224e-04,   0.00000000e+00,  -3.42392268e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.97991951e-04,   0.00000000e+00,
         0.00000000e+00,  -6.60197219e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.56292310e-05,   0.00000000e+00,   2.64621436e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.17740962e-03,   0.00000000e+00,
         0.00000000e+00,  -6.50193513e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.34088698e-03,   0.00000000e+00,
         3.78882055e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.59874625e-03,
         0.00000000e+00,   0.00000000e+00,  -2.59687601e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.95788619e-03,   0.00000000e+00,   2.60077316e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.43165387e-03,   0.00000000e+00,
         0.00000000e+00,  -6.35277988e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.52829031e-03,  -7.41153915e-03,  -2.35608130e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.72127977e-04,   0.00000000e+00,
        -9.22678567e-04,   7.12821152e-03,  -2.13176592e-04,
         0.00000000e+00,  -1.36911733e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.31365786e-04,   0.00000000e+00,  -2.98691125e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.43848000e-03,   0.00000000e+00,
         2.83193187e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.20132032e-03,   0.00000000e+00,   9.63100808e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.58824623e-03,   0.00000000e+00,   2.91476437e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.22086390e-03,   9.14325081e-04,
         1.57660185e-03,   0.00000000e+00,   8.05954970e-04,
         0.00000000e+00,  -3.88455995e-04,   1.72929826e-03,
         3.77371299e-03,  -8.35240418e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.57636873e-04,   0.00000000e+00,   4.83974800e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.26667305e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.24320212e-03,   0.00000000e+00,   1.91172595e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.35030728e-03,   0.00000000e+00,
         0.00000000e+00,  -1.46805923e-03,  -9.82221393e-04,
         1.00973880e-03,   0.00000000e+00,  -2.98117637e-04,
         0.00000000e+00,   2.43901376e-03,  -1.42200248e-03,
        -6.37338464e-05,  -1.34469501e-05,   0.00000000e+00,
        -1.06623817e-03,  -8.12993145e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.45060229e-03,   0.00000000e+00,   1.85424869e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.83425896e-04,   0.00000000e+00,
         0.00000000e+00,  -2.52156466e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.01185753e-03,   0.00000000e+00,   1.34608232e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.42479721e-03,   0.00000000e+00,
         0.00000000e+00,   9.57409768e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.24913254e-04,   0.00000000e+00,
        -3.30488047e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.03602000e-02,
         0.00000000e+00,   0.00000000e+00,  -9.31411618e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.00328427e-03,   0.00000000e+00,  -1.17223785e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.88894810e-03,   0.00000000e+00,
         0.00000000e+00,   4.21758837e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.26603250e-02,  -6.56989396e-02,   2.38543121e-02,
         1.69001161e-02,   1.07330068e-02,   6.40143158e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.21172470e-02,  -1.76858968e-02,  -2.71559802e-02,
         2.11540729e-04,   0.00000000e+00,   5.30311236e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.56715191e-02,   0.00000000e+00,  -2.55808380e-02,
         2.13777071e-03,   4.60883281e-03,  -4.10067699e-02,
         0.00000000e+00,  -3.96273236e-02,   0.00000000e+00,
        -1.64571202e-02,  -2.25053749e-02,   1.61747510e-02,
        -1.95340599e-02,   0.00000000e+00,   4.61409933e-02,
         0.00000000e+00,  -1.13662711e-02,  -7.77119089e-03,
        -7.06557593e-03,   1.77265151e-02,   2.88045840e-02,
         0.00000000e+00,  -1.58331844e-02,   0.00000000e+00,
        -4.37659219e-03,   6.62809041e-03,   2.62864526e-02,
        -7.34976616e-03,   6.63671730e-03,   1.86118869e-02,
         0.00000000e+00,   6.76624280e-03,   0.00000000e+00,
        -2.85013123e-03,   2.41693462e-03,   1.89843057e-02,
         2.90281587e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.50425252e-02,   0.00000000e+00,
         4.64528532e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.82228557e-02,
        -1.42909348e-03,   5.67300893e-03,  -1.72253403e-02,
         0.00000000e+00,  -4.28420438e-02,   0.00000000e+00,
         3.52607160e-02,  -1.91675269e-02,  -1.32369752e-04,
        -1.40221942e-02,   0.00000000e+00,   7.66131970e-02,
         7.44978467e-04,   5.55172622e-03,   3.94815483e-02,
         0.00000000e+00,  -2.55850957e-02,   0.00000000e+00,
        -1.67462179e-02,  -1.57313967e-02,   2.82344673e-02,
         1.79999117e-02,   0.00000000e+00,   2.73341730e-03,
         7.27707678e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.50568464e-02,   0.00000000e+00,
         3.07228859e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.23042326e-02,
         0.00000000e+00,   0.00000000e+00,  -4.64884354e-02,
         3.54044258e-03,  -4.68846903e-03,   1.98249043e-02,
         0.00000000e+00,   1.18811508e-02,   0.00000000e+00,
         2.07354888e-02,  -1.16694554e-03,   2.25330727e-03,
        -2.63425558e-03,   0.00000000e+00,  -2.14280478e-02,
         2.19752056e-02,   0.00000000e+00,  -3.32107957e-02,
        -7.55190308e-03,   1.89892907e-03,   2.18428880e-04,
         0.00000000e+00,  -3.86624790e-03,   0.00000000e+00,
         1.44307544e-04,   3.62418806e-02,  -8.02756540e-03,
         2.75604764e-03,   0.00000000e+00,  -1.33936969e-02,
        -1.75683468e-02,   0.00000000e+00,  -3.69738416e-03,
        -4.08717521e-02,  -2.75084412e-02,   4.65911024e-02,
        -8.89865833e-03,   0.00000000e+00,   6.97763159e-04,
         0.00000000e+00,   3.98603325e-03,   2.14768956e-02,
         1.38065006e-02,   9.40934370e-03,   0.00000000e+00,
         6.10983360e-03,   7.14899538e-03,   0.00000000e+00,
        -1.11307974e-02,   2.47474535e-02,   6.84933100e-02,
         2.83891530e-02,   1.04688333e-02,  -8.72748272e-04,
         0.00000000e+00,   6.75299833e-03,   0.00000000e+00,
        -1.79926555e-03,   3.85915579e-03,  -7.87025182e-03,
         8.82208159e-05,   0.00000000e+00,   2.78726288e-03,
         7.98318928e-03,   0.00000000e+00,   4.86332670e-03,
         2.75662040e-03,  -3.77273442e-02,  -2.74354922e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.47656085e-03,  -1.10841167e-03,   1.68057724e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.13633127e-03,   0.00000000e+00,
         4.32390182e-03,   8.56807249e-03,  -4.18515259e-03,
         0.00000000e+00,  -1.23900738e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.54913012e-03,   0.00000000e+00,  -2.31942536e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.89675327e-04,   0.00000000e+00,
         1.79418709e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.77749390e-04,   0.00000000e+00,  -3.58644080e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.02108296e-03,   0.00000000e+00,   4.83974800e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.67517204e-03,   2.08037039e-03,
        -2.94307001e-03,   0.00000000e+00,  -6.32557289e-03,
         0.00000000e+00,   4.80450903e-03,  -1.43631804e-03,
         5.80973668e-04,  -8.62783136e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.01584472e-03,   0.00000000e+00,   5.85009539e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.22676873e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.25657431e-05,   0.00000000e+00,   2.73075768e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.53586435e-04,   0.00000000e+00,
         0.00000000e+00,  -2.97513283e-03,  -3.95213662e-03,
         2.89605709e-03,   0.00000000e+00,   6.67808949e-04,
         0.00000000e+00,   3.19696469e-03,   6.54131119e-04,
         1.86009505e-04,  -6.24983972e-04,   0.00000000e+00,
        -1.58356406e-03,  -1.49587418e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.45467085e-03,   0.00000000e+00,   2.92094042e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.50191449e-03,   0.00000000e+00,
         0.00000000e+00,  -3.24787345e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.24227202e-04,   0.00000000e+00,   2.00842805e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.63481453e-04,   0.00000000e+00,
         0.00000000e+00,  -1.48650513e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.91634023e-03,   0.00000000e+00,
        -5.10849730e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.83770953e-03,
         0.00000000e+00,   0.00000000e+00,   2.01954746e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.20121627e-03,   0.00000000e+00,  -4.00704374e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.31592503e-05,   0.00000000e+00,
         0.00000000e+00,   6.79212386e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.12151851e-04,   4.53910915e-03,  -4.57733490e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.53089979e-03,   0.00000000e+00,
         8.32826272e-03,   8.01058165e-03,   1.34706081e-03,
         0.00000000e+00,   3.79264423e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.36660581e-03,   0.00000000e+00,   2.81766319e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.10381234e-03,   0.00000000e+00,
        -1.07364821e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.93464369e-03,   0.00000000e+00,   5.97409790e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.02404205e-04,   0.00000000e+00,   1.91172595e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.66188069e-04,  -5.96646965e-05,
         5.73052831e-03,   0.00000000e+00,  -3.71716434e-03,
         0.00000000e+00,  -2.01822045e-03,  -2.45980243e-03,
         2.30250922e-03,   2.81904881e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.02070486e-04,   0.00000000e+00,   2.73075768e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.35051618e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.36382009e-03,   0.00000000e+00,   6.15845865e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.19054020e-03,   0.00000000e+00,
         0.00000000e+00,  -4.61276651e-03,  -5.71184053e-03,
        -1.11703772e-03,   0.00000000e+00,  -3.03585104e-03,
         0.00000000e+00,  -3.57311669e-03,   6.81056757e-04,
         1.05041083e-04,  -4.73814582e-04,   0.00000000e+00,
         7.84673181e-05,  -2.08353455e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.00989578e-03,   0.00000000e+00,  -2.82785132e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.03878352e-03,   0.00000000e+00,
         0.00000000e+00,   2.84243898e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.03937585e-03,   0.00000000e+00,   2.06602576e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.83779317e-03,   0.00000000e+00,
         0.00000000e+00,  -1.89620777e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.17022114e-03,   0.00000000e+00,
        -3.51413146e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.41911882e-03,
         0.00000000e+00,   0.00000000e+00,   4.20275072e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.47169677e-03,   0.00000000e+00,  -5.77917614e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.17704765e-03,   0.00000000e+00,
         0.00000000e+00,   8.10345395e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.10435004e-01,  -8.59602969e-02,  -1.14593749e-01,
         9.88672860e-03,   2.34582022e-02,  -5.13369465e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.54719411e-02,  -1.02282325e-02,  -3.82683554e-02,
         2.06541486e-03,   0.00000000e+00,  -7.79481078e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.56782881e-02,   0.00000000e+00,  -1.97673510e-01,
         2.60114720e-03,   3.99010371e-03,  -5.50114367e-02,
         0.00000000e+00,  -4.86350897e-02,   0.00000000e+00,
        -1.68154145e-01,  -2.94759546e-02,  -1.37773015e-02,
        -2.49878100e-02,   0.00000000e+00,   4.75683804e-02,
         0.00000000e+00,  -9.23963830e-03,  -1.58780409e-01,
         1.58171588e-02,   6.49552497e-03,  -2.90314810e-06,
         0.00000000e+00,  -1.06027083e-02,   0.00000000e+00,
         5.33582474e-03,   4.30327165e-02,  -1.88866544e-02,
        -5.46259722e-03,  -6.62971360e-03,   1.67359615e-03,
         0.00000000e+00,   6.09445283e-03,   0.00000000e+00,
         2.18935124e-02,  -1.07105619e-02,  -1.09361007e-03,
        -1.11277393e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.87032255e-02,   0.00000000e+00,
         3.07228859e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.70507695e-02,
        -8.97344751e-03,  -1.27014003e-02,   1.65726551e-02,
         0.00000000e+00,   1.21459152e-02,   0.00000000e+00,
         2.58590051e-02,   9.83655317e-03,  -4.11319615e-06,
        -4.21359604e-03,   0.00000000e+00,  -2.95193527e-02,
        -1.28946655e-02,  -1.76733070e-02,  -1.24671336e-02,
         0.00000000e+00,  -1.50407066e-02,   0.00000000e+00,
        -2.94855141e-02,   8.92347109e-03,  -4.15392047e-03,
         2.40554458e-03,   0.00000000e+00,   6.77295120e-03,
        -3.51440996e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.73976977e-02,   0.00000000e+00,
         1.67172868e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.07647209e-02,
         0.00000000e+00,   0.00000000e+00,  -2.00861807e-01,
        -5.23818457e-03,  -3.11854930e-03,   3.92948236e-02,
         0.00000000e+00,   3.93438464e-02,   0.00000000e+00,
         1.20936225e-01,   5.21718190e-03,  -2.18151360e-03,
        -2.32128756e-02,   0.00000000e+00,  -3.67775636e-02,
         3.64271198e-02,   0.00000000e+00,  -1.71627628e-01,
         4.41821929e-05,  -2.22634379e-02,   2.69938235e-02,
         0.00000000e+00,  -5.41035201e-02,   0.00000000e+00,
         6.45822172e-03,   1.21356210e-01,  -3.34483686e-02,
         8.90431044e-03,   0.00000000e+00,  -9.29501156e-03,
        -1.23902481e-02,   0.00000000e+00,  -3.71111335e-03,
        -2.02601639e-01,   4.05497893e-02,   3.42622435e-02,
        -5.55483117e-03,   0.00000000e+00,   2.15607325e-02,
         0.00000000e+00,   6.87050282e-03,  -8.44625781e-04,
        -6.86375396e-03,  -6.87381929e-04,   0.00000000e+00,
         8.96280077e-03,   1.83477136e-02,   0.00000000e+00,
        -9.57398216e-03,   1.46130968e-02,  -4.93878343e-02,
         7.82682682e-02,   9.13063634e-02,  -1.98137886e-02,
         0.00000000e+00,   2.76573336e-02,   0.00000000e+00,
        -3.49403809e-03,   3.44662761e-02,  -1.60297216e-02,
         1.00887308e-02,   0.00000000e+00,   1.32770497e-02,
         1.90217401e-02,   0.00000000e+00,   5.88466719e-03,
        -9.34959011e-03,  -6.08327139e-02,  -1.78627098e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.52343211e-03,   3.65069560e-03,  -1.64113598e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.14330713e-03,   0.00000000e+00,
         2.75627509e-03,  -1.39007933e-04,  -3.07847984e-03,
         0.00000000e+00,  -2.35147629e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.44982958e-03,   0.00000000e+00,  -9.36392180e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.96220966e-04,   0.00000000e+00,
        -7.78976611e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.64118309e-04,   0.00000000e+00,  -3.42392268e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.93961514e-03,   0.00000000e+00,   1.85424869e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.21895767e-03,  -1.70223579e-03,
         3.97912171e-03,   0.00000000e+00,   1.98994159e-03,
         0.00000000e+00,   2.20023879e-03,  -8.61460983e-04,
        -5.30728591e-04,   4.74065111e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.03948015e-03,   0.00000000e+00,   2.92094042e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.38549819e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.48568326e-03,   0.00000000e+00,  -2.82785132e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.50735375e-04,   0.00000000e+00,
         0.00000000e+00,  -1.51299708e-03,  -1.05852708e-03,
         6.08402481e-03,   0.00000000e+00,   5.79294722e-03,
         0.00000000e+00,   1.74730123e-02,   7.27187033e-04,
        -3.31976961e-04,  -1.64929600e-03,   0.00000000e+00,
        -2.37340170e-03,   2.24678088e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.50131751e-03,   0.00000000e+00,   1.77161606e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.20043028e-03,   0.00000000e+00,
         0.00000000e+00,  -7.12842624e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.82825232e-04,   0.00000000e+00,   2.84624693e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.28983330e-04,   0.00000000e+00,
         0.00000000e+00,  -4.37052887e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.09978631e-03,   0.00000000e+00,
        -2.06489176e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.55939818e-03,
         0.00000000e+00,   0.00000000e+00,   6.98057415e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.53290496e-04,   0.00000000e+00,  -1.35766012e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.35800582e-03,   0.00000000e+00,
         0.00000000e+00,   1.16563267e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.64166217e-03,  -3.29340423e-03,   1.53427073e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.03270713e-03,   0.00000000e+00,
         4.19447026e-04,   8.48663520e-03,  -4.31931793e-03,
         0.00000000e+00,   6.22432751e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.71767929e-04,   0.00000000e+00,  -4.83753921e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.31978239e-03,   0.00000000e+00,
        -8.19621896e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.86469785e-04,   0.00000000e+00,   2.64621436e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.78006391e-03,   0.00000000e+00,   1.34608232e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.40066185e-03,   7.19654518e-04,
        -6.10340077e-05,   0.00000000e+00,  -1.41656658e-03,
         0.00000000e+00,   3.71340692e-04,   5.40967608e-03,
         5.52784002e-04,  -8.40517251e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.03700253e-05,   0.00000000e+00,   2.00842805e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.94721855e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.50863335e-03,   0.00000000e+00,   2.06602576e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.78954463e-03,   0.00000000e+00,
         0.00000000e+00,  -2.83645541e-03,  -7.42815295e-03,
         5.36743403e-03,   0.00000000e+00,  -1.01598015e-02,
         0.00000000e+00,   1.21289291e-03,   1.61272420e-02,
        -4.17568066e-03,   6.35715647e-04,   0.00000000e+00,
        -1.29765180e-03,  -1.47392858e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.85603859e-04,   0.00000000e+00,   2.84624693e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.14249942e-03,   0.00000000e+00,
         0.00000000e+00,  -3.38840697e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.98823027e-03,   0.00000000e+00,   2.14185100e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.31957476e-03,   0.00000000e+00,
         0.00000000e+00,  -1.17671118e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.75726896e-03,   0.00000000e+00,
        -3.21747499e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.60497239e-03,
         0.00000000e+00,   0.00000000e+00,   1.16900430e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.92748246e-03,   0.00000000e+00,  -4.78305885e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.01671001e-04,   0.00000000e+00,
         0.00000000e+00,   3.63232702e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.90481448e-03,  -1.47147857e-02,   4.97759041e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.38567883e-03,   0.00000000e+00,
        -1.79686572e-02,  -1.07446711e-02,   1.30430914e-03,
         0.00000000e+00,  -5.11122286e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.76918647e-04,   0.00000000e+00,   7.04377203e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.59794890e-03,   0.00000000e+00,
        -6.75502675e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.81070403e-03,   0.00000000e+00,   3.78882055e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.10645603e-03,   0.00000000e+00,  -3.30488047e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.50756460e-03,   1.57204688e-02,
        -3.39176281e-03,   0.00000000e+00,  -7.55243991e-04,
         0.00000000e+00,   1.72245206e-03,   4.45612514e-03,
         1.19610743e-03,   4.69288643e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.80027691e-03,   0.00000000e+00,  -5.10849730e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.81499489e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.85826400e-03,   0.00000000e+00,  -3.51413146e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.16219531e-04,   0.00000000e+00,
         0.00000000e+00,   1.40365884e-02,   1.13429487e-02,
        -2.29073750e-03,   0.00000000e+00,   6.23821790e-03,
         0.00000000e+00,   7.77335931e-04,   6.14781902e-05,
        -1.01414110e-03,  -2.71276232e-04,   0.00000000e+00,
         1.74205743e-03,   3.11224872e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.43500195e-03,   0.00000000e+00,  -2.06489176e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.00356391e-03,   0.00000000e+00,
         0.00000000e+00,   6.58838399e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.92107729e-03,   0.00000000e+00,  -3.21747499e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.10994390e-03,   0.00000000e+00,
         0.00000000e+00,   1.15089150e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.36538617e-02,   0.00000000e+00,
         1.69548854e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.00022916e-03,
         0.00000000e+00,   0.00000000e+00,  -7.08220860e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.24814291e-02,   0.00000000e+00,   1.37191314e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.73877720e-03,   0.00000000e+00,
         0.00000000e+00,  -1.60311915e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.16044712e-03,  -1.07931668e-02,   4.06273853e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.29709326e-03,   0.00000000e+00,
        -1.41108904e-02,  -1.15779028e-02,   2.72190724e-03,
         0.00000000e+00,  -5.50979498e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.04365528e-04,   0.00000000e+00,   7.15184951e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.00240333e-03,   0.00000000e+00,
        -3.04071918e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.08541705e-03,   0.00000000e+00,   2.60077316e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.64652248e-03,   0.00000000e+00,  -1.17223785e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.22582995e-02,   1.66151885e-03,
         6.55873601e-04,   0.00000000e+00,   9.27901349e-04,
         0.00000000e+00,  -4.60965735e-04,   1.83015496e-03,
         2.49761998e-03,  -3.30669993e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.07343397e-03,   0.00000000e+00,  -4.00704374e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.36393379e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.71161949e-03,   0.00000000e+00,  -5.77917614e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.66342880e-03,   0.00000000e+00,
         0.00000000e+00,   2.97454802e-02,   3.33509723e-02,
        -6.18944882e-03,   0.00000000e+00,   8.58787990e-03,
         0.00000000e+00,  -6.99322689e-04,   5.62808036e-03,
        -2.48698713e-03,   1.40909691e-03,   0.00000000e+00,
         1.34670207e-03,   2.12185811e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.23664956e-03,   0.00000000e+00,  -1.35766012e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.61848111e-04,   0.00000000e+00,
         0.00000000e+00,   5.85564130e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.71984151e-04,   0.00000000e+00,  -4.78305885e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.17941986e-03,   0.00000000e+00,
         0.00000000e+00,   1.34480801e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.64926252e-02,   0.00000000e+00,
         1.37191314e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.03259153e-03,
         0.00000000e+00,   0.00000000e+00,  -8.77000708e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.57349841e-02,   0.00000000e+00,   4.68142463e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.51822562e-03,   0.00000000e+00,
         0.00000000e+00,  -1.20800919e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.12400346e-02,  -1.09824668e-02,   5.26779107e-03,
         1.13468026e-02,   4.26804792e-02,  -5.18683454e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.29706484e-03,   2.39256508e-03,   3.37702024e-02,
        -5.94982366e-03,   0.00000000e+00,   1.13126800e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.34233548e-03,   0.00000000e+00,  -3.27898210e-03,
         7.14205380e-02,   5.10853740e-02,  -1.33027834e-02,
         0.00000000e+00,   2.19307578e-02,   0.00000000e+00,
        -9.64790728e-03,  -2.46663138e-03,   1.33835698e-02,
         5.12323985e-03,   0.00000000e+00,   1.19030819e-02,
         0.00000000e+00,   7.07737159e-03,   5.05727867e-03,
        -4.93152537e-03,   3.98384727e-04,  -2.63971252e-03,
         0.00000000e+00,   3.79856252e-04,   0.00000000e+00,
        -4.29742925e-03,   6.11644840e-03,   8.61870392e-03,
        -5.05749161e-03,  -6.36579971e-03,  -8.06886178e-03,
         0.00000000e+00,   2.39080920e-03,   0.00000000e+00,
         5.83946591e-03,   7.45913165e-03,   8.99665961e-03,
         2.27687279e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.21577704e-04,   0.00000000e+00,
         2.13777071e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.57023207e-03,
         3.47743951e-03,  -1.41615721e-02,   6.99599699e-03,
         0.00000000e+00,  -3.22226945e-03,   0.00000000e+00,
         7.11282492e-03,  -4.60214869e-03,  -1.96585467e-03,
        -8.99168712e-04,   0.00000000e+00,  -1.01752753e-02,
        -1.70476777e-04,   9.11267673e-03,  -1.24105091e-03,
         0.00000000e+00,   3.29314211e-03,   0.00000000e+00,
         5.12471938e-03,  -1.48510352e-03,   1.63557748e-03,
         1.16377121e-03,   0.00000000e+00,  -2.81232233e-05,
         1.11751656e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.59568323e-03,   0.00000000e+00,
         2.60114720e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.26918302e-04,
         0.00000000e+00,   0.00000000e+00,  -3.46018323e-03,
        -1.31075367e-02,  -1.40790499e-02,   5.92907515e-03,
         0.00000000e+00,  -3.72424588e-03,   0.00000000e+00,
         4.43274191e-03,  -8.35350389e-03,   6.84518132e-03,
        -7.22708807e-03,   0.00000000e+00,  -3.71113969e-03,
        -9.32823169e-03,   0.00000000e+00,  -9.52895319e-03,
        -1.23466985e-03,   4.05777119e-04,   6.52516192e-03,
         0.00000000e+00,   7.38640331e-04,   0.00000000e+00,
         1.34881989e-03,   3.74108294e-03,   2.02771279e-03,
         2.85074394e-03,   0.00000000e+00,  -4.54970450e-03,
        -2.30616664e-03,   0.00000000e+00,  -1.14754106e-02,
        -3.37127746e-03,  -2.27485926e-03,   3.22839678e-03,
         2.58355664e-03,   0.00000000e+00,   2.66404124e-03,
         0.00000000e+00,  -1.80276302e-02,   3.01066796e-03,
         5.12222542e-03,   9.88063249e-03,   0.00000000e+00,
        -1.50813354e-02,  -1.88982164e-03,   0.00000000e+00,
         2.97802384e-02,   5.17296135e-03,   1.41631267e-02,
         2.78470868e-03,   2.80210200e-03,  -2.14667294e-03,
         0.00000000e+00,  -5.77719393e-03,   0.00000000e+00,
        -1.18656082e-02,  -1.14757242e-03,  -2.21452717e-04,
         8.34436704e-03,   0.00000000e+00,   2.15995558e-02,
        -1.77889789e-02,   0.00000000e+00,   6.71694849e-02,
         4.94166352e-03,   1.14256087e-03,  -7.88817653e-04,
        -1.34567699e-02,  -3.73153872e-03,  -9.27878519e-03,
         5.67923118e-02,   1.82489787e-03,   2.03282810e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.15924451e-02,   4.23601485e-02,   1.69745932e-04,
         1.08039585e-02,   0.00000000e+00,   2.99633386e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.25897406e-02,   0.00000000e+00,  -8.10398733e-03,
         5.10853740e-02,   9.52341815e-02,  -2.77851313e-02,
         0.00000000e+00,   9.10670466e-03,   0.00000000e+00,
        -8.89524869e-03,   7.91540389e-03,  -7.87266935e-04,
        -3.08047215e-03,   0.00000000e+00,   1.10355667e-02,
         0.00000000e+00,   6.27519405e-03,  -1.19154984e-02,
         2.67536127e-03,  -6.79076276e-04,   1.53235001e-02,
         0.00000000e+00,  -9.92472322e-03,   0.00000000e+00,
        -5.90088916e-03,  -9.57071805e-03,  -1.95669398e-02,
        -2.46825652e-03,  -3.90834309e-04,   2.46716392e-02,
         0.00000000e+00,  -1.01981449e-02,   0.00000000e+00,
        -4.80024745e-03,  -8.24854373e-03,  -3.94507189e-03,
        -4.11862051e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.40392225e-03,   0.00000000e+00,
         4.60883281e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.32310632e-02,
        -8.08894628e-03,  -5.15486450e-04,   9.63441599e-05,
         0.00000000e+00,  -1.16396731e-02,   0.00000000e+00,
         1.21143689e-02,   5.03625043e-03,   1.01708808e-02,
        -1.08112961e-02,   0.00000000e+00,   1.85094965e-02,
         4.11278732e-03,   4.07916036e-03,  -3.86686144e-03,
         0.00000000e+00,   6.55816642e-03,   0.00000000e+00,
         4.88232249e-03,  -3.85647750e-03,  -3.32794865e-03,
        -5.13031265e-03,   0.00000000e+00,  -3.69272094e-03,
         2.95393529e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.06750090e-03,   0.00000000e+00,
         3.99010371e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.98339128e-03,
         0.00000000e+00,   0.00000000e+00,  -1.16072881e-02,
        -1.08655326e-02,  -1.64756174e-02,   3.06057129e-03,
         0.00000000e+00,  -5.28824816e-03,   0.00000000e+00,
         6.40847941e-03,  -7.68780802e-03,   5.30659522e-03,
        -1.64257667e-03,   0.00000000e+00,  -2.07261338e-02,
        -2.47641851e-03,   0.00000000e+00,  -1.25792325e-02,
        -1.31615558e-03,  -2.22006286e-03,   2.35726416e-03,
         0.00000000e+00,   1.59395230e-03,   0.00000000e+00,
         7.30714833e-03,   3.86989779e-03,  -2.32069785e-03,
        -2.02932670e-03,   0.00000000e+00,   2.71356327e-03,
        -6.66418546e-03,   0.00000000e+00,  -1.76718122e-02,
        -1.46436118e-02,  -3.02510853e-03,   4.26249959e-03,
        -8.99261686e-03,   0.00000000e+00,  -6.82112780e-03,
         0.00000000e+00,  -8.37176643e-03,  -2.31290394e-03,
         1.10636217e-03,  -2.50328983e-03,   0.00000000e+00,
         4.25833658e-02,  -2.03619127e-02,   0.00000000e+00,
         2.25026832e-02,  -1.03670651e-03,   1.33353369e-03,
         3.66145138e-03,  -2.69984493e-04,  -5.18586282e-03,
         0.00000000e+00,  -8.14777761e-04,   0.00000000e+00,
        -1.26536304e-02,   9.20183718e-04,  -2.11634589e-03,
         6.95082285e-03,   0.00000000e+00,   6.00077527e-03,
        -9.95189724e-03,   0.00000000e+00,   8.62288149e-02,
         4.22047019e-03,   3.95906050e-03,  -1.22769730e-02,
         1.97223647e-02,   1.35418254e-01,   1.71175864e-02,
        -2.78003651e-02,  -3.51227288e-02,  -8.00876644e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.01168657e-02,   4.92145292e-03,   6.21208205e-02,
        -1.26408676e-02,   0.00000000e+00,  -3.62384491e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.09184928e-01,   0.00000000e+00,   1.11302867e-01,
        -1.33027834e-02,  -2.77851313e-02,   1.11548513e-01,
         0.00000000e+00,   8.12913535e-02,   0.00000000e+00,
         1.15679500e-01,   3.37209385e-02,  -8.37720163e-03,
         4.33465222e-02,   0.00000000e+00,  -8.28142473e-02,
         0.00000000e+00,   2.31996210e-02,   8.99533429e-02,
        -3.86766606e-03,  -1.42048913e-02,  -3.18218803e-02,
         0.00000000e+00,   2.16107017e-02,   0.00000000e+00,
        -5.05612595e-04,  -3.68548669e-02,  -5.12076129e-02,
        -2.88298977e-04,   9.38484845e-03,  -9.92920398e-03,
         0.00000000e+00,  -8.82710877e-03,   0.00000000e+00,
        -1.28596699e-02,   1.38057424e-04,  -3.47265035e-02,
        -8.67598685e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.63504915e-02,   0.00000000e+00,
        -4.10067699e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.13122355e-02,
         5.47301554e-03,   2.14308009e-03,   1.61616159e-02,
         0.00000000e+00,   3.14228273e-02,   0.00000000e+00,
        -4.62820924e-02,   9.15484128e-03,  -2.32562948e-03,
         2.12543765e-02,   0.00000000e+00,  -1.00513119e-01,
        -7.39843507e-04,   1.64339319e-03,  -3.15801947e-02,
         0.00000000e+00,   1.92274398e-02,   0.00000000e+00,
         2.82942157e-02,   9.08473611e-03,  -2.80283096e-02,
        -1.87018804e-02,   0.00000000e+00,   1.28667191e-03,
        -8.55099418e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.32634969e-02,   0.00000000e+00,
        -5.50114367e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.43360236e-02,
         0.00000000e+00,   0.00000000e+00,   1.35241015e-01,
         1.91078263e-03,   7.45519548e-03,  -2.64965342e-02,
         0.00000000e+00,  -1.76077084e-02,   0.00000000e+00,
        -5.35598568e-02,   6.39352909e-05,  -1.97963883e-03,
         2.32153515e-02,   0.00000000e+00,   5.81031906e-02,
        -5.04932272e-02,   0.00000000e+00,   1.37326325e-01,
         8.13437086e-03,   8.43662005e-04,  -3.31958782e-03,
         0.00000000e+00,   1.15295285e-02,   0.00000000e+00,
        -5.33746230e-03,  -6.33450940e-02,   1.76359723e-02,
        -6.41549654e-03,   0.00000000e+00,   1.82861267e-02,
         2.30397063e-02,   0.00000000e+00,   1.56591579e-02,
         1.44624459e-01,   1.10844674e-02,  -4.50813645e-02,
         1.50813900e-02,   0.00000000e+00,  -6.26952537e-03,
         0.00000000e+00,  -2.47414469e-03,  -2.37423253e-02,
        -6.44401545e-03,  -4.39394875e-03,   0.00000000e+00,
        -3.01894380e-02,  -2.29343263e-02,   0.00000000e+00,
         1.46966550e-02,  -3.49885241e-02,  -6.73663307e-02,
        -3.38294326e-02,  -2.93653133e-02,   1.02847351e-02,
         0.00000000e+00,  -1.68857531e-02,   0.00000000e+00,
         6.35136338e-03,  -1.65591014e-02,   1.52036562e-02,
        -1.01749706e-02,   0.00000000e+00,  -1.04973582e-02,
        -1.86686185e-02,   0.00000000e+00,  -2.68288898e-02,
        -2.05035679e-03,   7.66164800e-02,   1.19959935e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.60997659e-03,   7.28393771e-03,  -8.74431433e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.53464788e-03,   0.00000000e+00,
         2.25972353e-03,  -4.96136681e-03,   1.10157327e-02,
         0.00000000e+00,   9.72784878e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.46539978e-02,   0.00000000e+00,   9.68080935e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.85702880e-04,   0.00000000e+00,
         1.46174685e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.15427018e-03,   0.00000000e+00,   1.82524432e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.56671145e-03,   0.00000000e+00,  -6.31365786e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.55883482e-03,  -1.66599044e-03,
         3.04261461e-03,   0.00000000e+00,   2.79822561e-03,
         0.00000000e+00,  -4.35311480e-03,   5.09007339e-05,
        -1.33509616e-04,   3.57350019e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.90456021e-03,   0.00000000e+00,  -4.54913012e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.20306889e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.13769208e-03,   0.00000000e+00,   2.36660581e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.98196565e-03,   0.00000000e+00,
         0.00000000e+00,   6.29702009e-04,  -2.40484362e-04,
        -1.11590321e-03,   0.00000000e+00,  -9.06028379e-04,
         0.00000000e+00,  -4.21255174e-03,  -6.86800575e-05,
        -8.95592129e-05,   6.69281774e-04,   0.00000000e+00,
         5.10894564e-03,  -3.09893400e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.17644093e-03,   0.00000000e+00,  -3.44982958e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.12813409e-03,   0.00000000e+00,
         0.00000000e+00,   1.15002292e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.17408454e-04,   0.00000000e+00,  -6.71767929e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.60709833e-04,   0.00000000e+00,
         0.00000000e+00,   9.96762504e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.88102276e-03,   0.00000000e+00,
        -9.76918647e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.13043100e-03,
         0.00000000e+00,   0.00000000e+00,   2.46507305e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.21291931e-04,   0.00000000e+00,   1.04365528e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.93046796e-03,   0.00000000e+00,
         0.00000000e+00,  -1.79562974e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.54098860e-03,   1.20894210e-01,   8.24793789e-03,
        -1.53083336e-02,  -1.19709049e-02,  -6.73198779e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.31936171e-02,   1.63439008e-02,   7.63802740e-02,
        -9.44771587e-03,   0.00000000e+00,  -4.52729483e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.00132955e-01,   0.00000000e+00,   9.28473202e-02,
         2.19307578e-02,   9.10670466e-03,   8.12913535e-02,
         0.00000000e+00,   1.03213108e-01,   0.00000000e+00,
         9.54985583e-02,   3.19051522e-02,  -4.68885975e-03,
         2.87596858e-02,   0.00000000e+00,  -8.54600932e-02,
         0.00000000e+00,   1.28251082e-02,   6.96711838e-02,
         2.14458079e-03,  -2.17256410e-02,  -2.95461624e-02,
         0.00000000e+00,   2.51807427e-02,   0.00000000e+00,
         1.14351114e-03,  -2.65975300e-02,  -3.64576557e-02,
         7.02375029e-03,  -7.61722169e-03,  -1.81026804e-02,
         0.00000000e+00,  -7.39306568e-03,   0.00000000e+00,
        -6.85076357e-03,   4.14542835e-03,  -2.19212241e-02,
        -4.87124676e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.81679716e-02,   0.00000000e+00,
        -3.96273236e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.09996360e-02,
         3.73560100e-04,  -4.93977632e-03,   1.54829521e-02,
         0.00000000e+00,   3.65231944e-02,   0.00000000e+00,
        -4.11780321e-02,   1.60128909e-02,  -5.03311977e-03,
         2.28277902e-02,   0.00000000e+00,  -1.12800639e-01,
         2.26879301e-03,   5.68999691e-03,  -2.86691366e-02,
         0.00000000e+00,   2.50533068e-02,   0.00000000e+00,
         2.82643521e-02,   7.41006907e-03,  -2.65930758e-02,
        -1.40262840e-02,   0.00000000e+00,  -1.16102675e-02,
        -7.41215505e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.17198624e-02,   0.00000000e+00,
        -4.86350897e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.01104197e-02,
         0.00000000e+00,   0.00000000e+00,   1.16368419e-01,
        -5.52880179e-03,  -3.29101740e-04,  -1.99693548e-02,
         0.00000000e+00,  -2.15124998e-02,   0.00000000e+00,
        -4.71978536e-02,  -4.00370187e-04,  -1.63046699e-05,
         1.52552962e-02,   0.00000000e+00,   4.78066410e-02,
        -4.90288792e-02,   0.00000000e+00,   1.18955039e-01,
         5.72685861e-03,   5.31976359e-04,  -9.72692128e-04,
         0.00000000e+00,   1.08264616e-02,   0.00000000e+00,
         4.98619877e-03,  -5.68723556e-02,   1.56859060e-02,
        -7.09087644e-03,   0.00000000e+00,   1.54233189e-02,
         2.47564741e-02,   0.00000000e+00,  -1.10474868e-02,
         1.21568410e-01,   1.28959404e-02,  -4.44140177e-02,
         9.28128614e-03,   0.00000000e+00,  -7.17161058e-03,
         0.00000000e+00,  -8.88652878e-03,  -2.47589802e-02,
        -1.01069756e-02,  -2.39555816e-03,   0.00000000e+00,
        -2.83666562e-02,  -2.88716744e-02,   0.00000000e+00,
         3.15447007e-02,  -3.42032723e-02,  -6.66323082e-02,
        -3.33768876e-02,  -2.38522864e-02,   5.18836941e-03,
         0.00000000e+00,  -1.83915440e-02,   0.00000000e+00,
        -1.63764349e-03,  -1.50689744e-02,   1.49638130e-02,
        -2.60103309e-03,   0.00000000e+00,  -1.16706619e-03,
        -2.29604953e-02,   0.00000000e+00,   1.48191000e-02,
        -1.20750688e-03,   7.19618334e-02,   1.02054976e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.69585484e-03,  -5.12990925e-03,   1.23172086e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.00356663e-02,   0.00000000e+00,
        -4.12121333e-03,  -1.27892618e-04,   9.19255226e-03,
         0.00000000e+00,   7.28384472e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.68080935e-03,   0.00000000e+00,   3.41436110e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.16869919e-03,   0.00000000e+00,
         2.10838034e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.79672381e-04,   0.00000000e+00,  -1.02870946e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.36342039e-04,   0.00000000e+00,  -2.98691125e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.98202808e-04,   1.49459271e-03,
        -2.32080770e-03,   0.00000000e+00,  -2.45809194e-03,
         0.00000000e+00,  -2.23394549e-03,  -2.77425102e-04,
         1.49495855e-04,  -3.67605550e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.77305542e-03,   0.00000000e+00,  -2.31942536e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.85973479e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.31749979e-03,   0.00000000e+00,   2.81766319e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.47775855e-03,   0.00000000e+00,
         0.00000000e+00,   5.48490007e-04,   9.55044034e-04,
        -2.96857331e-03,   0.00000000e+00,  -3.01690789e-03,
         0.00000000e+00,  -9.41636977e-03,  -3.97961522e-04,
        -7.87860505e-05,   3.81570971e-03,   0.00000000e+00,
         4.86092559e-03,  -5.74616812e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.08349230e-03,   0.00000000e+00,  -9.36392180e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.92274961e-03,   0.00000000e+00,
         0.00000000e+00,   2.88066031e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.38301631e-04,   0.00000000e+00,  -4.83753921e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.65047901e-04,   0.00000000e+00,
         0.00000000e+00,   2.03264903e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.59653854e-04,   0.00000000e+00,
         7.04377203e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.71588232e-03,
         0.00000000e+00,   0.00000000e+00,   5.86770543e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.30898908e-04,   0.00000000e+00,   7.15184951e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.95764561e-03,   0.00000000e+00,
         0.00000000e+00,  -1.95061126e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.05398906e-01,   1.55733120e-01,   5.96671101e-01,
        -4.99735296e-03,  -5.61780293e-02,   4.97347951e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.86579757e-01,   3.76508456e-03,   7.42111784e-02,
         7.06109208e-03,   0.00000000e+00,   5.45584961e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.14295382e-01,   0.00000000e+00,   6.93506882e-01,
        -9.64790728e-03,  -8.89524869e-03,   1.15679500e-01,
         0.00000000e+00,   9.54985583e-02,   0.00000000e+00,
         7.41270525e-01,   3.93814931e-02,   3.16411011e-02,
         5.29613305e-02,   0.00000000e+00,  -8.21885920e-02,
         0.00000000e+00,   1.69467832e-02,   6.56141757e-01,
        -3.23484078e-02,   4.25221873e-03,   3.04051608e-02,
         0.00000000e+00,   1.22300872e-02,   0.00000000e+00,
        -2.15742217e-02,  -1.07043446e-01,   3.19099037e-01,
         4.76788581e-03,   1.36968179e-02,   1.32099878e-02,
         0.00000000e+00,  -5.23517954e-04,   0.00000000e+00,
        -4.89164695e-02,   2.96023454e-02,   4.02958535e-02,
         3.32809425e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.64670950e-02,   0.00000000e+00,
        -1.64571202e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.17438487e-01,
         6.67615501e-03,   3.19169474e-02,  -4.01161394e-02,
         0.00000000e+00,  -5.27788036e-02,   0.00000000e+00,
        -2.21351516e-02,  -3.09489348e-02,  -6.74846086e-03,
         5.81278064e-03,   0.00000000e+00,   4.32826234e-01,
         1.52144838e-02,   3.28667750e-02,   4.01907129e-02,
         0.00000000e+00,   7.86265297e-03,   0.00000000e+00,
         4.21716524e-02,  -2.16301526e-02,   2.64708331e-02,
         6.70965289e-04,   0.00000000e+00,  -2.34044889e-02,
         4.39328451e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.32391590e-02,   0.00000000e+00,
        -1.68154145e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.18603170e-02,
         0.00000000e+00,   0.00000000e+00,   6.74004429e-01,
         9.49331508e-03,   3.71697021e-03,  -4.35021922e-02,
         0.00000000e+00,  -4.95296309e-02,   0.00000000e+00,
        -1.73174395e-01,  -9.70915403e-03,  -1.41850168e-03,
         5.35930899e-02,   0.00000000e+00,   7.05880502e-02,
        -6.78311071e-02,   0.00000000e+00,   7.06809711e-01,
         3.13285873e-03,   3.07112332e-02,  -3.43462503e-02,
         0.00000000e+00,   6.54637815e-02,   0.00000000e+00,
        -8.93143040e-03,  -1.50080771e-01,   4.83416427e-02,
        -1.67895100e-02,   0.00000000e+00,   9.53162483e-03,
         1.02201891e-02,   0.00000000e+00,   8.86051017e-03,
         7.04893998e-01,  -6.53856615e-02,  -2.42629520e-02,
        -3.60623801e-05,   0.00000000e+00,  -3.80263132e-02,
         0.00000000e+00,  -5.02748464e-04,   9.56739846e-03,
         4.05778430e-02,  -3.73293809e-03,   0.00000000e+00,
        -2.31768994e-02,  -5.17569096e-02,   0.00000000e+00,
         1.55370827e-02,  -1.81673681e-02,   4.67878596e-01,
        -7.46197803e-02,  -1.03676924e-01,   3.03061235e-02,
         0.00000000e+00,  -3.81412982e-02,   0.00000000e+00,
         4.63437816e-03,  -4.40260867e-02,   1.97601895e-02,
        -2.01590012e-02,   0.00000000e+00,  -2.63107945e-02,
        -3.13881979e-02,   0.00000000e+00,  -1.33332343e-02,
         1.05137695e-02,   9.92280775e-02,   6.99430026e-01,
        -9.49729656e-03,   3.28969533e-02,  -7.53488001e-03,
         7.66922092e-03,  -8.78535415e-03,  -1.05951649e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.52179758e-02,   1.37315339e-02,   1.58636745e-02,
        -5.78233574e-03,   0.00000000e+00,  -3.14414767e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.50679374e-02,   0.00000000e+00,   1.60907616e-02,
         7.07737159e-03,   6.27519405e-03,   2.31996210e-02,
         0.00000000e+00,   1.28251082e-02,   0.00000000e+00,
         1.69467832e-02,   9.03477954e-03,  -6.42058448e-03,
         1.62066524e-02,   0.00000000e+00,  -1.57230784e-02,
         0.00000000e+00,   3.73080784e-02,   1.32233002e-02,
         6.49261928e-03,  -9.22633274e-03,  -1.10410009e-02,
         0.00000000e+00,   3.95622206e-03,   0.00000000e+00,
        -7.07789381e-03,  -7.40142690e-03,  -9.44782239e-03,
         7.34761505e-03,  -5.87241506e-03,  -4.34219558e-03,
         0.00000000e+00,  -2.23905670e-03,   0.00000000e+00,
         1.15159587e-03,  -3.46211086e-03,  -4.24053171e-03,
        -1.27474896e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.35733657e-02,   0.00000000e+00,
        -1.13662711e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.88287063e-02,
        -1.27145712e-03,   1.13424140e-03,   3.07583191e-03,
         0.00000000e+00,   1.30355100e-02,   0.00000000e+00,
        -1.10801618e-02,   5.37631647e-03,   1.71935438e-03,
         6.20881490e-03,   0.00000000e+00,  -3.70017812e-02,
        -8.99714630e-04,  -2.36529480e-03,  -1.14131059e-02,
         0.00000000e+00,   6.79019318e-03,   0.00000000e+00,
         6.10687048e-03,   4.75420030e-03,  -1.15431086e-02,
        -4.23723061e-03,   0.00000000e+00,  -6.31844303e-03,
        -1.88588003e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.17326390e-03,   0.00000000e+00,
        -9.23963830e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.54785152e-03,
         0.00000000e+00,   0.00000000e+00,   2.27714633e-02,
        -4.50135538e-03,  -2.96280936e-03,  -4.96813594e-03,
         0.00000000e+00,  -3.48060593e-03,   0.00000000e+00,
        -8.21594541e-03,  -9.34999077e-03,   2.56714628e-03,
         5.19361684e-04,   0.00000000e+00,   1.02131076e-02,
        -7.71398656e-03,   0.00000000e+00,   2.21554056e-02,
         2.51539950e-03,  -3.16717247e-04,  -3.46659341e-03,
         0.00000000e+00,  -2.23217823e-03,   0.00000000e+00,
        -7.95341922e-03,  -1.39689606e-02,   3.00576550e-03,
         1.56715959e-03,   0.00000000e+00,   1.37232104e-02,
        -1.50598566e-03,   0.00000000e+00,   2.60185574e-02,
         2.70584840e-02,   5.76737447e-03,  -1.37654965e-02,
         1.22960843e-04,   0.00000000e+00,  -3.19483433e-03,
         0.00000000e+00,  -1.49777181e-03,  -9.76621040e-03,
        -6.55500196e-03,  -2.86237234e-03,   0.00000000e+00,
         2.56487263e-03,  -1.31807127e-02,   0.00000000e+00,
         4.55551588e-03,  -8.93322658e-03,  -2.81297771e-02,
        -7.69605241e-03,  -3.82373440e-03,   2.25905158e-04,
         0.00000000e+00,  -4.67165722e-03,   0.00000000e+00,
        -2.43204841e-03,  -1.83793552e-03,   4.14769163e-03,
         1.98587295e-03,   0.00000000e+00,  -5.83683377e-04,
        -6.19472878e-03,   0.00000000e+00,   1.10765095e-02,
        -1.93794606e-03,   1.88216005e-02,   1.73734310e-02,
        -2.17291438e-02,  -2.54354474e-03,  -1.51489371e-02,
        -1.21291704e-02,   7.92536674e-03,  -2.24337714e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.09176649e-02,   3.26222639e-03,  -8.58496843e-03,
        -1.69910146e-03,   0.00000000e+00,  -1.54537911e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.61125503e-04,   0.00000000e+00,  -2.04840625e-02,
        -4.29742925e-03,  -5.90088916e-03,  -5.05612595e-04,
         0.00000000e+00,   1.14351114e-03,   0.00000000e+00,
        -2.15742217e-02,   5.62455973e-03,  -7.21454771e-03,
        -5.54993485e-03,   0.00000000e+00,  -1.70710199e-03,
         0.00000000e+00,  -7.07789381e-03,  -1.96110528e-02,
         2.94840960e-03,  -4.89956014e-03,  -1.72461720e-02,
         0.00000000e+00,  -5.90914446e-04,   0.00000000e+00,
         1.04279353e-02,   1.13280038e-02,   1.44235273e-02,
         4.39201118e-03,  -7.35915057e-03,  -1.85588527e-02,
         0.00000000e+00,  -1.60895187e-03,   0.00000000e+00,
         9.79300509e-03,   1.50742286e-03,   2.73432275e-03,
         2.75322885e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.09446260e-02,   0.00000000e+00,
        -4.37659219e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.72766391e-02,
        -2.82554832e-03,   1.16567608e-03,   4.48124598e-03,
         0.00000000e+00,   7.81268872e-03,   0.00000000e+00,
        -3.82390148e-03,   5.37502328e-03,   1.74864984e-03,
         5.94057399e-03,   0.00000000e+00,  -1.56701985e-02,
         4.69337847e-04,  -4.32354465e-03,  -8.89927658e-03,
         0.00000000e+00,   3.45456446e-03,   0.00000000e+00,
         6.78916586e-04,   3.20133370e-03,  -4.97952177e-03,
        -2.43331803e-03,   0.00000000e+00,   8.46281161e-03,
        -2.23077141e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.84800766e-04,   0.00000000e+00,
         5.33582474e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.23601673e-03,
         0.00000000e+00,   0.00000000e+00,  -1.78244393e-02,
         1.82785309e-03,   2.40072812e-03,   5.39190573e-05,
         0.00000000e+00,   2.05061635e-03,   0.00000000e+00,
         4.00481899e-03,   3.64564893e-03,  -1.76024003e-03,
        -6.25732818e-03,   0.00000000e+00,   6.59226856e-04,
        -1.63418659e-03,   0.00000000e+00,  -1.90672187e-02,
         1.89543231e-03,  -2.94998392e-03,   2.13204983e-03,
         0.00000000e+00,  -1.83822150e-03,   0.00000000e+00,
         2.25945822e-03,   2.41724171e-03,  -1.92359275e-03,
         6.64495751e-04,   0.00000000e+00,  -1.01829015e-03,
         3.95569310e-03,   0.00000000e+00,  -5.99461470e-03,
        -2.09591718e-02,   9.26793350e-03,  -5.92297559e-03,
         5.93901003e-04,   0.00000000e+00,  -1.24078185e-03,
         0.00000000e+00,   2.51287729e-03,  -5.74564609e-03,
        -7.82483222e-03,  -2.48493953e-03,   0.00000000e+00,
         1.05365664e-03,   1.08480073e-02,   0.00000000e+00,
         3.45931900e-04,  -2.52900644e-03,  -1.59259258e-02,
         3.56766593e-04,   3.12709071e-03,  -1.23787787e-04,
         0.00000000e+00,   4.51315602e-03,   0.00000000e+00,
         1.59643625e-03,   3.06121889e-03,   9.12414326e-04,
         2.69123518e-03,   0.00000000e+00,   9.35586418e-04,
        -1.09203611e-04,   0.00000000e+00,  -7.71743198e-03,
         4.84715526e-04,  -1.80675744e-03,  -1.89728166e-02,
        -3.46077260e-02,  -2.04603749e-02,  -2.53901687e-02,
        -1.55983930e-02,   2.43188896e-02,  -2.00227137e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.77843765e-02,   3.80450676e-03,  -1.30595025e-02,
        -4.97604854e-03,   0.00000000e+00,  -3.06744474e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.77175262e-03,   0.00000000e+00,  -4.65323598e-02,
         5.83946591e-03,  -4.80024745e-03,  -1.28596699e-02,
         0.00000000e+00,  -6.85076357e-03,   0.00000000e+00,
        -4.89164695e-02,   3.38055411e-03,  -8.56704369e-03,
        -7.58170865e-03,   0.00000000e+00,   8.89896447e-03,
         0.00000000e+00,   1.15159587e-03,  -4.08849201e-02,
         5.46181205e-03,  -5.51635639e-03,  -2.13683309e-02,
         0.00000000e+00,  -2.31102692e-03,   0.00000000e+00,
         9.79300509e-03,   2.02131719e-02,   1.94497884e-02,
         8.96108700e-03,  -1.75456881e-02,  -3.30830231e-02,
         0.00000000e+00,   4.26862277e-04,   0.00000000e+00,
         2.14772674e-02,   3.48010003e-03,   1.50897255e-02,
         6.43851970e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.75574489e-02,   0.00000000e+00,
        -2.85013123e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.05138078e-02,
        -2.66837027e-03,  -5.29048555e-03,   8.45211695e-03,
         0.00000000e+00,   1.67895444e-02,   0.00000000e+00,
        -1.59159946e-03,   8.25023571e-03,   2.49991237e-03,
         7.98741959e-03,   0.00000000e+00,  -2.14998172e-02,
        -1.48421792e-03,  -5.92198287e-03,  -1.32769789e-02,
         0.00000000e+00,   4.01573566e-03,   0.00000000e+00,
        -3.53293553e-03,   7.73459643e-03,  -4.76908202e-03,
        -2.00022402e-03,   0.00000000e+00,   9.67936024e-03,
        -2.28709460e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.81261979e-03,   0.00000000e+00,
         2.18935124e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.71656323e-03,
         0.00000000e+00,   0.00000000e+00,  -4.42883498e-02,
        -4.50969347e-03,  -1.29787969e-03,   7.30377898e-03,
         0.00000000e+00,   6.99495629e-03,   0.00000000e+00,
         2.31783167e-02,   4.95886635e-06,  -2.12620403e-03,
        -1.52592879e-02,   0.00000000e+00,  -5.36693149e-03,
         4.54019752e-03,   0.00000000e+00,  -4.61239836e-02,
         2.26817174e-03,  -5.70275299e-03,   4.69703226e-03,
         0.00000000e+00,  -9.34361299e-03,   0.00000000e+00,
         4.32341840e-04,   1.66794019e-02,  -5.06620560e-03,
         3.83540297e-03,   0.00000000e+00,  -8.23264706e-04,
         1.05555951e-03,   0.00000000e+00,   1.20908084e-04,
        -4.99652783e-02,   1.61293788e-02,  -4.73424240e-03,
         7.50452954e-04,   0.00000000e+00,   2.65319862e-03,
         0.00000000e+00,  -6.93234029e-04,  -5.37231850e-03,
        -7.89595405e-03,  -1.82140491e-03,   0.00000000e+00,
         7.33393195e-04,   1.76253701e-02,   0.00000000e+00,
         1.70678704e-03,   1.08192148e-03,  -2.00522945e-02,
         9.20796279e-03,   1.47588750e-02,  -5.62128117e-03,
         0.00000000e+00,   6.28225420e-03,   0.00000000e+00,
        -3.99410651e-03,   8.14400324e-03,  -3.82692787e-04,
         6.84667944e-03,   0.00000000e+00,   6.30955489e-03,
         2.93100203e-04,   0.00000000e+00,  -1.22500534e-03,
         7.70028874e-04,  -1.09418492e-02,  -4.37479277e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.18854004e-03,  -1.80357445e-03,   3.11803113e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.92636754e-03,   0.00000000e+00,
        -7.37944227e-05,   1.88667160e-03,  -3.26186709e-03,
         0.00000000e+00,  -2.89027657e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.35311480e-03,   0.00000000e+00,  -2.23394549e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.06388916e-04,   0.00000000e+00,
        -2.86935749e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.93440133e-04,   0.00000000e+00,  -2.98735718e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.08362412e-03,   0.00000000e+00,  -3.88455995e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.56784394e-03,   2.29515657e-03,
        -5.21870860e-03,   0.00000000e+00,  -5.13040468e-03,
         0.00000000e+00,   5.22789140e-03,  -8.11737021e-04,
        -4.70615014e-04,  -1.26953783e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.25609744e-03,   0.00000000e+00,   4.80450903e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.66379842e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.74574939e-03,   0.00000000e+00,  -2.01822045e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.35976095e-03,   0.00000000e+00,
         0.00000000e+00,   2.37278144e-04,  -4.44356108e-04,
         2.33963779e-03,   0.00000000e+00,   1.89768245e-03,
         0.00000000e+00,   2.60172063e-03,   3.96326370e-04,
         6.43347123e-05,  -3.95368212e-04,   0.00000000e+00,
        -9.77540335e-04,   6.47800139e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.55039766e-03,   0.00000000e+00,   2.20023879e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.31275996e-03,   0.00000000e+00,
         0.00000000e+00,  -3.21285879e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.10212070e-04,   0.00000000e+00,   3.71340692e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.66662264e-04,   0.00000000e+00,
         0.00000000e+00,  -1.02653815e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.77410632e-03,   0.00000000e+00,
         1.72245206e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.93181617e-03,
         0.00000000e+00,   0.00000000e+00,   1.17664701e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.11305066e-04,   0.00000000e+00,  -4.60965735e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.93470598e-04,   0.00000000e+00,
         0.00000000e+00,   9.56972706e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.64613694e-02,  -6.19060014e-02,   2.08882570e-02,
         1.70853760e-02,   1.23290057e-02,   6.07560021e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.61336525e-02,  -1.15773928e-02,  -2.60053027e-02,
         3.63229215e-03,   0.00000000e+00,   5.41222539e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.37155576e-02,   0.00000000e+00,  -2.18313641e-02,
         7.11282492e-03,   1.21143689e-02,  -4.62820924e-02,
         0.00000000e+00,  -4.11780321e-02,   0.00000000e+00,
        -2.21351516e-02,  -2.04188688e-02,   1.19255679e-02,
        -1.73816429e-02,   0.00000000e+00,   4.45650678e-02,
         0.00000000e+00,  -1.10801618e-02,  -9.67938751e-03,
        -5.27791299e-03,   1.55626469e-02,   2.51391404e-02,
         0.00000000e+00,  -1.46649173e-02,   0.00000000e+00,
        -3.82390148e-03,   7.77964243e-03,   2.73349963e-02,
        -5.77050164e-03,   2.57756996e-03,   1.74182147e-02,
         0.00000000e+00,   9.23076520e-03,   0.00000000e+00,
        -1.59159946e-03,   3.21762077e-03,   1.86861461e-02,
         3.40934124e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.80072895e-02,   0.00000000e+00,
         3.52607160e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.29089738e-02,
        -5.01054787e-03,   8.76693612e-03,  -2.40225492e-02,
         0.00000000e+00,  -5.18207584e-02,   0.00000000e+00,
         4.48146908e-02,  -2.10349644e-02,  -1.04947544e-03,
        -1.48887744e-02,   0.00000000e+00,   7.59361608e-02,
         1.99174044e-03,   4.95860102e-03,   3.73762000e-02,
         0.00000000e+00,  -2.21798869e-02,   0.00000000e+00,
        -1.78309778e-02,  -1.40248737e-02,   2.70135557e-02,
         1.83679589e-02,   0.00000000e+00,   1.53619100e-03,
         6.57680716e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.91723693e-02,   0.00000000e+00,
         2.58590051e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.93985133e-02,
         0.00000000e+00,   0.00000000e+00,  -3.97496946e-02,
         5.41424698e-04,  -8.84026627e-03,   2.51960117e-02,
         0.00000000e+00,   1.58344224e-02,   0.00000000e+00,
         2.68334231e-02,   6.44306703e-04,   2.72263224e-03,
        -4.22288894e-03,   0.00000000e+00,  -2.30346065e-02,
         2.12465605e-02,   0.00000000e+00,  -3.97658398e-02,
        -6.83806657e-03,   3.74530501e-04,   1.71613493e-03,
         0.00000000e+00,  -3.67889960e-03,   0.00000000e+00,
         2.15039468e-03,   3.63867958e-02,  -8.62584648e-03,
         2.65491609e-03,   0.00000000e+00,  -1.32516227e-02,
        -1.56054810e-02,   0.00000000e+00,  -4.78121253e-03,
        -4.09285398e-02,  -2.39691672e-02,   4.33588463e-02,
        -1.16722312e-02,   0.00000000e+00,  -3.71950892e-03,
         0.00000000e+00,   4.86382872e-03,   1.68785888e-02,
         1.15523980e-02,   6.91604695e-03,   0.00000000e+00,
         8.48203226e-03,   6.79024278e-03,   0.00000000e+00,
        -7.84212421e-03,   2.12413456e-02,   6.33829652e-02,
         2.78048247e-02,   1.15222539e-02,  -1.92088932e-03,
         0.00000000e+00,   6.89223125e-03,   0.00000000e+00,
        -6.26515100e-03,   4.65663666e-03,  -7.11471482e-03,
         2.74710417e-03,   0.00000000e+00,   2.89419063e-03,
         5.42564656e-03,   0.00000000e+00,   1.09782763e-02,
         1.67618570e-03,  -3.64659138e-02,  -2.83699626e-02,
         8.12925039e-03,   3.97615061e-02,   1.21550099e-02,
        -5.71648522e-03,  -7.59113915e-03,  -1.98858441e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.64047656e-02,   9.75113722e-03,   2.13520008e-02,
        -7.41959009e-04,   0.00000000e+00,   8.20459520e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.29064042e-02,   0.00000000e+00,   4.02411149e-02,
         5.12471938e-03,   4.88232249e-03,   2.82942157e-02,
         0.00000000e+00,   2.82643521e-02,   0.00000000e+00,
         4.21716524e-02,   1.02646880e-02,  -4.68353619e-03,
         1.26657084e-02,   0.00000000e+00,  -2.50126791e-02,
         0.00000000e+00,   6.10687048e-03,   3.23648930e-02,
        -3.31515783e-04,  -6.44477598e-03,  -1.18624323e-02,
         0.00000000e+00,   6.55088427e-03,   0.00000000e+00,
         6.78916586e-04,  -1.14313162e-02,  -1.00712821e-02,
         1.87447310e-03,  -1.88714103e-03,  -8.44607842e-03,
         0.00000000e+00,  -3.18248470e-03,   0.00000000e+00,
        -3.53293553e-03,   2.08956292e-03,  -6.91116515e-03,
        -1.35926647e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.28404451e-02,   0.00000000e+00,
        -1.67462179e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.39192325e-02,
         1.24308391e-03,   3.87472188e-04,   8.49167810e-03,
         0.00000000e+00,   7.79377461e-03,   0.00000000e+00,
        -1.78309778e-02,   2.26746951e-03,   3.15306242e-03,
         8.74108615e-03,   0.00000000e+00,  -2.35163987e-02,
         1.86100496e-03,   4.47165195e-03,  -1.57447220e-02,
         0.00000000e+00,   7.66678344e-03,   0.00000000e+00,
         1.86763476e-02,   2.77650200e-03,  -1.14144463e-02,
        -7.94643732e-03,   0.00000000e+00,  -6.44849581e-04,
        -2.27327207e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.44660320e-02,   0.00000000e+00,
        -2.94855141e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.37486381e-02,
         0.00000000e+00,   0.00000000e+00,   4.81773127e-02,
        -4.79850616e-03,  -2.51958921e-03,  -1.65246182e-02,
         0.00000000e+00,  -1.51700842e-02,   0.00000000e+00,
        -3.21751925e-02,  -3.21897154e-04,  -1.46073145e-03,
         5.16055182e-03,   0.00000000e+00,   1.50099023e-02,
        -1.71043367e-02,   0.00000000e+00,   4.90145434e-02,
         2.07927784e-03,   2.45305789e-03,  -3.26887554e-03,
         0.00000000e+00,   1.10129054e-02,   0.00000000e+00,
         6.84812233e-04,  -3.09963243e-02,   8.02876839e-03,
        -2.56494392e-03,   0.00000000e+00,   5.12497892e-03,
         9.86969694e-03,   0.00000000e+00,   5.99283171e-04,
         5.27321184e-02,   1.58980231e-03,  -2.02204577e-02,
         3.96922482e-03,   0.00000000e+00,  -6.20613117e-03,
         0.00000000e+00,  -6.01647228e-03,  -8.67580598e-03,
        -1.42487214e-03,  -4.91649757e-04,   0.00000000e+00,
        -4.68414929e-03,  -9.00665398e-03,   0.00000000e+00,
         8.60499804e-03,  -1.32733217e-02,  -1.60161626e-02,
        -2.20278994e-02,  -1.81494793e-02,   6.29905508e-04,
         0.00000000e+00,  -9.13171588e-03,   0.00000000e+00,
        -3.73145942e-03,  -7.58725714e-03,   4.79037581e-03,
        -1.51750346e-03,   0.00000000e+00,  -2.64058644e-03,
        -7.51284374e-03,   0.00000000e+00,   4.45297571e-03,
        -1.64409953e-03,   2.47530261e-02,   4.18908429e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.70974536e-03,  -4.38556514e-04,  -1.92433087e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.01656667e-03,   0.00000000e+00,
         6.24445577e-04,   1.51720943e-03,  -3.72549352e-03,
         0.00000000e+00,  -3.07228052e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.21255174e-03,   0.00000000e+00,  -9.41636977e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.34994534e-04,   0.00000000e+00,
        -6.86638205e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.77490302e-05,   0.00000000e+00,   2.53585734e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.87084318e-04,   0.00000000e+00,   2.43901376e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.16097753e-04,  -4.18688499e-04,
         2.86459388e-03,   0.00000000e+00,   2.15748890e-03,
         0.00000000e+00,   2.60172063e-03,   5.82011295e-04,
         2.14566464e-04,  -1.80192311e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.25511809e-03,   0.00000000e+00,   3.19696469e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.09524357e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.65914583e-03,   0.00000000e+00,  -3.57311669e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.97378901e-04,   0.00000000e+00,
         0.00000000e+00,  -8.17958902e-04,  -6.24691792e-04,
         6.49170972e-03,   0.00000000e+00,   5.29977826e-03,
         0.00000000e+00,   1.76693861e-02,   1.05567378e-03,
        -5.33457176e-04,  -1.43835961e-03,   0.00000000e+00,
        -2.69010494e-03,   2.11354795e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.19598738e-03,   0.00000000e+00,   1.74730123e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.73516663e-03,   0.00000000e+00,
         0.00000000e+00,  -7.44875600e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.47224688e-04,   0.00000000e+00,   1.21289291e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.20185461e-04,   0.00000000e+00,
         0.00000000e+00,  -2.70187126e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.13697676e-03,   0.00000000e+00,
         7.77335931e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.27632183e-03,
         0.00000000e+00,   0.00000000e+00,  -2.35677897e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.94364068e-04,   0.00000000e+00,  -6.99322689e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.26672314e-04,   0.00000000e+00,
         0.00000000e+00,   1.34786842e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.05700869e-01,  -7.37370590e-02,  -1.10852291e-01,
         1.15666918e-02,   1.89371143e-02,  -5.55457371e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.56835678e-02,  -8.69135728e-03,  -3.04848975e-02,
         5.57578136e-04,   0.00000000e+00,  -7.88650035e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.78586842e-02,   0.00000000e+00,  -1.63828868e-01,
         4.43274191e-03,   6.40847941e-03,  -5.35598568e-02,
         0.00000000e+00,  -4.71978536e-02,   0.00000000e+00,
        -1.73174395e-01,  -2.73301093e-02,  -1.32859092e-02,
        -2.13530267e-02,   0.00000000e+00,   4.02569695e-02,
         0.00000000e+00,  -8.21594541e-03,  -1.47427642e-01,
         1.58646541e-02,   5.08069427e-03,   1.16650969e-04,
         0.00000000e+00,  -8.32091772e-03,   0.00000000e+00,
         4.00481899e-03,   3.84686925e-02,  -2.33148469e-02,
        -5.80523197e-03,  -5.54635263e-03,   5.59080301e-03,
         0.00000000e+00,   6.63543886e-03,   0.00000000e+00,
         2.31783167e-02,  -1.08252781e-02,  -4.84369817e-03,
        -2.33215367e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.41842132e-02,   0.00000000e+00,
         2.07354888e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.28828985e-02,
        -6.96021138e-03,  -1.42942289e-02,   2.39098868e-02,
         0.00000000e+00,   1.86421994e-02,   0.00000000e+00,
         2.68334231e-02,   1.06830194e-02,   2.80098946e-04,
        -3.41250099e-03,   0.00000000e+00,  -3.44450812e-02,
        -1.29281149e-02,  -1.55549631e-02,  -1.98270041e-02,
         0.00000000e+00,  -1.66850588e-02,   0.00000000e+00,
        -3.21751925e-02,   8.32868687e-03,  -7.86874499e-03,
         5.50515303e-04,   0.00000000e+00,   4.90527693e-03,
        -3.75775021e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.75099849e-02,   0.00000000e+00,
         1.20936225e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.17070226e-02,
         0.00000000e+00,   0.00000000e+00,  -1.69027269e-01,
        -7.50172505e-03,  -3.64348374e-03,   4.63977191e-02,
         0.00000000e+00,   4.57566172e-02,   0.00000000e+00,
         1.46271382e-01,   6.36978896e-03,  -3.68046848e-03,
        -2.34402103e-02,   0.00000000e+00,  -3.80035882e-02,
         3.71426473e-02,   0.00000000e+00,  -1.70280551e-01,
         2.48849405e-04,  -2.09541549e-02,   2.63979471e-02,
         0.00000000e+00,  -5.01886477e-02,   0.00000000e+00,
         7.75862991e-03,   1.12314990e-01,  -3.07558279e-02,
         7.88131079e-03,   0.00000000e+00,  -7.79806341e-03,
        -1.03528214e-02,   0.00000000e+00,  -3.81855797e-03,
        -1.85543990e-01,   3.87386555e-02,   2.98672753e-02,
        -2.42757581e-03,   0.00000000e+00,   2.25566944e-02,
         0.00000000e+00,   6.90249972e-03,  -1.46166827e-03,
        -6.55557305e-03,   3.16293962e-04,   0.00000000e+00,
         7.32508548e-03,   1.35841941e-02,   0.00000000e+00,
        -8.40088927e-03,   1.16185969e-02,  -5.35180438e-02,
         7.23384814e-02,   8.54927932e-02,  -1.99015309e-02,
         0.00000000e+00,   2.38226540e-02,   0.00000000e+00,
        -4.62716765e-03,   3.16577730e-02,  -1.46104268e-02,
         8.21447028e-03,   0.00000000e+00,   1.24605188e-02,
         1.73506140e-02,   0.00000000e+00,   8.53927732e-03,
        -9.59570720e-03,  -5.29714717e-02,  -1.64992406e-01,
        -6.56224336e-03,  -2.02906849e-04,  -8.73777823e-03,
         6.94429458e-03,  -1.07808074e-03,  -2.59946694e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.59474827e-03,   1.42286389e-03,  -2.97004598e-04,
         9.58238970e-04,   0.00000000e+00,  -4.13386822e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.27259645e-03,   0.00000000e+00,  -7.98645640e-03,
         1.34881989e-03,   7.30714833e-03,  -5.33746230e-03,
         0.00000000e+00,   4.98619877e-03,   0.00000000e+00,
        -8.93143040e-03,   1.41006178e-03,   2.12127094e-04,
        -5.79832453e-03,   0.00000000e+00,  -3.37536235e-03,
         0.00000000e+00,  -7.95341922e-03,  -9.08613907e-03,
         2.77818557e-03,  -2.55825146e-03,   1.59534061e-03,
         0.00000000e+00,   7.25770044e-04,   0.00000000e+00,
         2.25945822e-03,   7.33953014e-04,  -3.36201153e-03,
         1.71552720e-03,  -2.70292510e-03,   1.68462432e-03,
         0.00000000e+00,  -1.66451562e-03,   0.00000000e+00,
         4.32341840e-04,   3.07661289e-04,  -1.11319222e-03,
        -3.39899863e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.42469974e-03,   0.00000000e+00,
         1.44307544e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.05945999e-03,
        -2.46597263e-03,  -1.14972952e-03,   2.57256498e-03,
         0.00000000e+00,   1.50412342e-03,   0.00000000e+00,
         2.15039468e-03,   6.17666846e-03,  -3.33839171e-04,
         3.60626749e-04,   0.00000000e+00,  -6.76760450e-03,
         2.64509726e-05,  -8.66769615e-04,  -2.90412392e-03,
         0.00000000e+00,   3.13400522e-03,   0.00000000e+00,
         6.84812233e-04,  -3.20948993e-03,  -1.58929306e-03,
        -1.12629119e-03,   0.00000000e+00,  -2.35626102e-03,
        -1.67657258e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.45992760e-03,   0.00000000e+00,
         6.45822172e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.01765335e-04,
         0.00000000e+00,   0.00000000e+00,  -7.51450448e-03,
        -3.33521280e-03,  -7.00745527e-03,   6.74864555e-03,
         0.00000000e+00,  -7.23861536e-03,   0.00000000e+00,
         7.75862991e-03,   1.55346228e-02,  -4.15087116e-03,
        -3.43386421e-04,   0.00000000e+00,  -2.77376959e-03,
         8.64686896e-04,   0.00000000e+00,  -7.49312161e-03,
        -2.15832867e-04,  -2.56905701e-03,   8.73522503e-03,
         0.00000000e+00,   2.08371804e-03,   0.00000000e+00,
         2.06865676e-02,   7.36133991e-03,  -2.42549681e-03,
        -2.11380008e-03,   0.00000000e+00,  -2.09667348e-03,
         1.62121753e-03,   0.00000000e+00,  -1.11020498e-02,
        -9.88412228e-03,   3.67557540e-03,  -7.62114114e-04,
        -2.80966190e-03,   0.00000000e+00,  -1.99816735e-03,
         0.00000000e+00,  -2.60471566e-03,  -7.65352422e-04,
        -2.28630770e-03,  -9.70579117e-04,   0.00000000e+00,
         4.51080541e-03,  -4.93054831e-03,   0.00000000e+00,
         7.06958290e-04,  -9.49504243e-05,  -6.90119351e-03,
         3.41675326e-03,   5.04709241e-03,  -2.25927017e-03,
         0.00000000e+00,  -1.49284477e-04,   0.00000000e+00,
        -4.68138518e-03,   6.02596396e-04,   2.48443910e-04,
         1.51638579e-03,   0.00000000e+00,   6.57428481e-04,
         3.16719273e-04,   0.00000000e+00,   3.34883670e-03,
         1.34894320e-03,  -1.08726552e-03,  -7.24858591e-03,
        -2.11818502e-03,  -1.60614150e-03,  -1.49050528e-03,
         3.61272055e-03,  -1.18711340e-02,   1.07140311e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.50722555e-03,   1.29041042e-03,  -1.22208084e-02,
         2.12276278e-03,   0.00000000e+00,   5.07143860e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.03568401e-03,   0.00000000e+00,  -2.49105325e-03,
        -1.80276302e-02,  -8.37176643e-03,  -2.47414469e-03,
         0.00000000e+00,  -8.88652878e-03,   0.00000000e+00,
        -5.02748464e-04,  -4.80188566e-05,  -4.40798872e-03,
        -4.26071482e-03,   0.00000000e+00,  -1.88616790e-03,
         0.00000000e+00,  -1.49777181e-03,  -5.64117308e-03,
         4.07698968e-03,  -1.02407886e-03,   2.37891561e-03,
         0.00000000e+00,  -2.63123182e-03,   0.00000000e+00,
         2.51287729e-03,  -2.33082024e-03,  -2.16759530e-03,
         5.33979887e-03,  -1.70369849e-03,   2.54524977e-03,
         0.00000000e+00,   5.47030542e-04,   0.00000000e+00,
        -6.93234029e-04,  -2.33972450e-03,   6.63168215e-07,
        -1.80307247e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.93735441e-03,   0.00000000e+00,
         3.98603325e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.11706894e-03,
        -7.82232745e-03,   1.40575411e-02,  -6.32298301e-03,
         0.00000000e+00,  -6.73830067e-03,   0.00000000e+00,
         4.86382872e-03,   1.39036531e-03,   1.03156696e-03,
         1.08835829e-03,   0.00000000e+00,   6.69658576e-03,
        -6.65163413e-04,  -6.31519876e-03,   2.35494619e-03,
         0.00000000e+00,  -5.08959699e-03,   0.00000000e+00,
        -6.01647228e-03,  -3.06159013e-03,   1.66058515e-03,
         2.52761200e-03,   0.00000000e+00,  -1.95759998e-03,
         1.53050704e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.03095646e-03,   0.00000000e+00,
         6.87050282e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.19042552e-03,
         0.00000000e+00,   0.00000000e+00,  -4.16628595e-03,
         1.28337525e-02,   1.02733529e-02,   2.73431755e-03,
         0.00000000e+00,   9.91744846e-03,   0.00000000e+00,
         6.90249972e-03,   7.31934731e-04,  -8.63695052e-04,
         8.46060058e-04,   0.00000000e+00,  -1.80941298e-03,
         4.37685193e-03,   0.00000000e+00,  -2.44953138e-03,
         1.66429565e-03,  -1.32713349e-03,  -2.10516830e-03,
         0.00000000e+00,  -5.49427092e-03,   0.00000000e+00,
        -2.60471566e-03,   6.06109504e-03,  -2.84077454e-03,
        -4.46353781e-04,   0.00000000e+00,   2.43917777e-03,
        -3.39681477e-03,   0.00000000e+00,   9.06113332e-04,
        -4.80154318e-03,   3.89186675e-03,   3.64281874e-03,
        -7.71523142e-03,   0.00000000e+00,  -6.54929814e-03,
         0.00000000e+00,   1.69265686e-02,  -3.52160373e-03,
        -1.91862573e-03,  -4.87098333e-03,   0.00000000e+00,
         9.36856406e-03,  -3.66137728e-03,   0.00000000e+00,
        -8.72999311e-03,  -1.02432118e-03,  -8.65566353e-04,
         4.42973321e-03,   5.34330230e-03,   7.43735405e-03,
         0.00000000e+00,   9.59030004e-03,   0.00000000e+00,
         1.29585043e-02,   4.03095134e-03,  -1.05894351e-03,
        -7.86677593e-04,   0.00000000e+00,  -6.76587192e-03,
         5.13305941e-03,   0.00000000e+00,  -1.37120493e-02,
        -1.49570671e-03,  -4.09513358e-03,  -3.35882444e-03,
         2.03415726e-03,   5.90293232e-03,  -1.00366496e-03,
         2.21081379e-03,  -8.72860912e-03,   4.68259380e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.25331854e-04,  -4.19804609e-03,  -1.26672918e-03,
        -2.64423801e-03,   0.00000000e+00,  -6.34830796e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.40727318e-03,   0.00000000e+00,   4.42944585e-03,
        -1.18656082e-02,  -1.26536304e-02,   6.35136338e-03,
         0.00000000e+00,  -1.63764349e-03,   0.00000000e+00,
         4.63437816e-03,  -5.86944324e-05,   8.81079420e-04,
        -4.57916465e-04,   0.00000000e+00,  -4.21403199e-03,
         0.00000000e+00,  -2.43204841e-03,   3.57678197e-03,
         8.32470147e-04,  -1.16502048e-03,   4.97258184e-03,
         0.00000000e+00,   3.30482276e-03,   0.00000000e+00,
         1.59643625e-03,  -2.82038868e-03,  -6.51562553e-03,
         4.81918459e-03,   3.96393767e-03,   8.31148800e-04,
         0.00000000e+00,  -7.17148882e-04,   0.00000000e+00,
        -3.99410651e-03,   1.39861704e-03,   8.87523372e-04,
        -7.18663004e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.91791058e-03,   0.00000000e+00,
        -1.79926555e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.51680734e-03,
         1.15168551e-02,   2.57219700e-03,  -7.56769233e-04,
         0.00000000e+00,   1.20405627e-03,   0.00000000e+00,
        -6.26515100e-03,   1.45794576e-03,   1.86612743e-03,
        -1.71979437e-04,   0.00000000e+00,  -4.44300884e-03,
        -9.14897355e-03,  -5.66361784e-03,  -6.31058959e-03,
         0.00000000e+00,  -3.23023265e-03,   0.00000000e+00,
        -3.73145942e-03,  -2.53618858e-03,  -2.40705708e-03,
        -2.07998684e-03,   0.00000000e+00,  -3.48586732e-03,
         4.69831950e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.49613173e-03,   0.00000000e+00,
        -3.49403809e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.57348308e-03,
         0.00000000e+00,   0.00000000e+00,   5.19409669e-03,
         2.72732653e-02,   3.13357001e-02,  -9.40263003e-03,
         0.00000000e+00,   6.22209906e-03,   0.00000000e+00,
        -4.62716765e-03,   4.93594688e-03,  -2.15580571e-03,
         1.24341674e-03,   0.00000000e+00,   2.78100740e-03,
         2.61574671e-03,   0.00000000e+00,   6.53485784e-03,
         1.19844305e-03,   2.32259368e-03,  -4.04196219e-04,
         0.00000000e+00,   6.33102908e-04,   0.00000000e+00,
        -4.68138518e-03,  -3.42683723e-03,   1.77334749e-03,
         1.58971563e-03,   0.00000000e+00,   3.29521632e-03,
        -3.30372119e-03,   0.00000000e+00,   4.01255725e-04,
         6.06280290e-03,   4.11661905e-04,   1.66209333e-03,
         9.76494677e-03,   0.00000000e+00,   1.02275240e-02,
         0.00000000e+00,   1.29585043e-02,   2.57948355e-03,
         2.07108839e-04,  -3.91747597e-04,   0.00000000e+00,
        -1.10507907e-03,  -3.76432202e-03,   0.00000000e+00,
        -7.60278149e-03,  -1.28367986e-03,  -4.88183140e-03,
        -2.14866987e-03,  -2.50273464e-03,   1.43065930e-02,
         0.00000000e+00,   1.15717032e-02,   0.00000000e+00,
         4.40736461e-02,   1.18110021e-03,  -6.94706316e-04,
        -3.93199092e-03,   0.00000000e+00,  -5.75261629e-03,
         5.36222052e-03,   0.00000000e+00,  -1.14324884e-02,
         4.15345977e-05,   2.77395984e-03,   4.61223207e-03])
  elif name == "AB MO 2E INTEGRALS":
    dimens = (norbtt,nrorb,nob)
    arr = np.array([  6.55673096e-01,   1.77229866e-01,   6.07151084e-01,
         5.98564508e-03,  -5.13230384e-02,   4.94651961e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.04799885e-01,  -3.76658696e-02,   9.04525968e-02,
        -1.14906622e-02,   0.00000000e+00,   5.49266678e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.38510904e-01,   0.00000000e+00,   7.42505236e-01,
         2.46935968e-03,  -1.48757991e-02,   1.21425546e-01,
         0.00000000e+00,   1.00579918e-01,   0.00000000e+00,
         7.20779491e-01,   6.46831057e-02,   6.79950678e-02,
         5.27484323e-02,   0.00000000e+00,  -9.28527978e-02,
         0.00000000e+00,   1.58468808e-02,   7.07883798e-01,
        -4.03912616e-02,  -6.80187375e-03,   3.05857272e-02,
         0.00000000e+00,   1.87423230e-02,   0.00000000e+00,
        -2.16810552e-02,  -1.21045531e-01,   3.19603941e-01,
         2.22487505e-03,   1.84447457e-02,   1.58687935e-02,
         0.00000000e+00,   3.84741694e-03,   0.00000000e+00,
        -4.70949393e-02,   3.52685535e-02,   3.53226987e-02,
         3.25684548e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.80746108e-02,   0.00000000e+00,
        -1.97862305e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.23677847e-01,
         5.90253672e-03,   2.63108195e-02,  -2.87648960e-02,
         0.00000000e+00,  -4.21972039e-02,   0.00000000e+00,
        -2.22691634e-02,  -3.49806345e-02,  -9.87630837e-03,
         1.18772444e-02,   0.00000000e+00,   4.15567848e-01,
         1.47196640e-02,   3.06705894e-02,   3.32909870e-02,
         0.00000000e+00,   2.81722181e-03,   0.00000000e+00,
         3.92961382e-02,  -2.79975512e-02,   2.32432486e-02,
        -8.66796532e-04,   0.00000000e+00,  -2.11552174e-02,
         4.40122036e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.22126364e-02,   0.00000000e+00,
        -1.76914533e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.39037815e-02,
         0.00000000e+00,   0.00000000e+00,   7.16837537e-01,
         7.88435776e-03,   2.89654491e-03,  -3.89277877e-02,
         0.00000000e+00,  -4.68906023e-02,   0.00000000e+00,
        -1.63213237e-01,  -1.01140655e-02,  -1.93079603e-04,
         5.35891192e-02,   0.00000000e+00,   7.68753657e-02,
        -6.74811169e-02,   0.00000000e+00,   6.90239076e-01,
         1.50729174e-03,   2.27624084e-02,  -2.95541687e-02,
         0.00000000e+00,   5.98354722e-02,   0.00000000e+00,
        -7.13420607e-03,  -1.64135553e-01,   5.52749202e-02,
        -2.00008311e-02,   0.00000000e+00,   1.96344435e-03,
         3.72638767e-03,   0.00000000e+00,   3.97650160e-03,
         7.38967808e-01,  -5.75390366e-02,  -2.97101542e-02,
         1.73123046e-03,   0.00000000e+00,  -3.73879844e-02,
         0.00000000e+00,  -3.48124149e-03,   9.85289025e-03,
         4.11464788e-02,  -4.61364509e-03,   0.00000000e+00,
        -5.08996665e-02,  -6.52727481e-02,   0.00000000e+00,
         1.56165244e-02,  -3.69196790e-04,   4.77904096e-01,
        -7.60731832e-02,  -1.04391187e-01,   3.35298821e-02,
         0.00000000e+00,  -4.48798766e-02,   0.00000000e+00,
         5.33243590e-03,  -5.79408261e-02,   2.51570136e-02,
        -2.20105595e-02,   0.00000000e+00,  -2.14376217e-02,
        -3.30945292e-02,   0.00000000e+00,  -1.34430578e-02,
         4.21519408e-02,   1.08907178e-01,   7.40938792e-01,
         7.91531247e-03,  -1.49207054e-01,  -1.00088383e-02,
         1.72283196e-02,   4.74507966e-02,   8.02284255e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.01760624e-02,  -4.17168348e-02,  -6.76269296e-02,
         1.50673797e-03,   0.00000000e+00,   4.19607410e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.23942507e-01,   0.00000000e+00,  -1.21828908e-01,
         9.15936745e-03,  -2.95532501e-04,  -9.50246629e-02,
         0.00000000e+00,  -8.58591255e-02,   0.00000000e+00,
        -1.09883052e-01,  -2.95858951e-02,   3.24942871e-02,
        -4.78250439e-02,   0.00000000e+00,   1.03374819e-01,
         0.00000000e+00,  -2.42744603e-02,  -8.67724149e-02,
        -5.50117505e-03,   1.76385882e-02,   3.22261438e-02,
         0.00000000e+00,  -2.67710943e-02,   0.00000000e+00,
         1.34219241e-03,   4.06738012e-02,   5.88850002e-02,
        -8.33123100e-03,   1.11217915e-03,   7.41878374e-03,
         0.00000000e+00,   1.18895574e-02,   0.00000000e+00,
         1.40524238e-02,   2.73866006e-03,   3.31600430e-02,
         9.25679651e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.81700063e-02,   0.00000000e+00,
         4.82615578e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.09818105e-01,
        -1.10105211e-03,  -4.64487762e-03,  -9.13434957e-03,
         0.00000000e+00,  -3.08998177e-02,   0.00000000e+00,
         4.46903624e-02,  -1.79743525e-02,   5.07855844e-04,
        -1.72353678e-02,   0.00000000e+00,   1.03189478e-01,
        -1.47657046e-03,  -2.89655102e-03,   3.26187624e-02,
         0.00000000e+00,  -2.81386043e-02,   0.00000000e+00,
        -2.97568920e-02,  -1.22189251e-02,   3.26631055e-02,
         1.86819586e-02,   0.00000000e+00,   9.87458752e-03,
         9.12270174e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.90678045e-02,   0.00000000e+00,
         6.25824982e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.72506481e-02,
         0.00000000e+00,   0.00000000e+00,  -1.46018495e-01,
         7.66952764e-04,  -5.35199143e-03,   2.72050496e-02,
         0.00000000e+00,   2.09530266e-02,   0.00000000e+00,
         5.38501591e-02,   2.90958912e-05,   2.07072146e-03,
        -2.11139697e-02,   0.00000000e+00,  -4.69980334e-02,
         4.87609115e-02,   0.00000000e+00,  -1.30824280e-01,
        -8.06563727e-03,  -4.07473171e-03,   7.27578156e-03,
         0.00000000e+00,  -1.78934802e-02,   0.00000000e+00,
         9.34514297e-04,   7.02734049e-02,  -1.67475141e-02,
         7.93331295e-03,   0.00000000e+00,  -2.77183908e-02,
        -3.15405272e-02,   0.00000000e+00,  -7.90170378e-03,
        -1.57607576e-01,  -9.58683794e-03,   4.91207827e-02,
        -1.02098528e-02,   0.00000000e+00,   1.03921415e-02,
         0.00000000e+00,   1.12596930e-03,   3.08828195e-02,
         1.16471406e-02,   7.38242628e-03,   0.00000000e+00,
         6.34868989e-03,   3.24345480e-02,   0.00000000e+00,
        -1.96925091e-02,   5.36145541e-02,   8.71012812e-02,
         4.10257830e-02,   3.54273809e-02,  -8.36624104e-03,
         0.00000000e+00,   1.76125760e-02,   0.00000000e+00,
        -3.37422049e-03,   1.29429549e-02,  -1.51477355e-02,
         7.49043008e-03,   0.00000000e+00,   1.53535538e-02,
         2.09507548e-02,   0.00000000e+00,   5.02955585e-03,
         1.82856549e-02,  -8.62993342e-02,  -1.11836857e-01,
         4.39310904e-02,  -1.64761316e-02,  -2.40001806e-03,
         6.93350222e-02,   3.72251613e-03,   4.54525479e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.69283100e-02,  -2.39871363e-02,  -1.20842730e-02,
         3.66582461e-03,   0.00000000e+00,   3.23478315e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.61923576e-02,   0.00000000e+00,  -6.66977772e-03,
         3.62710086e-02,   5.72222937e-02,  -2.82106041e-02,
         0.00000000e+00,  -6.78956152e-03,   0.00000000e+00,
        -6.69121626e-03,   3.10921737e-02,   5.81140451e-02,
        -2.12207718e-02,   0.00000000e+00,   3.76461955e-02,
         0.00000000e+00,   4.66474131e-03,   8.39515545e-03,
        -4.04548820e-03,  -1.47783583e-02,   2.76897069e-02,
         0.00000000e+00,  -9.29966567e-03,   0.00000000e+00,
        -8.47852569e-03,  -1.01239342e-02,  -3.21238979e-04,
         5.12886761e-04,   3.07494335e-03,   2.85789492e-02,
         0.00000000e+00,   5.02309815e-04,   0.00000000e+00,
        -6.08138128e-03,  -1.65085814e-03,   2.50280070e-03,
        -1.51458675e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.03155997e-02,   0.00000000e+00,
         1.57678503e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.62018003e-02,
        -2.41285893e-03,  -2.83603640e-03,   7.88951390e-04,
         0.00000000e+00,  -1.36970358e-02,   0.00000000e+00,
         1.68468995e-02,  -6.87753639e-03,   4.55261737e-03,
        -8.99484953e-03,   0.00000000e+00,   3.79146211e-02,
         2.87147500e-03,  -2.24107000e-03,   3.24892357e-03,
         0.00000000e+00,  -7.68978881e-03,   0.00000000e+00,
        -4.71379738e-03,  -1.59420622e-02,   1.42147947e-03,
        -6.11459066e-04,   0.00000000e+00,  -1.00299284e-02,
         6.12586146e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.09619399e-03,   0.00000000e+00,
         6.54431241e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.18059495e-03,
         0.00000000e+00,   0.00000000e+00,  -1.48610661e-02,
        -3.82475339e-03,  -8.66092491e-03,   7.14699683e-03,
         0.00000000e+00,  -2.84863354e-03,   0.00000000e+00,
         7.38779894e-03,  -6.44924548e-03,   4.68909426e-03,
         2.11901340e-05,   0.00000000e+00,  -1.67579369e-02,
         8.50427800e-03,   0.00000000e+00,  -1.40130870e-02,
        -1.01833252e-02,  -1.29279196e-02,   6.35816426e-03,
         0.00000000e+00,  -8.60979470e-03,   0.00000000e+00,
         5.93299145e-03,   4.47027713e-03,   1.78624659e-03,
        -1.96689532e-03,   0.00000000e+00,  -1.11536172e-02,
        -2.89371029e-02,   0.00000000e+00,  -1.06363418e-02,
        -3.08065261e-02,  -5.19970420e-03,   1.06224696e-02,
        -1.01013656e-02,   0.00000000e+00,   7.20146830e-04,
         0.00000000e+00,  -4.80666854e-03,   8.08678125e-03,
         2.17814461e-03,  -2.22169553e-03,   0.00000000e+00,
         1.50199513e-02,  -3.13301470e-02,   0.00000000e+00,
         6.25543773e-03,   3.91528426e-02,   3.09107666e-02,
         8.75783600e-03,   4.79577612e-03,  -1.41611084e-03,
         0.00000000e+00,  -4.39809078e-05,   0.00000000e+00,
        -2.87933213e-03,  -1.80611868e-02,   2.92695866e-03,
         2.39828915e-03,   0.00000000e+00,   7.87827218e-03,
         3.36383709e-03,   0.00000000e+00,   5.52328269e-02,
         4.92716481e-02,  -9.35132543e-03,   1.42924028e-02,
        -5.95889259e-02,   5.62626923e-03,  -1.21624855e-02,
         1.46929718e-02,   6.15138909e-03,  -2.83271047e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.91720139e-02,   7.62232312e-02,   3.33835549e-02,
        -1.00149870e-04,   0.00000000e+00,  -3.09604090e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.50247510e-03,   0.00000000e+00,  -7.54827159e-03,
         5.06839970e-02,   7.41937347e-02,  -1.20695532e-02,
         0.00000000e+00,   2.40145723e-02,   0.00000000e+00,
        -1.12127093e-02,  -3.71085320e-02,  -6.03903596e-02,
         1.78197455e-02,   0.00000000e+00,  -2.05199181e-02,
         0.00000000e+00,   1.56195942e-02,  -2.32425740e-02,
         1.36592129e-02,   1.30987379e-02,  -3.63740285e-03,
         0.00000000e+00,  -1.09281377e-03,   0.00000000e+00,
        -4.56740389e-03,   1.93667683e-05,  -2.30055124e-02,
        -3.75620790e-04,  -8.91686449e-03,   2.34830168e-03,
         0.00000000e+00,  -1.16784946e-02,   0.00000000e+00,
         9.77544345e-04,  -6.88293198e-03,  -7.35850595e-04,
        -2.78006398e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.86053124e-04,   0.00000000e+00,
        -7.59179868e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.64552935e-02,
        -8.58040759e-04,  -4.45757023e-03,   4.70524401e-04,
         0.00000000e+00,  -3.27473809e-03,   0.00000000e+00,
         3.53849192e-04,   1.15061961e-02,   6.91390098e-03,
        -5.59754544e-03,   0.00000000e+00,  -2.79864928e-02,
         1.00647034e-03,   7.90869380e-03,  -6.82145550e-03,
         0.00000000e+00,   1.37335552e-02,   0.00000000e+00,
         9.99070304e-03,   6.79446135e-03,  -5.45603692e-03,
        -3.84779457e-03,   0.00000000e+00,  -1.01861480e-03,
        -8.92975616e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.77330545e-03,   0.00000000e+00,
         2.19975898e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.33385230e-03,
         0.00000000e+00,   0.00000000e+00,  -3.97992066e-03,
        -1.01876461e-02,  -1.33254246e-02,   4.25621181e-04,
         0.00000000e+00,  -5.44915876e-03,   0.00000000e+00,
         5.14011622e-03,  -6.83427877e-03,   4.69265598e-03,
        -5.53664559e-03,   0.00000000e+00,  -1.12766537e-02,
        -9.59461942e-03,   0.00000000e+00,  -6.96308497e-03,
         9.65065917e-03,   1.54346158e-02,  -1.76976282e-03,
         0.00000000e+00,   1.13849541e-02,   0.00000000e+00,
         3.23181034e-03,   7.18821279e-03,  -5.38217828e-03,
         2.79087356e-03,   0.00000000e+00,   1.82700329e-02,
         1.53660931e-02,   0.00000000e+00,  -7.34979904e-03,
         1.38759339e-02,  -2.45146780e-03,  -1.19567160e-03,
        -5.25598633e-04,   0.00000000e+00,  -1.65940267e-03,
         0.00000000e+00,  -1.00996139e-02,  -5.49393783e-03,
        -1.05769641e-03,   3.79650735e-03,   0.00000000e+00,
         3.08728129e-02,  -6.49432109e-03,   0.00000000e+00,
         2.94680002e-02,  -4.14009889e-02,  -2.63682402e-02,
        -6.09149791e-04,  -1.39834724e-03,  -3.88751343e-03,
         0.00000000e+00,  -5.07349357e-03,   0.00000000e+00,
        -1.06138569e-02,   2.32610372e-02,  -6.80033392e-03,
         1.01672294e-02,   0.00000000e+00,   7.15410723e-03,
        -1.85443880e-02,   0.00000000e+00,   7.59474623e-02,
        -5.28429493e-02,   1.22434797e-02,  -3.69081775e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.55281672e-02,   3.18547177e-02,  -5.33285982e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.36679449e-03,   0.00000000e+00,
         8.89484411e-02,   1.10655058e-01,  -2.35449318e-02,
         0.00000000e+00,   3.28149208e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.77802506e-03,   0.00000000e+00,  -2.60535276e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.67190528e-03,   0.00000000e+00,
         1.86781394e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.95709145e-03,   0.00000000e+00,  -8.10540026e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.20425325e-03,   0.00000000e+00,   5.11546841e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.69987390e-03,  -1.04833930e-02,
         5.07162406e-03,   0.00000000e+00,  -9.17199867e-03,
         0.00000000e+00,   1.30769551e-03,   6.19314700e-03,
         7.14397791e-03,  -5.15178646e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.29204085e-03,   0.00000000e+00,   8.69239156e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.11489708e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.04726355e-04,   0.00000000e+00,   1.03866981e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.19723584e-02,   0.00000000e+00,
         0.00000000e+00,  -1.57361527e-02,  -2.18225857e-02,
         7.10922212e-03,   0.00000000e+00,  -1.18289107e-02,
         0.00000000e+00,   1.69723960e-03,  -1.19214362e-02,
         8.12318780e-03,  -5.17210111e-03,   0.00000000e+00,
        -1.23783003e-02,  -1.73130298e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.83237789e-04,   0.00000000e+00,   1.40499014e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.35693596e-03,   0.00000000e+00,
         0.00000000e+00,  -3.70641582e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.21177476e-03,   0.00000000e+00,   6.72382368e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.69275137e-03,   0.00000000e+00,
         0.00000000e+00,  -1.54514400e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.17237303e-04,   0.00000000e+00,
        -1.87991880e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.23207981e-02,
         0.00000000e+00,   0.00000000e+00,   4.25912372e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.88813728e-03,   0.00000000e+00,  -1.47969868e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.31110136e-02,   0.00000000e+00,
         0.00000000e+00,   1.16834928e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.57612091e-02,   5.25354077e-03,   9.59312484e-03,
         1.67799871e-02,   4.06222722e-02,  -7.56278772e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.35299603e-03,  -3.16478192e-03,   2.35586917e-02,
        -3.72550729e-04,   0.00000000e+00,   1.31665269e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.18876602e-03,   0.00000000e+00,   1.18046759e-02,
         6.78433793e-02,   5.44325474e-02,  -5.85905784e-03,
         0.00000000e+00,   2.81918104e-02,   0.00000000e+00,
         5.77309686e-03,   2.68357293e-02,   3.41755720e-02,
         3.47300783e-03,   0.00000000e+00,   9.76544102e-03,
         0.00000000e+00,   6.24025872e-03,   1.86115604e-02,
        -1.11084607e-02,  -7.92290068e-03,  -3.77161949e-03,
         0.00000000e+00,   6.01370788e-05,   0.00000000e+00,
        -3.03437828e-03,  -5.53686673e-04,   8.03978323e-03,
        -3.42576394e-03,  -4.73461670e-03,  -6.74925580e-03,
         0.00000000e+00,   8.48908917e-04,   0.00000000e+00,
         4.54379961e-03,   7.55067520e-03,   5.02714628e-03,
         1.70440724e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.26986598e-03,   0.00000000e+00,
        -1.45821425e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.10175364e-03,
        -5.52327856e-04,  -1.13070019e-02,   7.78644120e-03,
         0.00000000e+00,   1.26085001e-03,   0.00000000e+00,
         3.75442622e-03,  -2.81371468e-03,  -8.05288072e-04,
         1.28090203e-03,   0.00000000e+00,  -8.34064131e-03,
        -4.21626095e-05,   8.86864763e-03,  -6.05835833e-03,
         0.00000000e+00,   6.78384427e-03,   0.00000000e+00,
         7.37081637e-03,  -6.88544687e-04,  -1.60067111e-03,
        -1.56283634e-03,   0.00000000e+00,  -1.08290166e-03,
         8.54311955e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.40758537e-03,   0.00000000e+00,
        -6.97436730e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.78456738e-03,
         0.00000000e+00,   0.00000000e+00,   1.25921098e-02,
        -1.38959102e-02,  -1.42512746e-02,   1.93148357e-03,
         0.00000000e+00,  -6.52126520e-03,   0.00000000e+00,
        -4.75863873e-03,  -8.13926217e-03,   6.28534274e-03,
        -4.16048605e-03,   0.00000000e+00,   1.13286325e-04,
        -1.41322003e-02,   0.00000000e+00,   5.57124270e-03,
        -6.19946127e-03,  -8.74103807e-03,   7.16787239e-03,
         0.00000000e+00,  -1.02325482e-03,   0.00000000e+00,
         2.24083294e-03,  -1.05554876e-02,   6.41499207e-03,
        -1.08847306e-04,   0.00000000e+00,  -7.15987870e-03,
        -5.21442062e-03,   0.00000000e+00,  -1.39003874e-02,
         2.62536705e-03,   3.97536209e-04,  -3.79976204e-03,
         2.15296951e-03,   0.00000000e+00,  -2.77840849e-03,
         0.00000000e+00,  -1.73690142e-02,  -3.10316218e-03,
         4.72193504e-03,   6.38166590e-03,   0.00000000e+00,
        -1.07861513e-02,  -3.61901438e-03,   0.00000000e+00,
         2.96355961e-02,   1.45694391e-02,   1.13530564e-02,
        -4.06456653e-03,  -3.05722400e-03,  -2.66074685e-03,
         0.00000000e+00,  -4.12075487e-03,   0.00000000e+00,
        -1.30243730e-02,  -1.42409014e-02,   4.74172950e-03,
         5.95240672e-03,   0.00000000e+00,   1.87421536e-02,
        -1.82619018e-02,   0.00000000e+00,   6.54017574e-02,
         2.97328454e-02,   9.84578412e-03,   2.50597484e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.78069020e-02,  -3.98100172e-02,   1.28631098e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.97080902e-03,   0.00000000e+00,
        -3.15470598e-02,  -3.18764741e-03,   3.96278096e-04,
         0.00000000e+00,  -9.38296307e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.79074859e-03,   0.00000000e+00,   2.73760186e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.31193686e-02,   0.00000000e+00,
         6.62726140e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.74706213e-03,   0.00000000e+00,   3.09007294e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.47771552e-03,   0.00000000e+00,   3.50304575e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.03101306e-03,   9.26675313e-03,
        -3.96682533e-03,   0.00000000e+00,   1.74772560e-03,
         0.00000000e+00,   6.43224660e-04,   7.77148006e-03,
         8.44277385e-03,  -2.10454870e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.63705487e-03,   0.00000000e+00,  -7.46651893e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.68345329e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.51702327e-04,   0.00000000e+00,  -4.17760905e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.66672068e-03,   0.00000000e+00,
         0.00000000e+00,   8.40944632e-03,   8.52289038e-03,
         8.23312629e-05,   0.00000000e+00,  -1.09655441e-03,
         0.00000000e+00,   4.17406247e-04,   2.04090817e-03,
        -2.66558477e-03,   1.68879259e-03,   0.00000000e+00,
         4.81498658e-05,   1.74908923e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.36740102e-03,   0.00000000e+00,  -2.06790533e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.10481522e-03,   0.00000000e+00,
         0.00000000e+00,   1.13374941e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.98912192e-03,   0.00000000e+00,   2.66312235e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.13225709e-03,   0.00000000e+00,
         0.00000000e+00,   6.88787150e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.02307614e-03,   0.00000000e+00,
         9.07291088e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.59983322e-02,
         0.00000000e+00,   0.00000000e+00,  -1.35910333e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.01822144e-03,   0.00000000e+00,   1.05946527e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.68205150e-02,   0.00000000e+00,
         0.00000000e+00,  -1.49322013e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.60416289e-02,   7.03214767e-02,   1.59763858e-02,
        -8.48791505e-03,  -2.33809276e-03,  -2.97095339e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.19846732e-02,   1.37923792e-02,  -1.20389317e-02,
         1.06326944e-02,   0.00000000e+00,  -2.19700921e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.62163134e-02,   0.00000000e+00,   6.10504920e-02,
        -8.20841827e-03,   2.79062726e-03,   4.06525333e-02,
         0.00000000e+00,   3.65562750e-02,   0.00000000e+00,
         5.82211197e-02,   7.64493449e-02,   3.08133758e-02,
         1.20386041e-02,   0.00000000e+00,  -3.18581146e-02,
         0.00000000e+00,   9.68870312e-03,   4.30525309e-02,
        -1.47778574e-02,  -1.98957379e-02,  -1.68542646e-02,
         0.00000000e+00,   4.68697238e-03,   0.00000000e+00,
         4.12274268e-03,  -1.88488597e-02,  -6.05099591e-03,
         9.79149299e-03,  -6.12943011e-04,  -1.17532496e-02,
         0.00000000e+00,  -9.57317439e-03,   0.00000000e+00,
        -5.61620966e-04,   1.11940427e-03,  -1.10532271e-02,
        -1.25853264e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.44603530e-02,   0.00000000e+00,
        -2.41256277e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.04913603e-02,
        -5.02484187e-03,   6.28758060e-03,   2.51698845e-03,
         0.00000000e+00,   2.15483974e-02,   0.00000000e+00,
        -2.26747431e-02,   1.26939394e-02,   3.65167535e-03,
         1.04941954e-02,   0.00000000e+00,  -3.25563193e-02,
        -4.50079362e-03,   3.21936034e-03,  -2.28771457e-02,
         0.00000000e+00,   2.04533096e-02,   0.00000000e+00,
         1.29135590e-02,   1.17468775e-02,  -1.41763949e-02,
        -1.00258758e-02,   0.00000000e+00,  -2.64329956e-03,
        -3.31884114e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.09272419e-02,   0.00000000e+00,
        -4.11142915e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.23239490e-02,
         0.00000000e+00,   0.00000000e+00,   6.97444845e-02,
        -5.44723247e-04,   3.27964201e-03,  -1.87945627e-02,
         0.00000000e+00,  -1.25554031e-02,   0.00000000e+00,
        -3.80415417e-02,   1.29424593e-03,  -2.12839109e-03,
         7.74216058e-03,   0.00000000e+00,   2.04666783e-02,
        -2.40194404e-02,   0.00000000e+00,   6.29336922e-02,
        -1.17266345e-02,  -2.01353033e-02,  -2.11844369e-04,
         0.00000000e+00,   4.24719717e-03,   0.00000000e+00,
         5.84182931e-06,  -5.44518756e-02,   1.53635968e-02,
        -6.05685698e-03,   0.00000000e+00,   5.53996438e-03,
         4.37832095e-03,   0.00000000e+00,   2.07647905e-03,
         4.64545824e-02,   6.97150077e-03,  -3.05857917e-02,
         8.13405291e-03,   0.00000000e+00,  -1.35995939e-02,
         0.00000000e+00,  -6.32917626e-05,  -2.53305961e-02,
        -1.82871675e-03,  -6.32748028e-03,   0.00000000e+00,
         1.23679946e-02,   3.51235889e-03,   0.00000000e+00,
         7.69671113e-03,   2.16440822e-03,  -3.41088953e-02,
        -3.12966256e-02,  -2.60147228e-02,  -5.56763500e-04,
         0.00000000e+00,   3.75640772e-03,   0.00000000e+00,
         8.99756247e-04,  -3.31741166e-02,   1.53499112e-02,
        -6.24714398e-03,   0.00000000e+00,  -9.24783136e-03,
        -1.04517786e-02,   0.00000000e+00,  -6.05465119e-03,
         4.85413633e-02,   4.15754940e-02,   7.97058672e-02,
        -2.78802665e-02,  -8.47188734e-03,  -2.97258515e-02,
         9.85240024e-03,  -7.10428527e-03,  -6.57453075e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.87967741e-02,   5.43882932e-04,   2.99187879e-03,
        -1.92771571e-03,   0.00000000e+00,  -2.08913329e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.48219310e-03,   0.00000000e+00,  -3.35922137e-02,
        -2.09406853e-03,   2.15534506e-03,  -8.83215153e-03,
         0.00000000e+00,  -5.39015240e-03,   0.00000000e+00,
        -3.04278539e-02,  -1.47219442e-02,  -1.24421431e-02,
        -6.16837612e-03,   0.00000000e+00,   2.01761137e-03,
         0.00000000e+00,   2.49090311e-03,  -2.96819726e-02,
         1.28877972e-02,  -4.96839587e-03,  -3.49698680e-03,
         0.00000000e+00,   1.24801830e-03,   0.00000000e+00,
         1.28603749e-03,   8.09387417e-03,  -3.50677408e-03,
         3.99351572e-03,  -6.91182109e-03,  -8.52885853e-04,
         0.00000000e+00,   1.42303574e-03,   0.00000000e+00,
         3.76418626e-03,  -3.36775329e-03,  -6.44237526e-04,
        -4.01563918e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.84098172e-03,   0.00000000e+00,
         1.72000393e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.28129293e-02,
        -1.51788109e-03,  -1.48316057e-03,   4.14639463e-03,
         0.00000000e+00,   5.67832058e-03,   0.00000000e+00,
         9.17960561e-04,   3.63078554e-03,  -3.05929197e-05,
         1.16120921e-03,   0.00000000e+00,  -1.28435213e-02,
         1.94397038e-03,  -7.36906145e-03,  -5.55415881e-03,
         0.00000000e+00,  -1.22108646e-03,   0.00000000e+00,
        -3.07211919e-03,  -1.47857516e-03,  -6.03626231e-03,
        -1.64394068e-03,   0.00000000e+00,  -2.60387588e-03,
        -8.45137195e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.38945211e-03,   0.00000000e+00,
         1.77915492e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.37994545e-03,
         0.00000000e+00,   0.00000000e+00,  -3.02435613e-02,
        -2.66860153e-04,   3.14292676e-06,   5.30939895e-03,
         0.00000000e+00,   3.88608515e-03,   0.00000000e+00,
         1.72692222e-02,   4.26510862e-05,  -4.42569303e-04,
        -4.27876350e-03,   0.00000000e+00,  -5.47585625e-03,
         6.66437350e-03,   0.00000000e+00,  -2.65608932e-02,
         5.38742854e-03,   2.65056229e-03,   1.42529695e-03,
         0.00000000e+00,  -5.95832481e-03,   0.00000000e+00,
         1.95064569e-03,   1.71080018e-02,  -5.96610174e-03,
         1.50882419e-03,   0.00000000e+00,   2.06016408e-03,
        -1.82903856e-03,   0.00000000e+00,   3.88367136e-04,
        -2.70072386e-02,   8.83358446e-03,  -4.63648920e-04,
        -4.99061259e-03,   0.00000000e+00,   4.17897583e-03,
         0.00000000e+00,   2.76044318e-03,   1.03222061e-03,
        -8.54681045e-03,  -3.17070563e-03,   0.00000000e+00,
         2.13927960e-03,  -9.22746265e-03,   0.00000000e+00,
        -2.62395681e-03,  -3.21276894e-03,  -1.80682146e-02,
         9.60451574e-03,   1.32232557e-02,  -8.93259834e-04,
         0.00000000e+00,  -2.17571014e-04,   0.00000000e+00,
         4.11892850e-04,   1.12013344e-02,  -2.75124489e-03,
         3.44264230e-03,   0.00000000e+00,   1.25393405e-03,
         5.66442520e-03,   0.00000000e+00,   1.89704542e-03,
        -1.21048711e-02,  -7.42004311e-03,  -3.44999018e-02,
        -7.82306167e-04,   1.25513203e-02,   4.55078868e-04,
         1.54944640e-03,  -4.88282315e-03,   7.38881119e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.03936956e-02,   4.04768184e-03,  -1.70843854e-03,
        -8.85425236e-04,   0.00000000e+00,  -9.24802490e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.07805036e-02,   0.00000000e+00,   7.97028001e-03,
        -6.83465837e-03,  -4.25182901e-03,   4.09801673e-03,
         0.00000000e+00,   4.87534298e-03,   0.00000000e+00,
         9.95681841e-03,   9.14840577e-03,  -6.67172698e-04,
        -1.35863586e-03,   0.00000000e+00,  -8.25813611e-03,
         0.00000000e+00,   4.95380022e-03,   7.21417040e-03,
         4.23622097e-03,  -8.22701203e-03,  -5.16784480e-03,
         0.00000000e+00,   2.45099876e-03,   0.00000000e+00,
         2.17545671e-03,  -2.25588559e-03,   4.39596511e-03,
         1.07173079e-02,  -9.16045014e-03,  -1.05667012e-02,
         0.00000000e+00,  -1.01210243e-03,   0.00000000e+00,
         3.28696392e-03,   1.68703101e-03,   6.25823068e-03,
         2.06454687e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.86334720e-03,   0.00000000e+00,
        -5.36329531e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.17440391e-02,
         7.17141070e-04,   2.41969324e-03,  -1.43484246e-03,
         0.00000000e+00,   3.85942968e-03,   0.00000000e+00,
        -5.19233356e-03,   4.31606162e-03,   1.82039665e-03,
         3.60420743e-03,   0.00000000e+00,  -9.07662775e-03,
         1.55353590e-04,  -3.53660658e-03,  -4.98597264e-03,
         0.00000000e+00,   2.88259296e-03,   0.00000000e+00,
         1.54877125e-03,   1.64707061e-04,  -4.27490295e-03,
        -1.27672211e-03,   0.00000000e+00,  -3.39955584e-03,
        -2.36053095e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.33761830e-03,   0.00000000e+00,
        -8.17396203e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.95801549e-03,
         0.00000000e+00,   0.00000000e+00,   1.02572364e-02,
         4.27676152e-03,   5.42095193e-03,  -3.30521606e-03,
         0.00000000e+00,  -2.68428566e-03,   0.00000000e+00,
        -8.11795165e-03,   7.52436205e-04,  -1.55285014e-03,
        -1.70142602e-03,   0.00000000e+00,   2.49112174e-03,
        -1.34921332e-03,   0.00000000e+00,   1.07891750e-02,
        -1.27204282e-03,  -2.14278296e-03,  -1.45748260e-03,
         0.00000000e+00,   1.47894498e-03,   0.00000000e+00,
         4.62777859e-04,  -9.27279933e-03,   2.01407363e-03,
         6.00034866e-05,   0.00000000e+00,   4.49738289e-03,
        -5.21277187e-04,   0.00000000e+00,   2.55106234e-03,
         1.04296610e-02,   1.53589822e-03,  -6.64534287e-03,
        -1.17521168e-03,   0.00000000e+00,  -2.81980422e-04,
         0.00000000e+00,   4.16491522e-03,  -4.48873003e-03,
        -4.94231284e-03,  -2.51508915e-03,   0.00000000e+00,
         5.16936703e-03,  -5.69129239e-03,   0.00000000e+00,
        -1.71001480e-03,  -2.49614028e-03,  -1.07065348e-02,
        -6.37322945e-03,  -5.31309331e-03,   2.20982083e-03,
         0.00000000e+00,   1.47250492e-03,   0.00000000e+00,
         6.30353872e-03,  -4.19547623e-03,   3.49550559e-03,
         3.27477873e-04,   0.00000000e+00,  -3.52232482e-03,
         1.27931568e-03,   0.00000000e+00,  -4.45494883e-03,
         3.84889274e-03,   7.37991662e-03,   1.02062606e-02,
         5.79518241e-03,   1.78652272e-03,   5.54559854e-03,
        -1.91699661e-03,  -2.03508832e-03,   5.02799606e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.30173176e-03,  -3.76841072e-03,   3.03278225e-03,
        -3.53067865e-03,   0.00000000e+00,   1.22806396e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.54764153e-03,   0.00000000e+00,   7.82560676e-03,
        -3.17763895e-03,  -9.62849330e-03,   5.86772208e-03,
         0.00000000e+00,  -1.92850652e-03,   0.00000000e+00,
         8.14461600e-03,  -4.52093440e-03,   1.20355677e-03,
         2.32245115e-03,   0.00000000e+00,   2.28919848e-03,
         0.00000000e+00,  -5.55506648e-05,   6.86167894e-03,
        -1.82292905e-03,   2.69413414e-03,   4.90402408e-03,
         0.00000000e+00,   1.89672950e-03,   0.00000000e+00,
        -1.64092205e-03,  -1.29549488e-03,  -3.15413143e-03,
         1.62682038e-04,   4.09003322e-03,   1.05273797e-03,
         0.00000000e+00,  -4.26806722e-04,   0.00000000e+00,
        -2.94162617e-03,   1.94320752e-03,   1.77979251e-03,
        -3.61340597e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.09431071e-03,   0.00000000e+00,
        -6.86905367e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.97092968e-03,
         1.32702338e-02,  -4.79849338e-03,   6.99059959e-05,
         0.00000000e+00,  -3.05426117e-03,   0.00000000e+00,
        -3.46998486e-03,  -3.03793681e-03,   1.36236970e-03,
        -3.02413469e-03,   0.00000000e+00,   1.24776651e-03,
        -4.72776507e-03,   8.47077227e-04,  -2.44626518e-03,
         0.00000000e+00,  -1.79848336e-03,   0.00000000e+00,
        -1.42345022e-04,  -1.21484350e-03,   1.12342001e-04,
        -1.42181511e-03,   0.00000000e+00,  -3.01158003e-04,
         9.52989445e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.40893531e-03,   0.00000000e+00,
        -6.42255235e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.69163062e-04,
         0.00000000e+00,   0.00000000e+00,   7.01507661e-03,
         8.35316053e-03,   1.07515865e-02,  -5.26672455e-03,
         0.00000000e+00,  -1.31883752e-03,   0.00000000e+00,
        -5.44723011e-03,   2.04927416e-03,  -9.54348147e-04,
         9.90589463e-04,   0.00000000e+00,   1.32136614e-03,
         8.83685412e-04,   0.00000000e+00,   7.65568423e-03,
        -4.98194091e-04,   4.01900369e-03,   2.11018043e-04,
         0.00000000e+00,   5.60981062e-03,   0.00000000e+00,
        -2.39747619e-03,  -4.24409300e-03,   2.43700186e-03,
         2.13674453e-03,   0.00000000e+00,   1.35859820e-03,
        -1.95237768e-03,   0.00000000e+00,   4.04501363e-03,
         6.89074219e-03,  -7.08061760e-03,   2.52530319e-03,
         9.36132245e-03,   0.00000000e+00,   1.01548555e-02,
         0.00000000e+00,  -6.62990539e-04,   6.04544439e-03,
         2.98857776e-03,   4.15836759e-03,   0.00000000e+00,
        -3.35671753e-03,  -5.01767710e-04,   0.00000000e+00,
        -2.16486733e-03,  -4.10738004e-04,   1.97855003e-03,
        -1.60611628e-03,  -4.98394164e-03,   3.41143963e-03,
         0.00000000e+00,   1.55854977e-04,   0.00000000e+00,
         1.49760017e-02,  -6.97239246e-04,  -3.84378784e-04,
        -2.76008746e-03,   0.00000000e+00,  -1.13149939e-03,
         1.72122448e-03,   0.00000000e+00,  -4.89673324e-03,
        -2.64091216e-03,   1.92731288e-03,   5.77309823e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.95671897e-03,  -6.19579564e-03,   1.87391280e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.34468923e-03,   0.00000000e+00,
         2.28209037e-04,   1.12805859e-02,  -3.82619044e-03,
         0.00000000e+00,   3.68701073e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.28398084e-03,   0.00000000e+00,   1.18316197e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.97640948e-03,   0.00000000e+00,
         1.54049454e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.01462629e-03,   0.00000000e+00,   1.32455578e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.52040193e-04,   0.00000000e+00,   1.38103698e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.44172825e-02,   8.55342946e-03,
        -3.54778318e-03,   0.00000000e+00,   7.59779257e-04,
         0.00000000e+00,   7.76832997e-04,   4.18776338e-03,
         2.04804619e-04,   3.84471920e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.60101463e-04,   0.00000000e+00,   2.25383986e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.13134082e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.71648223e-03,   0.00000000e+00,   1.32157997e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.12207836e-04,   0.00000000e+00,
         0.00000000e+00,  -6.96819648e-03,  -9.86768162e-03,
         1.72369112e-03,   0.00000000e+00,  -1.84757576e-03,
         0.00000000e+00,   6.54867462e-05,  -2.78543304e-03,
         7.38238723e-04,  -6.82334457e-04,   0.00000000e+00,
        -9.13027498e-05,  -4.82598388e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.37803882e-03,   0.00000000e+00,  -5.46473717e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.52511422e-03,   0.00000000e+00,
         0.00000000e+00,   8.99763891e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.25486697e-03,   0.00000000e+00,   2.52845964e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.63425458e-04,   0.00000000e+00,
         0.00000000e+00,  -4.14742489e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.76064002e-02,   0.00000000e+00,
         2.32989910e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.31310647e-03,
         0.00000000e+00,   0.00000000e+00,   1.30402005e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.85509567e-04,   0.00000000e+00,  -1.33211462e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.13061766e-06,   0.00000000e+00,
         0.00000000e+00,   4.94229062e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.31829235e-02,   6.35930908e-03,   2.09020649e-02,
         3.13802551e-03,  -5.23589583e-03,   1.67070039e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.74928226e-02,  -3.47659291e-03,   1.12864464e-02,
        -3.07239071e-03,   0.00000000e+00,   2.55095478e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.32264067e-03,   0.00000000e+00,   3.02988720e-02,
         3.20033455e-03,   2.78607218e-03,   3.76578428e-03,
         0.00000000e+00,   6.17542968e-03,   0.00000000e+00,
         2.82041962e-02,  -6.26037210e-03,   1.83117331e-03,
        -2.73703015e-03,   0.00000000e+00,   2.02201134e-03,
         0.00000000e+00,  -8.70434237e-04,   2.66342598e-02,
         6.55300400e-04,  -2.09166187e-03,   5.43438318e-04,
         0.00000000e+00,   9.23819986e-04,   0.00000000e+00,
        -1.32432157e-03,  -4.85693132e-03,   7.53468057e-03,
        -3.97739295e-04,  -7.43375238e-04,   1.20653241e-04,
         0.00000000e+00,   5.12842986e-04,   0.00000000e+00,
        -3.71177435e-03,   1.49680839e-03,   1.80077816e-03,
         1.03989386e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.25205457e-02,   0.00000000e+00,
        -2.93954526e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.37091920e-02,
         3.62958467e-03,  -1.13420682e-03,  -5.54345632e-03,
         0.00000000e+00,  -7.40852506e-03,   0.00000000e+00,
         1.60147565e-04,  -5.53761609e-03,  -1.28282385e-03,
        -2.96835851e-03,   0.00000000e+00,   1.56742570e-02,
         1.53324681e-02,  -2.09283775e-03,   1.44029615e-02,
         0.00000000e+00,  -6.13938607e-04,   0.00000000e+00,
         4.51584897e-03,  -7.10377889e-03,   5.95149899e-03,
         1.80000205e-03,   0.00000000e+00,   4.04142615e-03,
         1.35101472e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.39209975e-03,   0.00000000e+00,
        -2.09685366e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.56257903e-03,
         0.00000000e+00,   0.00000000e+00,   2.64251795e-02,
        -2.32939934e-03,  -6.05406079e-03,  -1.87706838e-03,
         0.00000000e+00,  -7.85058993e-03,   0.00000000e+00,
        -1.96883015e-02,  -3.52486917e-03,   2.29526495e-03,
         3.41158451e-03,   0.00000000e+00,   4.31573419e-03,
        -3.23819185e-03,   0.00000000e+00,   2.44029916e-02,
        -6.88517435e-04,   8.19213860e-03,  -8.81484761e-03,
         0.00000000e+00,   1.27529695e-02,   0.00000000e+00,
        -8.36075340e-04,  -1.57626575e-02,   3.39828859e-03,
        -1.60065477e-03,   0.00000000e+00,  -1.48334371e-03,
         6.53812869e-04,   0.00000000e+00,  -2.18137355e-03,
         2.70038670e-02,  -1.30645976e-02,  -3.73949551e-03,
        -9.74326481e-03,   0.00000000e+00,   2.99107939e-03,
         0.00000000e+00,  -3.99574582e-03,   9.12186684e-03,
        -3.62859581e-03,  -1.31167923e-03,   0.00000000e+00,
        -4.17779272e-03,  -7.48573275e-03,   0.00000000e+00,
         1.69294819e-03,   6.47691644e-05,   1.76320001e-02,
        -7.75375928e-03,  -1.36558196e-02,   3.74278138e-03,
         0.00000000e+00,  -9.93324844e-03,   0.00000000e+00,
        -7.13727376e-03,  -3.76637650e-03,   2.91343448e-03,
         2.54428083e-04,   0.00000000e+00,   1.39668855e-03,
        -5.51621763e-04,   0.00000000e+00,   2.13613963e-03,
        -5.17196472e-03,   5.35784818e-03,   2.45980642e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.52951707e-04,  -1.27196446e-02,   4.84222560e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.68558073e-03,   0.00000000e+00,
        -2.03418295e-02,  -1.87254900e-02,   3.55763458e-03,
         0.00000000e+00,  -6.51505938e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.65136484e-04,   0.00000000e+00,   8.37687631e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.98668763e-03,   0.00000000e+00,
        -4.63283535e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.95609890e-03,   0.00000000e+00,   3.91987675e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.39497791e-03,   0.00000000e+00,  -1.73326515e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.93845559e-03,   7.75040940e-03,
        -1.07969213e-03,   0.00000000e+00,   7.60263917e-04,
         0.00000000e+00,   1.23588296e-04,   3.01071146e-03,
         1.09152684e-03,  -3.08072031e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.46004802e-03,   0.00000000e+00,  -4.21204474e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.10991005e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.97019690e-03,   0.00000000e+00,  -6.53445951e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.51776381e-03,   0.00000000e+00,
         0.00000000e+00,   2.92683031e-02,   3.04146383e-02,
        -5.94203736e-03,   0.00000000e+00,   9.03255231e-03,
         0.00000000e+00,  -9.21301918e-04,   4.58799891e-03,
        -2.20607779e-03,   9.60101744e-04,   0.00000000e+00,
         1.97070822e-03,   2.96072612e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.13342498e-04,   0.00000000e+00,  -1.77091548e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.19666274e-04,   0.00000000e+00,
         0.00000000e+00,   8.03628856e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.36923539e-03,   0.00000000e+00,  -5.27711441e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.64279442e-03,   0.00000000e+00,
         0.00000000e+00,   1.06317275e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.13401904e-03,   0.00000000e+00,
         1.79589678e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.46265055e-03,
         0.00000000e+00,   0.00000000e+00,  -9.39193371e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.77936784e-02,   0.00000000e+00,   4.04120790e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.10823545e-03,   0.00000000e+00,
         0.00000000e+00,  -1.86200973e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.56883871e-03,   2.15696928e-03,   6.95390170e-03,
        -6.63002002e-04,  -1.03707295e-02,   1.19423842e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.63241987e-03,  -3.89902769e-03,  -5.93766071e-03,
        -2.37753768e-03,   0.00000000e+00,   3.65638658e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.56979672e-04,   0.00000000e+00,   9.56837814e-03,
        -1.77471840e-02,  -1.64795463e-02,   5.06641616e-03,
         0.00000000e+00,  -5.04321061e-03,   0.00000000e+00,
         1.01146160e-02,  -2.25688986e-03,  -1.44604229e-03,
        -2.48025568e-03,   0.00000000e+00,  -2.64774312e-03,
         0.00000000e+00,  -5.50002657e-03,   6.28239962e-03,
         5.40084848e-04,   9.46407634e-04,   5.45699314e-03,
         0.00000000e+00,   6.06790327e-04,   0.00000000e+00,
         2.92476026e-03,  -3.18104911e-03,  -1.52635902e-03,
         4.16964156e-03,   4.57410939e-03,   1.98839463e-03,
         0.00000000e+00,  -1.15714297e-03,   0.00000000e+00,
        -4.44589858e-03,   3.61753463e-04,   8.01733927e-04,
        -3.37651192e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.15916766e-03,   0.00000000e+00,
         8.17212379e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.33254078e-03,
         6.77650196e-03,   7.98770851e-03,  -5.25370641e-03,
         0.00000000e+00,  -3.70616257e-03,   0.00000000e+00,
        -3.33963682e-03,   5.38975169e-05,   1.06532334e-03,
        -1.18410993e-03,   0.00000000e+00,   5.78533513e-03,
        -4.95307304e-03,  -6.38361008e-03,   8.02538636e-04,
         0.00000000e+00,  -4.00969230e-03,   0.00000000e+00,
        -5.31490157e-03,  -4.40580181e-03,   2.10911899e-03,
         2.74810990e-04,   0.00000000e+00,  -6.57339138e-04,
         9.22749652e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.64146670e-03,   0.00000000e+00,
        -5.76331026e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.02594868e-04,
         0.00000000e+00,   0.00000000e+00,   7.97389390e-03,
         2.68762711e-02,   2.75898682e-02,  -7.40215234e-03,
         0.00000000e+00,   6.99276553e-03,   0.00000000e+00,
        -7.91420699e-03,   3.46310556e-03,  -9.69589320e-04,
         2.46095385e-03,   0.00000000e+00,   2.67546423e-03,
         2.38359915e-03,   0.00000000e+00,   8.97315517e-03,
         2.70717713e-03,   4.87401681e-03,  -3.38279299e-03,
         0.00000000e+00,   2.57965688e-03,   0.00000000e+00,
        -5.62897628e-03,  -5.00102900e-03,   1.44828934e-03,
         8.67216278e-04,   0.00000000e+00,   2.57989055e-03,
        -3.48334090e-03,   0.00000000e+00,  -6.73761214e-04,
         8.53631792e-03,  -1.80569998e-03,   2.51877220e-03,
         3.83548701e-03,   0.00000000e+00,   5.06153562e-03,
         0.00000000e+00,   1.61150390e-02,   3.83131283e-03,
        -2.77489451e-05,  -1.83062015e-03,   0.00000000e+00,
         1.29298845e-03,  -1.45057302e-03,   0.00000000e+00,
        -8.86609475e-03,  -1.23434637e-03,   4.23771385e-03,
        -2.08049176e-03,  -3.97525324e-03,   1.57075913e-02,
         0.00000000e+00,   1.07392552e-02,   0.00000000e+00,
         3.73954786e-02,   3.29004500e-03,  -1.19106139e-03,
        -3.56252620e-03,   0.00000000e+00,  -6.36377933e-03,
         5.07787491e-03,   0.00000000e+00,  -1.60884997e-02,
        -2.67462996e-03,   2.81318409e-04,   7.56374227e-03,
         9.36230322e-03,   5.29264873e-03,   1.11239657e-02,
        -1.64873971e-03,  -3.84366607e-03,   8.46825065e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.87752633e-03,   3.98742267e-03,   1.10498303e-02,
        -3.04200332e-03,   0.00000000e+00,   1.45358102e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.89977959e-03,   0.00000000e+00,   1.62182122e-02,
         1.56100532e-03,   8.65352527e-04,   5.80264997e-03,
         0.00000000e+00,   4.90670010e-03,   0.00000000e+00,
         1.57723909e-02,  -1.32015439e-02,  -1.76268915e-02,
         5.07827259e-03,   0.00000000e+00,  -8.07192333e-03,
         0.00000000e+00,   2.33489617e-03,   2.13303701e-03,
         5.43753187e-03,   3.11176887e-03,  -2.23739340e-03,
         0.00000000e+00,   8.64252659e-04,   0.00000000e+00,
         5.78486739e-05,   2.21695402e-03,   4.23360436e-03,
        -1.48162969e-03,  -2.36950162e-03,  -1.26162315e-03,
         0.00000000e+00,   2.75539797e-04,   0.00000000e+00,
         5.32667186e-05,  -1.48694341e-03,   3.79638467e-04,
         6.84162131e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.72255751e-03,   0.00000000e+00,
        -4.61541698e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.04201758e-03,
        -2.56865987e-03,   2.70245364e-03,   1.72198246e-03,
         0.00000000e+00,   7.79607418e-03,   0.00000000e+00,
        -4.20308379e-03,  -2.46078964e-03,   1.08745570e-03,
         3.78680905e-03,   0.00000000e+00,   4.49570482e-03,
        -8.65262135e-04,   4.01926116e-03,  -8.54969002e-03,
         0.00000000e+00,   6.72791742e-03,   0.00000000e+00,
         2.98903150e-03,  -4.10836428e-03,  -2.24823295e-03,
        -2.90158059e-03,   0.00000000e+00,  -2.04870976e-03,
         5.91326078e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.10288686e-03,   0.00000000e+00,
        -9.09806558e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.46120449e-03,
         0.00000000e+00,   0.00000000e+00,   1.46904058e-02,
        -3.31845212e-03,  -1.75826952e-03,  -3.26893280e-03,
         0.00000000e+00,  -2.69859595e-03,   0.00000000e+00,
        -8.21184543e-03,  -1.80337775e-03,   1.80868713e-04,
         1.49815848e-03,   0.00000000e+00,   4.08898067e-03,
        -4.39975705e-03,   0.00000000e+00,   1.27736650e-02,
         2.96446222e-02,   2.85692668e-02,  -6.72676123e-03,
         0.00000000e+00,   1.19821367e-02,   0.00000000e+00,
        -4.24812999e-04,  -1.36815051e-02,   2.64874975e-03,
         2.87819797e-04,   0.00000000e+00,  -1.51561363e-04,
         9.44890138e-04,   0.00000000e+00,   7.81420878e-04,
         1.54821475e-02,   5.86334058e-03,  -8.89277931e-03,
         5.25325984e-03,   0.00000000e+00,  -1.32995443e-02,
         0.00000000e+00,  -8.81064103e-04,   1.17461031e-02,
        -3.43776160e-03,  -8.45067824e-04,   0.00000000e+00,
        -2.37680292e-03,  -2.51309226e-03,   0.00000000e+00,
         8.73711937e-04,  -6.81053585e-03,   5.89703360e-03,
         4.15855269e-03,  -1.25568529e-04,   5.15392756e-03,
         0.00000000e+00,  -1.51816163e-02,   0.00000000e+00,
        -2.30943162e-03,   3.27103609e-02,  -8.48506679e-03,
         2.34042072e-03,   0.00000000e+00,  -1.33180630e-03,
        -3.60949576e-03,   0.00000000e+00,   1.34053886e-03,
        -2.50985780e-02,   4.00210319e-03,   8.86529463e-03,
        -5.80176274e-02,  -1.39344597e-02,  -6.22921332e-02,
        -1.29303347e-03,   7.45347691e-03,  -4.75516387e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.10665096e-02,  -2.72768906e-03,  -8.59411742e-03,
         1.05894788e-03,   0.00000000e+00,  -5.52680900e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.78382125e-03,   0.00000000e+00,  -7.63300707e-02,
        -3.84499378e-04,  -9.65066965e-04,  -9.55394440e-03,
         0.00000000e+00,  -7.30392884e-03,   0.00000000e+00,
        -7.38243228e-02,  -5.44984883e-04,  -1.15635285e-02,
        -3.94285542e-03,   0.00000000e+00,   9.67134407e-04,
         0.00000000e+00,  -4.13817287e-04,  -6.97364031e-02,
         1.10533960e-02,  -6.44829212e-03,  -1.40790375e-02,
         0.00000000e+00,   1.82059127e-03,   0.00000000e+00,
         6.06039497e-03,   1.78427892e-02,  -1.63641181e-02,
         1.00118421e-03,  -7.10499687e-03,  -8.88125510e-03,
         0.00000000e+00,   1.14600708e-03,   0.00000000e+00,
         1.35162611e-02,  -5.90534750e-03,  -8.14047617e-03,
        -1.06709225e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.21570022e-02,   0.00000000e+00,
        -5.88599952e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.16711820e-02,
        -9.54531273e-03,  -5.35185670e-03,   1.81209775e-02,
         0.00000000e+00,   3.08490923e-02,   0.00000000e+00,
        -4.04627511e-03,   1.47725810e-02,   8.86801856e-05,
         7.42237591e-03,   0.00000000e+00,  -4.20831348e-02,
        -9.07524670e-03,  -1.22130899e-02,  -3.01303323e-02,
         0.00000000e+00,   5.79132686e-03,   0.00000000e+00,
        -7.60506477e-03,   1.16192040e-02,  -1.68052501e-02,
        -8.26195189e-03,   0.00000000e+00,   1.02361330e-03,
        -4.53576791e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.73374008e-02,   0.00000000e+00,
         5.47111681e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.38951133e-03,
         0.00000000e+00,   0.00000000e+00,  -6.86015302e-02,
        -3.34638128e-03,   2.02622855e-03,   9.89923473e-03,
         0.00000000e+00,   1.59565815e-02,   0.00000000e+00,
         5.11125413e-02,   3.07712376e-03,  -2.53555335e-03,
        -1.03303946e-02,   0.00000000e+00,  -7.58541903e-03,
         7.61493261e-03,   0.00000000e+00,  -6.60641750e-02,
         9.89521802e-03,  -1.01648591e-02,   1.38467094e-02,
         0.00000000e+00,  -2.81237753e-02,   0.00000000e+00,
         3.29303497e-03,   4.22843371e-02,  -1.22399013e-02,
         2.35821650e-03,   0.00000000e+00,  -1.84854499e-04,
         4.70803841e-04,   0.00000000e+00,  -1.68549410e-03,
        -7.44999706e-02,   4.01191931e-02,  -8.05394627e-03,
         1.09893247e-03,   0.00000000e+00,   3.02087645e-03,
         0.00000000e+00,   4.83381512e-03,  -1.10779692e-02,
        -9.69474752e-03,  -6.57505409e-03,   0.00000000e+00,
        -3.77370023e-04,   5.02912721e-03,   0.00000000e+00,
        -1.01245308e-03,  -7.40862418e-04,  -4.74830951e-02,
         2.44099823e-02,   4.09327287e-02,  -6.76077346e-03,
         0.00000000e+00,   1.02099435e-02,   0.00000000e+00,
         6.51953114e-04,   1.95978910e-02,  -5.45492162e-03,
         5.24048719e-03,   0.00000000e+00,   4.75681481e-03,
         5.51388080e-03,   0.00000000e+00,  -8.87812982e-04,
        -2.21761805e-03,  -1.33646266e-02,  -6.88936329e-02,
        -5.57346959e-02,  -6.93151342e-02,  -6.61729264e-02,
         1.39806867e-02,   1.60413979e-02,  -1.21620036e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.37311669e-02,  -1.59816093e-02,  -2.74854457e-02,
        -1.48082669e-03,   0.00000000e+00,  -3.06522780e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.50474430e-02,   0.00000000e+00,  -1.16231097e-01,
         3.44542962e-03,   3.49866054e-03,  -4.31531182e-02,
         0.00000000e+00,  -4.06012885e-02,   0.00000000e+00,
        -1.09127834e-01,  -2.92372955e-02,  -6.13681025e-03,
        -2.23843212e-02,   0.00000000e+00,   4.55715459e-02,
         0.00000000e+00,  -8.67844170e-03,  -1.08367708e-01,
         1.03798587e-02,   9.47751927e-03,   9.05278721e-03,
         0.00000000e+00,  -1.16384453e-02,   0.00000000e+00,
         1.63304398e-03,   3.11640603e-02,  -5.99217918e-03,
        -6.38103955e-03,  -3.22761540e-03,   8.17629452e-03,
         0.00000000e+00,   7.45222686e-03,   0.00000000e+00,
         1.43596430e-02,  -7.27710273e-03,   4.60126268e-03,
        -5.73091076e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.51383860e-05,   0.00000000e+00,
         3.05858456e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.59227945e-03,
        -4.89866613e-03,  -7.98158499e-03,   7.53687055e-03,
         0.00000000e+00,  -3.79254661e-03,   0.00000000e+00,
         3.04871600e-02,  -1.09453246e-03,  -2.44739464e-04,
        -6.45788490e-03,   0.00000000e+00,   2.79514302e-03,
        -7.52815543e-03,  -1.05132045e-02,   2.26116514e-03,
         0.00000000e+00,  -1.93772897e-02,   0.00000000e+00,
        -2.74855013e-02,  -1.55022151e-03,   5.29629762e-03,
         6.46705163e-03,   0.00000000e+00,   5.55127027e-03,
         1.56518895e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.85594696e-02,   0.00000000e+00,
         1.07726188e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.70989652e-02,
         0.00000000e+00,   0.00000000e+00,  -1.26153661e-01,
        -3.43238921e-03,  -3.83680276e-03,   3.85994680e-02,
         0.00000000e+00,   3.46425178e-02,   0.00000000e+00,
         9.99407707e-02,   3.05091818e-03,  -8.63836453e-04,
        -1.52045678e-02,   0.00000000e+00,  -2.82288069e-02,
         2.90538381e-02,   0.00000000e+00,  -1.16344671e-01,
         7.67889130e-03,  -7.76085420e-03,   1.96118449e-02,
         0.00000000e+00,  -4.00812749e-02,   0.00000000e+00,
         5.05316991e-03,   1.01943845e-01,  -2.74065432e-02,
         7.37001619e-03,   0.00000000e+00,  -1.11435378e-02,
        -1.50600209e-02,   0.00000000e+00,  -3.26199629e-03,
        -1.46922458e-01,   2.02438233e-02,   3.88434857e-02,
        -5.22121272e-03,   0.00000000e+00,   1.48903192e-02,
         0.00000000e+00,   6.24537789e-03,   1.08792963e-02,
        -2.32900874e-03,   2.75429743e-03,   0.00000000e+00,
         4.35991435e-03,   9.89561803e-03,   0.00000000e+00,
        -9.08476668e-03,   1.65628587e-02,  -1.27544546e-02,
         7.38205861e-02,   7.15476877e-02,  -1.19591893e-02,
         0.00000000e+00,   1.52081237e-02,   0.00000000e+00,
        -2.90634767e-03,   3.59682810e-02,  -1.55574672e-02,
         6.88334111e-03,   0.00000000e+00,   9.41808396e-03,
         1.42461149e-02,   0.00000000e+00,   5.45701523e-03,
        -1.19047542e-02,  -4.81441100e-02,  -1.20996022e-01,
         7.91531247e-03,  -1.49207054e-01,  -1.00088383e-02,
         1.72283196e-02,   4.74507966e-02,   8.02284255e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.01760624e-02,  -4.17168348e-02,  -6.76269296e-02,
         1.50673797e-03,   0.00000000e+00,   4.19607410e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.23942507e-01,   0.00000000e+00,  -1.21828908e-01,
         9.15936745e-03,  -2.95532501e-04,  -9.50246629e-02,
         0.00000000e+00,  -8.58591255e-02,   0.00000000e+00,
        -1.09883052e-01,  -2.95858951e-02,   3.24942871e-02,
        -4.78250439e-02,   0.00000000e+00,   1.03374819e-01,
         0.00000000e+00,  -2.42744603e-02,  -8.67724149e-02,
        -5.50117505e-03,   1.76385882e-02,   3.22261438e-02,
         0.00000000e+00,  -2.67710943e-02,   0.00000000e+00,
         1.34219241e-03,   4.06738012e-02,   5.88850002e-02,
        -8.33123100e-03,   1.11217915e-03,   7.41878374e-03,
         0.00000000e+00,   1.18895574e-02,   0.00000000e+00,
         1.40524238e-02,   2.73866006e-03,   3.31600430e-02,
         9.25679651e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.81700063e-02,   0.00000000e+00,
         4.82615578e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.09818105e-01,
        -1.10105211e-03,  -4.64487762e-03,  -9.13434957e-03,
         0.00000000e+00,  -3.08998177e-02,   0.00000000e+00,
         4.46903624e-02,  -1.79743525e-02,   5.07855844e-04,
        -1.72353678e-02,   0.00000000e+00,   1.03189478e-01,
        -1.47657046e-03,  -2.89655102e-03,   3.26187624e-02,
         0.00000000e+00,  -2.81386043e-02,   0.00000000e+00,
        -2.97568920e-02,  -1.22189251e-02,   3.26631055e-02,
         1.86819586e-02,   0.00000000e+00,   9.87458752e-03,
         9.12270174e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.90678045e-02,   0.00000000e+00,
         6.25824982e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.72506481e-02,
         0.00000000e+00,   0.00000000e+00,  -1.46018495e-01,
         7.66952764e-04,  -5.35199143e-03,   2.72050496e-02,
         0.00000000e+00,   2.09530266e-02,   0.00000000e+00,
         5.38501591e-02,   2.90958912e-05,   2.07072146e-03,
        -2.11139697e-02,   0.00000000e+00,  -4.69980334e-02,
         4.87609115e-02,   0.00000000e+00,  -1.30824280e-01,
        -8.06563727e-03,  -4.07473171e-03,   7.27578156e-03,
         0.00000000e+00,  -1.78934802e-02,   0.00000000e+00,
         9.34514297e-04,   7.02734049e-02,  -1.67475141e-02,
         7.93331295e-03,   0.00000000e+00,  -2.77183908e-02,
        -3.15405272e-02,   0.00000000e+00,  -7.90170378e-03,
        -1.57607576e-01,  -9.58683794e-03,   4.91207827e-02,
        -1.02098528e-02,   0.00000000e+00,   1.03921415e-02,
         0.00000000e+00,   1.12596930e-03,   3.08828195e-02,
         1.16471406e-02,   7.38242628e-03,   0.00000000e+00,
         6.34868989e-03,   3.24345480e-02,   0.00000000e+00,
        -1.96925091e-02,   5.36145541e-02,   8.71012812e-02,
         4.10257830e-02,   3.54273809e-02,  -8.36624104e-03,
         0.00000000e+00,   1.76125760e-02,   0.00000000e+00,
        -3.37422049e-03,   1.29429549e-02,  -1.51477355e-02,
         7.49043008e-03,   0.00000000e+00,   1.53535538e-02,
         2.09507548e-02,   0.00000000e+00,   5.02955585e-03,
         1.82856549e-02,  -8.62993342e-02,  -1.11836857e-01,
         5.81721657e-01,  -1.19876374e-01,   5.88379150e-01,
        -1.49631661e-02,   5.28980702e-02,   6.08018195e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.32438321e-01,  -2.92546378e-02,  -4.11071735e-02,
        -9.44916860e-03,   0.00000000e+00,   6.07604496e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.64843644e-02,   0.00000000e+00,   4.88379685e-01,
         1.56383239e-02,  -1.21364621e-02,  -6.47825543e-02,
         0.00000000e+00,  -6.21437551e-02,   0.00000000e+00,
         4.91507005e-01,  -3.77234454e-02,   3.71756849e-02,
        -1.81919384e-02,   0.00000000e+00,   7.81259302e-02,
         0.00000000e+00,  -2.70038558e-02,   4.98394420e-01,
        -4.27029191e-02,   5.56935372e-02,   7.12737944e-02,
         0.00000000e+00,  -3.66579672e-02,   0.00000000e+00,
        -1.18055273e-02,  -2.72882599e-02,   4.36357152e-01,
        -1.11250628e-02,   1.07129213e-02,   3.39160369e-03,
         0.00000000e+00,   1.33060369e-02,   0.00000000e+00,
        -8.74899411e-03,   3.58981213e-02,   1.06593957e-01,
         5.27411973e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.32320560e-01,   0.00000000e+00,
         6.09928108e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.97130561e-01,
         4.72600656e-03,   2.07900240e-02,  -5.37528147e-02,
         0.00000000e+00,  -1.00476713e-01,   0.00000000e+00,
         5.60857703e-02,  -5.42957444e-02,  -2.69402116e-03,
        -2.16165100e-02,   0.00000000e+00,   5.86951083e-01,
         7.81354104e-03,   3.43981797e-02,   9.55305464e-02,
         0.00000000e+00,  -3.68495310e-02,   0.00000000e+00,
        -1.18155884e-02,  -3.07180889e-02,   9.10247190e-02,
         3.71654699e-02,   0.00000000e+00,   1.25820992e-02,
         5.79034322e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.06016902e-03,   0.00000000e+00,
        -5.76342573e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.30450160e-02,
         0.00000000e+00,   0.00000000e+00,   4.19973205e-01,
         8.66617144e-03,  -8.33791215e-03,   8.19113810e-03,
         0.00000000e+00,  -6.11583269e-03,   0.00000000e+00,
        -6.15845840e-02,  -7.47362322e-03,   2.19167396e-03,
         3.54214312e-03,   0.00000000e+00,  -1.83565420e-02,
         2.18800011e-02,   0.00000000e+00,   4.23863937e-01,
        -5.29303988e-03,   3.22730636e-02,  -2.36162143e-02,
         0.00000000e+00,   4.33809276e-02,   0.00000000e+00,
        -8.41563224e-03,  -2.51573202e-02,   1.60731719e-02,
         3.68590616e-04,   0.00000000e+00,  -2.98262634e-02,
        -2.54154141e-02,   0.00000000e+00,  -5.79857892e-03,
         4.40636964e-01,  -7.99868107e-02,   6.28857571e-02,
        -9.19773817e-03,   0.00000000e+00,  -2.07003072e-02,
         0.00000000e+00,  -1.40206451e-03,   5.86880048e-02,
         6.50305959e-02,   1.51255466e-02,   0.00000000e+00,
        -8.53459967e-03,   4.00359412e-02,   0.00000000e+00,
        -1.24211053e-02,   4.56827478e-02,   6.14262446e-01,
        -5.06654428e-03,  -4.46303596e-02,   1.25402193e-02,
         0.00000000e+00,  -4.71149836e-03,   0.00000000e+00,
        -4.89802127e-03,  -4.05807873e-03,  -1.26065491e-02,
        -2.12631477e-03,   0.00000000e+00,   3.75919622e-03,
        -5.93131402e-03,   0.00000000e+00,  -1.71992599e-03,
         4.92778483e-03,  -5.48140855e-02,   4.67435984e-01,
         1.51459169e-02,   8.48294146e-02,  -6.23654751e-03,
         4.69856562e-02,  -8.79895514e-02,  -7.87441727e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.15625818e-02,   4.33030300e-03,   4.04958545e-02,
         3.29135861e-03,   0.00000000e+00,   4.12774740e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.11242108e-02,   0.00000000e+00,   7.40637659e-02,
        -3.36904063e-02,   6.29782500e-03,   4.64412448e-02,
         0.00000000e+00,   2.40614500e-02,   0.00000000e+00,
         6.90509136e-02,  -8.61836583e-03,  -1.57208966e-02,
         1.90126565e-02,   0.00000000e+00,  -5.33243785e-02,
         0.00000000e+00,   1.52480485e-02,   6.45165531e-02,
         1.74416115e-02,  -1.33063308e-02,   1.22785483e-02,
         0.00000000e+00,   1.62230945e-02,   0.00000000e+00,
        -1.18782835e-02,  -4.35892301e-02,  -6.85307879e-02,
         1.06840718e-03,   1.28435991e-02,   4.32700018e-02,
         0.00000000e+00,  -3.78931513e-03,   0.00000000e+00,
        -2.91281816e-02,  -1.19089462e-02,  -3.34605643e-02,
        -1.31725779e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.47997060e-03,   0.00000000e+00,
        -1.40507570e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.70713470e-02,
         3.67138082e-04,   9.86853148e-03,   1.47436702e-05,
         0.00000000e+00,  -3.32942051e-04,   0.00000000e+00,
        -1.56100756e-02,   2.39753810e-03,   1.14959914e-03,
        -2.26488911e-03,   0.00000000e+00,  -2.19569238e-02,
         8.93317620e-03,  -9.88488730e-03,  -8.13613841e-03,
         0.00000000e+00,   9.97017156e-04,   0.00000000e+00,
         1.09617126e-02,  -1.11765857e-02,  -2.20242856e-02,
        -1.27511504e-02,   0.00000000e+00,  -1.94039991e-02,
        -1.77344018e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.97329054e-03,   0.00000000e+00,
        -2.89064767e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.25068475e-02,
         0.00000000e+00,   0.00000000e+00,   8.24722172e-02,
         7.25493258e-03,   6.43490782e-03,  -1.24397686e-02,
         0.00000000e+00,  -1.07720510e-02,   0.00000000e+00,
        -2.25678985e-02,  -1.14239099e-03,  -1.65071630e-03,
         2.36480954e-02,   0.00000000e+00,   1.64946984e-02,
        -1.21014949e-02,   0.00000000e+00,   7.83075849e-02,
         7.61585845e-03,   1.06046129e-02,  -9.28470931e-03,
         0.00000000e+00,   8.56607942e-03,   0.00000000e+00,
         1.14188596e-03,  -2.93681539e-02,   5.64670172e-03,
        -7.70838211e-03,   0.00000000e+00,   1.73415540e-02,
         4.24140469e-03,   0.00000000e+00,   9.42977989e-03,
         1.06557948e-01,  -2.32153631e-03,  -1.60423853e-02,
        -9.34481189e-03,   0.00000000e+00,  -6.42904686e-05,
         0.00000000e+00,   9.74712625e-03,  -3.11485567e-03,
        -1.07577738e-02,  -1.32648199e-02,   0.00000000e+00,
         9.57645799e-03,  -6.69924304e-02,   0.00000000e+00,
        -9.31386633e-03,  -2.44658897e-02,  -3.61464995e-02,
        -1.35366342e-02,  -1.47386513e-02,   1.01227483e-02,
         0.00000000e+00,  -1.71963022e-02,   0.00000000e+00,
         9.61060583e-03,  -2.93557344e-03,   5.03555916e-03,
        -8.59608883e-03,   0.00000000e+00,  -2.02112772e-02,
         7.50130345e-03,   0.00000000e+00,  -8.82883493e-03,
        -1.96166475e-02,   4.13332081e-02,   6.44558477e-02,
        -1.78309422e-02,  -8.19477141e-02,  -4.43317986e-03,
         3.24437950e-03,   1.40880355e-02,   4.61013635e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.63854540e-02,   4.71802906e-03,  -8.91568176e-02,
         9.95399988e-03,   0.00000000e+00,   1.50911948e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.15430680e-02,   0.00000000e+00,  -7.06494896e-02,
        -3.36231942e-02,  -1.11678686e-02,  -5.14169249e-02,
         0.00000000e+00,  -6.76922976e-02,   0.00000000e+00,
        -5.86240956e-02,   9.57393096e-03,   1.14822250e-02,
        -3.07077841e-02,   0.00000000e+00,   6.34081468e-02,
         0.00000000e+00,  -9.61496844e-03,  -6.98084572e-02,
        -7.20674034e-03,   1.21976347e-02,   1.89421425e-02,
         0.00000000e+00,  -2.64473979e-02,   0.00000000e+00,
         4.99417148e-03,   2.14726125e-02,   3.51092487e-02,
         2.32262443e-03,   3.49457605e-03,   4.51984128e-03,
         0.00000000e+00,  -3.75757004e-03,   0.00000000e+00,
         9.83291858e-03,  -6.29665504e-03,   1.74724814e-02,
         4.97776846e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.06040692e-02,   0.00000000e+00,
         2.43188715e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.04381110e-02,
        -4.11228980e-03,   9.53591384e-03,  -1.28334012e-02,
         0.00000000e+00,  -1.68059546e-02,   0.00000000e+00,
         2.15283815e-02,  -1.37188634e-03,   9.66941393e-03,
        -1.15313766e-02,   0.00000000e+00,   7.23898032e-02,
        -5.52344802e-03,  -3.36567983e-03,   1.37591642e-02,
         0.00000000e+00,  -1.11290424e-02,   0.00000000e+00,
        -1.93273369e-02,   1.65244884e-03,   1.94906196e-02,
         8.46262854e-03,   0.00000000e+00,   1.22449575e-02,
         5.30578561e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.88576233e-03,   0.00000000e+00,
         3.04926610e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.93984061e-02,
         0.00000000e+00,   0.00000000e+00,  -8.70705925e-02,
         7.49615024e-03,   3.66541580e-03,   8.25276889e-03,
         0.00000000e+00,   1.32615097e-02,   0.00000000e+00,
         2.40828075e-02,   3.72341381e-03,  -2.73840633e-03,
        -1.17773239e-02,   0.00000000e+00,  -3.13556710e-02,
         3.28243604e-02,   0.00000000e+00,  -7.54115578e-02,
        -9.50574738e-03,  -1.10113423e-02,   1.27105270e-03,
         0.00000000e+00,  -1.00219293e-02,   0.00000000e+00,
        -1.79003788e-03,   3.34013986e-02,  -1.03885667e-02,
         4.07862696e-03,   0.00000000e+00,  -9.49062544e-03,
        -1.99673408e-02,   0.00000000e+00,   7.70224921e-03,
        -1.13382135e-01,  -6.15846398e-03,   2.47593150e-02,
        -3.11112023e-03,   0.00000000e+00,  -9.41992428e-04,
         0.00000000e+00,   1.09573273e-02,   7.69327870e-03,
         7.08246049e-03,  -1.79330023e-03,   0.00000000e+00,
         4.21058625e-02,   3.73478368e-02,   0.00000000e+00,
        -2.52510134e-02,   2.92069724e-02,   3.60665926e-02,
         1.80529709e-02,   1.25076656e-02,  -8.15368832e-03,
         0.00000000e+00,   2.26784426e-02,   0.00000000e+00,
         3.90504783e-03,   2.22514046e-03,  -7.21561259e-03,
         3.96352435e-05,   0.00000000e+00,  -6.41817694e-03,
         1.75748739e-02,   0.00000000e+00,  -2.29901971e-02,
         2.08865608e-02,  -4.83721407e-02,  -6.74930638e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.84384302e-03,  -3.31410896e-02,   7.25296904e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.10363355e-03,   0.00000000e+00,
        -4.58307160e-02,  -3.88252973e-02,   9.97646787e-03,
         0.00000000e+00,  -2.04433960e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.03453241e-03,   0.00000000e+00,   1.98009338e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.24550918e-03,   0.00000000e+00,
         5.23056732e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.76118279e-03,   0.00000000e+00,   2.48314966e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.26190748e-03,   0.00000000e+00,   8.41805168e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.39015720e-04,   8.47097110e-03,
        -3.46028349e-03,   0.00000000e+00,   3.53518394e-03,
         0.00000000e+00,   2.37007285e-05,   1.18506550e-03,
         3.22153237e-03,   2.97448709e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.45040793e-03,   0.00000000e+00,  -3.30254187e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.26229245e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.60786789e-03,   0.00000000e+00,  -5.80017389e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.60212871e-03,   0.00000000e+00,
         0.00000000e+00,   9.65896548e-03,   1.20035087e-02,
        -2.51082249e-03,   0.00000000e+00,   3.82889185e-03,
         0.00000000e+00,  -2.33643999e-04,   2.71963234e-03,
        -3.45563408e-03,   2.24717578e-03,   0.00000000e+00,
         4.04799899e-03,   6.96538755e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.66870441e-04,   0.00000000e+00,  -1.53098899e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.17742911e-03,   0.00000000e+00,
         0.00000000e+00,   1.13082962e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.67953505e-03,   0.00000000e+00,  -3.77968438e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.63451267e-03,   0.00000000e+00,
         0.00000000e+00,   1.67935949e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.09712553e-03,   0.00000000e+00,
         1.07030304e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.03413310e-02,
         0.00000000e+00,   0.00000000e+00,  -2.22075408e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.95679926e-03,   0.00000000e+00,   1.10112687e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.33643940e-02,   0.00000000e+00,
         0.00000000e+00,  -4.57433417e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.65571374e-03,   1.98750132e-02,   9.01817117e-03,
        -6.45371673e-02,   2.36561442e-02,  -2.85982916e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.92219451e-02,  -3.00898431e-02,   3.57127993e-02,
        -1.72489062e-02,   0.00000000e+00,  -3.91475442e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.39324240e-02,   0.00000000e+00,   1.54754661e-02,
        -6.66899307e-03,  -6.87048478e-02,   3.52878115e-02,
         0.00000000e+00,   2.03125083e-02,   0.00000000e+00,
         1.09696696e-02,  -9.99940547e-03,  -7.82490244e-03,
         1.72940720e-02,   0.00000000e+00,  -2.67388863e-02,
         0.00000000e+00,   2.73306395e-03,   2.35135784e-02,
        -2.60390182e-03,  -8.85793231e-04,  -3.09059162e-02,
         0.00000000e+00,   1.64810844e-02,   0.00000000e+00,
         5.58958480e-03,   1.18471540e-02,   2.04581209e-02,
         2.03845062e-03,  -8.48272987e-03,  -4.10550946e-02,
         0.00000000e+00,   1.03962268e-02,   0.00000000e+00,
         1.10760586e-02,   1.36283480e-02,   6.46147754e-03,
         5.49308330e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.75036573e-02,   0.00000000e+00,
        -1.41826131e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.18081638e-02,
         8.85559636e-03,  -8.52803297e-03,   7.38642873e-03,
         0.00000000e+00,   2.01105737e-02,   0.00000000e+00,
        -1.69969614e-02,  -2.68607409e-03,  -1.23892132e-02,
         1.62653816e-02,   0.00000000e+00,  -5.30308140e-02,
        -4.76120885e-03,   1.77261057e-03,  -4.86943263e-03,
         0.00000000e+00,   2.38519658e-03,   0.00000000e+00,
         3.50125480e-03,   8.33676416e-03,  -2.02161694e-03,
         3.08867375e-03,   0.00000000e+00,   4.25001253e-03,
        -5.06702135e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.97552923e-03,   0.00000000e+00,
        -8.88357262e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.25855214e-02,
         0.00000000e+00,   0.00000000e+00,   2.58123466e-02,
         1.08565439e-03,   8.32653084e-03,  -2.93688019e-03,
         0.00000000e+00,   1.22874073e-03,   0.00000000e+00,
        -9.30002474e-03,   2.57284331e-03,  -1.56081336e-03,
        -2.51594910e-03,   0.00000000e+00,   2.76069653e-02,
        -1.24227704e-02,   0.00000000e+00,   2.04647642e-02,
         5.28008769e-03,   4.95804134e-03,   4.02813340e-04,
         0.00000000e+00,   1.33276474e-03,   0.00000000e+00,
        -7.34298617e-03,  -1.16421379e-02,   5.33488401e-03,
         3.34073314e-03,   0.00000000e+00,   6.06157033e-04,
         1.55040783e-02,   0.00000000e+00,   1.24404940e-02,
         3.85053668e-02,   8.29104739e-03,  -1.27719428e-02,
         1.33697609e-02,   0.00000000e+00,   5.55288659e-03,
         0.00000000e+00,  -3.22658030e-03,  -3.21760419e-03,
        -1.99724473e-03,   7.92391829e-03,   0.00000000e+00,
        -5.71844647e-02,   2.08186465e-02,   0.00000000e+00,
         9.50291102e-04,  -1.10338485e-02,  -1.46973434e-02,
        -8.07611496e-03,  -1.58193921e-03,   4.90268494e-03,
         0.00000000e+00,  -5.62484692e-03,   0.00000000e+00,
         4.31785662e-03,   1.76124718e-03,   3.57462851e-03,
        -1.19919288e-03,   0.00000000e+00,   6.43324871e-03,
        -6.66615465e-03,   0.00000000e+00,  -4.82780600e-02,
        -1.25259456e-02,   1.08052170e-02,   1.87375681e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.99221828e-02,  -7.03578599e-02,   1.68850296e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.14157497e-02,   0.00000000e+00,
        -1.85074064e-02,   5.86622918e-02,  -1.10977426e-02,
         0.00000000e+00,  -2.52073168e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.18894455e-03,   0.00000000e+00,   4.65973457e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.37194779e-02,   0.00000000e+00,
         1.43705819e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.24013814e-02,   0.00000000e+00,   6.12713555e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.44055129e-02,   0.00000000e+00,   1.17076205e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.21960500e-02,   1.36857395e-02,
        -5.44129853e-03,   0.00000000e+00,  -2.57887756e-03,
         0.00000000e+00,   2.37172792e-03,   1.80136984e-02,
         2.43862521e-02,  -6.18812753e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.25934304e-02,   0.00000000e+00,   5.37237963e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.03496030e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.03467789e-03,   0.00000000e+00,  -3.83047963e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.56364707e-03,   0.00000000e+00,
         0.00000000e+00,   1.61585140e-03,   2.14230225e-03,
         3.65789369e-03,   0.00000000e+00,  -8.20917223e-03,
         0.00000000e+00,   1.46804869e-03,  -3.28791097e-03,
        -1.70159749e-03,   1.46625390e-03,   0.00000000e+00,
        -7.22479736e-03,  -7.01897804e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.41522103e-03,   0.00000000e+00,  -3.65948135e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.27762829e-03,   0.00000000e+00,
         0.00000000e+00,   1.21477594e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.11116817e-03,   0.00000000e+00,   9.21487069e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.54253037e-02,   0.00000000e+00,
         0.00000000e+00,  -2.49640699e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.51762355e-03,   0.00000000e+00,
         6.38005715e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.28575324e-02,
         0.00000000e+00,   0.00000000e+00,  -6.68345919e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.14991233e-03,   0.00000000e+00,   6.18353001e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.86459715e-02,   0.00000000e+00,
         0.00000000e+00,   3.13866286e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.80168776e-02,   1.96102635e-02,  -2.94173128e-02,
        -2.39711608e-02,  -7.34930001e-04,  -5.99880746e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.53166503e-02,   7.46732231e-02,  -3.00701680e-02,
         2.04715306e-03,   0.00000000e+00,  -3.74809964e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.97888741e-02,   0.00000000e+00,  -3.43593840e-02,
        -1.64280901e-02,   1.58809529e-02,   6.92269771e-03,
         0.00000000e+00,   4.38911573e-03,   0.00000000e+00,
        -2.91835111e-02,   1.14487960e-02,  -6.32924430e-02,
         1.29614578e-02,   0.00000000e+00,  -3.15288346e-02,
         0.00000000e+00,   7.77259863e-03,  -4.07432507e-02,
         7.29566541e-03,   6.17500494e-03,  -2.65444644e-02,
         0.00000000e+00,  -5.28639750e-03,   0.00000000e+00,
         1.21061669e-02,   5.00201225e-03,  -7.74403547e-03,
         9.88897368e-03,  -1.01903369e-02,  -2.08345138e-02,
         0.00000000e+00,  -1.90054199e-02,   0.00000000e+00,
         1.39017874e-02,  -1.10347203e-02,  -5.78723651e-03,
        -3.62333753e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.95999779e-02,   0.00000000e+00,
        -2.06849973e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.53722705e-02,
        -9.26937785e-03,   6.06721450e-03,   2.30195135e-03,
         0.00000000e+00,   2.20547565e-02,   0.00000000e+00,
        -1.50589640e-02,   2.54152026e-02,   1.34742538e-02,
         5.21597375e-03,   0.00000000e+00,  -4.01536122e-02,
        -6.25715934e-03,  -2.67882200e-03,  -2.60542922e-02,
         0.00000000e+00,   2.22064730e-02,   0.00000000e+00,
         5.64730384e-03,   2.23759039e-02,  -1.11430438e-02,
        -9.88702487e-03,   0.00000000e+00,   1.59375980e-02,
        -4.94204703e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.36924820e-03,   0.00000000e+00,
         4.72835319e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.12194097e-03,
         0.00000000e+00,   0.00000000e+00,  -2.27957655e-02,
        -1.48577297e-03,   7.27145872e-04,  -8.11651393e-03,
         0.00000000e+00,   1.50888471e-03,   0.00000000e+00,
         3.68963435e-03,   3.82845163e-03,  -3.50466681e-03,
        -7.81933519e-03,   0.00000000e+00,  -3.04017843e-03,
        -6.75815359e-03,   0.00000000e+00,  -2.16957045e-02,
         9.32458778e-03,  -1.99121357e-03,  -1.38499470e-03,
         0.00000000e+00,   3.04354273e-03,   0.00000000e+00,
         1.01232686e-03,  -7.07587437e-03,  -4.47615261e-03,
         1.92281326e-04,   0.00000000e+00,   1.91314500e-02,
         2.05258507e-02,   0.00000000e+00,   3.80116296e-03,
        -9.45309010e-03,   1.95950731e-02,  -1.79472456e-02,
         6.78846787e-03,   0.00000000e+00,  -1.10320899e-02,
         0.00000000e+00,   5.24495722e-03,  -2.31726152e-02,
        -9.26796016e-03,  -7.06438002e-03,   0.00000000e+00,
         4.88096005e-02,   3.03917837e-02,   0.00000000e+00,
         4.86187050e-03,  -3.85711614e-02,  -6.40300917e-02,
        -5.47600027e-03,  -4.31564970e-03,  -6.63519380e-03,
         0.00000000e+00,   1.00153216e-02,   0.00000000e+00,
        -1.92514709e-03,   1.61346988e-02,  -1.59315471e-03,
         3.22206321e-03,   0.00000000e+00,  -1.12735936e-02,
        -8.00401118e-03,   0.00000000e+00,   1.11714402e-03,
        -2.62149137e-02,   1.62552489e-02,  -4.53989347e-02,
        -3.94460126e-02,   4.32288378e-02,  -5.83177925e-02,
         1.44434519e-02,  -2.03318777e-02,  -4.27567447e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.01402463e-02,  -8.85024292e-03,   2.67315516e-02,
         1.73384714e-03,   0.00000000e+00,  -6.84710158e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.49011402e-02,   0.00000000e+00,  -1.91999000e-02,
        -2.03675720e-03,  -8.81376049e-04,   1.68296949e-02,
         0.00000000e+00,   2.58247884e-02,   0.00000000e+00,
        -1.82665920e-02,   1.37131041e-02,   1.09619307e-03,
        -3.67750052e-03,   0.00000000e+00,  -2.47211013e-02,
         0.00000000e+00,   1.24523240e-02,  -1.97832110e-02,
         2.31074841e-02,  -3.64682598e-02,  -3.17810998e-02,
         0.00000000e+00,   1.80183797e-02,   0.00000000e+00,
         6.48153621e-03,   8.39056563e-03,  -6.71246201e-03,
         1.69708190e-02,  -2.12802446e-02,  -2.01173525e-02,
         0.00000000e+00,   3.91014135e-03,   0.00000000e+00,
         7.53929430e-03,  -6.36627838e-04,  -9.12425957e-03,
         3.84139055e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.07733661e-02,   0.00000000e+00,
        -2.17156507e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.61606569e-02,
        -2.64686953e-03,  -4.49761657e-03,   1.30849998e-02,
         0.00000000e+00,   3.23044721e-02,   0.00000000e+00,
        -1.88829178e-02,   1.40420056e-02,  -2.63202350e-03,
         1.31643355e-02,   0.00000000e+00,  -6.63543972e-02,
         8.97604177e-03,  -1.88474612e-02,  -2.97615324e-02,
         0.00000000e+00,   1.34341628e-02,   0.00000000e+00,
         7.13366582e-03,   1.92515860e-03,  -3.01542288e-02,
        -1.22086093e-02,   0.00000000e+00,  -1.14998167e-02,
        -6.01996558e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.90133382e-03,   0.00000000e+00,
         1.88429175e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.09936258e-02,
         0.00000000e+00,   0.00000000e+00,  -4.11304039e-03,
        -2.16686321e-03,   2.61781128e-03,  -3.81994295e-03,
         0.00000000e+00,  -4.67664254e-03,   0.00000000e+00,
         1.89441056e-03,  -8.28303099e-04,  -1.25080927e-03,
        -4.44093180e-03,   0.00000000e+00,   9.63926992e-03,
        -6.96422545e-03,   0.00000000e+00,  -4.68681221e-03,
         3.85001667e-03,  -4.52797574e-03,   1.21840228e-03,
         0.00000000e+00,  -8.10105846e-03,   0.00000000e+00,
         3.42598327e-03,  -7.97158792e-03,   2.56615752e-04,
        -6.95635596e-04,   0.00000000e+00,   6.76700406e-03,
         1.88754913e-03,   0.00000000e+00,   2.02003051e-04,
        -9.95767945e-03,   2.49261655e-02,  -3.07450309e-02,
        -8.94035404e-03,   0.00000000e+00,   5.67431998e-03,
         0.00000000e+00,   2.22956381e-03,  -1.30974501e-02,
        -2.88761931e-02,  -1.21736077e-02,   0.00000000e+00,
        -9.77832271e-03,  -3.14457323e-02,   0.00000000e+00,
         2.74769606e-03,  -5.08601260e-03,  -6.76466606e-02,
        -7.56724917e-03,   8.03899102e-03,   1.45382525e-03,
         0.00000000e+00,  -5.74744458e-03,   0.00000000e+00,
         1.50340977e-03,  -1.93420815e-03,   8.71672344e-03,
         5.13147970e-03,   0.00000000e+00,   1.64123272e-03,
         5.14157032e-03,   0.00000000e+00,  -7.35687619e-04,
         4.98969508e-03,   1.88748450e-02,  -8.13196487e-03,
        -2.50168128e-02,   7.03540145e-03,  -1.77343462e-02,
        -6.87294176e-03,   1.17109461e-02,   4.18346296e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.12306133e-02,   9.37432158e-03,   4.34365885e-03,
        -1.53375636e-03,   0.00000000e+00,  -3.41270771e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.42712998e-02,   0.00000000e+00,  -1.92147906e-02,
         5.19113001e-03,  -1.69688446e-03,  -8.35706302e-03,
         0.00000000e+00,   1.19999816e-02,   0.00000000e+00,
        -1.18321857e-02,   8.15013191e-03,  -1.17376873e-02,
        -8.01860230e-03,   0.00000000e+00,  -1.16107141e-02,
         0.00000000e+00,   8.86091887e-03,  -1.59375609e-02,
         1.70425750e-02,  -2.25134841e-02,  -2.94850966e-02,
         0.00000000e+00,   7.60091144e-03,   0.00000000e+00,
         1.03611118e-02,   1.45880239e-02,   2.67259381e-02,
         2.77726622e-02,  -3.92929749e-02,  -5.01577907e-02,
         0.00000000e+00,   4.94221111e-03,   0.00000000e+00,
         2.30821613e-02,   9.74163701e-03,   2.85871815e-02,
         1.04558762e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.02934287e-02,   0.00000000e+00,
        -1.07769436e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.84829756e-02,
        -3.90860491e-03,  -1.45891842e-03,   1.69897330e-03,
         0.00000000e+00,   1.61500402e-02,   0.00000000e+00,
        -6.17495525e-03,   1.11080307e-02,   2.04235237e-03,
         1.48455296e-02,   0.00000000e+00,  -3.12050545e-02,
         4.20440191e-03,  -9.29733247e-03,  -1.60656892e-02,
         0.00000000e+00,   8.90003952e-03,   0.00000000e+00,
         3.28883359e-03,   3.62367225e-03,  -1.25827922e-02,
        -1.17684252e-03,   0.00000000e+00,  -5.60787944e-03,
        -2.45994415e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.87898567e-03,   0.00000000e+00,
         3.50122428e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.56931230e-03,
         0.00000000e+00,   0.00000000e+00,  -1.16721123e-02,
        -3.65418021e-03,   1.27281030e-03,   3.34421304e-03,
         0.00000000e+00,  -1.91181060e-03,   0.00000000e+00,
         2.18270288e-03,  -1.00182523e-03,  -3.77425572e-03,
        -1.58958689e-02,   0.00000000e+00,  -4.86402664e-05,
        -1.56855440e-03,   0.00000000e+00,  -8.45194695e-03,
         3.11011697e-03,  -2.83187209e-03,  -4.37232646e-04,
         0.00000000e+00,  -3.30051011e-03,   0.00000000e+00,
         3.44325385e-03,  -1.40840008e-03,  -9.74068870e-04,
         2.86811592e-03,   0.00000000e+00,   5.78588959e-03,
         2.99108610e-03,   0.00000000e+00,  -1.18402328e-03,
        -1.20050709e-02,   1.43292603e-02,  -1.53152816e-02,
        -7.05955328e-03,   0.00000000e+00,  -1.49407243e-03,
         0.00000000e+00,   3.05674175e-03,  -1.02204313e-02,
        -1.80064241e-02,  -5.10285219e-03,   0.00000000e+00,
         2.12877509e-03,  -5.99560895e-03,   0.00000000e+00,
         3.94967890e-03,  -6.60956629e-03,  -3.17352032e-02,
        -2.26998972e-03,   4.08391802e-03,  -2.11889899e-03,
         0.00000000e+00,   5.07234626e-04,   0.00000000e+00,
        -1.66492501e-03,   3.90953910e-03,   5.46495182e-03,
         9.53275821e-03,   0.00000000e+00,   2.01968337e-03,
         4.54121578e-04,   0.00000000e+00,   2.91372474e-03,
        -1.68013419e-03,   5.67974658e-03,  -1.39062836e-02,
        -7.46929643e-03,  -4.97251517e-03,  -1.14767660e-02,
        -5.14336520e-03,   1.40807355e-02,  -1.43969955e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.60312259e-02,  -9.24296315e-03,   1.48396176e-02,
        -5.66613035e-03,   0.00000000e+00,  -1.44676254e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.70696573e-04,   0.00000000e+00,  -1.55629273e-02,
         1.66823786e-02,  -1.29910505e-03,  -3.06413739e-04,
         0.00000000e+00,   5.42199466e-03,   0.00000000e+00,
        -1.70339667e-02,  -7.22845256e-03,   5.13676422e-03,
         2.37519950e-03,   0.00000000e+00,   5.27946816e-03,
         0.00000000e+00,  -2.46611023e-03,  -6.98686587e-03,
        -3.26050393e-03,   2.44264497e-03,   2.45151268e-03,
         0.00000000e+00,   6.52422858e-03,   0.00000000e+00,
        -3.70030563e-03,   6.12683561e-03,  -6.63630869e-03,
        -4.72181959e-03,   2.69038413e-03,  -2.68118277e-03,
         0.00000000e+00,   9.33070707e-04,   0.00000000e+00,
         1.38394389e-03,   3.46932641e-03,   1.69530548e-03,
        -2.15087315e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.27397444e-03,   0.00000000e+00,
        -2.49241621e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.24703450e-02,
         1.93068687e-02,  -2.34295064e-02,   8.75795366e-03,
         0.00000000e+00,   1.11896235e-02,   0.00000000e+00,
        -6.33695514e-03,  -3.50658529e-04,  -1.16243013e-03,
        -4.08397770e-03,   0.00000000e+00,  -1.55106755e-02,
        -4.45600387e-03,   3.33257704e-03,  -5.76641232e-03,
         0.00000000e+00,   2.84075690e-03,   0.00000000e+00,
         5.05025918e-04,   4.58714283e-03,  -2.30185110e-03,
        -3.12289594e-03,   0.00000000e+00,   3.45628331e-04,
        -8.11136089e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.15521747e-04,   0.00000000e+00,
         4.83985401e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.58495206e-03,
         0.00000000e+00,   0.00000000e+00,  -1.32571627e-02,
        -5.81870407e-03,   7.38384442e-04,  -1.40704454e-03,
         0.00000000e+00,  -4.55679361e-03,   0.00000000e+00,
         7.19453261e-03,   6.31794290e-04,  -1.35134631e-04,
        -3.00918075e-03,   0.00000000e+00,  -1.30166781e-03,
         1.34867295e-03,   0.00000000e+00,  -1.32444231e-02,
        -3.70538768e-03,  -8.55208103e-05,   5.92703877e-03,
         0.00000000e+00,   7.13207142e-04,   0.00000000e+00,
         6.26271678e-04,   6.82100019e-03,   6.77297219e-04,
         2.99569044e-03,   0.00000000e+00,  -2.08409204e-03,
         1.82415787e-03,   0.00000000e+00,  -1.35754884e-03,
        -1.20869084e-02,  -3.50038007e-03,   2.00458835e-03,
         1.48024803e-02,   0.00000000e+00,   2.15063288e-02,
         0.00000000e+00,  -1.63671155e-02,   8.05148392e-03,
         2.91853446e-03,   8.20728174e-03,   0.00000000e+00,
        -1.44949260e-02,   3.65143739e-03,   0.00000000e+00,
         6.40724838e-03,   1.94955168e-03,  -7.98711428e-03,
         3.55047712e-03,   1.92668623e-03,  -6.92177057e-03,
         0.00000000e+00,  -6.01890727e-03,   0.00000000e+00,
         1.10863707e-03,  -2.70689414e-03,   1.75654488e-04,
        -7.71616790e-04,   0.00000000e+00,   7.58631985e-03,
        -3.03116463e-04,   0.00000000e+00,   9.32377115e-03,
        -6.81020229e-04,   4.90389067e-04,  -1.46980520e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.29689045e-02,  -2.95668284e-02,   7.82171533e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.07937035e-03,   0.00000000e+00,
        -1.96497573e-02,   6.45233738e-03,  -1.75169306e-03,
         0.00000000e+00,  -4.55584989e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.10628781e-03,   0.00000000e+00,   2.07818403e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.24654098e-02,   0.00000000e+00,
         6.09999539e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.08242616e-02,   0.00000000e+00,   5.83332503e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.33255698e-03,   0.00000000e+00,   2.71729363e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.50218888e-02,   2.72745682e-02,
        -4.82059405e-03,   0.00000000e+00,  -3.14042516e-03,
         0.00000000e+00,   2.59633057e-03,   8.67015474e-03,
         4.51290697e-03,   9.01808606e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.52137987e-03,   0.00000000e+00,   3.05958772e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.63494475e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.53228883e-03,   0.00000000e+00,   2.72205098e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.31837295e-04,   0.00000000e+00,
         0.00000000e+00,   5.89967217e-03,  -6.64004642e-04,
        -2.76925682e-04,   0.00000000e+00,   1.95913699e-03,
         0.00000000e+00,  -2.11963410e-04,  -1.57395375e-03,
        -4.33622742e-04,  -1.01119567e-03,   0.00000000e+00,
         1.12051040e-03,   2.07677607e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.55275440e-03,   0.00000000e+00,  -2.30573622e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.28610872e-03,   0.00000000e+00,
         0.00000000e+00,   1.13155192e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.37504733e-03,   0.00000000e+00,   1.60428356e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.44892091e-03,   0.00000000e+00,
         0.00000000e+00,   8.92346862e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.25863180e-02,   0.00000000e+00,
         1.87670649e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.38406261e-02,
         0.00000000e+00,   0.00000000e+00,  -6.43533550e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.63605474e-03,   0.00000000e+00,  -1.06831079e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.83849517e-03,   0.00000000e+00,
         0.00000000e+00,  -7.39856449e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.63189723e-02,   8.20233205e-04,  -3.95046371e-02,
         1.00691816e-02,  -9.16888102e-03,  -2.26415372e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.12443318e-02,  -1.33722155e-02,   6.11121291e-03,
        -4.18451239e-03,   0.00000000e+00,  -2.97937256e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.26557552e-04,   0.00000000e+00,  -3.51615508e-02,
        -3.63717318e-03,  -4.29004329e-03,  -8.72741374e-04,
         0.00000000e+00,  -2.13849920e-03,   0.00000000e+00,
        -3.38475696e-02,  -4.25114967e-03,  -6.75706202e-04,
        -9.93051872e-03,   0.00000000e+00,   5.58121172e-03,
         0.00000000e+00,   1.61953963e-03,  -2.18506230e-02,
         1.36200642e-02,  -1.70685222e-02,  -1.42839634e-02,
         0.00000000e+00,   8.41933862e-03,   0.00000000e+00,
         3.39015955e-03,   8.39321122e-03,  -1.05186042e-02,
         5.44671364e-03,  -7.79822433e-03,  -8.93734738e-03,
         0.00000000e+00,   1.54392302e-03,   0.00000000e+00,
         6.25651886e-03,  -2.98992183e-03,  -6.76313970e-03,
         1.43247829e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.97426419e-02,   0.00000000e+00,
        -6.72856709e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.71435254e-02,
         6.18103296e-03,  -1.26473883e-02,   4.85550069e-03,
         0.00000000e+00,   2.06530809e-02,   0.00000000e+00,
        -6.88205379e-03,   9.63089654e-03,  -2.51192352e-03,
        -2.06939573e-03,   0.00000000e+00,  -2.43634691e-02,
         1.77875807e-02,  -2.78125088e-02,  -1.14957194e-02,
         0.00000000e+00,   9.51509892e-03,   0.00000000e+00,
        -3.20623691e-03,   3.04982809e-03,  -1.22382931e-02,
        -9.33698016e-03,   0.00000000e+00,   7.05474878e-03,
        -2.68886210e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.94212206e-03,   0.00000000e+00,
         1.60005259e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.65387569e-03,
         0.00000000e+00,   0.00000000e+00,  -3.03356033e-02,
         2.47397051e-03,   1.28069111e-03,   3.42453090e-03,
         0.00000000e+00,   2.70820696e-03,   0.00000000e+00,
         1.47743823e-02,  -7.49837648e-04,   7.53716057e-04,
        -4.91490077e-03,   0.00000000e+00,   1.91100192e-04,
         4.82654786e-03,   0.00000000e+00,  -2.89678797e-02,
        -3.30021599e-03,  -5.57148044e-03,   1.20716587e-03,
         0.00000000e+00,  -9.05292312e-03,   0.00000000e+00,
         6.02560927e-04,   1.56377038e-02,  -5.35325179e-03,
         9.42631074e-04,   0.00000000e+00,   1.76418522e-03,
        -1.25882666e-03,   0.00000000e+00,   1.93534948e-04,
        -2.99419740e-02,   1.49946813e-02,  -1.57160322e-02,
        -1.75305837e-02,   0.00000000e+00,   2.42179968e-02,
         0.00000000e+00,   8.99465251e-04,   4.06028377e-03,
        -1.99462817e-02,  -1.05256326e-02,   0.00000000e+00,
        -4.67720659e-03,  -1.40769747e-02,   0.00000000e+00,
        -2.73786812e-03,   2.67354635e-03,  -3.01558194e-02,
         5.91505612e-03,   1.26469403e-02,   2.72268287e-03,
         0.00000000e+00,  -7.49370414e-04,   0.00000000e+00,
         2.46467128e-03,  -1.32690683e-03,   5.33548105e-03,
         3.46113739e-03,   0.00000000e+00,   5.54037651e-03,
         9.96801315e-03,   0.00000000e+00,  -4.45772285e-03,
         4.96911937e-04,  -8.94739546e-04,  -3.15561615e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.55873472e-03,   4.32880716e-03,   1.59144202e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.60236312e-04,   0.00000000e+00,
         9.20163976e-03,   1.14971027e-02,  -3.20699700e-03,
         0.00000000e+00,   5.17951482e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.68462771e-04,   0.00000000e+00,  -4.62267835e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.45940515e-03,   0.00000000e+00,
         2.37947024e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.20165464e-03,   0.00000000e+00,  -6.44061775e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.85531755e-04,   0.00000000e+00,   5.41978792e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.10209229e-03,   2.94958330e-03,
         1.24319253e-04,   0.00000000e+00,  -2.47715117e-03,
         0.00000000e+00,   5.97475301e-04,   1.35513988e-03,
        -9.43602977e-04,   2.80830863e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.59115279e-07,   0.00000000e+00,   2.80903371e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.23425498e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.05552669e-03,   0.00000000e+00,   3.78057840e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.64076498e-03,   0.00000000e+00,
         0.00000000e+00,  -1.13331794e-02,  -1.61742107e-02,
         3.92523139e-03,   0.00000000e+00,  -6.36208743e-03,
         0.00000000e+00,   1.95777864e-04,   1.79828698e-03,
         3.73071275e-04,  -1.11309955e-03,   0.00000000e+00,
        -8.99689980e-04,  -1.37947414e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.80467885e-04,   0.00000000e+00,   1.09104284e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.49154233e-04,   0.00000000e+00,
         0.00000000e+00,  -3.15113059e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.10544856e-03,   0.00000000e+00,   8.01568526e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.41157855e-04,   0.00000000e+00,
         0.00000000e+00,  -2.36224121e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.14389514e-02,   0.00000000e+00,
        -4.41394038e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.05100426e-03,
         0.00000000e+00,   0.00000000e+00,   5.77240018e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.83072067e-03,   0.00000000e+00,  -1.93876600e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.15151510e-03,   0.00000000e+00,
         0.00000000e+00,   1.01144223e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.57170224e-03,  -6.33256261e-03,   1.81206537e-03,
         5.31380815e-03,   3.27015431e-03,   1.93646417e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.47858678e-03,   2.70882482e-03,  -2.11260538e-03,
        -6.56518466e-04,   0.00000000e+00,   8.37077187e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.86056082e-03,   0.00000000e+00,  -2.40822074e-03,
         6.94697694e-03,   1.10843400e-02,  -5.22558393e-03,
         0.00000000e+00,  -8.51013634e-04,   0.00000000e+00,
        -3.66503120e-03,  -5.38216956e-04,   1.06501138e-03,
        -2.65667484e-03,   0.00000000e+00,   5.51281337e-03,
         0.00000000e+00,   3.89927179e-04,  -1.03798274e-03,
        -5.23751161e-04,   1.55240866e-03,   1.02329567e-03,
         0.00000000e+00,  -3.96253255e-03,   0.00000000e+00,
        -7.17527912e-04,  -6.05503885e-05,   3.09537510e-03,
        -3.01796824e-03,   5.49414736e-04,   4.85061642e-03,
         0.00000000e+00,  -1.18002125e-03,   0.00000000e+00,
         3.48242204e-06,  -1.73993985e-03,  -2.36818497e-03,
        -3.54084144e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.86939552e-03,   0.00000000e+00,
         4.14556124e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.55970299e-03,
        -6.27789842e-03,   1.20822540e-03,  -2.09379127e-03,
         0.00000000e+00,  -6.90515459e-03,   0.00000000e+00,
         7.07509918e-03,  -6.26640234e-04,  -5.72940548e-04,
        -2.03947629e-03,   0.00000000e+00,   5.54063914e-03,
         5.88116074e-03,   4.09208453e-04,   6.22554112e-03,
         0.00000000e+00,   3.97156363e-04,   0.00000000e+00,
         8.47988061e-04,  -1.62607789e-03,   3.68525089e-03,
         1.67353632e-03,   0.00000000e+00,   3.66181042e-03,
         5.22131405e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.17231021e-03,   0.00000000e+00,
         3.46759967e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.57369532e-03,
         0.00000000e+00,   0.00000000e+00,  -4.57066303e-03,
        -9.89357812e-03,  -1.58524858e-02,   6.91452871e-03,
         0.00000000e+00,  -3.53610610e-03,   0.00000000e+00,
         2.81519838e-03,   1.98851789e-03,   1.02142280e-03,
         2.44690252e-04,   0.00000000e+00,  -2.33828422e-03,
         2.11145674e-05,   0.00000000e+00,  -5.55257281e-03,
        -2.49188965e-03,  -2.54171521e-03,   2.40196535e-03,
         0.00000000e+00,   3.01993610e-04,   0.00000000e+00,
         7.30529874e-03,   5.83711892e-03,  -2.20272596e-03,
        -1.14251343e-03,   0.00000000e+00,  -1.90384406e-03,
        -4.88396659e-04,   0.00000000e+00,  -1.85861650e-03,
        -5.15376278e-03,  -2.24796044e-03,   2.29063754e-03,
        -8.49949116e-03,   0.00000000e+00,  -4.74206140e-03,
         0.00000000e+00,  -4.36942094e-03,  -9.73332856e-05,
         6.38052865e-05,  -2.72907543e-04,   0.00000000e+00,
         4.05195889e-03,   2.59039596e-05,   0.00000000e+00,
         3.14901739e-03,   2.17606099e-03,   7.33320064e-03,
         2.78904564e-03,   1.55932653e-03,  -4.47570591e-03,
         0.00000000e+00,  -3.23351638e-03,   0.00000000e+00,
        -1.84573812e-02,  -1.95417495e-03,   4.10370152e-04,
         2.06805841e-03,   0.00000000e+00,   2.96503110e-03,
        -2.49230725e-03,   0.00000000e+00,   8.20805244e-03,
         1.35855298e-03,  -3.60882139e-03,  -3.54485045e-03,
        -3.29442168e-02,  -6.28124659e-03,  -3.52302267e-02,
         2.39080672e-04,   6.74496383e-03,  -2.87264481e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.26594704e-02,  -6.01822866e-04,  -1.57235209e-02,
         1.75616042e-03,   0.00000000e+00,  -3.18707570e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.90321342e-03,   0.00000000e+00,  -4.38507400e-02,
        -1.99656052e-03,   1.12209393e-03,  -4.95328875e-03,
         0.00000000e+00,  -5.68030960e-03,   0.00000000e+00,
        -4.11583971e-02,   1.19650530e-02,   2.98139868e-03,
        -4.37614712e-03,   0.00000000e+00,   5.69649551e-03,
         0.00000000e+00,  -4.13848629e-04,  -3.94275074e-02,
         7.90361814e-04,  -2.89642072e-03,  -4.89719925e-03,
         0.00000000e+00,  -3.15716136e-03,   0.00000000e+00,
         3.55399030e-03,   6.75445427e-03,  -1.05822214e-02,
         1.67858754e-03,  -2.50555915e-03,  -3.71574839e-03,
         0.00000000e+00,  -4.22140029e-04,   0.00000000e+00,
         7.45974672e-03,  -2.91824474e-03,  -2.71090483e-03,
        -9.66551595e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.51580602e-02,   0.00000000e+00,
         9.62012330e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.72922677e-02,
        -6.37593237e-03,  -1.25311601e-03,   7.89144145e-03,
         0.00000000e+00,   7.94451286e-03,   0.00000000e+00,
         2.33436584e-03,   8.47311774e-03,   1.43422399e-03,
         3.36924324e-03,   0.00000000e+00,  -2.22134906e-02,
        -7.75610328e-03,  -4.46481943e-03,  -9.94932648e-03,
         0.00000000e+00,  -3.21214444e-03,   0.00000000e+00,
        -5.52226219e-03,   8.84681483e-03,  -6.16381059e-03,
        -1.47668119e-03,   0.00000000e+00,   2.81650810e-03,
        -2.41075564e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.25292410e-02,   0.00000000e+00,
         3.37364586e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.43652599e-03,
         0.00000000e+00,   0.00000000e+00,  -3.99132473e-02,
        -1.37049566e-03,   1.06473151e-03,   8.25207932e-03,
         0.00000000e+00,   1.11196485e-02,   0.00000000e+00,
         3.15120931e-02,   2.27103377e-03,  -1.79971362e-03,
        -5.53633694e-03,   0.00000000e+00,  -5.39375528e-03,
         4.59273415e-03,   0.00000000e+00,  -3.74849095e-02,
        -8.62383508e-03,  -2.35181038e-02,   1.34777257e-02,
         0.00000000e+00,  -2.63932766e-02,   0.00000000e+00,
         1.96395311e-03,   3.73818689e-02,  -1.00368704e-02,
         1.14114049e-03,   0.00000000e+00,  -3.41453101e-04,
        -1.15845496e-03,   0.00000000e+00,  -4.04182070e-04,
        -5.10369307e-02,   1.69818978e-02,   5.23715069e-03,
         5.28271038e-04,   0.00000000e+00,   2.90854901e-03,
         0.00000000e+00,   3.81943165e-03,  -1.55821770e-02,
        -4.36078349e-04,  -1.82132636e-03,   0.00000000e+00,
         5.26711023e-03,   6.52703192e-03,   0.00000000e+00,
        -9.81562320e-04,   3.42411278e-03,  -2.82686959e-02,
         1.48206842e-02,   2.10258248e-02,  -7.68327180e-03,
         0.00000000e+00,   1.41457263e-02,   0.00000000e+00,
        -6.23955889e-05,  -6.46576623e-03,   1.10817345e-03,
         8.17252020e-04,   0.00000000e+00,   6.75559304e-04,
         2.70264980e-03,   0.00000000e+00,  -8.80479708e-04,
         1.39376081e-02,  -6.42072898e-03,  -3.80012718e-02,
        -4.64048730e-02,   6.99370738e-02,  -4.47669330e-02,
        -1.45745927e-02,  -1.16940208e-02,  -8.16143393e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.21857680e-02,   1.38864906e-02,   2.46233105e-02,
         2.21342057e-03,   0.00000000e+00,  -7.54921729e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.27398355e-02,   0.00000000e+00,   4.76367080e-03,
        -4.40050461e-03,  -4.56724188e-03,   4.38099508e-02,
         0.00000000e+00,   4.35949653e-02,   0.00000000e+00,
         9.73061069e-04,   3.32901611e-02,  -1.47375265e-02,
         1.66300407e-02,   0.00000000e+00,  -4.99492651e-02,
         0.00000000e+00,   1.41679827e-02,  -1.04732269e-02,
         1.40075648e-02,  -2.99471412e-02,  -4.17865684e-02,
         0.00000000e+00,   1.88943810e-02,   0.00000000e+00,
         8.61078485e-03,  -1.82382548e-03,  -3.19720401e-02,
         1.11839814e-02,  -1.32468058e-02,  -2.84099225e-02,
         0.00000000e+00,  -7.37532932e-03,   0.00000000e+00,
         9.78574198e-03,  -5.11252473e-03,  -2.47448448e-02,
        -2.47425051e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.53242034e-02,   0.00000000e+00,
        -5.08809541e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.63306240e-02,
        -6.62430014e-03,  -6.19576464e-03,   2.75828759e-02,
         0.00000000e+00,   6.95956089e-02,   0.00000000e+00,
        -4.66459953e-02,   3.01929019e-02,  -3.48357731e-04,
         2.05926118e-02,   0.00000000e+00,  -9.39997883e-02,
         2.77496959e-03,  -1.83381260e-02,  -6.25505260e-02,
         0.00000000e+00,   3.82578605e-02,   0.00000000e+00,
         1.86158754e-02,   2.12625818e-02,  -4.19485098e-02,
        -2.71369597e-02,   0.00000000e+00,  -2.40214933e-03,
        -9.48165126e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.20372897e-02,   0.00000000e+00,
        -1.74395468e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.12185027e-02,
         0.00000000e+00,   0.00000000e+00,   2.86906549e-02,
        -6.13884996e-03,   3.12768689e-03,  -2.24130709e-02,
         0.00000000e+00,  -1.18278163e-02,   0.00000000e+00,
        -1.42419232e-02,   1.26660264e-03,  -3.49502207e-03,
        -4.49132423e-04,   0.00000000e+00,   2.32029385e-02,
        -2.29311418e-02,   0.00000000e+00,   2.14504699e-02,
         1.55176646e-02,  -2.85833339e-03,   1.17181820e-03,
         0.00000000e+00,  -2.77434458e-03,   0.00000000e+00,
         2.06756163e-03,  -3.77705315e-02,   7.82059780e-03,
        -3.77010551e-03,   0.00000000e+00,   1.35069791e-02,
         1.67767703e-02,   0.00000000e+00,   3.02832769e-03,
         2.23779914e-02,   5.26985702e-02,  -6.87742522e-02,
         1.53649752e-03,   0.00000000e+00,  -2.77593417e-03,
         0.00000000e+00,  -1.18798351e-03,  -2.59250738e-02,
        -2.43278113e-02,  -1.83512310e-02,   0.00000000e+00,
        -6.23073350e-03,  -1.13081111e-02,   0.00000000e+00,
         1.08541977e-02,  -2.15447068e-02,  -8.87312514e-02,
        -3.00533102e-02,   1.45792011e-03,   1.48261642e-03,
         0.00000000e+00,  -6.65918605e-03,   0.00000000e+00,
        -1.48847368e-03,   3.35781341e-03,   8.54945658e-03,
         2.78923469e-03,   0.00000000e+00,  -1.83670624e-04,
        -4.91201641e-03,   0.00000000e+00,  -7.20074014e-03,
         3.22231191e-03,   3.82744001e-02,   1.83142674e-02,
         4.90002669e-02,   1.82971317e-02,   5.49094939e-02,
        -1.48161978e-03,  -6.48338992e-03,   3.62575060e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.47456926e-02,   6.68211921e-03,   5.24239122e-03,
        -4.77900669e-03,   0.00000000e+00,   5.33534244e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.43059536e-02,   0.00000000e+00,   6.64138657e-02,
        -1.36517503e-03,   1.59178854e-03,   1.26574307e-02,
         0.00000000e+00,   7.95762285e-03,   0.00000000e+00,
         6.48590217e-02,   3.06361552e-03,   3.69646781e-04,
         6.52150419e-03,   0.00000000e+00,  -8.27424856e-03,
         0.00000000e+00,   4.09584209e-04,   6.60830903e-02,
        -9.41171985e-03,   7.05270302e-03,   8.32446000e-03,
         0.00000000e+00,  -1.69407498e-03,   0.00000000e+00,
        -2.85141339e-03,  -1.71559199e-02,   1.51198093e-02,
         1.42778262e-04,   4.88575093e-03,   3.87505596e-03,
         0.00000000e+00,  -3.06064764e-03,   0.00000000e+00,
        -9.79687944e-03,   4.59441475e-03,   7.62687869e-03,
         1.27695205e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.22426031e-02,   0.00000000e+00,
         2.30350131e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.70990205e-02,
         6.43633657e-03,   5.36288402e-03,  -1.56772752e-02,
         0.00000000e+00,  -2.28912494e-02,   0.00000000e+00,
         1.04664600e-03,  -1.09129766e-02,   2.69391899e-03,
        -4.26090078e-03,   0.00000000e+00,   3.43573048e-02,
         5.80844982e-03,   1.05722131e-02,   2.14998588e-02,
         0.00000000e+00,  -1.52219868e-03,   0.00000000e+00,
         7.66484413e-03,  -8.45571668e-03,   1.35720935e-02,
         5.20202343e-03,   0.00000000e+00,   3.26962276e-03,
         3.69267027e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.66960208e-02,   0.00000000e+00,
        -5.20897119e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.94950743e-03,
         0.00000000e+00,   0.00000000e+00,   6.30522418e-02,
         3.34931936e-03,  -5.55439870e-05,  -1.08879247e-02,
         0.00000000e+00,  -1.37768328e-02,   0.00000000e+00,
        -4.91366250e-02,  -2.64954245e-03,   1.88883367e-03,
         8.86192821e-03,   0.00000000e+00,   9.24342576e-03,
        -9.73059862e-03,   0.00000000e+00,   5.97632754e-02,
        -1.96344391e-04,   1.26672963e-02,  -1.26036710e-02,
         0.00000000e+00,   2.52902391e-02,   0.00000000e+00,
        -3.38093139e-03,  -4.14027266e-02,   1.12201330e-02,
        -2.52826390e-03,   0.00000000e+00,   1.54696059e-03,
         2.25647321e-03,   0.00000000e+00,   9.99464554e-04,
         7.73512186e-02,  -3.07440186e-02,   4.53963454e-03,
         2.47003687e-03,   0.00000000e+00,  -7.95563118e-03,
         0.00000000e+00,  -3.35443576e-03,   8.99630198e-03,
         7.10570491e-03,   4.65812207e-03,   0.00000000e+00,
         3.86488000e-03,  -9.82003221e-04,   0.00000000e+00,
         1.13867407e-03,  -4.00777741e-03,   3.69437298e-02,
        -2.09398795e-02,  -4.00258302e-02,   7.67905421e-03,
         0.00000000e+00,  -1.12386495e-02,   0.00000000e+00,
         1.38998375e-03,  -1.03265980e-02,   3.80942799e-03,
        -4.41850654e-03,   0.00000000e+00,  -6.77597288e-03,
        -7.27864550e-03,   0.00000000e+00,  -3.41922010e-04,
        -2.37289650e-03,   1.76739850e-02,   6.05850285e-02,
         4.39310904e-02,  -1.64761316e-02,  -2.40001806e-03,
         6.93350222e-02,   3.72251613e-03,   4.54525479e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.69283100e-02,  -2.39871363e-02,  -1.20842730e-02,
         3.66582461e-03,   0.00000000e+00,   3.23478315e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.61923576e-02,   0.00000000e+00,  -6.66977772e-03,
         3.62710086e-02,   5.72222937e-02,  -2.82106041e-02,
         0.00000000e+00,  -6.78956152e-03,   0.00000000e+00,
        -6.69121626e-03,   3.10921737e-02,   5.81140451e-02,
        -2.12207718e-02,   0.00000000e+00,   3.76461955e-02,
         0.00000000e+00,   4.66474131e-03,   8.39515545e-03,
        -4.04548820e-03,  -1.47783583e-02,   2.76897069e-02,
         0.00000000e+00,  -9.29966567e-03,   0.00000000e+00,
        -8.47852569e-03,  -1.01239342e-02,  -3.21238979e-04,
         5.12886761e-04,   3.07494335e-03,   2.85789492e-02,
         0.00000000e+00,   5.02309815e-04,   0.00000000e+00,
        -6.08138128e-03,  -1.65085814e-03,   2.50280070e-03,
        -1.51458675e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.03155997e-02,   0.00000000e+00,
         1.57678503e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.62018003e-02,
        -2.41285893e-03,  -2.83603640e-03,   7.88951390e-04,
         0.00000000e+00,  -1.36970358e-02,   0.00000000e+00,
         1.68468995e-02,  -6.87753639e-03,   4.55261737e-03,
        -8.99484953e-03,   0.00000000e+00,   3.79146211e-02,
         2.87147500e-03,  -2.24107000e-03,   3.24892357e-03,
         0.00000000e+00,  -7.68978881e-03,   0.00000000e+00,
        -4.71379738e-03,  -1.59420622e-02,   1.42147947e-03,
        -6.11459066e-04,   0.00000000e+00,  -1.00299284e-02,
         6.12586146e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.09619399e-03,   0.00000000e+00,
         6.54431241e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.18059495e-03,
         0.00000000e+00,   0.00000000e+00,  -1.48610661e-02,
        -3.82475339e-03,  -8.66092491e-03,   7.14699683e-03,
         0.00000000e+00,  -2.84863354e-03,   0.00000000e+00,
         7.38779894e-03,  -6.44924548e-03,   4.68909426e-03,
         2.11901340e-05,   0.00000000e+00,  -1.67579369e-02,
         8.50427800e-03,   0.00000000e+00,  -1.40130870e-02,
        -1.01833252e-02,  -1.29279196e-02,   6.35816426e-03,
         0.00000000e+00,  -8.60979470e-03,   0.00000000e+00,
         5.93299145e-03,   4.47027713e-03,   1.78624659e-03,
        -1.96689532e-03,   0.00000000e+00,  -1.11536172e-02,
        -2.89371029e-02,   0.00000000e+00,  -1.06363418e-02,
        -3.08065261e-02,  -5.19970420e-03,   1.06224696e-02,
        -1.01013656e-02,   0.00000000e+00,   7.20146830e-04,
         0.00000000e+00,  -4.80666854e-03,   8.08678125e-03,
         2.17814461e-03,  -2.22169553e-03,   0.00000000e+00,
         1.50199513e-02,  -3.13301470e-02,   0.00000000e+00,
         6.25543773e-03,   3.91528426e-02,   3.09107666e-02,
         8.75783600e-03,   4.79577612e-03,  -1.41611084e-03,
         0.00000000e+00,  -4.39809078e-05,   0.00000000e+00,
        -2.87933213e-03,  -1.80611868e-02,   2.92695866e-03,
         2.39828915e-03,   0.00000000e+00,   7.87827218e-03,
         3.36383709e-03,   0.00000000e+00,   5.52328269e-02,
         4.92716481e-02,  -9.35132543e-03,   1.42924028e-02,
         1.51459169e-02,   8.48294146e-02,  -6.23654751e-03,
         4.69856562e-02,  -8.79895514e-02,  -7.87441727e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.15625818e-02,   4.33030300e-03,   4.04958545e-02,
         3.29135861e-03,   0.00000000e+00,   4.12774740e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.11242108e-02,   0.00000000e+00,   7.40637659e-02,
        -3.36904063e-02,   6.29782500e-03,   4.64412448e-02,
         0.00000000e+00,   2.40614500e-02,   0.00000000e+00,
         6.90509136e-02,  -8.61836583e-03,  -1.57208966e-02,
         1.90126565e-02,   0.00000000e+00,  -5.33243785e-02,
         0.00000000e+00,   1.52480485e-02,   6.45165531e-02,
         1.74416115e-02,  -1.33063308e-02,   1.22785483e-02,
         0.00000000e+00,   1.62230945e-02,   0.00000000e+00,
        -1.18782835e-02,  -4.35892301e-02,  -6.85307879e-02,
         1.06840718e-03,   1.28435991e-02,   4.32700018e-02,
         0.00000000e+00,  -3.78931513e-03,   0.00000000e+00,
        -2.91281816e-02,  -1.19089462e-02,  -3.34605643e-02,
        -1.31725779e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.47997060e-03,   0.00000000e+00,
        -1.40507570e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.70713470e-02,
         3.67138082e-04,   9.86853148e-03,   1.47436702e-05,
         0.00000000e+00,  -3.32942051e-04,   0.00000000e+00,
        -1.56100756e-02,   2.39753810e-03,   1.14959914e-03,
        -2.26488911e-03,   0.00000000e+00,  -2.19569238e-02,
         8.93317620e-03,  -9.88488730e-03,  -8.13613841e-03,
         0.00000000e+00,   9.97017156e-04,   0.00000000e+00,
         1.09617126e-02,  -1.11765857e-02,  -2.20242856e-02,
        -1.27511504e-02,   0.00000000e+00,  -1.94039991e-02,
        -1.77344018e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.97329054e-03,   0.00000000e+00,
        -2.89064767e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.25068475e-02,
         0.00000000e+00,   0.00000000e+00,   8.24722172e-02,
         7.25493258e-03,   6.43490782e-03,  -1.24397686e-02,
         0.00000000e+00,  -1.07720510e-02,   0.00000000e+00,
        -2.25678985e-02,  -1.14239099e-03,  -1.65071630e-03,
         2.36480954e-02,   0.00000000e+00,   1.64946984e-02,
        -1.21014949e-02,   0.00000000e+00,   7.83075849e-02,
         7.61585845e-03,   1.06046129e-02,  -9.28470931e-03,
         0.00000000e+00,   8.56607942e-03,   0.00000000e+00,
         1.14188596e-03,  -2.93681539e-02,   5.64670172e-03,
        -7.70838211e-03,   0.00000000e+00,   1.73415540e-02,
         4.24140469e-03,   0.00000000e+00,   9.42977989e-03,
         1.06557948e-01,  -2.32153631e-03,  -1.60423853e-02,
        -9.34481189e-03,   0.00000000e+00,  -6.42904686e-05,
         0.00000000e+00,   9.74712625e-03,  -3.11485567e-03,
        -1.07577738e-02,  -1.32648199e-02,   0.00000000e+00,
         9.57645799e-03,  -6.69924304e-02,   0.00000000e+00,
        -9.31386633e-03,  -2.44658897e-02,  -3.61464995e-02,
        -1.35366342e-02,  -1.47386513e-02,   1.01227483e-02,
         0.00000000e+00,  -1.71963022e-02,   0.00000000e+00,
         9.61060583e-03,  -2.93557344e-03,   5.03555916e-03,
        -8.59608883e-03,   0.00000000e+00,  -2.02112772e-02,
         7.50130345e-03,   0.00000000e+00,  -8.82883493e-03,
        -1.96166475e-02,   4.13332081e-02,   6.44558477e-02,
         5.85844796e-01,   3.51401173e-03,   5.64383188e-01,
         2.38318488e-02,  -1.37038837e-02,   5.90368346e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.53767829e-01,  -2.71301352e-02,   1.21949312e-02,
        -1.37641934e-02,   0.00000000e+00,   5.54698804e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.46652190e-03,   0.00000000e+00,   5.56777083e-01,
        -2.22475569e-03,  -1.12472425e-02,   2.35403900e-03,
         0.00000000e+00,  -5.10907668e-03,   0.00000000e+00,
         5.71670228e-01,  -6.75712702e-03,   3.62032823e-02,
         5.19557180e-03,   0.00000000e+00,   4.95613789e-03,
         0.00000000e+00,   1.32614127e-02,   5.69005304e-01,
        -2.06614184e-02,   1.82724377e-02,   6.14907479e-02,
         0.00000000e+00,  -1.12754182e-02,   0.00000000e+00,
        -2.21563815e-02,  -6.71592593e-02,   3.84772502e-01,
         1.08430467e-02,   4.39815235e-04,   1.59496871e-02,
         0.00000000e+00,   9.89854404e-03,   0.00000000e+00,
        -2.47771173e-02,   2.90012948e-02,   8.18315636e-02,
         4.44037495e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.54162523e-02,   0.00000000e+00,
         2.78507775e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.07713491e-01,
         5.94492875e-03,   2.43402692e-02,  -4.68538425e-02,
         0.00000000e+00,  -7.36357543e-02,   0.00000000e+00,
         2.42404954e-02,  -4.13969891e-02,  -3.44433842e-03,
        -8.78886130e-03,   0.00000000e+00,   5.06188445e-01,
         1.09611452e-02,   2.25963993e-02,   6.81048707e-02,
         0.00000000e+00,  -2.34364792e-02,   0.00000000e+00,
         3.71740986e-03,  -3.48642296e-02,   5.62902778e-02,
         2.18842316e-02,   0.00000000e+00,  -1.76820762e-02,
         5.37662913e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.10359010e-02,   0.00000000e+00,
        -9.51304057e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.39492503e-02,
         0.00000000e+00,   0.00000000e+00,   5.13200205e-01,
         1.18317234e-02,   6.46987065e-04,  -7.96595625e-03,
         0.00000000e+00,  -2.23049343e-02,   0.00000000e+00,
        -9.47567211e-02,  -1.22613949e-02,   1.36928492e-03,
         2.16081102e-02,   0.00000000e+00,   1.35509537e-02,
        -2.22137966e-03,   0.00000000e+00,   5.22865799e-01,
         8.69008540e-04,   3.12427915e-02,  -2.95628677e-02,
         0.00000000e+00,   4.60728758e-02,   0.00000000e+00,
        -8.81295444e-03,  -7.52506658e-02,   2.80820239e-02,
        -6.09032287e-03,   0.00000000e+00,  -5.30944514e-03,
        -2.33748660e-02,   0.00000000e+00,   1.42028835e-02,
         5.55843466e-01,  -6.72013212e-02,   2.51900153e-02,
        -1.25642009e-02,   0.00000000e+00,  -2.26721113e-02,
         0.00000000e+00,   5.23333187e-03,   3.93384238e-02,
         4.30021399e-02,   2.13031745e-03,   0.00000000e+00,
        -1.02877116e-02,  -2.96478345e-02,   0.00000000e+00,
        -1.00069840e-02,   2.29523610e-02,   5.33518219e-01,
        -2.82765108e-02,  -6.24936380e-02,   2.16619210e-02,
         0.00000000e+00,  -2.25390040e-02,   0.00000000e+00,
         6.20486407e-03,  -1.92604865e-02,   2.36296885e-03,
        -7.88902449e-03,   0.00000000e+00,  -1.20486386e-02,
        -6.23009115e-03,   0.00000000e+00,  -4.23029299e-03,
         1.03229640e-02,   1.03408403e-02,   5.52958672e-01,
        -2.95722068e-03,  -5.50759514e-03,  -8.51101921e-03,
         1.30943614e-02,  -1.18592711e-02,   1.44914746e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.74658372e-03,  -1.70802036e-03,  -1.33229833e-02,
         1.87929759e-02,   0.00000000e+00,  -5.63196725e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.70566647e-03,   0.00000000e+00,  -9.93388043e-03,
        -1.05620305e-02,   2.18962740e-03,  -4.66818501e-03,
         0.00000000e+00,  -6.97307805e-03,   0.00000000e+00,
         1.54201165e-02,   6.50674977e-03,   1.56411148e-02,
        -7.18798850e-03,   0.00000000e+00,   1.76833397e-02,
         0.00000000e+00,   1.65426845e-03,  -2.83668833e-02,
         1.91750673e-03,  -5.99786194e-03,   8.67412922e-03,
         0.00000000e+00,  -2.44215928e-03,   0.00000000e+00,
        -3.83353122e-03,   4.57601709e-03,  -6.02203203e-03,
         1.34769713e-03,   1.06508920e-03,   1.09486157e-02,
         0.00000000e+00,   2.81442439e-03,   0.00000000e+00,
        -5.77502228e-03,  -3.49644579e-03,  -1.96895890e-03,
        -1.16956500e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.45039720e-03,   0.00000000e+00,
         3.93786987e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.15493072e-03,
        -1.65135287e-03,   4.68178043e-03,  -4.17790482e-03,
         0.00000000e+00,  -2.74478435e-03,   0.00000000e+00,
         2.39623841e-03,  -5.71194493e-04,  -1.07345008e-03,
        -3.66335358e-03,   0.00000000e+00,   1.93579420e-02,
        -2.26274993e-04,  -1.12265761e-03,  -1.03823532e-04,
         0.00000000e+00,   2.37651969e-04,   0.00000000e+00,
        -1.99914077e-03,  -8.21246509e-04,  -3.12375342e-03,
        -5.23221872e-04,   0.00000000e+00,  -1.21972206e-02,
         7.61559518e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.95139156e-03,   0.00000000e+00,
         4.60805048e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.49606634e-03,
         0.00000000e+00,   0.00000000e+00,  -1.16003411e-02,
         9.39913207e-04,   1.69557839e-03,  -1.10538201e-03,
         0.00000000e+00,  -1.18598648e-04,   0.00000000e+00,
        -3.46711627e-04,  -5.91270125e-04,  -8.88412855e-04,
         3.37845830e-03,   0.00000000e+00,  -4.77876626e-03,
         3.58996979e-03,   0.00000000e+00,   9.82533632e-03,
        -2.69066829e-03,  -2.73820138e-03,   5.61376408e-04,
         0.00000000e+00,  -6.25265718e-03,   0.00000000e+00,
        -3.18799603e-04,   1.01752311e-02,  -2.40236827e-03,
         2.69055516e-04,   0.00000000e+00,  -2.52294270e-03,
        -8.91092576e-03,   0.00000000e+00,   3.60806333e-03,
        -3.77051935e-02,  -1.62392400e-03,   1.23507806e-03,
        -3.75318960e-03,   0.00000000e+00,  -1.13117569e-03,
         0.00000000e+00,   3.60300123e-03,   6.06101858e-04,
        -5.39209722e-04,  -2.84116088e-03,   0.00000000e+00,
         1.02067795e-02,  -7.85676898e-03,   0.00000000e+00,
        -6.00928007e-03,   1.15187241e-02,  -4.81028285e-04,
         2.83855256e-03,   6.57805697e-03,  -1.63695046e-03,
         0.00000000e+00,   3.99975271e-03,   0.00000000e+00,
         1.00978822e-03,  -1.80868660e-03,  -4.74483137e-04,
        -1.52656841e-03,   0.00000000e+00,  -3.34613472e-03,
         6.90863878e-03,   0.00000000e+00,  -2.47612752e-03,
         9.49965399e-03,  -6.35512581e-03,  -1.83688629e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.37987717e-03,  -8.67864250e-03,   1.22026471e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.40542054e-03,   0.00000000e+00,
        -1.15666990e-02,  -1.34852267e-02,   9.74383034e-03,
         0.00000000e+00,  -7.36750418e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.59433398e-03,   0.00000000e+00,   1.72346656e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.29579698e-03,   0.00000000e+00,
         1.83319464e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.53495136e-04,   0.00000000e+00,  -4.73619930e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.75377703e-04,   0.00000000e+00,  -1.10780435e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.33915645e-03,   3.21539285e-03,
        -1.33422916e-03,   0.00000000e+00,   1.01217300e-03,
         0.00000000e+00,  -1.27626640e-03,  -9.75558498e-04,
         2.43027972e-04,  -1.80817786e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.91789853e-03,   0.00000000e+00,  -2.81368738e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.68836262e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.78922745e-04,   0.00000000e+00,  -1.09290882e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.93550832e-03,   0.00000000e+00,
         0.00000000e+00,   3.35516425e-03,   3.38134335e-03,
        -2.05290337e-03,   0.00000000e+00,   7.37715112e-04,
         0.00000000e+00,  -3.86277007e-03,  -3.74006153e-03,
         6.67934342e-04,   1.64281586e-03,   0.00000000e+00,
         4.32405675e-03,   1.78682816e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.49559475e-03,   0.00000000e+00,  -4.11212255e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.70063182e-04,   0.00000000e+00,
         0.00000000e+00,   1.44609637e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.60504246e-03,   0.00000000e+00,  -6.57001250e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.35560161e-03,   0.00000000e+00,
         0.00000000e+00,   2.05944097e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.55459668e-03,   0.00000000e+00,
         2.93674990e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.87743285e-03,
         0.00000000e+00,   0.00000000e+00,  -5.89757116e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.13008780e-03,   0.00000000e+00,   3.88930505e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.92361369e-03,   0.00000000e+00,
         0.00000000e+00,  -1.13995898e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.50276102e-02,   1.70462078e-01,   2.95557552e-02,
        -3.73737194e-02,  -4.01497748e-02,  -1.02679336e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.59074253e-02,   1.66434795e-02,   8.06425594e-02,
        -1.55440287e-02,   0.00000000e+00,  -3.73969069e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.38584310e-01,   0.00000000e+00,   1.46557347e-01,
        -7.87001516e-03,  -2.61091801e-02,   1.37409964e-01,
         0.00000000e+00,   9.76046590e-02,   0.00000000e+00,
         1.44467694e-01,   4.06566347e-02,  -1.81374675e-02,
         6.46923821e-02,   0.00000000e+00,  -1.07906754e-01,
         0.00000000e+00,   3.63357565e-02,   1.26853912e-01,
        -7.60905810e-03,  -1.32016818e-02,  -4.20608879e-02,
         0.00000000e+00,   2.74888312e-02,   0.00000000e+00,
        -3.04964671e-03,  -4.97500256e-02,  -6.43071516e-02,
        -2.17581337e-03,   1.26316159e-02,  -1.28467102e-02,
         0.00000000e+00,  -1.17583942e-02,   0.00000000e+00,
        -1.58339346e-02,   7.42397526e-04,  -4.27117696e-02,
        -1.09413711e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.27611600e-02,   0.00000000e+00,
        -5.21377988e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.13272477e-01,
         6.12438974e-03,   2.51007514e-03,   1.77016172e-02,
         0.00000000e+00,   3.62388884e-02,   0.00000000e+00,
        -5.60678155e-02,   1.05193368e-02,  -2.18277523e-03,
         2.42035485e-02,   0.00000000e+00,  -1.21320786e-01,
        -1.81843577e-03,   4.74312913e-03,  -3.79163123e-02,
         0.00000000e+00,   2.63903339e-02,   0.00000000e+00,
         3.66084733e-02,   1.44225934e-02,  -3.36460635e-02,
        -2.28007589e-02,   0.00000000e+00,   3.43888280e-03,
        -1.08711993e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.16021532e-02,   0.00000000e+00,
        -7.36737386e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.60496843e-02,
         0.00000000e+00,   0.00000000e+00,   1.76093795e-01,
        -6.73928066e-04,   6.14308692e-03,  -3.42589706e-02,
         0.00000000e+00,  -2.22873000e-02,   0.00000000e+00,
        -6.99262436e-02,  -3.46768745e-03,  -7.48265975e-04,
         2.81016151e-02,   0.00000000e+00,   7.06352011e-02,
        -6.44537397e-02,   0.00000000e+00,   1.70247355e-01,
         9.40320936e-03,   2.30390906e-03,  -6.30307923e-03,
         0.00000000e+00,   1.80035019e-02,   0.00000000e+00,
        -1.03449343e-02,  -8.69144976e-02,   2.40270874e-02,
        -7.58133346e-03,   0.00000000e+00,   2.64166033e-02,
         3.22899583e-02,   0.00000000e+00,   2.51910749e-02,
         2.00080252e-01,   1.13593987e-02,  -5.57348003e-02,
         1.99363239e-02,   0.00000000e+00,  -1.02371917e-02,
         0.00000000e+00,  -5.79283781e-03,  -3.13152327e-02,
        -5.26509624e-03,  -4.02750932e-03,   0.00000000e+00,
        -3.43618814e-02,  -2.44136215e-02,   0.00000000e+00,
         2.17927766e-02,  -4.95658730e-02,  -8.05981415e-02,
        -4.63701449e-02,  -4.22949347e-02,   1.27881421e-02,
         0.00000000e+00,  -2.20332633e-02,   0.00000000e+00,
         4.39006521e-03,  -2.12170693e-02,   1.88599967e-02,
        -1.18454620e-02,   0.00000000e+00,  -1.20823945e-02,
        -2.86684727e-02,   0.00000000e+00,  -2.38211978e-02,
        -6.77955585e-03,   9.88350116e-02,   1.52453304e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.59119295e-02,  -2.69799197e-03,   2.39391247e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.18445554e-04,   0.00000000e+00,
         2.38938795e-03,   1.11147041e-02,  -1.46981788e-02,
         0.00000000e+00,   2.68608247e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.75757059e-03,   0.00000000e+00,   1.20346392e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.06134693e-03,   0.00000000e+00,
         1.17219534e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.45804087e-03,   0.00000000e+00,  -2.87457016e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.35877074e-03,   0.00000000e+00,  -1.76794941e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.39760774e-03,   1.84897498e-03,
        -3.70282029e-03,   0.00000000e+00,  -1.88547881e-04,
         0.00000000e+00,   2.72837893e-03,   3.74552319e-03,
        -3.29582041e-03,  -3.49829490e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.80451896e-03,   0.00000000e+00,   2.42587900e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.85136018e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.56679789e-03,   0.00000000e+00,  -2.83650754e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.00400117e-02,   0.00000000e+00,
         0.00000000e+00,   2.12422297e-03,  -6.59634510e-04,
         1.60457988e-03,   0.00000000e+00,  -1.90659817e-03,
         0.00000000e+00,   2.36531666e-03,   8.94652017e-04,
         7.88659171e-04,  -3.28318944e-05,   0.00000000e+00,
        -3.52783414e-03,   1.27155993e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.48136978e-04,   0.00000000e+00,   1.48604503e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.14301805e-03,   0.00000000e+00,
         0.00000000e+00,  -1.04091557e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.35608265e-04,   0.00000000e+00,   4.11537575e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.23063387e-03,   0.00000000e+00,
         0.00000000e+00,  -4.03605407e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.16952651e-03,   0.00000000e+00,
         1.78668741e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.18548450e-02,
         0.00000000e+00,   0.00000000e+00,   2.81961962e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.04643873e-04,   0.00000000e+00,   1.68014356e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.15501511e-03,   0.00000000e+00,
         0.00000000e+00,   1.02165378e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.18095912e-02,   8.84173212e-02,   2.55592033e-02,
        -2.53141354e-02,  -1.68334491e-02,  -5.23129317e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.28931571e-02,   2.41499402e-02,   4.68090422e-02,
         1.00496998e-02,   0.00000000e+00,  -1.13264264e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.37746390e-02,   0.00000000e+00,   8.42446919e-02,
         6.51224303e-03,   2.06350436e-04,   5.66569368e-02,
         0.00000000e+00,   4.61045532e-02,   0.00000000e+00,
         7.80637784e-02,   2.23143472e-02,  -1.37681270e-02,
         4.93465867e-02,   0.00000000e+00,  -6.85505480e-02,
         0.00000000e+00,   1.72423738e-02,   8.03090920e-02,
        -8.75154623e-03,  -2.74937151e-03,  -2.10440022e-02,
         0.00000000e+00,   2.07790292e-02,   0.00000000e+00,
        -5.50084614e-03,  -2.97172990e-02,  -3.85537599e-02,
        -2.84775946e-03,   5.53709366e-03,  -4.38610029e-03,
         0.00000000e+00,  -2.78235095e-03,   0.00000000e+00,
        -1.07505215e-02,   3.82476511e-03,  -2.01220223e-02,
        -5.89965841e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.97743740e-02,   0.00000000e+00,
        -2.84156956e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.74938890e-02,
        -1.11221353e-03,   1.83057640e-03,   4.22100571e-03,
         0.00000000e+00,   1.60274000e-02,   0.00000000e+00,
        -2.49148669e-02,   6.02756762e-03,  -4.91974799e-03,
         7.68019053e-03,   0.00000000e+00,  -4.69840525e-02,
        -6.98708010e-03,   1.00417787e-02,  -2.01152809e-02,
         0.00000000e+00,   2.06615125e-02,   0.00000000e+00,
         1.92494366e-02,   1.41029694e-02,  -1.84730296e-02,
        -1.03262078e-02,   0.00000000e+00,  -1.02400489e-02,
        -6.40099644e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.01581560e-02,   0.00000000e+00,
        -4.37557646e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.95134979e-02,
         0.00000000e+00,   0.00000000e+00,   9.94782782e-02,
        -5.59249674e-03,   7.59604006e-04,  -1.96657420e-02,
         0.00000000e+00,  -1.26704415e-02,   0.00000000e+00,
        -3.77275276e-02,  -2.68932748e-03,  -1.91863892e-04,
         1.45409841e-02,   0.00000000e+00,   2.82316182e-02,
        -3.44354165e-02,   0.00000000e+00,   8.81673618e-02,
         5.27734662e-04,   1.12881868e-03,  -3.92360328e-03,
         0.00000000e+00,   1.34788286e-02,   0.00000000e+00,
        -5.80998993e-03,  -5.60563279e-02,   1.64146717e-02,
        -4.83923458e-03,   0.00000000e+00,   1.62394720e-02,
         2.52637646e-02,   0.00000000e+00,   1.03936324e-02,
         1.26708280e-01,   4.25522323e-03,  -2.80237059e-02,
         1.26291635e-02,   0.00000000e+00,  -1.14705863e-02,
         0.00000000e+00,  -5.81907227e-03,  -2.14726254e-02,
         4.42174281e-03,   5.75843301e-04,   0.00000000e+00,
        -1.33762253e-02,  -8.75661558e-03,   0.00000000e+00,
         1.60636966e-02,  -3.32585955e-02,  -3.71842240e-02,
        -3.32306345e-02,  -2.65913880e-02,   5.06060194e-03,
         0.00000000e+00,  -1.01164217e-02,   0.00000000e+00,
        -2.68499185e-03,  -1.37375388e-02,   8.78777758e-03,
        -6.11287020e-03,   0.00000000e+00,  -6.22052826e-03,
        -2.10224134e-02,   0.00000000e+00,   1.16772586e-03,
        -5.04307645e-03,   5.34857220e-02,   8.41584008e-02,
         5.75279164e-02,  -4.79346086e-02,   4.71492832e-02,
         3.04425083e-02,  -3.55118007e-03,   8.89938514e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.06452286e-02,  -1.07810079e-02,  -2.27277405e-02,
        -9.58596884e-04,   0.00000000e+00,   7.36830367e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.52649898e-02,   0.00000000e+00,   1.71185428e-02,
        -1.63313969e-03,   1.22169506e-02,  -3.25157309e-02,
         0.00000000e+00,  -3.12064067e-02,   0.00000000e+00,
         1.93054917e-02,  -1.97062577e-02,   1.80690005e-02,
        -1.43836415e-02,   0.00000000e+00,   3.71508803e-02,
         0.00000000e+00,  -1.05377511e-02,   1.66198786e-02,
        -1.05627603e-02,   2.39574989e-02,   5.64303200e-02,
         0.00000000e+00,  -1.72164829e-02,   0.00000000e+00,
        -1.44292528e-02,  -1.62775706e-02,  -5.60661108e-03,
        -1.01904646e-02,   1.86560148e-02,   4.35835061e-02,
         0.00000000e+00,  -1.59594229e-04,   0.00000000e+00,
        -1.63970588e-02,  -3.33415108e-03,   1.07555744e-02,
        -2.20957289e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.34914857e-02,   0.00000000e+00,
         2.79355872e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.80464603e-02,
         4.37848864e-03,   4.28095710e-03,  -1.38907634e-02,
         0.00000000e+00,  -3.63966686e-02,   0.00000000e+00,
         2.43712339e-02,  -1.63793128e-02,   2.11204919e-03,
        -1.80073296e-02,   0.00000000e+00,   8.46347383e-02,
        -3.88130906e-03,   1.12550914e-02,   3.36273634e-02,
         0.00000000e+00,  -2.20454901e-02,   0.00000000e+00,
        -1.23181303e-02,  -1.57853963e-02,   2.85291030e-02,
         1.23626478e-02,   0.00000000e+00,  -6.60759858e-03,
         1.02087904e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.62231434e-03,   0.00000000e+00,
         5.73405531e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.36960369e-02,
         0.00000000e+00,   0.00000000e+00,  -9.10351075e-04,
         6.23314313e-03,   2.01993650e-04,   7.77143154e-03,
         0.00000000e+00,   2.94694024e-03,   0.00000000e+00,
         5.01547936e-03,  -4.57731639e-04,   1.51767886e-03,
         7.53915117e-03,   0.00000000e+00,  -1.88278804e-02,
         2.03483039e-02,   0.00000000e+00,   4.01892206e-03,
        -3.75385744e-03,   6.12385999e-03,  -1.90213946e-03,
         0.00000000e+00,   3.32970366e-03,   0.00000000e+00,
         1.31616447e-03,   1.85315688e-02,  -2.66268932e-03,
        -6.76428617e-04,   0.00000000e+00,  -8.97538017e-03,
        -1.89219150e-02,   0.00000000e+00,  -3.56459665e-03,
        -3.31921550e-03,  -2.65871600e-02,   3.41926937e-02,
        -2.57247728e-03,   0.00000000e+00,   9.54320304e-04,
         0.00000000e+00,   2.57169867e-03,   2.32909981e-02,
         2.51174760e-02,   6.92432383e-03,   0.00000000e+00,
         1.41596160e-02,  -5.68391709e-03,   0.00000000e+00,
        -1.05050326e-02,   2.01213556e-02,   7.67794111e-02,
         1.42854941e-02,   5.52994129e-05,   5.94605543e-04,
         0.00000000e+00,   1.72122483e-03,   0.00000000e+00,
         4.84972639e-03,   1.10066817e-03,  -9.65091441e-03,
        -5.34768427e-03,   0.00000000e+00,  -3.48417559e-03,
         8.67920931e-03,   0.00000000e+00,   1.13597381e-02,
         2.59635746e-03,  -2.62915189e-02,   1.08427196e-02,
         2.19395325e-02,  -4.91230779e-03,   5.76751532e-03,
         4.04138249e-02,  -2.97949390e-02,   2.37451193e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.05988958e-02,  -3.96424469e-03,  -5.46979291e-03,
         6.25682778e-03,   0.00000000e+00,   3.41643655e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.69950987e-02,   0.00000000e+00,   1.28937549e-02,
        -5.79307558e-03,   2.27311183e-02,  -7.23662065e-03,
         0.00000000e+00,  -1.43420297e-02,   0.00000000e+00,
         9.33818023e-03,  -8.81353994e-03,   1.39802429e-02,
        -4.99434428e-04,   0.00000000e+00,   1.10085192e-02,
         0.00000000e+00,  -4.40707820e-03,   1.18897131e-02,
        -6.89466640e-03,   1.50527839e-02,   4.49704886e-02,
         0.00000000e+00,  -7.71007472e-03,   0.00000000e+00,
        -1.58995068e-02,  -2.16913324e-02,  -3.52489021e-02,
        -1.98088400e-02,   3.35803064e-02,   6.83000703e-02,
         0.00000000e+00,  -4.97202863e-03,   0.00000000e+00,
        -2.88154174e-02,  -1.51543579e-02,  -2.98760241e-02,
        -1.23715334e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.50533766e-02,   0.00000000e+00,
         1.50269285e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.90503458e-02,
        -1.70888596e-04,   5.10297734e-03,  -6.38447887e-03,
         0.00000000e+00,  -2.29481107e-02,   0.00000000e+00,
         1.37812670e-02,  -9.61462230e-03,  -8.42483533e-04,
        -1.93065881e-02,   0.00000000e+00,   3.91549367e-02,
        -1.78038178e-03,   6.29597747e-03,   1.91908158e-02,
         0.00000000e+00,  -1.18481598e-02,   0.00000000e+00,
        -6.87076482e-03,  -1.13158526e-02,   1.04854590e-02,
         2.92191549e-03,   0.00000000e+00,  -9.44202091e-03,
         4.74821183e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.82862748e-03,   0.00000000e+00,
         1.13199729e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.26139173e-03,
         0.00000000e+00,   0.00000000e+00,   5.07044021e-03,
         3.31858091e-03,  -3.72472683e-03,   1.79767336e-03,
         0.00000000e+00,   1.11771075e-03,   0.00000000e+00,
         5.39804045e-03,   4.95871475e-04,   4.23934182e-03,
         1.76848678e-02,   0.00000000e+00,  -9.67125802e-03,
         9.46348636e-03,   0.00000000e+00,   4.90122717e-03,
        -3.80991806e-03,   2.68311866e-03,  -4.43546100e-04,
         0.00000000e+00,   1.69606370e-03,   0.00000000e+00,
         2.10841075e-03,   5.74841950e-03,  -1.36467399e-03,
        -4.53746976e-03,   0.00000000e+00,  -2.71423349e-03,
        -1.10096784e-02,   0.00000000e+00,  -1.93201448e-03,
         7.75348017e-03,  -1.66908701e-02,   1.97455379e-02,
        -2.81784126e-03,   0.00000000e+00,  -1.79204996e-04,
         0.00000000e+00,   1.48995268e-03,   1.14103349e-02,
         1.35154122e-02,   2.64150331e-03,   0.00000000e+00,
         1.49200208e-02,  -1.86837883e-02,   0.00000000e+00,
        -6.52350470e-03,   8.96248158e-03,   2.61794713e-02,
         7.05938933e-03,  -5.24123149e-04,   1.34544293e-03,
         0.00000000e+00,  -2.01416913e-03,   0.00000000e+00,
         7.06318147e-04,  -3.70854600e-03,  -5.93823142e-03,
        -9.21072037e-03,   0.00000000e+00,  -6.24529134e-03,
         5.77472222e-03,   0.00000000e+00,   1.33457791e-02,
         3.12156666e-03,  -5.91299472e-03,   9.04882273e-03,
        -5.04193413e-02,   1.42642468e-02,  -5.53371170e-02,
        -1.62451977e-04,   3.25448940e-03,  -6.44788971e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.21828572e-02,   3.68243212e-04,   8.22714344e-03,
        -3.22953968e-03,   0.00000000e+00,  -5.75050954e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.45656006e-02,   0.00000000e+00,  -4.54719709e-02,
         7.55789698e-03,   4.65669922e-03,   1.16796518e-02,
         0.00000000e+00,   1.27391503e-02,   0.00000000e+00,
        -5.07472699e-02,   8.46752032e-03,  -5.93527751e-03,
         2.87383647e-03,   0.00000000e+00,  -1.11723912e-02,
         0.00000000e+00,   2.51957648e-03,  -4.49401235e-02,
         8.80106637e-03,  -1.07728768e-02,  -1.75791746e-02,
         0.00000000e+00,   4.28478574e-03,   0.00000000e+00,
         5.84018106e-03,   7.49773697e-03,  -2.67857151e-02,
         9.39696083e-04,  -4.14430711e-03,  -1.05084154e-02,
         0.00000000e+00,  -3.62672369e-03,   0.00000000e+00,
         1.04618515e-02,  -4.42579322e-03,  -1.48078901e-02,
        -3.28319946e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.49147552e-02,   0.00000000e+00,
        -1.70207065e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.81749461e-02,
         2.80785759e-04,  -1.03392759e-02,   3.44464694e-02,
         0.00000000e+00,   3.72446636e-02,   0.00000000e+00,
        -2.02423626e-02,   1.44113890e-02,   4.06205019e-03,
         1.25242514e-02,   0.00000000e+00,  -6.09642959e-02,
        -9.24886927e-03,  -5.97624575e-03,  -4.44828033e-02,
         0.00000000e+00,   5.15173567e-03,   0.00000000e+00,
         6.84545130e-03,   9.35071810e-03,  -2.63330612e-02,
        -1.62252791e-02,   0.00000000e+00,   1.27933767e-03,
        -5.28638789e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.66399101e-03,   0.00000000e+00,
         2.46264540e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.31412549e-03,
         0.00000000e+00,   0.00000000e+00,  -3.39590015e-02,
        -6.08816969e-03,   1.49459991e-03,  -3.15032321e-03,
         0.00000000e+00,   1.67109201e-03,   0.00000000e+00,
         3.25170879e-02,   4.38085724e-03,  -4.56708407e-03,
        -6.54254871e-03,   0.00000000e+00,   1.16519280e-03,
        -3.12957690e-03,   0.00000000e+00,  -3.53799967e-02,
         6.15850596e-03,  -9.08698912e-03,   1.26560990e-02,
         0.00000000e+00,  -1.44369245e-02,   0.00000000e+00,
         5.59498964e-03,   1.52725514e-02,  -3.99406000e-03,
         9.15157008e-04,   0.00000000e+00,   2.34266455e-03,
         3.93666832e-03,   0.00000000e+00,  -2.04483999e-03,
        -4.01806397e-02,   3.29180946e-02,  -2.03773574e-02,
         8.96392996e-03,   0.00000000e+00,   6.88668353e-03,
         0.00000000e+00,  -4.01723283e-03,  -1.30920476e-02,
        -7.50950770e-03,  -2.38082954e-03,   0.00000000e+00,
        -5.24366031e-03,  -4.65630868e-03,   0.00000000e+00,
         5.66848146e-03,  -6.23125450e-03,  -5.96438235e-02,
         5.53747322e-03,   2.29686311e-02,  -6.80084242e-03,
         0.00000000e+00,   2.08370156e-03,   0.00000000e+00,
         6.51807241e-04,   7.20511923e-03,  -1.56781164e-03,
         1.58732037e-03,   0.00000000e+00,   4.75842106e-03,
         9.38557579e-04,   0.00000000e+00,   6.99441391e-03,
         2.52582282e-03,   4.73760349e-03,  -3.65789004e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.09116859e-03,  -5.29692727e-03,   8.65624433e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.06586563e-04,   0.00000000e+00,
        -6.65164047e-03,  -3.18662112e-03,  -3.02319759e-03,
         0.00000000e+00,  -1.55030603e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.91506251e-03,   0.00000000e+00,   2.92902036e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.72483644e-03,   0.00000000e+00,
         2.32213887e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.93245580e-03,   0.00000000e+00,  -2.24852077e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.39205375e-03,   0.00000000e+00,  -1.66649864e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.88866529e-03,   1.36804436e-03,
        -1.33218790e-02,   0.00000000e+00,   1.35790170e-03,
         0.00000000e+00,   3.71304850e-03,   2.85680616e-03,
        -3.12732903e-03,  -3.77350178e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.22706058e-03,   0.00000000e+00,   1.60362594e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.81969878e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.17337505e-02,   0.00000000e+00,  -5.17580128e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.17283774e-03,   0.00000000e+00,
         0.00000000e+00,   3.27887328e-04,   9.43055072e-04,
         2.23813734e-04,   0.00000000e+00,   4.91211567e-04,
         0.00000000e+00,  -3.08819817e-03,  -2.63938612e-03,
         4.64145088e-04,   8.13675369e-04,   0.00000000e+00,
         6.95457414e-04,   1.79297455e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.35734657e-03,   0.00000000e+00,  -3.90455324e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.83070014e-04,   0.00000000e+00,
         0.00000000e+00,   7.24839468e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.12004146e-03,   0.00000000e+00,  -1.81067435e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.47017423e-03,   0.00000000e+00,
         0.00000000e+00,   1.67715807e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.99588209e-03,   0.00000000e+00,
         2.32781297e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.38862476e-03,
         0.00000000e+00,   0.00000000e+00,  -3.31518137e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.65070367e-04,   0.00000000e+00,  -4.53528879e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.29393943e-03,   0.00000000e+00,
         0.00000000e+00,  -5.04882264e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.72997086e-02,  -3.87660433e-02,   4.41874701e-02,
         5.25215251e-03,   6.17684940e-03,   6.43738943e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.86053480e-02,  -1.52310414e-02,  -8.19999679e-03,
        -6.30980425e-03,   0.00000000e+00,   6.14048959e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.43891842e-02,   0.00000000e+00,   1.78979542e-02,
         9.87581191e-04,  -2.87127207e-03,  -2.29360954e-02,
         0.00000000e+00,  -2.10286098e-02,   0.00000000e+00,
         1.98007017e-02,  -2.35821555e-02,   1.17398957e-02,
        -1.27263912e-02,   0.00000000e+00,   2.92254701e-02,
         0.00000000e+00,  -8.59951121e-03,   2.73661317e-02,
        -9.47865211e-03,   1.87510673e-02,   2.79888282e-02,
         0.00000000e+00,  -1.39456532e-02,   0.00000000e+00,
        -6.46651367e-03,  -5.29188872e-03,   2.73314578e-02,
        -7.85157431e-03,   9.19522224e-03,   1.85601810e-02,
         0.00000000e+00,   3.79536438e-03,   0.00000000e+00,
        -8.79850836e-03,   2.62772528e-03,   1.54447909e-02,
         2.15002071e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.73208767e-02,   0.00000000e+00,
         2.97192117e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.91967480e-02,
        -8.01657909e-05,   6.87469441e-03,  -1.97108321e-02,
         0.00000000e+00,  -4.39248958e-02,   0.00000000e+00,
         2.63587015e-02,  -2.03695557e-02,  -5.03331164e-03,
        -1.25015876e-02,   0.00000000e+00,   6.62261146e-02,
         1.07324118e-02,   1.16772967e-02,   6.44688475e-02,
         0.00000000e+00,  -2.96002863e-02,   0.00000000e+00,
        -1.06680539e-02,  -2.01840795e-02,   3.68548180e-02,
         2.39595594e-02,   0.00000000e+00,   5.26020320e-03,
         6.60695874e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.50914345e-03,   0.00000000e+00,
        -2.17902058e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.12787376e-02,
         0.00000000e+00,   0.00000000e+00,   2.30376748e-03,
         2.47591452e-03,  -6.72471430e-03,   1.46659238e-02,
         0.00000000e+00,   1.26789514e-03,   0.00000000e+00,
        -7.30851840e-03,  -4.14507942e-03,   5.17145966e-03,
         4.88386371e-03,   0.00000000e+00,  -8.37931209e-03,
         1.19801052e-02,   0.00000000e+00,   5.73867099e-03,
        -1.29821524e-02,   1.89796614e-03,  -7.60647497e-03,
         0.00000000e+00,   5.35695403e-03,   0.00000000e+00,
        -1.88756973e-03,   1.67061735e-02,  -4.79149269e-03,
        -6.70897499e-04,   0.00000000e+00,  -9.50970103e-03,
        -8.98108428e-03,   0.00000000e+00,  -2.79502150e-03,
         8.59462208e-03,  -3.79362990e-02,   3.87328770e-02,
        -1.13058392e-02,   0.00000000e+00,  -2.56571010e-04,
         0.00000000e+00,   1.69281134e-04,   1.68697137e-02,
         1.33533047e-02,   7.99906121e-03,   0.00000000e+00,
        -5.07403330e-03,   5.37745866e-03,   0.00000000e+00,
        -7.16320858e-03,   1.30510938e-02,   7.07622731e-02,
         1.05890483e-02,  -9.10766409e-03,   3.78789787e-03,
         0.00000000e+00,  -2.67080222e-04,   0.00000000e+00,
        -6.47378157e-03,  -9.04168457e-03,  -2.32102118e-03,
        -1.47896736e-03,   0.00000000e+00,   1.77083399e-03,
         1.41966911e-03,   0.00000000e+00,  -2.51993215e-03,
        -2.95654766e-03,  -2.21006440e-02,   8.19768143e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.19639930e-03,  -1.11322778e-03,   1.24772989e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.99234744e-04,   0.00000000e+00,
         1.24599887e-03,   4.93551639e-03,  -3.52178911e-03,
         0.00000000e+00,   1.67505907e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.87705356e-03,   0.00000000e+00,  -3.76230654e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.95037625e-03,   0.00000000e+00,
        -3.05911376e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.17702199e-03,   0.00000000e+00,   4.33982578e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.19778555e-04,   0.00000000e+00,   8.31891845e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.11877592e-04,  -8.64952548e-04,
        -1.19345982e-03,   0.00000000e+00,  -5.28080669e-04,
         0.00000000e+00,   2.62938481e-03,   2.86440865e-03,
        -3.88105599e-05,  -1.04251434e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.65735063e-04,   0.00000000e+00,   3.27582407e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.96671978e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.53032383e-03,   0.00000000e+00,  -1.38986160e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.05826637e-03,   0.00000000e+00,
         0.00000000e+00,  -2.88066132e-03,  -5.19125619e-03,
         6.55226215e-03,   0.00000000e+00,  -3.24861337e-03,
         0.00000000e+00,   7.97508941e-03,   8.24538147e-03,
        -2.16814908e-03,  -1.57010558e-04,   0.00000000e+00,
        -1.59860548e-03,  -3.32937346e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.38461862e-03,   0.00000000e+00,   7.30466475e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.19357858e-03,   0.00000000e+00,
         0.00000000e+00,  -3.04849103e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.67077115e-03,   0.00000000e+00,   1.13355169e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.03660987e-04,   0.00000000e+00,
         0.00000000e+00,  -4.64376759e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.94774882e-04,   0.00000000e+00,
        -2.32904373e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.62027212e-03,
         0.00000000e+00,   0.00000000e+00,   9.04435558e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.96394538e-03,   0.00000000e+00,  -4.44828373e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.13079372e-05,   0.00000000e+00,
         0.00000000e+00,   3.02545277e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.68293126e-02,  -4.37186641e-02,  -3.30273877e-02,
         7.93646154e-03,   1.27968330e-02,   8.92825532e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.37470192e-03,  -1.11888992e-02,  -1.43648322e-02,
        -2.01766682e-03,   0.00000000e+00,  -1.35405605e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.51326087e-02,   0.00000000e+00,  -6.43068413e-02,
         4.61170842e-03,   2.54813401e-03,  -3.20197469e-02,
         0.00000000e+00,  -2.39429724e-02,   0.00000000e+00,
        -6.71164900e-02,  -1.73952926e-02,  -1.25386213e-04,
        -1.59089862e-02,   0.00000000e+00,   2.55932342e-02,
         0.00000000e+00,  -9.21350189e-03,  -5.40829475e-02,
         5.33653438e-03,   5.40820019e-03,   6.11995952e-03,
         0.00000000e+00,  -6.75989874e-03,   0.00000000e+00,
         1.75097592e-03,   1.69734864e-02,   3.16805861e-03,
        -1.87178357e-03,  -4.83900014e-03,   3.06173757e-03,
         0.00000000e+00,   5.73212209e-03,   0.00000000e+00,
         9.93345944e-03,  -6.01462308e-04,   7.77867858e-03,
         1.42914098e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.16579238e-03,   0.00000000e+00,
         2.06467647e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.41584574e-03,
        -5.28587358e-03,  -3.33157878e-03,  -6.95390392e-04,
         0.00000000e+00,  -1.03603318e-02,   0.00000000e+00,
         2.64612871e-02,  -5.88806298e-04,  -3.29503492e-03,
        -4.86979933e-03,   0.00000000e+00,   4.93156763e-03,
        -1.62251321e-03,  -5.10678131e-03,   1.18762319e-02,
         0.00000000e+00,  -1.28745297e-02,   0.00000000e+00,
        -1.92389016e-02,  -4.64776880e-03,   8.61883222e-03,
         8.57711912e-03,   0.00000000e+00,   2.95696583e-03,
         6.41095479e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.64173340e-02,   0.00000000e+00,
         5.56248581e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.64690329e-02,
         0.00000000e+00,   0.00000000e+00,  -7.15767533e-02,
        -4.32418663e-03,  -8.88566161e-03,   3.28122164e-02,
         0.00000000e+00,   1.85681574e-02,   0.00000000e+00,
         6.46821665e-02,   9.97618838e-03,  -1.92004755e-03,
        -9.66464670e-03,   0.00000000e+00,  -1.80498900e-02,
         1.82194439e-02,   0.00000000e+00,  -7.12248787e-02,
        -3.06447119e-03,  -9.37450962e-03,   1.46891179e-02,
         0.00000000e+00,  -1.94531025e-02,   0.00000000e+00,
         1.40327777e-02,   5.91484423e-02,  -1.56859981e-02,
         2.93592712e-03,   0.00000000e+00,  -8.12188728e-03,
        -7.70364836e-03,   0.00000000e+00,  -6.98001625e-03,
        -7.86383761e-02,   5.60225769e-03,   2.67738894e-02,
        -7.91785871e-03,   0.00000000e+00,   7.02124943e-03,
         0.00000000e+00,   2.73218035e-03,   5.16700139e-03,
        -7.78360417e-04,   2.04715150e-03,   0.00000000e+00,
         6.31308799e-04,   5.12003991e-03,   0.00000000e+00,
        -4.65896756e-03,   1.10330495e-02,   3.76523034e-04,
         3.94574248e-02,   3.72295397e-02,  -7.51049553e-03,
         0.00000000e+00,   9.88423144e-03,   0.00000000e+00,
        -8.01534673e-03,   1.20262120e-02,  -5.69984263e-03,
         5.29529192e-03,   0.00000000e+00,   7.33272670e-03,
         6.51363899e-03,   0.00000000e+00,   3.04980094e-03,
        -3.12165690e-03,  -2.97510942e-02,  -6.66088789e-02,
        -5.22210563e-02,  -2.81472963e-02,  -5.84716992e-02,
         4.67601570e-03,   1.26348663e-02,  -3.82717412e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.63849358e-02,  -6.39267198e-03,  -1.18153728e-02,
         2.26923023e-03,   0.00000000e+00,  -4.62749040e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.10734456e-02,   0.00000000e+00,  -7.93952517e-02,
         6.51456227e-03,   4.18844375e-03,  -1.76335320e-02,
         0.00000000e+00,  -1.35422979e-02,   0.00000000e+00,
        -7.58448996e-02,  -6.20483402e-03,  -9.22366198e-04,
        -8.50294953e-03,   0.00000000e+00,   1.80556743e-02,
         0.00000000e+00,  -5.40330381e-03,  -7.79836409e-02,
         5.65056301e-03,   1.06002059e-04,  -2.54581740e-03,
         0.00000000e+00,  -2.31799712e-03,   0.00000000e+00,
         3.09759729e-03,   1.98340228e-02,  -1.77566467e-02,
        -2.71553072e-03,  -1.93616189e-03,   7.27523957e-06,
         0.00000000e+00,   2.37167021e-03,   0.00000000e+00,
         9.47472862e-03,  -4.15819542e-03,  -4.70139620e-03,
        -1.83105847e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.92782789e-02,   0.00000000e+00,
         6.95732122e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.67987210e-02,
        -3.22981761e-03,  -8.86886874e-03,   1.25140842e-02,
         0.00000000e+00,   9.19160171e-03,   0.00000000e+00,
         8.50504896e-03,   9.89010647e-03,  -9.52468415e-04,
        -2.32982774e-04,   0.00000000e+00,  -2.89811212e-02,
        -1.13305068e-02,  -7.96854232e-03,  -1.67103702e-02,
         0.00000000e+00,  -2.76382299e-03,   0.00000000e+00,
        -1.05153330e-02,   9.61475320e-03,  -9.16236743e-03,
        -2.98198136e-03,   0.00000000e+00,   1.39117361e-03,
        -2.82715318e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.39231485e-02,   0.00000000e+00,
         6.13368430e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.26364498e-02,
         0.00000000e+00,   0.00000000e+00,  -7.92148563e-02,
        -3.96412770e-03,  -2.67295829e-03,   1.74542115e-02,
         0.00000000e+00,   1.44270784e-02,   0.00000000e+00,
         5.68241619e-02,   9.40375181e-03,  -2.90411862e-03,
        -9.76414871e-03,   0.00000000e+00,  -1.36160350e-02,
         1.15572267e-02,   0.00000000e+00,  -7.45223587e-02,
        -2.65599691e-03,  -2.05541456e-02,   2.47415438e-02,
         0.00000000e+00,  -3.59500412e-02,   0.00000000e+00,
         1.11522079e-02,   7.39082271e-02,  -1.90448261e-02,
         4.51991737e-03,   0.00000000e+00,  -3.53011319e-03,
        -3.20797042e-03,   0.00000000e+00,  -4.16421585e-03,
        -9.91368004e-02,   2.42958100e-02,   1.23282193e-02,
         1.36472435e-03,   0.00000000e+00,   1.10753464e-02,
         0.00000000e+00,   2.69484882e-04,  -9.24070382e-03,
        -1.28758996e-03,   1.04209619e-03,   0.00000000e+00,
         3.96889234e-04,   5.54360572e-03,   0.00000000e+00,
        -4.61844089e-04,   5.39770774e-03,  -3.37833648e-02,
         3.36197919e-02,   4.22866858e-02,  -1.01886088e-02,
         0.00000000e+00,   1.35173210e-02,   0.00000000e+00,
        -1.49505380e-03,   9.41348142e-03,  -5.10826741e-03,
         4.00690774e-03,   0.00000000e+00,   6.73508951e-03,
         5.01866611e-03,   0.00000000e+00,   5.93892146e-03,
         2.00711596e-03,  -2.09721314e-02,  -7.98517905e-02,
        -3.05048779e-03,   4.78659256e-03,   2.53663464e-03,
        -1.44956100e-02,   7.94656132e-03,  -1.39548543e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.49454804e-03,   2.33243483e-03,   4.68847983e-04,
        -1.49271211e-03,   0.00000000e+00,  -8.13639922e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.66542713e-03,   0.00000000e+00,   2.67956058e-03,
        -6.22851861e-05,  -9.49810406e-03,   9.78316594e-03,
         0.00000000e+00,   3.58206937e-03,   0.00000000e+00,
         1.04013477e-03,   2.57880743e-03,  -3.69930261e-03,
         9.19367157e-03,   0.00000000e+00,  -6.93993020e-03,
         0.00000000e+00,  -1.53350796e-03,  -4.09159439e-03,
        -6.71266269e-03,   7.87063662e-03,  -2.46197956e-04,
         0.00000000e+00,   9.69143566e-04,   0.00000000e+00,
         5.67024373e-04,   3.47297331e-03,   1.24544415e-03,
        -4.20938920e-03,   6.12561837e-03,  -2.02778463e-03,
         0.00000000e+00,  -1.45382123e-03,   0.00000000e+00,
        -9.79312707e-05,   2.07751604e-03,  -3.83981842e-05,
        -5.49543471e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.59720587e-03,   0.00000000e+00,
        -4.16979915e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.52537203e-03,
         6.86624599e-03,  -3.38392409e-03,   5.73863205e-03,
         0.00000000e+00,   6.11501837e-03,   0.00000000e+00,
        -6.76651974e-03,  -1.29484102e-03,   2.42310066e-03,
         3.41963004e-03,   0.00000000e+00,  -1.15223699e-02,
        -1.80721700e-02,   1.35863931e-02,  -1.16378967e-02,
         0.00000000e+00,   1.57599448e-03,   0.00000000e+00,
         1.46278697e-03,   4.42211319e-03,  -2.42096184e-03,
        -1.61347739e-03,   0.00000000e+00,  -1.45837022e-03,
        -5.68012189e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.94982043e-03,   0.00000000e+00,
        -3.69369619e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.85326676e-03,
         0.00000000e+00,   0.00000000e+00,   4.63609547e-03,
         1.89267254e-03,   9.20872867e-03,  -6.87797216e-03,
         0.00000000e+00,   2.28999785e-04,   0.00000000e+00,
        -1.47495845e-03,   2.94309224e-03,  -2.17479885e-03,
         4.71041540e-06,   0.00000000e+00,   3.35870753e-03,
        -4.04594343e-03,   0.00000000e+00,   3.19358804e-03,
         9.37742761e-03,   6.87913850e-03,   3.37769610e-03,
         0.00000000e+00,   3.42289808e-03,   0.00000000e+00,
        -2.22696815e-03,  -8.28430666e-03,   3.69235700e-03,
         1.97744562e-03,   0.00000000e+00,  -1.74931611e-04,
         2.96379628e-03,   0.00000000e+00,   2.36807922e-03,
         2.70308412e-03,   1.43102081e-03,   2.12959229e-03,
         2.51397259e-02,   0.00000000e+00,  -4.15553929e-03,
         0.00000000e+00,  -4.06645635e-03,  -6.78309692e-04,
         7.44947291e-03,   7.29717768e-03,   0.00000000e+00,
        -5.24285788e-03,   1.40066018e-02,   0.00000000e+00,
         1.38300429e-03,  -3.66609836e-03,  -5.54626788e-03,
        -2.97449495e-04,  -2.12023647e-03,  -2.01437773e-03,
         0.00000000e+00,  -4.00193457e-04,   0.00000000e+00,
         1.07055984e-02,   9.05495221e-03,  -4.29503307e-03,
        -2.63315542e-03,   0.00000000e+00,  -2.03224534e-03,
        -4.60428451e-03,   0.00000000e+00,  -5.30647290e-03,
        -3.91159218e-03,   3.89338323e-03,   2.65768049e-03,
         1.67383160e-02,   6.48227876e-03,   1.35537011e-02,
         1.72330121e-03,  -8.98760802e-03,   1.36052900e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.14927088e-02,  -4.22197562e-03,   1.21663400e-02,
        -3.94407924e-03,   0.00000000e+00,   1.60277387e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.46116064e-03,   0.00000000e+00,   2.05950140e-02,
        -3.15804711e-03,  -5.97710662e-03,   6.89697010e-03,
         0.00000000e+00,   1.66407859e-03,   0.00000000e+00,
         2.00676706e-02,  -1.27962647e-02,  -8.04414460e-03,
         3.46873952e-03,   0.00000000e+00,  -6.44381585e-03,
         0.00000000e+00,  -2.24454531e-04,   1.70957842e-02,
         3.72147144e-03,   1.44762776e-03,   1.72319980e-03,
         0.00000000e+00,   2.09585002e-03,   0.00000000e+00,
         4.07419913e-05,  -4.27756090e-03,  -1.23995673e-03,
         7.72162048e-04,   1.54558254e-03,   2.46037239e-03,
         0.00000000e+00,   9.00896983e-04,   0.00000000e+00,
        -4.52956349e-03,   1.30838693e-04,  -9.45648268e-04,
        -3.08725755e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.34809729e-03,   0.00000000e+00,
         3.09502319e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.68789739e-03,
         2.06987913e-03,   6.46310790e-03,  -3.98678968e-03,
         0.00000000e+00,  -4.02478251e-03,   0.00000000e+00,
        -1.12218305e-03,  -3.55368145e-03,  -2.22784546e-03,
        -9.40321719e-04,   0.00000000e+00,   8.05479926e-03,
         3.22386357e-03,  -4.64413686e-03,   5.28670255e-03,
         0.00000000e+00,  -1.39883317e-03,   0.00000000e+00,
        -1.47909600e-03,  -8.45246050e-03,   2.70509597e-03,
         7.93437088e-04,   0.00000000e+00,  -9.04977306e-04,
         7.90423513e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.13215415e-03,   0.00000000e+00,
        -1.04904835e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.84224684e-03,
         0.00000000e+00,   0.00000000e+00,   1.86215998e-02,
         1.38478940e-02,   1.16171451e-02,  -2.84546127e-03,
         0.00000000e+00,   1.28383779e-03,   0.00000000e+00,
        -1.12258145e-02,   2.98395283e-04,   1.31024812e-03,
         4.19729323e-03,   0.00000000e+00,   5.32215047e-03,
        -2.58744942e-03,   0.00000000e+00,   1.72931230e-02,
         1.35128733e-02,   1.71053487e-02,  -5.95570068e-03,
         0.00000000e+00,   8.36765595e-03,   0.00000000e+00,
        -2.50691829e-03,  -7.40512567e-03,   1.52010522e-03,
         1.75073389e-04,   0.00000000e+00,   1.89313556e-03,
        -1.00363334e-03,   0.00000000e+00,   3.32354613e-04,
         2.58044281e-02,  -2.16821286e-03,  -1.76615486e-03,
        -3.26661786e-03,   0.00000000e+00,  -1.41423567e-03,
         0.00000000e+00,   8.77806967e-03,   1.00499617e-02,
        -2.77736816e-03,  -1.52454976e-03,   0.00000000e+00,
        -6.14369609e-03,  -8.60671537e-03,   0.00000000e+00,
        -2.90125147e-03,  -5.36933557e-03,   1.06479491e-02,
         6.24600241e-04,  -3.83924649e-03,   1.59961986e-02,
         0.00000000e+00,  -3.76700941e-03,   0.00000000e+00,
         1.77969298e-02,   1.53834714e-02,  -3.53679832e-03,
        -3.13310341e-04,   0.00000000e+00,  -1.73598213e-03,
        -8.17790405e-04,   0.00000000e+00,  -4.99883087e-03,
        -1.64245825e-02,   3.61294977e-03,   1.44239282e-02,
        -5.95889259e-02,   5.62626923e-03,  -1.21624855e-02,
         1.46929718e-02,   6.15138909e-03,  -2.83271047e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.91720139e-02,   7.62232312e-02,   3.33835549e-02,
        -1.00149870e-04,   0.00000000e+00,  -3.09604090e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.50247510e-03,   0.00000000e+00,  -7.54827159e-03,
         5.06839970e-02,   7.41937347e-02,  -1.20695532e-02,
         0.00000000e+00,   2.40145723e-02,   0.00000000e+00,
        -1.12127093e-02,  -3.71085320e-02,  -6.03903596e-02,
         1.78197455e-02,   0.00000000e+00,  -2.05199181e-02,
         0.00000000e+00,   1.56195942e-02,  -2.32425740e-02,
         1.36592129e-02,   1.30987379e-02,  -3.63740285e-03,
         0.00000000e+00,  -1.09281377e-03,   0.00000000e+00,
        -4.56740389e-03,   1.93667683e-05,  -2.30055124e-02,
        -3.75620790e-04,  -8.91686449e-03,   2.34830168e-03,
         0.00000000e+00,  -1.16784946e-02,   0.00000000e+00,
         9.77544345e-04,  -6.88293198e-03,  -7.35850595e-04,
        -2.78006398e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.86053124e-04,   0.00000000e+00,
        -7.59179868e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.64552935e-02,
        -8.58040759e-04,  -4.45757023e-03,   4.70524401e-04,
         0.00000000e+00,  -3.27473809e-03,   0.00000000e+00,
         3.53849192e-04,   1.15061961e-02,   6.91390098e-03,
        -5.59754544e-03,   0.00000000e+00,  -2.79864928e-02,
         1.00647034e-03,   7.90869380e-03,  -6.82145550e-03,
         0.00000000e+00,   1.37335552e-02,   0.00000000e+00,
         9.99070304e-03,   6.79446135e-03,  -5.45603692e-03,
        -3.84779457e-03,   0.00000000e+00,  -1.01861480e-03,
        -8.92975616e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.77330545e-03,   0.00000000e+00,
         2.19975898e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.33385230e-03,
         0.00000000e+00,   0.00000000e+00,  -3.97992066e-03,
        -1.01876461e-02,  -1.33254246e-02,   4.25621181e-04,
         0.00000000e+00,  -5.44915876e-03,   0.00000000e+00,
         5.14011622e-03,  -6.83427877e-03,   4.69265598e-03,
        -5.53664559e-03,   0.00000000e+00,  -1.12766537e-02,
        -9.59461942e-03,   0.00000000e+00,  -6.96308497e-03,
         9.65065917e-03,   1.54346158e-02,  -1.76976282e-03,
         0.00000000e+00,   1.13849541e-02,   0.00000000e+00,
         3.23181034e-03,   7.18821279e-03,  -5.38217828e-03,
         2.79087356e-03,   0.00000000e+00,   1.82700329e-02,
         1.53660931e-02,   0.00000000e+00,  -7.34979904e-03,
         1.38759339e-02,  -2.45146780e-03,  -1.19567160e-03,
        -5.25598633e-04,   0.00000000e+00,  -1.65940267e-03,
         0.00000000e+00,  -1.00996139e-02,  -5.49393783e-03,
        -1.05769641e-03,   3.79650735e-03,   0.00000000e+00,
         3.08728129e-02,  -6.49432109e-03,   0.00000000e+00,
         2.94680002e-02,  -4.14009889e-02,  -2.63682402e-02,
        -6.09149791e-04,  -1.39834724e-03,  -3.88751343e-03,
         0.00000000e+00,  -5.07349357e-03,   0.00000000e+00,
        -1.06138569e-02,   2.32610372e-02,  -6.80033392e-03,
         1.01672294e-02,   0.00000000e+00,   7.15410723e-03,
        -1.85443880e-02,   0.00000000e+00,   7.59474623e-02,
        -5.28429493e-02,   1.22434797e-02,  -3.69081775e-02,
        -1.78309422e-02,  -8.19477141e-02,  -4.43317986e-03,
         3.24437950e-03,   1.40880355e-02,   4.61013635e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.63854540e-02,   4.71802906e-03,  -8.91568176e-02,
         9.95399988e-03,   0.00000000e+00,   1.50911948e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.15430680e-02,   0.00000000e+00,  -7.06494896e-02,
        -3.36231942e-02,  -1.11678686e-02,  -5.14169249e-02,
         0.00000000e+00,  -6.76922976e-02,   0.00000000e+00,
        -5.86240956e-02,   9.57393096e-03,   1.14822250e-02,
        -3.07077841e-02,   0.00000000e+00,   6.34081468e-02,
         0.00000000e+00,  -9.61496844e-03,  -6.98084572e-02,
        -7.20674034e-03,   1.21976347e-02,   1.89421425e-02,
         0.00000000e+00,  -2.64473979e-02,   0.00000000e+00,
         4.99417148e-03,   2.14726125e-02,   3.51092487e-02,
         2.32262443e-03,   3.49457605e-03,   4.51984128e-03,
         0.00000000e+00,  -3.75757004e-03,   0.00000000e+00,
         9.83291858e-03,  -6.29665504e-03,   1.74724814e-02,
         4.97776846e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.06040692e-02,   0.00000000e+00,
         2.43188715e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.04381110e-02,
        -4.11228980e-03,   9.53591384e-03,  -1.28334012e-02,
         0.00000000e+00,  -1.68059546e-02,   0.00000000e+00,
         2.15283815e-02,  -1.37188634e-03,   9.66941393e-03,
        -1.15313766e-02,   0.00000000e+00,   7.23898032e-02,
        -5.52344802e-03,  -3.36567983e-03,   1.37591642e-02,
         0.00000000e+00,  -1.11290424e-02,   0.00000000e+00,
        -1.93273369e-02,   1.65244884e-03,   1.94906196e-02,
         8.46262854e-03,   0.00000000e+00,   1.22449575e-02,
         5.30578561e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.88576233e-03,   0.00000000e+00,
         3.04926610e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.93984061e-02,
         0.00000000e+00,   0.00000000e+00,  -8.70705925e-02,
         7.49615024e-03,   3.66541580e-03,   8.25276889e-03,
         0.00000000e+00,   1.32615097e-02,   0.00000000e+00,
         2.40828075e-02,   3.72341381e-03,  -2.73840633e-03,
        -1.17773239e-02,   0.00000000e+00,  -3.13556710e-02,
         3.28243604e-02,   0.00000000e+00,  -7.54115578e-02,
        -9.50574738e-03,  -1.10113423e-02,   1.27105270e-03,
         0.00000000e+00,  -1.00219293e-02,   0.00000000e+00,
        -1.79003788e-03,   3.34013986e-02,  -1.03885667e-02,
         4.07862696e-03,   0.00000000e+00,  -9.49062544e-03,
        -1.99673408e-02,   0.00000000e+00,   7.70224921e-03,
        -1.13382135e-01,  -6.15846398e-03,   2.47593150e-02,
        -3.11112023e-03,   0.00000000e+00,  -9.41992428e-04,
         0.00000000e+00,   1.09573273e-02,   7.69327870e-03,
         7.08246049e-03,  -1.79330023e-03,   0.00000000e+00,
         4.21058625e-02,   3.73478368e-02,   0.00000000e+00,
        -2.52510134e-02,   2.92069724e-02,   3.60665926e-02,
         1.80529709e-02,   1.25076656e-02,  -8.15368832e-03,
         0.00000000e+00,   2.26784426e-02,   0.00000000e+00,
         3.90504783e-03,   2.22514046e-03,  -7.21561259e-03,
         3.96352435e-05,   0.00000000e+00,  -6.41817694e-03,
         1.75748739e-02,   0.00000000e+00,  -2.29901971e-02,
         2.08865608e-02,  -4.83721407e-02,  -6.74930638e-02,
        -2.95722068e-03,  -5.50759514e-03,  -8.51101921e-03,
         1.30943614e-02,  -1.18592711e-02,   1.44914746e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.74658372e-03,  -1.70802036e-03,  -1.33229833e-02,
         1.87929759e-02,   0.00000000e+00,  -5.63196725e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.70566647e-03,   0.00000000e+00,  -9.93388043e-03,
        -1.05620305e-02,   2.18962740e-03,  -4.66818501e-03,
         0.00000000e+00,  -6.97307805e-03,   0.00000000e+00,
         1.54201165e-02,   6.50674977e-03,   1.56411148e-02,
        -7.18798850e-03,   0.00000000e+00,   1.76833397e-02,
         0.00000000e+00,   1.65426845e-03,  -2.83668833e-02,
         1.91750673e-03,  -5.99786194e-03,   8.67412922e-03,
         0.00000000e+00,  -2.44215928e-03,   0.00000000e+00,
        -3.83353122e-03,   4.57601709e-03,  -6.02203203e-03,
         1.34769713e-03,   1.06508920e-03,   1.09486157e-02,
         0.00000000e+00,   2.81442439e-03,   0.00000000e+00,
        -5.77502228e-03,  -3.49644579e-03,  -1.96895890e-03,
        -1.16956500e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.45039720e-03,   0.00000000e+00,
         3.93786987e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.15493072e-03,
        -1.65135287e-03,   4.68178043e-03,  -4.17790482e-03,
         0.00000000e+00,  -2.74478435e-03,   0.00000000e+00,
         2.39623841e-03,  -5.71194493e-04,  -1.07345008e-03,
        -3.66335358e-03,   0.00000000e+00,   1.93579420e-02,
        -2.26274993e-04,  -1.12265761e-03,  -1.03823532e-04,
         0.00000000e+00,   2.37651969e-04,   0.00000000e+00,
        -1.99914077e-03,  -8.21246509e-04,  -3.12375342e-03,
        -5.23221872e-04,   0.00000000e+00,  -1.21972206e-02,
         7.61559518e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.95139156e-03,   0.00000000e+00,
         4.60805048e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.49606634e-03,
         0.00000000e+00,   0.00000000e+00,  -1.16003411e-02,
         9.39913207e-04,   1.69557839e-03,  -1.10538201e-03,
         0.00000000e+00,  -1.18598648e-04,   0.00000000e+00,
        -3.46711627e-04,  -5.91270125e-04,  -8.88412855e-04,
         3.37845830e-03,   0.00000000e+00,  -4.77876626e-03,
         3.58996979e-03,   0.00000000e+00,   9.82533632e-03,
        -2.69066829e-03,  -2.73820138e-03,   5.61376408e-04,
         0.00000000e+00,  -6.25265718e-03,   0.00000000e+00,
        -3.18799603e-04,   1.01752311e-02,  -2.40236827e-03,
         2.69055516e-04,   0.00000000e+00,  -2.52294270e-03,
        -8.91092576e-03,   0.00000000e+00,   3.60806333e-03,
        -3.77051935e-02,  -1.62392400e-03,   1.23507806e-03,
        -3.75318960e-03,   0.00000000e+00,  -1.13117569e-03,
         0.00000000e+00,   3.60300123e-03,   6.06101858e-04,
        -5.39209722e-04,  -2.84116088e-03,   0.00000000e+00,
         1.02067795e-02,  -7.85676898e-03,   0.00000000e+00,
        -6.00928007e-03,   1.15187241e-02,  -4.81028285e-04,
         2.83855256e-03,   6.57805697e-03,  -1.63695046e-03,
         0.00000000e+00,   3.99975271e-03,   0.00000000e+00,
         1.00978822e-03,  -1.80868660e-03,  -4.74483137e-04,
        -1.52656841e-03,   0.00000000e+00,  -3.34613472e-03,
         6.90863878e-03,   0.00000000e+00,  -2.47612752e-03,
         9.49965399e-03,  -6.35512581e-03,  -1.83688629e-03,
         6.01198067e-01,   1.38762892e-01,   5.91204248e-01,
        -5.90435668e-04,  -4.69162302e-02,   4.82232031e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.92351299e-01,   4.50786236e-03,   7.18638329e-02,
         7.65466578e-04,   0.00000000e+00,   5.72277680e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.01848132e-01,   0.00000000e+00,   6.77020109e-01,
         2.24217387e-03,   1.29295968e-02,   9.06233225e-02,
         0.00000000e+00,   9.29253774e-02,   0.00000000e+00,
         6.93638742e-01,   3.30967394e-02,   2.10189045e-02,
         4.46553979e-02,   0.00000000e+00,  -9.13062173e-02,
         0.00000000e+00,  -1.37487302e-02,   6.61747150e-01,
        -3.43103136e-02,   1.15410013e-02,   3.32242253e-02,
         0.00000000e+00,   1.13600970e-02,   0.00000000e+00,
        -1.29126622e-02,  -1.09240698e-01,   3.19382002e-01,
        -2.38907749e-03,   1.61039641e-02,   1.75418020e-02,
         0.00000000e+00,  -3.49109166e-03,   0.00000000e+00,
        -4.52332470e-02,   3.03596760e-02,   3.82167210e-02,
         3.27397277e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.64564722e-02,   0.00000000e+00,
        -1.23980458e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.24816620e-01,
        -2.26177000e-05,   2.77980067e-02,  -3.35990708e-02,
         0.00000000e+00,  -5.35355751e-02,   0.00000000e+00,
        -1.36255430e-02,  -2.86356456e-02,  -4.36115005e-03,
         4.02087577e-03,   0.00000000e+00,   4.40817856e-01,
         1.70815895e-02,   3.32122419e-02,   3.98583845e-02,
         0.00000000e+00,   5.71480310e-03,   0.00000000e+00,
         3.93255655e-02,  -2.44819913e-02,   3.04853134e-02,
         3.83958298e-05,   0.00000000e+00,  -1.24172144e-02,
         4.42704409e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.86324625e-02,   0.00000000e+00,
        -1.56761181e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.67051166e-02,
         0.00000000e+00,   0.00000000e+00,   6.54844638e-01,
         6.64372957e-03,  -1.05177247e-03,  -3.61098497e-02,
         0.00000000e+00,  -4.54916944e-02,   0.00000000e+00,
        -1.53541307e-01,  -2.94632386e-03,  -2.39781677e-03,
         4.93828913e-02,   0.00000000e+00,   5.90478868e-02,
        -6.31765418e-02,   0.00000000e+00,   6.62858563e-01,
         5.93373605e-03,   3.06009164e-02,  -3.07388760e-02,
         0.00000000e+00,   6.80135001e-02,   0.00000000e+00,
         2.12551699e-03,  -1.45785816e-01,   4.63096031e-02,
        -2.09119452e-02,   0.00000000e+00,   1.89010199e-03,
         1.88772588e-02,   0.00000000e+00,  -2.28774454e-02,
         7.09397511e-01,  -5.86211121e-02,  -1.80377612e-02,
        -2.18433918e-03,   0.00000000e+00,  -3.98540946e-02,
         0.00000000e+00,  -2.59441893e-03,   1.19234222e-02,
         4.19507374e-02,  -4.29721314e-03,   0.00000000e+00,
        -1.99673522e-02,  -4.60361917e-02,   0.00000000e+00,
         2.04232734e-02,  -2.22044878e-02,   4.76947317e-01,
        -6.81899533e-02,  -1.00237120e-01,   2.82544082e-02,
         0.00000000e+00,  -3.85274293e-02,   0.00000000e+00,
        -2.22121896e-04,  -3.80358107e-02,   1.59361428e-02,
        -1.82208749e-02,   0.00000000e+00,  -2.35715230e-02,
        -3.22274895e-02,   0.00000000e+00,   2.02482975e-03,
         7.32576746e-03,   9.18084432e-02,   6.75350628e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.10705779e-03,   3.07296914e-03,   2.08204108e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.41065221e-02,   0.00000000e+00,
         5.29878575e-03,   1.22178054e-02,   1.97085156e-03,
         0.00000000e+00,   1.99927478e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.74816747e-03,   0.00000000e+00,   2.45076173e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.17526369e-03,   0.00000000e+00,
        -1.89568723e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.25012797e-03,   0.00000000e+00,   4.44719767e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.37186663e-04,   0.00000000e+00,  -2.55559781e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.26520279e-03,  -1.50862006e-03,
         9.40783881e-05,   0.00000000e+00,  -2.10648200e-03,
         0.00000000e+00,  -2.35788350e-03,   1.71695324e-03,
        -2.15570589e-04,   1.14002630e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.11502717e-05,   0.00000000e+00,  -9.88139908e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.42650640e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.63919147e-03,   0.00000000e+00,   4.44094017e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.70031362e-04,   0.00000000e+00,
         0.00000000e+00,  -2.02032649e-03,  -1.91912577e-03,
        -9.98642898e-04,   0.00000000e+00,  -4.36051477e-03,
         0.00000000e+00,  -6.72396522e-03,   4.55875958e-03,
        -1.23516516e-03,   3.26814176e-03,   0.00000000e+00,
         2.60157278e-03,  -7.65393657e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.08718853e-03,   0.00000000e+00,  -6.34311751e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.51082262e-03,   0.00000000e+00,
         0.00000000e+00,   2.19945202e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.09206891e-03,   0.00000000e+00,   7.55429485e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.74686682e-03,   0.00000000e+00,
         0.00000000e+00,  -2.16215966e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.80271243e-03,   0.00000000e+00,
        -1.64074410e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.56459021e-04,
         0.00000000e+00,   0.00000000e+00,   6.83410587e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.08664613e-03,   0.00000000e+00,  -2.53922637e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.10975362e-04,   0.00000000e+00,
         0.00000000e+00,   7.56408268e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.56151761e-02,   1.14033151e-01,   1.55122248e-02,
        -2.77058330e-02,  -9.28257417e-03,  -6.22238604e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.70671153e-02,   6.32534725e-03,   7.06544156e-02,
        -1.01555912e-02,   0.00000000e+00,  -4.33062210e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.64481595e-02,   0.00000000e+00,   9.32990692e-02,
         1.22335016e-02,  -1.17170116e-02,   8.93708629e-02,
         0.00000000e+00,   9.60476608e-02,   0.00000000e+00,
         1.07642798e-01,   2.85824863e-02,  -2.18547061e-04,
         2.81778354e-02,   0.00000000e+00,  -7.23341307e-02,
         0.00000000e+00,   1.40140532e-02,   6.39358417e-02,
        -9.72441214e-04,  -1.85695099e-02,  -3.05866344e-02,
         0.00000000e+00,   2.23202790e-02,   0.00000000e+00,
         1.30531966e-03,  -2.12573333e-02,  -2.96075047e-02,
         5.40609361e-03,  -4.67349272e-03,  -2.25486197e-02,
         0.00000000e+00,  -5.16994235e-03,   0.00000000e+00,
        -6.77571819e-03,   5.71687742e-03,  -1.92912671e-02,
        -3.69144232e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.29757952e-02,   0.00000000e+00,
        -3.67935636e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.41785836e-02,
         5.32729891e-03,  -3.79535154e-03,   1.29990160e-02,
         0.00000000e+00,   3.09392622e-02,   0.00000000e+00,
        -4.09198995e-02,   1.06678681e-02,  -6.20783317e-03,
         2.25362771e-02,   0.00000000e+00,  -1.03867726e-01,
         1.77725527e-03,   5.90051026e-03,  -2.38882643e-02,
         0.00000000e+00,   2.11403260e-02,   0.00000000e+00,
         2.72685694e-02,   7.12532099e-03,  -2.25245967e-02,
        -1.21237305e-02,   0.00000000e+00,  -7.08855481e-03,
        -7.16417632e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.08176819e-02,   0.00000000e+00,
        -4.87355709e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.88374698e-02,
         0.00000000e+00,   0.00000000e+00,   1.15432439e-01,
        -2.18475881e-03,   2.95657167e-03,  -2.06701948e-02,
         0.00000000e+00,  -2.02213563e-02,   0.00000000e+00,
        -5.16800540e-02,   1.19962733e-04,  -4.78398484e-04,
         1.62265220e-02,   0.00000000e+00,   5.21392593e-02,
        -4.88535089e-02,   0.00000000e+00,   1.27579288e-01,
         5.29558401e-03,   1.27587720e-03,  -8.69720380e-04,
         0.00000000e+00,   1.02311351e-02,   0.00000000e+00,
         1.01723980e-03,  -5.13124923e-02,   1.49249081e-02,
        -4.87991546e-03,   0.00000000e+00,   1.28972385e-02,
         2.16707983e-02,   0.00000000e+00,  -2.11310839e-03,
         1.09884416e-01,   8.07687777e-03,  -4.10322552e-02,
         1.19082899e-02,   0.00000000e+00,  -4.40226800e-03,
         0.00000000e+00,  -7.70692542e-03,  -2.09851296e-02,
        -7.80115933e-03,  -6.97807691e-05,   0.00000000e+00,
        -3.59331040e-02,  -2.06202570e-02,   0.00000000e+00,
         2.63537692e-02,  -2.90846924e-02,  -5.81280345e-02,
        -3.09122785e-02,  -2.35353549e-02,   6.79339211e-03,
         0.00000000e+00,  -1.65761388e-02,   0.00000000e+00,
         1.51317949e-03,  -1.52629084e-02,   1.47057878e-02,
        -4.34992681e-03,   0.00000000e+00,  -1.16927816e-03,
        -2.10474788e-02,   0.00000000e+00,  -3.28085805e-03,
        -1.35260825e-03,   6.70273508e-02,   1.04412609e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.26910596e-02,  -2.09555548e-02,   6.92925517e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.39243240e-02,   0.00000000e+00,
        -1.13535762e-02,   4.64115876e-03,  -3.55692360e-03,
         0.00000000e+00,  -1.35925360e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.10053423e-02,   0.00000000e+00,  -9.26119229e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.80477111e-03,   0.00000000e+00,
         3.44314018e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.94732259e-03,   0.00000000e+00,   1.28214652e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.28826360e-03,   0.00000000e+00,   2.63125227e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.63163347e-03,   4.17266196e-03,
        -1.81765823e-03,   0.00000000e+00,  -2.06425464e-03,
         0.00000000e+00,   2.86777549e-03,   6.98034260e-04,
         5.39080025e-03,  -2.64876504e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.00464705e-03,   0.00000000e+00,   3.42791069e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.56562067e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.48851763e-04,   0.00000000e+00,  -1.27061225e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.29396738e-03,   0.00000000e+00,
         0.00000000e+00,  -1.10356755e-03,   1.91885476e-03,
         2.28358695e-04,   0.00000000e+00,   9.01749772e-04,
         0.00000000e+00,   2.59796853e-03,  -1.71511912e-03,
        -5.30561524e-04,   7.70416571e-04,   0.00000000e+00,
        -3.18202318e-03,   1.10928963e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.28350882e-03,   0.00000000e+00,   1.38732950e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.50864909e-03,   0.00000000e+00,
         0.00000000e+00,  -3.86046846e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.03840002e-03,   0.00000000e+00,  -1.46561053e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.39664528e-03,   0.00000000e+00,
         0.00000000e+00,   4.85886862e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.75411883e-03,   0.00000000e+00,
         2.13529578e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.83731711e-02,
         0.00000000e+00,   0.00000000e+00,  -7.31793557e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.27690166e-03,   0.00000000e+00,   5.92743265e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.32221809e-03,   0.00000000e+00,
         0.00000000e+00,  -2.92933120e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.62823417e-02,  -1.32328495e-01,  -1.63896379e-02,
         2.12194204e-02,   3.93459663e-02,   5.66683079e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.60443385e-02,  -1.17759129e-02,  -6.74493879e-02,
         5.18315972e-03,   0.00000000e+00,   4.33071286e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.05631611e-01,   0.00000000e+00,  -1.11615866e-01,
         1.54636475e-02,   2.11653482e-02,  -8.24559207e-02,
         0.00000000e+00,  -8.47584260e-02,   0.00000000e+00,
        -9.81428019e-02,  -3.17965030e-02,   1.19578518e-02,
        -3.71514731e-02,   0.00000000e+00,   1.07962353e-01,
         0.00000000e+00,  -8.80532310e-03,  -1.03474876e-01,
        -2.58866145e-03,   2.07237675e-02,   2.62768265e-02,
         0.00000000e+00,  -3.23336252e-02,   0.00000000e+00,
        -9.15361342e-04,   3.96414353e-02,   4.23475331e-02,
        -1.03706887e-02,   3.21523445e-03,   1.03714406e-02,
         0.00000000e+00,   5.37182712e-03,   0.00000000e+00,
         1.29335123e-02,  -4.67994727e-03,   2.55731346e-02,
         6.42448139e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.22139401e-02,   0.00000000e+00,
         4.01086550e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.71535143e-02,
         7.68698912e-04,  -3.26511931e-03,  -8.19326602e-03,
         0.00000000e+00,  -3.11989346e-02,   0.00000000e+00,
         4.11170603e-02,  -1.53307635e-02,   7.01173548e-03,
        -2.06443863e-02,   0.00000000e+00,   1.01304767e-01,
         1.87985176e-03,  -2.84101027e-03,   2.59020885e-02,
         0.00000000e+00,  -2.20186942e-02,   0.00000000e+00,
        -2.37906191e-02,  -7.02534121e-03,   2.73818051e-02,
         1.25095024e-02,   0.00000000e+00,   1.83445329e-02,
         7.94742182e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.53596873e-02,   0.00000000e+00,
         5.84428030e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.28523522e-02,
         0.00000000e+00,   0.00000000e+00,  -1.34745609e-01,
        -3.47586195e-03,  -9.65501348e-03,   2.34610377e-02,
         0.00000000e+00,   1.99133018e-02,   0.00000000e+00,
         5.14692970e-02,  -5.37681304e-03,   3.83627467e-03,
        -1.98552150e-02,   0.00000000e+00,  -4.68493470e-02,
         4.21624232e-02,   0.00000000e+00,  -1.22025657e-01,
        -1.38273596e-03,  -5.97959267e-04,   5.50366389e-03,
         0.00000000e+00,  -1.66487362e-02,   0.00000000e+00,
        -4.27582056e-03,   7.39394249e-02,  -1.98988641e-02,
         9.52546101e-03,   0.00000000e+00,  -2.07250171e-02,
        -2.99845136e-02,   0.00000000e+00,   4.17318774e-03,
        -1.66147893e-01,  -9.64953666e-03,   4.28975098e-02,
        -9.50149607e-03,   0.00000000e+00,   8.78084659e-03,
         0.00000000e+00,  -1.61581234e-03,   2.73699783e-02,
         8.97060719e-03,   5.26985133e-03,   0.00000000e+00,
         2.56618601e-02,   3.33447445e-02,   0.00000000e+00,
        -1.40004283e-02,   4.15527267e-02,   6.63969987e-02,
         4.29896812e-02,   3.29607879e-02,  -9.37388839e-03,
         0.00000000e+00,   1.63620360e-02,   0.00000000e+00,
        -8.13904201e-03,   2.09243935e-02,  -1.62463876e-02,
         8.48443129e-03,   0.00000000e+00,   1.41140084e-02,
         1.51400387e-02,   0.00000000e+00,   2.21930470e-02,
         2.51019338e-03,  -7.44666397e-02,  -1.16227567e-01,
         1.41114435e-03,   3.38508283e-02,  -7.82621518e-03,
         2.12783968e-04,  -1.35056391e-02,  -1.44126239e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.39765798e-02,  -6.73639992e-03,   2.34071631e-02,
         1.46909458e-03,   0.00000000e+00,  -2.16840129e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.70570790e-02,   0.00000000e+00,   1.95786637e-02,
        -3.06999466e-03,  -7.74050277e-03,   1.73695173e-02,
         0.00000000e+00,   2.02730849e-02,   0.00000000e+00,
         1.72668304e-02,   6.75577604e-03,   2.99155679e-03,
         7.34601478e-03,   0.00000000e+00,  -2.56488371e-02,
         0.00000000e+00,   2.86210413e-03,   2.15577420e-02,
         4.56149961e-03,  -1.26082898e-02,  -8.35194791e-03,
         0.00000000e+00,   1.44183025e-02,   0.00000000e+00,
        -7.61433609e-04,  -6.40541365e-03,  -1.23025309e-02,
         5.00175876e-03,  -4.01311379e-03,  -3.64757251e-03,
         0.00000000e+00,   2.58206668e-03,   0.00000000e+00,
        -3.56350861e-03,   2.57682428e-03,  -6.21965156e-03,
        -1.35313471e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.31708600e-02,   0.00000000e+00,
        -1.16014209e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.76970059e-02,
         3.02722948e-03,  -3.50728440e-03,   2.33498837e-03,
         0.00000000e+00,   1.21722633e-02,   0.00000000e+00,
        -1.12949542e-02,   4.57331497e-03,  -2.95372303e-03,
         4.25756428e-03,   0.00000000e+00,  -2.98234343e-02,
         1.10646133e-03,  -4.09268589e-03,  -1.07657948e-02,
         0.00000000e+00,   7.38605778e-03,   0.00000000e+00,
         5.13698786e-03,   1.57270999e-03,  -1.15621503e-02,
        -4.90337530e-03,   0.00000000e+00,  -1.02025556e-02,
        -2.45625473e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.77471405e-03,   0.00000000e+00,
        -1.26518513e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.04489294e-02,
         0.00000000e+00,   0.00000000e+00,   2.65609173e-02,
         1.45413357e-03,   4.81811870e-03,  -6.16980674e-03,
         0.00000000e+00,  -5.40799733e-03,   0.00000000e+00,
        -1.07172865e-02,   1.37210266e-03,  -9.36744661e-04,
         3.53790895e-03,   0.00000000e+00,   1.01593379e-02,
        -7.83103915e-03,   0.00000000e+00,   2.36263813e-02,
        -5.77472846e-04,  -1.80216620e-04,  -5.84120022e-04,
         0.00000000e+00,   1.91940205e-03,   0.00000000e+00,
         1.36294617e-03,  -1.68838322e-02,   4.96481759e-03,
        -1.75898257e-03,   0.00000000e+00,   4.69942329e-03,
         5.66146647e-03,   0.00000000e+00,  -8.62940942e-04,
         3.39703411e-02,   5.11181356e-03,  -1.36204453e-02,
         8.14171401e-04,   0.00000000e+00,   3.38617247e-03,
         0.00000000e+00,  -1.82478382e-04,  -5.25330453e-03,
        -7.09791836e-03,  -2.66477627e-03,   0.00000000e+00,
        -1.15402624e-02,  -1.65328783e-02,   0.00000000e+00,
         2.17083936e-03,  -6.84917551e-03,  -2.36669337e-02,
        -1.08151092e-02,  -5.29351826e-03,   2.79461655e-03,
         0.00000000e+00,  -5.39063246e-03,   0.00000000e+00,
         4.97543363e-03,  -6.38897897e-03,   5.59300038e-03,
        -1.35179379e-03,   0.00000000e+00,  -2.02919195e-03,
        -1.85523520e-04,   0.00000000e+00,  -5.11945060e-03,
         1.97901757e-03,   1.79616720e-02,   2.35163428e-02,
        -2.10578754e-03,  -2.21004511e-02,  -1.14482924e-02,
         3.23506577e-03,   5.31982466e-03,   1.27111610e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.68180775e-03,  -1.45981143e-02,  -2.02824671e-03,
         2.53313507e-03,   0.00000000e+00,  -4.25919257e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.58377808e-02,   0.00000000e+00,  -2.50284244e-02,
         2.19206873e-03,  -4.70673480e-03,  -1.75056777e-02,
         0.00000000e+00,  -1.40183616e-02,   0.00000000e+00,
        -2.42695018e-02,  -9.24125141e-03,   5.66385643e-03,
        -7.36666523e-03,   0.00000000e+00,   1.44866215e-02,
         0.00000000e+00,  -8.61223430e-04,  -1.93369203e-02,
         4.44121916e-03,  -2.71435905e-03,   5.04022496e-04,
         0.00000000e+00,   4.51332951e-04,   0.00000000e+00,
        -5.38758406e-04,   1.03851399e-02,   9.70298743e-03,
         1.54835031e-03,  -6.81705475e-03,  -3.57001354e-03,
         0.00000000e+00,   8.86812498e-03,   0.00000000e+00,
         4.58250808e-03,   2.85799907e-03,   8.11428001e-03,
         2.54542211e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.47600776e-03,   0.00000000e+00,
         8.00300027e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.44375739e-03,
        -2.38587198e-03,  -1.33754325e-03,  -8.95103573e-04,
         0.00000000e+00,  -3.27227285e-03,   0.00000000e+00,
         1.03610315e-02,  -4.41457921e-03,  -3.01367747e-03,
         9.26689526e-04,   0.00000000e+00,   1.03258106e-02,
         3.43327765e-04,  -2.66782378e-03,   2.91971201e-03,
         0.00000000e+00,  -6.49928443e-03,   0.00000000e+00,
        -6.58431240e-03,  -2.54518745e-03,   1.11537421e-03,
         4.53411283e-03,   0.00000000e+00,  -5.20917919e-03,
         4.53102609e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.29205368e-03,   0.00000000e+00,
         1.81673501e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.12928628e-03,
         0.00000000e+00,   0.00000000e+00,  -2.74477000e-02,
        -2.67466693e-03,  -1.43683194e-03,   9.46497941e-03,
         0.00000000e+00,   7.67804730e-03,   0.00000000e+00,
         1.96137065e-02,  -1.94424322e-03,  -4.91014353e-05,
        -5.35366667e-03,   0.00000000e+00,  -7.74683099e-03,
         9.47400769e-03,   0.00000000e+00,  -2.66155722e-02,
         8.22245456e-04,  -5.54037840e-04,   1.83979466e-03,
         0.00000000e+00,  -8.84842307e-03,   0.00000000e+00,
        -1.01909806e-03,   1.96328067e-02,  -4.57998491e-03,
         2.05074454e-03,   0.00000000e+00,  -5.09160427e-03,
        -5.51428417e-03,   0.00000000e+00,   6.61470402e-04,
        -3.08581613e-02,   2.92777349e-03,   8.33934186e-03,
        -4.41976654e-03,   0.00000000e+00,   1.75687450e-03,
         0.00000000e+00,   1.43274656e-03,   4.10829840e-03,
        -1.94339740e-03,   4.61411176e-04,   0.00000000e+00,
        -7.85647879e-03,  -2.32453568e-03,   0.00000000e+00,
        -4.29030680e-03,   9.36037071e-03,   6.67032597e-03,
         1.23675594e-02,   1.38285988e-02,  -2.35744280e-03,
         0.00000000e+00,   1.13834072e-03,   0.00000000e+00,
        -2.62625776e-03,   5.67064100e-03,  -2.48212676e-03,
         3.10896899e-03,   0.00000000e+00,   3.61068322e-03,
         5.27128628e-03,   0.00000000e+00,  -1.47019243e-03,
         4.54007526e-04,  -1.49433709e-02,  -2.31145705e-02,
        -5.24334900e-02,   6.71910218e-03,  -5.85265325e-02,
        -8.90425920e-03,   8.01975181e-03,  -5.86300472e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.40209135e-02,  -6.42321417e-03,   5.07189181e-03,
        -2.68765666e-03,   0.00000000e+00,  -7.00680106e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.09377026e-02,   0.00000000e+00,  -5.42581095e-02,
         1.73370664e-03,  -8.32360189e-03,   5.73341161e-03,
         0.00000000e+00,   8.13962067e-03,   0.00000000e+00,
        -6.08483677e-02,   8.79176309e-03,  -3.46423720e-03,
         3.93075266e-04,   0.00000000e+00,  -8.99645439e-03,
         0.00000000e+00,   4.92240511e-03,  -5.23396342e-02,
         8.51427127e-03,  -1.22251198e-02,  -1.88394563e-02,
         0.00000000e+00,   7.77855630e-03,   0.00000000e+00,
         4.11003054e-03,   1.44576597e-02,  -1.76509628e-02,
         1.26849606e-03,  -5.88706409e-03,  -1.40109238e-02,
         0.00000000e+00,  -1.09429727e-03,   0.00000000e+00,
         1.33110334e-02,  -4.84778455e-03,  -1.16343094e-02,
        -1.36340347e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.71194170e-02,   0.00000000e+00,
        -1.67742018e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.78029575e-02,
         1.95408834e-05,  -1.59002271e-02,   2.83095538e-02,
         0.00000000e+00,   5.26204584e-02,   0.00000000e+00,
        -2.19934571e-02,   1.80166905e-02,  -8.84622605e-04,
         1.09908620e-02,   0.00000000e+00,  -6.10630500e-02,
        -5.81754832e-03,  -9.36356673e-03,  -3.48130045e-02,
         0.00000000e+00,   1.12953685e-02,   0.00000000e+00,
        -1.17736297e-03,   1.33577395e-02,  -2.14922028e-02,
        -1.25005217e-02,   0.00000000e+00,  -6.07700773e-04,
        -5.52050696e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.07821908e-03,   0.00000000e+00,
         2.67836265e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.96413316e-04,
         0.00000000e+00,   0.00000000e+00,  -4.33264320e-02,
        -7.10627284e-03,   3.24262723e-03,  -2.89490630e-04,
         0.00000000e+00,   5.57443319e-03,   0.00000000e+00,
         3.52506995e-02,  -5.62449287e-04,  -2.44849534e-03,
        -8.14745953e-03,   0.00000000e+00,   1.22279263e-03,
         1.60521043e-03,   0.00000000e+00,  -4.64460861e-02,
         7.73409837e-03,  -6.34804098e-03,   7.42533167e-03,
         0.00000000e+00,  -1.70876730e-02,   0.00000000e+00,
        -1.91051765e-04,   1.28041871e-02,  -3.67027174e-03,
         1.04457639e-03,   0.00000000e+00,   1.66306675e-03,
         3.87970405e-03,   0.00000000e+00,   1.67878574e-03,
        -5.13928876e-02,   3.49176273e-02,  -2.20874931e-02,
         8.16182120e-03,   0.00000000e+00,   1.03038902e-02,
         0.00000000e+00,  -4.82797442e-03,  -8.58808391e-03,
        -1.17305541e-02,  -5.30776741e-03,   0.00000000e+00,
        -1.06999670e-02,   3.91043480e-03,   0.00000000e+00,
         1.67655501e-03,  -9.41776075e-04,  -5.80933951e-02,
         7.27470994e-03,   2.48690077e-02,  -7.31826817e-03,
         0.00000000e+00,   1.44335237e-03,   0.00000000e+00,
        -2.71091376e-04,   9.90006597e-03,  -7.28618737e-04,
         2.34475210e-03,   0.00000000e+00,   6.21429640e-03,
         3.76227785e-03,   0.00000000e+00,  -4.02068455e-03,
         3.37907947e-03,   1.19769428e-03,  -4.45042319e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.06466680e-03,  -5.86745712e-03,   2.81814406e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.14909138e-03,   0.00000000e+00,
         7.76969318e-04,   8.41399045e-03,  -1.80380190e-03,
         0.00000000e+00,  -3.39223955e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.37060256e-03,   0.00000000e+00,   3.99981320e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.58903475e-04,   0.00000000e+00,
        -7.51880891e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.67486735e-03,   0.00000000e+00,   1.67788177e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.05320951e-03,   0.00000000e+00,  -3.43822864e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.93267631e-03,   6.30299131e-03,
        -2.92203579e-03,   0.00000000e+00,  -9.15132687e-03,
         0.00000000e+00,   3.44012408e-03,  -1.47498382e-04,
         2.08108602e-03,   3.57242351e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.00445709e-02,   0.00000000e+00,   4.07120217e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.98380875e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.39106364e-03,   0.00000000e+00,   2.15337857e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.93477359e-04,   0.00000000e+00,
         0.00000000e+00,   1.14767633e-03,  -1.57688344e-03,
         4.33579643e-05,   0.00000000e+00,  -1.89663876e-03,
         0.00000000e+00,  -3.68455218e-03,   2.31145282e-03,
        -2.84949715e-04,  -1.74068939e-04,   0.00000000e+00,
        -8.81272972e-04,  -1.54342681e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.08742704e-04,   0.00000000e+00,  -4.22228889e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.08789262e-03,   0.00000000e+00,
         0.00000000e+00,   1.62920862e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.43448848e-03,   0.00000000e+00,   3.46408126e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.09264705e-03,   0.00000000e+00,
         0.00000000e+00,  -2.12777437e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.59700149e-03,   0.00000000e+00,
         3.01025850e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.50347195e-03,
         0.00000000e+00,   0.00000000e+00,   1.85155652e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.80414067e-03,   0.00000000e+00,  -4.73310342e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.23628102e-03,   0.00000000e+00,
         0.00000000e+00,   5.09425092e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.39357811e-03,   3.77265200e-02,  -9.50405026e-04,
        -7.52861591e-03,  -3.68277558e-03,  -2.59642889e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.95255785e-02,   1.30290485e-02,   1.85379796e-02,
         2.04792209e-03,   0.00000000e+00,  -1.91590790e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.29482487e-02,   0.00000000e+00,   2.56180964e-02,
         4.75180570e-03,   4.90645102e-03,   2.17282300e-02,
         0.00000000e+00,   2.87692866e-02,   0.00000000e+00,
         2.53940783e-02,   1.53837083e-02,  -6.45559487e-03,
         1.03041779e-02,   0.00000000e+00,  -2.73090573e-02,
         0.00000000e+00,   5.84118731e-03,   1.69070923e-02,
         2.76054637e-03,  -1.19443538e-02,  -1.75492708e-02,
         0.00000000e+00,   1.13223028e-02,   0.00000000e+00,
         1.80487337e-03,  -3.41646528e-03,  -7.03339567e-03,
         4.03310418e-03,  -4.77869473e-03,  -1.16110364e-02,
         0.00000000e+00,  -5.49535840e-03,   0.00000000e+00,
         5.17571779e-04,  -5.81463468e-04,  -9.10247603e-03,
        -3.27153240e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.57273921e-02,   0.00000000e+00,
        -2.19235098e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.43801428e-02,
         8.50359654e-04,  -6.60466527e-03,   2.48847651e-03,
         0.00000000e+00,   2.97761253e-02,   0.00000000e+00,
        -2.19663937e-02,   1.38045721e-02,  -2.63916333e-03,
         4.10156153e-03,   0.00000000e+00,  -3.40185675e-02,
         6.38407972e-03,  -5.92185561e-03,  -1.81049932e-02,
         0.00000000e+00,   2.70478676e-02,   0.00000000e+00,
         1.03232362e-02,   9.24596220e-03,  -1.36933333e-02,
        -1.09996901e-02,   0.00000000e+00,  -1.24862221e-03,
        -3.29294743e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.60716028e-02,   0.00000000e+00,
        -2.63957532e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.27829795e-02,
         0.00000000e+00,   0.00000000e+00,   3.52061934e-02,
        -4.67039924e-03,  -2.97954952e-03,  -1.28993026e-02,
         0.00000000e+00,  -1.44603073e-02,   0.00000000e+00,
        -2.79095400e-02,   1.46563600e-03,   3.01766167e-05,
         3.01074939e-03,   0.00000000e+00,   1.40228070e-02,
        -1.59844762e-02,   0.00000000e+00,   3.21715236e-02,
         6.33882283e-03,   5.98009957e-03,  -3.74805238e-03,
         0.00000000e+00,   1.17017078e-02,   0.00000000e+00,
         4.00989016e-03,  -3.61090272e-02,   8.84943299e-03,
        -2.86918821e-03,   0.00000000e+00,   7.05205466e-03,
         1.10302295e-02,   0.00000000e+00,  -1.89926727e-03,
         3.64420875e-02,   1.09721894e-02,  -3.13215660e-02,
         4.08047181e-04,   0.00000000e+00,  -8.51756344e-04,
         0.00000000e+00,  -6.89428707e-03,  -4.94704894e-03,
        -1.09520227e-02,  -6.71142236e-03,   0.00000000e+00,
        -1.06239878e-03,  -3.49770463e-03,   0.00000000e+00,
         9.60874786e-03,  -1.12147035e-02,  -2.76258902e-02,
        -2.16196815e-02,  -1.43997964e-02,   2.35201737e-03,
         0.00000000e+00,  -8.90838173e-03,   0.00000000e+00,
        -4.50025334e-03,  -1.85074713e-03,   6.22329445e-03,
         9.00446362e-04,   0.00000000e+00,   9.05536355e-04,
        -6.88307054e-03,   0.00000000e+00,   3.27361886e-03,
        -1.03231620e-03,   2.55878093e-02,   2.84785046e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.05748059e-03,   1.37050883e-03,  -8.78295231e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.66702128e-04,   0.00000000e+00,
        -1.89448354e-04,  -3.49473997e-03,  -6.51439586e-04,
         0.00000000e+00,  -5.12273080e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.75158189e-03,   0.00000000e+00,  -6.42953382e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.82535064e-03,   0.00000000e+00,
         4.08396751e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.02138170e-04,   0.00000000e+00,  -1.03948523e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.38464733e-03,   0.00000000e+00,   1.33579506e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.71244523e-03,   2.32163907e-03,
         1.02491535e-04,   0.00000000e+00,   6.89092919e-04,
         0.00000000e+00,   3.16952306e-03,  -2.68250799e-03,
        -6.36910224e-04,   1.12185991e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.85399241e-05,   0.00000000e+00,   2.59266632e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.56793780e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.27216397e-03,   0.00000000e+00,  -3.93393960e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.03079855e-03,   0.00000000e+00,
         0.00000000e+00,   1.56690239e-03,   3.64486727e-03,
         1.70369312e-03,   0.00000000e+00,   1.10973279e-02,
         0.00000000e+00,   1.18591661e-02,  -9.02749017e-03,
         2.19592578e-03,  -1.61543464e-03,   0.00000000e+00,
        -5.34563975e-04,   2.68547531e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.81456161e-03,   0.00000000e+00,   1.22287004e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.22593648e-03,   0.00000000e+00,
         0.00000000e+00,  -5.01337460e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.41943572e-03,   0.00000000e+00,  -1.19876852e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.96381513e-04,   0.00000000e+00,
         0.00000000e+00,   5.21429855e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.51471733e-03,   0.00000000e+00,
         4.71320783e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.74684956e-03,
         0.00000000e+00,   0.00000000e+00,  -6.44451810e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.10199123e-03,   0.00000000e+00,   1.95949330e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.07675661e-04,   0.00000000e+00,
         0.00000000e+00,  -1.73041566e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.18132627e-02,  -5.42612084e-02,  -5.43635735e-02,
         5.16239096e-03,   1.52145395e-02,  -1.88417782e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.63205131e-02,  -7.64304253e-03,  -2.29850129e-02,
        -9.05546781e-04,   0.00000000e+00,  -3.22471491e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.30320026e-02,   0.00000000e+00,  -9.41905239e-02,
         3.12683759e-03,   2.11789991e-03,  -3.68680500e-02,
         0.00000000e+00,  -3.65410256e-02,   0.00000000e+00,
        -1.00449412e-01,  -1.99976340e-02,  -6.91090338e-03,
        -1.35318240e-02,   0.00000000e+00,   3.19802861e-02,
         0.00000000e+00,  -3.21409415e-03,  -8.19969057e-02,
         6.94575009e-03,   7.69459144e-03,   2.58596287e-03,
         0.00000000e+00,  -8.85567639e-03,   0.00000000e+00,
         1.54184995e-03,   2.36557374e-02,  -4.20135001e-03,
        -5.01717987e-03,  -2.33242229e-03,   4.90789905e-03,
         0.00000000e+00,   6.68256231e-03,   0.00000000e+00,
         1.42438644e-02,  -5.93805223e-03,   1.87037200e-03,
        -1.05136723e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.68198672e-04,   0.00000000e+00,
         2.07373539e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.43508425e-03,
        -7.45198569e-03,  -2.69489446e-03,   4.22830787e-03,
         0.00000000e+00,  -2.13249601e-03,   0.00000000e+00,
         2.72624565e-02,  -1.05440572e-03,  -1.03761980e-03,
        -4.74530559e-03,   0.00000000e+00,  -3.60984427e-03,
        -5.92309706e-03,  -9.16935901e-03,   2.99919538e-04,
         0.00000000e+00,  -1.52797154e-02,   0.00000000e+00,
        -2.56217903e-02,   3.09287812e-03,   3.64648633e-03,
         6.02274738e-03,   0.00000000e+00,   5.92421695e-03,
        -9.92029101e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.23820332e-02,   0.00000000e+00,
         7.51510825e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.13790199e-02,
         0.00000000e+00,   0.00000000e+00,  -1.01283094e-01,
        -1.12049622e-03,  -6.20776777e-04,   3.31767870e-02,
         0.00000000e+00,   3.80786699e-02,   0.00000000e+00,
         9.13375862e-02,  -4.22319533e-03,   1.15493803e-03,
        -1.42533670e-02,   0.00000000e+00,  -2.34976167e-02,
         2.42631949e-02,   0.00000000e+00,  -1.03021703e-01,
         2.68607690e-04,  -1.05801837e-02,   1.07001898e-02,
         0.00000000e+00,  -3.21042725e-02,   0.00000000e+00,
        -5.79725947e-03,   6.95583855e-02,  -1.88130835e-02,
         5.81618336e-03,   0.00000000e+00,  -6.14610039e-03,
        -9.92934042e-03,   0.00000000e+00,   1.08535740e-03,
        -1.09358921e-01,   1.69542331e-02,   2.79972825e-02,
        -5.23836960e-03,   0.00000000e+00,   1.04948531e-02,
         0.00000000e+00,   9.80702826e-03,   2.43266274e-03,
        -1.49493495e-03,   8.69845974e-04,   0.00000000e+00,
         3.62304677e-03,   1.31448260e-02,   0.00000000e+00,
        -6.13612579e-03,   1.07014119e-02,  -1.41175696e-02,
         4.94328371e-02,   5.18078716e-02,  -9.19795239e-03,
         0.00000000e+00,   1.69477733e-02,   0.00000000e+00,
        -1.65740626e-03,   2.10700042e-02,  -9.86806023e-03,
         5.12655928e-03,   0.00000000e+00,   7.50063191e-03,
         9.93187179e-03,   0.00000000e+00,   4.37243820e-03,
        -6.53008698e-03,  -3.71235342e-02,  -9.64730188e-02,
         6.57188057e-02,   4.75609810e-02,   7.49304627e-02,
        -5.56865353e-03,  -1.14854519e-02,   3.49745071e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.65331119e-02,   1.35730119e-02,   2.09119584e-02,
        -1.73425007e-03,   0.00000000e+00,   5.81364671e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.74738741e-02,   0.00000000e+00,   1.08307349e-01,
         1.17741813e-03,   3.76963007e-03,   2.92997155e-02,
         0.00000000e+00,   3.00112731e-02,   0.00000000e+00,
         1.04163938e-01,   1.61265902e-02,   3.17810980e-03,
         1.49891959e-02,   0.00000000e+00,  -3.12849220e-02,
         0.00000000e+00,  -2.45272302e-04,   1.04022064e-01,
        -1.02019289e-02,  -5.63930868e-04,   1.63627478e-03,
         0.00000000e+00,   5.37434795e-03,   0.00000000e+00,
        -1.63246901e-03,  -2.75198384e-02,   1.58748228e-02,
         3.04327311e-03,   3.80973863e-03,  -8.05570199e-04,
         0.00000000e+00,  -7.08073223e-03,   0.00000000e+00,
        -1.37851487e-02,   8.33708927e-03,   1.94265135e-03,
         1.16451451e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.65354078e-02,   0.00000000e+00,
        -1.48177771e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.27574591e-02,
         7.94708674e-03,   7.53352210e-03,  -1.08744072e-02,
         0.00000000e+00,  -1.24979896e-02,   0.00000000e+00,
        -1.40426685e-02,  -7.32241625e-03,   2.12053519e-03,
         6.45137888e-04,   0.00000000e+00,   2.47084960e-02,
         7.76178866e-03,   1.44323118e-02,   7.50497540e-03,
         0.00000000e+00,   1.26699214e-02,   0.00000000e+00,
         2.10815160e-02,  -1.18519266e-02,   5.81344838e-03,
        -1.83215539e-03,   0.00000000e+00,  -2.43900722e-03,
         3.08034564e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.40575788e-02,   0.00000000e+00,
        -8.41613186e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.04285028e-02,
         0.00000000e+00,   0.00000000e+00,   1.11602884e-01,
         1.40812982e-03,  -3.32222266e-03,  -2.33388938e-02,
         0.00000000e+00,  -3.33238362e-02,   0.00000000e+00,
        -7.97795382e-02,   7.95506723e-03,  -1.35454091e-03,
         1.40804505e-02,   0.00000000e+00,   1.97199264e-02,
        -2.25755388e-02,   0.00000000e+00,   1.04776605e-01,
         2.59570251e-03,   2.33381512e-02,  -1.80614438e-02,
         0.00000000e+00,   5.43585125e-02,   0.00000000e+00,
         9.14639680e-03,  -9.84173773e-02,   2.65747744e-02,
        -7.09827312e-03,   0.00000000e+00,   3.63547533e-03,
         8.78262495e-03,   0.00000000e+00,  -4.08880190e-03,
         1.35125401e-01,  -2.91615778e-02,  -2.13528410e-02,
         5.38451373e-03,   0.00000000e+00,  -1.64013384e-02,
         0.00000000e+00,  -8.65340055e-03,   8.32414087e-03,
         4.24153014e-03,   2.34469713e-03,   0.00000000e+00,
         1.21469520e-03,  -8.15865744e-03,   0.00000000e+00,
         7.37056295e-03,  -1.04164694e-02,   3.38194749e-02,
        -4.85260260e-02,  -5.79457147e-02,   1.12900092e-02,
         0.00000000e+00,  -1.86715132e-02,   0.00000000e+00,
        -8.08022108e-04,  -1.62529421e-02,   8.06186684e-03,
        -5.19495259e-03,   0.00000000e+00,  -6.74191187e-03,
        -1.27009571e-02,   0.00000000e+00,   5.51843528e-04,
         2.07223418e-03,   3.48402311e-02,   1.11319906e-01,
        -3.03550830e-02,   6.67021471e-03,  -2.98349829e-02,
        -3.32367594e-03,  -3.09200824e-03,  -3.05099889e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.47582280e-02,  -1.29261969e-03,   3.27427576e-03,
        -2.84150942e-03,   0.00000000e+00,  -3.62541641e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.06506708e-03,   0.00000000e+00,  -2.50001073e-02,
        -5.09353368e-03,  -9.57935164e-03,   6.62324060e-03,
         0.00000000e+00,   2.13029996e-03,   0.00000000e+00,
        -2.53516178e-02,   4.90245954e-05,  -2.54955365e-03,
         1.83140443e-04,   0.00000000e+00,  -3.33810305e-03,
         0.00000000e+00,  -3.36513738e-04,  -1.90138687e-02,
         4.10434396e-03,  -5.47967255e-03,  -6.18741133e-03,
         0.00000000e+00,   6.26480497e-03,   0.00000000e+00,
         1.64480448e-03,   3.50317825e-03,  -1.77484042e-02,
         2.41479716e-03,   5.93915718e-04,  -5.03378471e-03,
         0.00000000e+00,  -2.18487736e-03,   0.00000000e+00,
         2.83034271e-03,  -1.48576834e-03,  -6.40566806e-03,
        -1.74584346e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.82424872e-02,   0.00000000e+00,
        -8.50643899e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.14436571e-02,
         1.29930352e-02,  -1.23341619e-02,   8.79866009e-03,
         0.00000000e+00,   1.62851727e-02,   0.00000000e+00,
        -1.10712327e-02,   8.49352800e-03,  -6.02215948e-04,
        -1.30833205e-03,   0.00000000e+00,  -3.22640064e-02,
        -1.18927053e-03,  -1.14857652e-02,  -1.41369461e-02,
         0.00000000e+00,   3.99739062e-03,   0.00000000e+00,
        -2.09935611e-03,   7.68776846e-03,  -1.05346157e-02,
        -7.26380368e-03,   0.00000000e+00,   2.73693787e-03,
        -2.57469086e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.27507602e-04,   0.00000000e+00,
         1.26885800e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.57851380e-03,
         0.00000000e+00,   0.00000000e+00,  -1.94309387e-02,
         7.84058190e-03,   1.22925085e-02,  -3.02911933e-03,
         0.00000000e+00,   3.85578402e-03,   0.00000000e+00,
         1.44763409e-02,   1.77460707e-03,  -1.43757682e-03,
        -2.90850468e-03,   0.00000000e+00,   7.03145912e-04,
         2.21175113e-03,   0.00000000e+00,  -1.83636150e-02,
        -8.88691413e-03,  -1.03559971e-02,   5.33682616e-03,
         0.00000000e+00,  -8.17914122e-03,   0.00000000e+00,
        -2.56274980e-03,   1.22763088e-02,  -2.79043804e-03,
         2.19765320e-03,   0.00000000e+00,   4.78117986e-03,
         2.54261015e-03,   0.00000000e+00,   1.86959716e-03,
        -2.01572137e-02,   8.98171754e-03,  -7.20527182e-03,
         4.14874683e-03,   0.00000000e+00,   2.37637904e-02,
         0.00000000e+00,   7.52171772e-06,  -3.66270421e-03,
        -5.53806226e-03,  -1.41347697e-03,   0.00000000e+00,
        -3.57047038e-03,  -1.52359494e-03,   0.00000000e+00,
        -6.62991716e-04,  -4.46765444e-03,  -3.30076502e-02,
         1.09099147e-03,   8.22235627e-03,  -3.78912532e-04,
         0.00000000e+00,   6.76411269e-03,   0.00000000e+00,
         1.53046112e-02,  -7.23916896e-03,   3.27062848e-03,
        -1.52437467e-03,   0.00000000e+00,   1.47553586e-03,
         5.52358937e-03,   0.00000000e+00,  -6.68798490e-03,
         1.83271591e-03,   2.80479994e-03,  -2.31697895e-02,
        -1.08424449e-03,  -5.37287390e-03,   5.10743807e-04,
        -1.17037670e-03,   3.25621553e-03,   3.05100865e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.31695793e-03,  -2.13963455e-04,  -1.93081162e-02,
         2.99654293e-03,   0.00000000e+00,  -3.92676346e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.90268691e-03,   0.00000000e+00,  -6.15018416e-03,
        -8.85417507e-03,  -6.04158109e-03,  -3.03814129e-03,
         0.00000000e+00,  -8.58065271e-03,   0.00000000e+00,
        -3.95075027e-03,   1.55700784e-02,   1.24914897e-02,
        -4.41865267e-03,   0.00000000e+00,   7.55864199e-03,
         0.00000000e+00,  -3.81117781e-03,  -1.75302062e-03,
        -5.91931483e-03,  -8.37209308e-04,   3.21327583e-03,
         0.00000000e+00,  -3.52016557e-03,   0.00000000e+00,
         3.33817669e-03,  -1.37004994e-03,   2.80050654e-03,
         4.44344824e-03,   3.65175128e-03,  -1.17480418e-03,
         0.00000000e+00,  -2.10778125e-03,   0.00000000e+00,
        -4.72315578e-04,   1.54681492e-03,   2.58430324e-03,
         3.97531548e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.26585760e-03,   0.00000000e+00,
         3.09080262e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.41981594e-03,
         2.33274546e-03,   7.00035136e-03,  -4.91904840e-03,
         0.00000000e+00,  -5.79258890e-03,   0.00000000e+00,
         1.12703234e-03,   3.33177859e-03,   1.60109287e-03,
        -1.77330434e-03,   0.00000000e+00,   6.73198792e-03,
        -6.73859850e-03,  -4.41284360e-03,   2.54517721e-03,
         0.00000000e+00,  -4.01428752e-03,   0.00000000e+00,
        -5.40574390e-03,   1.66781087e-03,   3.26873939e-03,
         1.78537607e-03,   0.00000000e+00,   2.13227197e-03,
         4.14622107e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.57717035e-04,   0.00000000e+00,
         1.26924155e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.73351063e-03,
         0.00000000e+00,   0.00000000e+00,  -5.88619149e-03,
         2.05176582e-02,   2.02300300e-02,  -3.58699705e-03,
         0.00000000e+00,   7.03627228e-03,   0.00000000e+00,
        -1.27154413e-03,   4.73603897e-03,  -1.19771115e-03,
        -8.33725853e-04,   0.00000000e+00,  -2.01119231e-03,
         3.39919527e-03,   0.00000000e+00,  -3.91259065e-03,
        -1.61759430e-02,  -1.72258778e-02,   3.21403215e-03,
         0.00000000e+00,  -6.00231987e-03,   0.00000000e+00,
        -2.65740397e-03,   6.90522886e-04,   6.79148046e-04,
         2.72886885e-04,   0.00000000e+00,   6.37064321e-04,
        -4.47680665e-03,   0.00000000e+00,  -5.49754617e-04,
        -1.12491955e-02,  -1.93628240e-03,   6.51506453e-03,
         1.66572066e-03,   0.00000000e+00,   4.75414561e-03,
         0.00000000e+00,   1.25703911e-02,  -8.30301178e-03,
         3.91750789e-03,  -9.87374544e-04,   0.00000000e+00,
         7.78733071e-03,   8.20515875e-03,   0.00000000e+00,
        -5.54168103e-03,   7.05484709e-03,   1.15978785e-03,
        -5.79299105e-03,  -3.53222740e-03,   7.35926447e-03,
         0.00000000e+00,   2.20881610e-02,   0.00000000e+00,
         2.81515320e-02,  -1.94836696e-02,   4.58641731e-03,
        -3.38245561e-03,   0.00000000e+00,  -3.02793074e-03,
         3.34465988e-03,   0.00000000e+00,  -8.14776309e-03,
         2.11260270e-02,  -3.11091542e-03,   6.89662872e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.55281672e-02,   3.18547177e-02,  -5.33285982e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.36679449e-03,   0.00000000e+00,
         8.89484411e-02,   1.10655058e-01,  -2.35449318e-02,
         0.00000000e+00,   3.28149208e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.77802506e-03,   0.00000000e+00,  -2.60535276e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.67190528e-03,   0.00000000e+00,
         1.86781394e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.95709145e-03,   0.00000000e+00,  -8.10540026e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.20425325e-03,   0.00000000e+00,   5.11546841e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.69987390e-03,  -1.04833930e-02,
         5.07162406e-03,   0.00000000e+00,  -9.17199867e-03,
         0.00000000e+00,   1.30769551e-03,   6.19314700e-03,
         7.14397791e-03,  -5.15178646e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.29204085e-03,   0.00000000e+00,   8.69239156e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.11489708e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.04726355e-04,   0.00000000e+00,   1.03866981e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.19723584e-02,   0.00000000e+00,
         0.00000000e+00,  -1.57361527e-02,  -2.18225857e-02,
         7.10922212e-03,   0.00000000e+00,  -1.18289107e-02,
         0.00000000e+00,   1.69723960e-03,  -1.19214362e-02,
         8.12318780e-03,  -5.17210111e-03,   0.00000000e+00,
        -1.23783003e-02,  -1.73130298e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.83237789e-04,   0.00000000e+00,   1.40499014e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.35693596e-03,   0.00000000e+00,
         0.00000000e+00,  -3.70641582e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.21177476e-03,   0.00000000e+00,   6.72382368e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.69275137e-03,   0.00000000e+00,
         0.00000000e+00,  -1.54514400e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.17237303e-04,   0.00000000e+00,
        -1.87991880e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.23207981e-02,
         0.00000000e+00,   0.00000000e+00,   4.25912372e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.88813728e-03,   0.00000000e+00,  -1.47969868e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.31110136e-02,   0.00000000e+00,
         0.00000000e+00,   1.16834928e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.84384302e-03,  -3.31410896e-02,   7.25296904e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.10363355e-03,   0.00000000e+00,
        -4.58307160e-02,  -3.88252973e-02,   9.97646787e-03,
         0.00000000e+00,  -2.04433960e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.03453241e-03,   0.00000000e+00,   1.98009338e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.24550918e-03,   0.00000000e+00,
         5.23056732e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.76118279e-03,   0.00000000e+00,   2.48314966e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.26190748e-03,   0.00000000e+00,   8.41805168e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.39015720e-04,   8.47097110e-03,
        -3.46028349e-03,   0.00000000e+00,   3.53518394e-03,
         0.00000000e+00,   2.37007285e-05,   1.18506550e-03,
         3.22153237e-03,   2.97448709e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.45040793e-03,   0.00000000e+00,  -3.30254187e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.26229245e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.60786789e-03,   0.00000000e+00,  -5.80017389e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.60212871e-03,   0.00000000e+00,
         0.00000000e+00,   9.65896548e-03,   1.20035087e-02,
        -2.51082249e-03,   0.00000000e+00,   3.82889185e-03,
         0.00000000e+00,  -2.33643999e-04,   2.71963234e-03,
        -3.45563408e-03,   2.24717578e-03,   0.00000000e+00,
         4.04799899e-03,   6.96538755e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.66870441e-04,   0.00000000e+00,  -1.53098899e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.17742911e-03,   0.00000000e+00,
         0.00000000e+00,   1.13082962e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.67953505e-03,   0.00000000e+00,  -3.77968438e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.63451267e-03,   0.00000000e+00,
         0.00000000e+00,   1.67935949e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.09712553e-03,   0.00000000e+00,
         1.07030304e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.03413310e-02,
         0.00000000e+00,   0.00000000e+00,  -2.22075408e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.95679926e-03,   0.00000000e+00,   1.10112687e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.33643940e-02,   0.00000000e+00,
         0.00000000e+00,  -4.57433417e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.37987717e-03,  -8.67864250e-03,   1.22026471e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.40542054e-03,   0.00000000e+00,
        -1.15666990e-02,  -1.34852267e-02,   9.74383034e-03,
         0.00000000e+00,  -7.36750418e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.59433398e-03,   0.00000000e+00,   1.72346656e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.29579698e-03,   0.00000000e+00,
         1.83319464e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.53495136e-04,   0.00000000e+00,  -4.73619930e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.75377703e-04,   0.00000000e+00,  -1.10780435e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.33915645e-03,   3.21539285e-03,
        -1.33422916e-03,   0.00000000e+00,   1.01217300e-03,
         0.00000000e+00,  -1.27626640e-03,  -9.75558498e-04,
         2.43027972e-04,  -1.80817786e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.91789853e-03,   0.00000000e+00,  -2.81368738e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.68836262e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.78922745e-04,   0.00000000e+00,  -1.09290882e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.93550832e-03,   0.00000000e+00,
         0.00000000e+00,   3.35516425e-03,   3.38134335e-03,
        -2.05290337e-03,   0.00000000e+00,   7.37715112e-04,
         0.00000000e+00,  -3.86277007e-03,  -3.74006153e-03,
         6.67934342e-04,   1.64281586e-03,   0.00000000e+00,
         4.32405675e-03,   1.78682816e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.49559475e-03,   0.00000000e+00,  -4.11212255e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.70063182e-04,   0.00000000e+00,
         0.00000000e+00,   1.44609637e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.60504246e-03,   0.00000000e+00,  -6.57001250e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.35560161e-03,   0.00000000e+00,
         0.00000000e+00,   2.05944097e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.55459668e-03,   0.00000000e+00,
         2.93674990e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.87743285e-03,
         0.00000000e+00,   0.00000000e+00,  -5.89757116e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.13008780e-03,   0.00000000e+00,   3.88930505e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.92361369e-03,   0.00000000e+00,
         0.00000000e+00,  -1.13995898e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.10705779e-03,   3.07296914e-03,   2.08204108e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.41065221e-02,   0.00000000e+00,
         5.29878575e-03,   1.22178054e-02,   1.97085156e-03,
         0.00000000e+00,   1.99927478e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.74816747e-03,   0.00000000e+00,   2.45076173e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.17526369e-03,   0.00000000e+00,
        -1.89568723e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.25012797e-03,   0.00000000e+00,   4.44719767e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.37186663e-04,   0.00000000e+00,  -2.55559781e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.26520279e-03,  -1.50862006e-03,
         9.40783881e-05,   0.00000000e+00,  -2.10648200e-03,
         0.00000000e+00,  -2.35788350e-03,   1.71695324e-03,
        -2.15570589e-04,   1.14002630e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.11502717e-05,   0.00000000e+00,  -9.88139908e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.42650640e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.63919147e-03,   0.00000000e+00,   4.44094017e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.70031362e-04,   0.00000000e+00,
         0.00000000e+00,  -2.02032649e-03,  -1.91912577e-03,
        -9.98642898e-04,   0.00000000e+00,  -4.36051477e-03,
         0.00000000e+00,  -6.72396522e-03,   4.55875958e-03,
        -1.23516516e-03,   3.26814176e-03,   0.00000000e+00,
         2.60157278e-03,  -7.65393657e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.08718853e-03,   0.00000000e+00,  -6.34311751e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.51082262e-03,   0.00000000e+00,
         0.00000000e+00,   2.19945202e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.09206891e-03,   0.00000000e+00,   7.55429485e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.74686682e-03,   0.00000000e+00,
         0.00000000e+00,  -2.16215966e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.80271243e-03,   0.00000000e+00,
        -1.64074410e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.56459021e-04,
         0.00000000e+00,   0.00000000e+00,   6.83410587e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.08664613e-03,   0.00000000e+00,  -2.53922637e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.10975362e-04,   0.00000000e+00,
         0.00000000e+00,   7.56408268e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.12545337e-01,   2.33962968e-01,   5.97080516e-01,
        -1.43779452e-02,  -6.99035341e-02,   4.34020564e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.59323789e-01,   5.50163094e-03,   1.18696722e-01,
        -1.17983765e-02,   0.00000000e+00,   5.04759969e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.10372914e-01,   0.00000000e+00,   8.26434447e-01,
        -3.05224192e-03,  -1.30235179e-02,   1.49604084e-01,
         0.00000000e+00,   1.28161780e-01,   0.00000000e+00,
         7.24694620e-01,   6.04217849e-02,   3.13843451e-02,
         7.27349193e-02,   0.00000000e+00,  -1.34287919e-01,
         0.00000000e+00,   2.51019378e-02,   6.99670027e-01,
        -3.33825610e-02,  -8.31831973e-03,   1.21345752e-02,
         0.00000000e+00,   2.74177592e-02,   0.00000000e+00,
        -1.98374542e-02,  -1.26487274e-01,   2.86230409e-01,
         5.01946304e-03,   1.60071347e-02,   7.67175540e-03,
         0.00000000e+00,  -3.31099646e-03,   0.00000000e+00,
        -4.86017776e-02,   3.07809231e-02,   2.01195451e-02,
         2.81229844e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.04800021e-02,   0.00000000e+00,
        -4.94499735e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.67306524e-01,
         7.02743112e-03,   2.95773980e-02,  -2.55620346e-02,
         0.00000000e+00,  -2.57063591e-02,   0.00000000e+00,
        -4.13622896e-02,  -2.21701641e-02,  -9.16129663e-03,
         1.83881009e-02,   0.00000000e+00,   3.55307223e-01,
         1.51066621e-02,   3.44067291e-02,   1.68773102e-02,
         0.00000000e+00,   1.88713427e-02,   0.00000000e+00,
         5.08352640e-02,  -1.68393775e-02,   8.57790307e-03,
        -7.98633063e-03,   0.00000000e+00,  -2.15104851e-02,
         3.80987693e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.19695276e-02,   0.00000000e+00,
        -2.15584032e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.00273694e-01,
         0.00000000e+00,   0.00000000e+00,   8.14159327e-01,
         7.31998452e-03,   5.00578669e-03,  -5.01872660e-02,
         0.00000000e+00,  -5.33638266e-02,   0.00000000e+00,
        -1.77838066e-01,  -9.13356939e-03,  -1.46242855e-03,
         5.77712580e-02,   0.00000000e+00,   9.06600829e-02,
        -8.43422322e-02,   0.00000000e+00,   7.14404021e-01,
         8.77177716e-03,   3.01029257e-02,  -3.34838404e-02,
         0.00000000e+00,   6.88169719e-02,   0.00000000e+00,
        -7.82968536e-03,  -1.82848670e-01,   5.75605103e-02,
        -2.12004182e-02,   0.00000000e+00,   1.81565379e-02,
         2.37115173e-02,   0.00000000e+00,   8.07079948e-03,
         7.79431570e-01,  -5.28453209e-02,  -5.24141033e-02,
         8.28822957e-03,   0.00000000e+00,  -4.15873507e-02,
         0.00000000e+00,  -3.73041978e-03,  -5.46431405e-03,
         3.51732004e-02,  -7.41079448e-03,   0.00000000e+00,
        -4.57669694e-02,  -6.92009368e-02,   0.00000000e+00,
         2.46994944e-02,  -3.65970540e-02,   4.23502481e-01,
        -9.20691736e-02,  -1.14628808e-01,   3.42595348e-02,
         0.00000000e+00,  -4.91287992e-02,   0.00000000e+00,
         5.75650474e-03,  -5.23731419e-02,   2.79476884e-02,
        -2.29403441e-02,   0.00000000e+00,  -2.81876073e-02,
        -4.35457197e-02,   0.00000000e+00,  -1.43089455e-02,
         1.24201540e-02,   1.43542272e-01,   7.63781844e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.72366311e-03,   2.94647791e-03,   1.88953797e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.50303225e-03,   0.00000000e+00,
         2.05382246e-03,  -2.98220124e-03,   1.30507626e-02,
         0.00000000e+00,   5.20700334e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.35543039e-02,   0.00000000e+00,   2.35924537e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.64254603e-03,   0.00000000e+00,
         1.14247648e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.56505937e-03,   0.00000000e+00,  -3.26075767e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.02948570e-04,   0.00000000e+00,  -1.61001851e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.85915598e-03,  -2.45712859e-04,
         3.00719658e-04,   0.00000000e+00,  -1.04382213e-04,
         0.00000000e+00,  -3.47097131e-03,  -1.49424350e-03,
         1.50692557e-04,   1.41988984e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.12019241e-05,   0.00000000e+00,  -3.68948643e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.57465661e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.14269923e-04,   0.00000000e+00,   2.88241492e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.27961366e-04,   0.00000000e+00,
         0.00000000e+00,  -2.85579160e-04,  -5.12567295e-04,
        -2.46866293e-03,   0.00000000e+00,  -1.48197701e-03,
         0.00000000e+00,  -7.59389656e-03,  -3.50116521e-03,
         1.03576372e-03,   1.81919960e-03,   0.00000000e+00,
         5.58833786e-03,  -4.38328978e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.02688210e-03,   0.00000000e+00,  -7.04548366e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.09053045e-03,   0.00000000e+00,
         0.00000000e+00,   2.13725508e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.30528613e-04,   0.00000000e+00,  -4.43953108e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.99492259e-03,   0.00000000e+00,
         0.00000000e+00,   1.07747874e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.23400472e-03,   0.00000000e+00,
        -1.04925899e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.72859094e-03,
         0.00000000e+00,   0.00000000e+00,   1.81924370e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.51173445e-04,   0.00000000e+00,  -4.29585606e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.93102448e-03,   0.00000000e+00,
         0.00000000e+00,   3.60496792e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.08402784e-02,  -9.04952455e-02,  -1.92845185e-02,
         1.71475113e-02,   2.11741534e-02,   3.83953866e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.21135736e-02,  -1.79531872e-02,  -4.24888132e-02,
         2.45764494e-03,   0.00000000e+00,   1.58690427e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.59899621e-02,   0.00000000e+00,  -9.58226233e-02,
         2.64369502e-03,   5.82748021e-03,  -5.64449689e-02,
         0.00000000e+00,  -5.13369627e-02,   0.00000000e+00,
        -7.36133499e-02,  -2.15252531e-02,   1.21748280e-02,
        -2.80867802e-02,   0.00000000e+00,   5.83309524e-02,
         0.00000000e+00,  -1.25060460e-02,  -6.32284730e-02,
         4.85332881e-04,   1.08411038e-02,   1.93205737e-02,
         0.00000000e+00,  -1.61085873e-02,   0.00000000e+00,
         5.79918394e-04,   2.41957386e-02,   2.56980885e-02,
        -6.16609771e-03,   2.39827996e-03,   9.18904350e-03,
         0.00000000e+00,   4.90923401e-03,   0.00000000e+00,
         7.47083158e-03,  -1.76210474e-03,   1.48066980e-02,
         3.81680614e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.84305398e-02,   0.00000000e+00,
         3.10597283e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.78976236e-02,
        -3.10023610e-03,  -1.97636590e-03,  -3.82862716e-03,
         0.00000000e+00,  -1.55535035e-02,   0.00000000e+00,
         2.55967073e-02,  -7.27170486e-03,   1.87252950e-03,
        -1.06511873e-02,   0.00000000e+00,   5.53543105e-02,
        -2.48859841e-03,  -4.00350092e-03,   1.46332246e-02,
         0.00000000e+00,  -1.52805891e-02,   0.00000000e+00,
        -1.79953183e-02,  -6.07839530e-03,   1.58474906e-02,
         8.81826373e-03,   0.00000000e+00,   5.00644157e-03,
         4.89625222e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.16884154e-02,   0.00000000e+00,
         5.07122494e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.35136529e-02,
         0.00000000e+00,   0.00000000e+00,  -1.10468905e-01,
         6.22732738e-04,  -3.43299268e-03,   1.64832328e-02,
         0.00000000e+00,   1.38056368e-02,   0.00000000e+00,
         3.85622752e-02,   3.29138149e-04,   8.96618057e-04,
        -1.27006378e-02,   0.00000000e+00,  -3.06705915e-02,
         3.06149905e-02,   0.00000000e+00,  -8.61228041e-02,
        -2.88148571e-03,  -1.67243813e-03,   5.12301907e-03,
         0.00000000e+00,  -1.29510552e-02,   0.00000000e+00,
         1.53444380e-03,   4.72216088e-02,  -1.20822914e-02,
         4.82203960e-03,   0.00000000e+00,  -1.41925494e-02,
        -1.88500746e-02,   0.00000000e+00,  -4.36830276e-03,
        -1.03421272e-01,  -2.80638887e-04,   2.83535687e-02,
        -6.43188994e-03,   0.00000000e+00,   6.31700736e-03,
         0.00000000e+00,   2.12873375e-03,   1.67250386e-02,
         5.30484143e-03,   1.74880174e-03,   0.00000000e+00,
         1.07501685e-02,   1.57803750e-02,   0.00000000e+00,
        -1.24323024e-02,   2.86686024e-02,   4.33544120e-02,
         2.68592848e-02,   2.68739477e-02,  -6.38037295e-03,
         0.00000000e+00,   1.14634571e-02,   0.00000000e+00,
        -1.51326804e-03,   1.30242821e-02,  -1.08340538e-02,
         5.68654774e-03,   0.00000000e+00,   8.01953585e-03,
         1.43091834e-02,   0.00000000e+00,   6.18661956e-03,
         6.09483758e-03,  -5.46520111e-02,  -8.19288042e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.62439901e-03,   1.16093853e-02,  -1.87191784e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.80475089e-03,   0.00000000e+00,
         2.14618323e-02,   1.52882008e-02,   8.14013395e-04,
         0.00000000e+00,  -4.22381536e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.88711442e-04,   0.00000000e+00,  -3.15034660e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.40819035e-02,   0.00000000e+00,
         2.00268299e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.07355156e-03,   0.00000000e+00,  -6.70729415e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.57147556e-03,   0.00000000e+00,   1.27371545e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.34225164e-03,  -3.01822223e-03,
         1.29283718e-03,   0.00000000e+00,  -1.56764388e-03,
         0.00000000e+00,   4.24473884e-04,  -3.57328315e-03,
         6.34268294e-04,  -9.54855483e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.71722106e-04,   0.00000000e+00,   1.97990735e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.44315434e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.57862108e-04,   0.00000000e+00,   2.52115171e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.32274312e-03,   0.00000000e+00,
         0.00000000e+00,  -7.61781993e-03,  -7.14278543e-03,
         4.85178207e-04,   0.00000000e+00,   1.90786423e-04,
         0.00000000e+00,   3.18195973e-04,  -9.18168891e-03,
         3.72060313e-03,  -1.80074978e-03,   0.00000000e+00,
        -1.46451504e-03,  -1.70066864e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.20935723e-04,   0.00000000e+00,   8.70720817e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.94781851e-04,   0.00000000e+00,
         0.00000000e+00,  -1.31474571e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.17143244e-03,   0.00000000e+00,  -7.71440034e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.13940649e-03,   0.00000000e+00,
         0.00000000e+00,   1.52545038e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.09801878e-05,   0.00000000e+00,
        -6.44189822e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.21321221e-03,
         0.00000000e+00,   0.00000000e+00,   6.73336151e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.76410816e-03,   0.00000000e+00,  -7.74175151e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.55728667e-03,   0.00000000e+00,
         0.00000000e+00,   2.16450834e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.88552741e-03,  -1.13162958e-03,   1.95392511e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.32978888e-03,   0.00000000e+00,
        -5.85393508e-03,  -7.14164794e-03,  -4.13753850e-04,
         0.00000000e+00,   1.51733664e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.04224473e-04,   0.00000000e+00,  -1.52800832e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.63344136e-03,   0.00000000e+00,
        -5.30730697e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.83061863e-03,   0.00000000e+00,   9.26084926e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.48899343e-04,   0.00000000e+00,  -1.04981703e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.13813131e-03,  -7.67527983e-04,
        -6.20800945e-04,   0.00000000e+00,   6.56580245e-04,
         0.00000000e+00,   1.15451291e-04,   4.22336283e-04,
        -5.42606411e-04,  -8.16391500e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.04666033e-04,   0.00000000e+00,  -8.62395666e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.95827061e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.74217728e-05,   0.00000000e+00,  -1.47433328e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.07506274e-03,   0.00000000e+00,
         0.00000000e+00,   3.51817228e-03,   3.81746989e-03,
        -3.72235520e-04,   0.00000000e+00,   4.44092064e-04,
         0.00000000e+00,  -7.49388000e-05,   2.85084591e-03,
        -1.05337291e-03,   5.46490361e-04,   0.00000000e+00,
         3.30293075e-04,   8.76876768e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.00926474e-04,   0.00000000e+00,  -1.07653924e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.85107172e-04,   0.00000000e+00,
         0.00000000e+00,  -1.20343633e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.43845258e-04,   0.00000000e+00,   1.46579376e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.82191448e-04,   0.00000000e+00,
         0.00000000e+00,  -2.92673206e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.66498676e-03,   0.00000000e+00,
         1.58074692e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.31193829e-03,
         0.00000000e+00,   0.00000000e+00,  -2.13078038e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.92900914e-04,   0.00000000e+00,   4.50454121e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.65439575e-03,   0.00000000e+00,
         0.00000000e+00,  -6.79297984e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.02760552e-03,   5.42149812e-03,   2.87797039e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.03974823e-04,   0.00000000e+00,
         3.79209594e-03,  -4.96526810e-04,  -1.52783723e-03,
         0.00000000e+00,  -4.32687937e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.42709019e-03,   0.00000000e+00,  -2.62322442e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.93843396e-03,   0.00000000e+00,
         6.43586827e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.31679310e-04,   0.00000000e+00,  -1.16432445e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.99075395e-03,   0.00000000e+00,  -4.95220284e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.05589957e-04,  -5.81053355e-04,
         1.91804861e-04,   0.00000000e+00,   2.23048055e-04,
         0.00000000e+00,   9.18935136e-04,  -1.21290983e-03,
        -1.96956898e-03,   9.93723654e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.12846974e-03,   0.00000000e+00,   1.00606412e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.66243343e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.08059096e-04,   0.00000000e+00,  -3.09071547e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.27910699e-03,   0.00000000e+00,
         0.00000000e+00,  -2.23948975e-03,  -2.44504954e-03,
         1.09761315e-03,   0.00000000e+00,   1.20220163e-03,
         0.00000000e+00,   2.46403982e-03,  -1.15616922e-03,
         6.30169255e-04,  -6.46857240e-04,   0.00000000e+00,
        -3.00614511e-04,   7.88991882e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.51126083e-04,   0.00000000e+00,   2.80330779e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.23589830e-04,   0.00000000e+00,
         0.00000000e+00,  -2.00814352e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.21516275e-04,   0.00000000e+00,  -1.07061863e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.33460642e-04,   0.00000000e+00,
         0.00000000e+00,   5.43952270e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.37084567e-03,   0.00000000e+00,
        -9.52965364e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.89377639e-03,
         0.00000000e+00,   0.00000000e+00,   1.44719556e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.21447708e-04,   0.00000000e+00,  -3.40469145e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.62161163e-03,   0.00000000e+00,
         0.00000000e+00,   1.00585800e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.31796890e-03,   3.49761717e-03,  -1.32359270e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.51617574e-04,   0.00000000e+00,
         3.38578885e-03,   1.92549045e-03,  -1.85287381e-03,
         0.00000000e+00,   5.41972711e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.13943385e-03,   0.00000000e+00,  -4.67536447e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.54478174e-04,   0.00000000e+00,
        -7.04276499e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.74001938e-05,   0.00000000e+00,  -1.36653553e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.05972788e-03,   0.00000000e+00,   8.52110424e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.02514280e-04,  -1.10758252e-03,
         3.05921002e-03,   0.00000000e+00,   2.61130494e-03,
         0.00000000e+00,  -2.28750520e-04,   3.19181131e-04,
        -4.66339991e-04,   1.16354797e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.58775024e-03,   0.00000000e+00,   4.71142577e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.50024683e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.40167067e-03,   0.00000000e+00,  -2.54524980e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.71384475e-04,   0.00000000e+00,
         0.00000000e+00,  -2.19722374e-03,  -2.21624090e-03,
         2.34428381e-03,   0.00000000e+00,   8.61997508e-04,
         0.00000000e+00,   5.90522076e-03,   7.18142523e-04,
        -1.27328547e-04,  -5.68663330e-04,   0.00000000e+00,
        -8.12768264e-04,   4.98107856e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.67437487e-03,   0.00000000e+00,   6.06530956e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.88028494e-04,   0.00000000e+00,
         0.00000000e+00,  -3.10637264e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.48405552e-04,   0.00000000e+00,   1.48654982e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.21942033e-04,   0.00000000e+00,
         0.00000000e+00,  -1.54975491e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.54130452e-04,   0.00000000e+00,
        -1.37457189e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.67145573e-03,
         0.00000000e+00,   0.00000000e+00,   9.79465855e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.90890669e-04,   0.00000000e+00,  -2.54810849e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.61468963e-03,   0.00000000e+00,
         0.00000000e+00,   2.39185483e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.28412507e-02,   1.71854085e-02,   4.89501954e-02,
        -2.73991133e-03,  -8.02407352e-03,   3.11706272e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.73378620e-02,   6.10661990e-03,   1.00164183e-02,
        -1.07311490e-03,   0.00000000e+00,   4.09600261e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.35230146e-02,   0.00000000e+00,   6.95944965e-02,
        -1.56193775e-03,  -3.75059951e-04,   1.12815260e-02,
         0.00000000e+00,   9.00538073e-03,   0.00000000e+00,
         5.87107739e-02,  -6.75338922e-04,   1.29698795e-03,
         6.62197148e-03,   0.00000000e+00,  -9.44250889e-03,
         0.00000000e+00,   8.78136324e-04,   5.58210525e-02,
        -6.88436029e-03,   4.89734996e-03,   6.56893493e-03,
         0.00000000e+00,   3.17432539e-04,   0.00000000e+00,
        -3.28859788e-03,  -1.47159887e-02,   1.01306434e-02,
         4.46801189e-05,   4.01315872e-03,   3.94676803e-03,
         0.00000000e+00,  -1.35835523e-03,   0.00000000e+00,
        -8.98860690e-03,   4.09254256e-03,   5.17477251e-03,
         7.07207601e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.20395816e-02,   0.00000000e+00,
         1.26877187e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.57790721e-02,
         3.99280520e-03,   6.04448450e-03,  -1.15170245e-02,
         0.00000000e+00,  -1.77350313e-02,   0.00000000e+00,
         1.06455649e-04,  -7.65399410e-03,   7.44347145e-05,
        -3.09428258e-03,   0.00000000e+00,   2.59908617e-02,
         6.06606515e-03,   7.91750850e-03,   1.72596208e-02,
         0.00000000e+00,  -1.86351311e-03,   0.00000000e+00,
         6.52088780e-03,  -6.07421223e-03,   9.52245476e-03,
         4.34999011e-03,   0.00000000e+00,  -8.36784276e-04,
         2.61610016e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.64548395e-02,   0.00000000e+00,
        -4.85311451e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.59242162e-03,
         0.00000000e+00,   0.00000000e+00,   6.36643254e-02,
         3.10222965e-03,  -3.18977538e-04,  -7.84447062e-03,
         0.00000000e+00,  -1.02218990e-02,   0.00000000e+00,
        -3.58454876e-02,  -1.94160531e-03,   1.21531225e-03,
         7.90988980e-03,   0.00000000e+00,   8.09368538e-03,
        -8.30723218e-03,   0.00000000e+00,   5.52702244e-02,
        -4.05233782e-03,   7.90555613e-03,  -9.80879517e-03,
         0.00000000e+00,   1.85393372e-02,   0.00000000e+00,
        -2.42085116e-03,  -3.06560861e-02,   8.47931110e-03,
        -2.13028327e-03,   0.00000000e+00,   2.61914619e-03,
         3.57772831e-03,   0.00000000e+00,   1.02420557e-03,
         6.65367465e-02,  -2.42966091e-02,   2.05421950e-03,
        -1.18770321e-03,   0.00000000e+00,  -5.31813268e-03,
         0.00000000e+00,  -1.13093454e-03,   4.60782917e-03,
         6.12873198e-03,   3.64153495e-03,   0.00000000e+00,
         4.22087458e-04,  -3.43054974e-03,   0.00000000e+00,
         1.38900198e-03,  -5.42067172e-03,   3.11455187e-02,
        -1.91035499e-02,  -2.94559533e-02,   6.31091868e-03,
         0.00000000e+00,  -7.23145076e-03,   0.00000000e+00,
         4.28920297e-04,  -1.14490932e-02,   3.92535400e-03,
        -3.90194413e-03,   0.00000000e+00,  -4.94514892e-03,
        -5.77397183e-03,   0.00000000e+00,  -1.25321403e-03,
        -3.50864090e-03,   1.44782162e-02,   5.50448578e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.33888712e-04,   5.51681272e-03,  -1.70927364e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.74744051e-03,   0.00000000e+00,
         7.56273286e-03,   7.34707821e-03,  -1.45793894e-03,
         0.00000000e+00,   5.18318370e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.03457476e-03,   0.00000000e+00,   1.76895933e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.10508226e-05,   0.00000000e+00,
        -7.17407548e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.83370583e-05,   0.00000000e+00,  -8.11113705e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.85854687e-04,   0.00000000e+00,  -3.67697191e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.08070613e-03,  -2.03304132e-03,
        -2.44329228e-03,   0.00000000e+00,   1.04429524e-03,
         0.00000000e+00,  -7.30169885e-04,   9.88213928e-04,
        -1.82542813e-03,  -2.85479090e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.60479983e-03,   0.00000000e+00,   3.59964326e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.72063781e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.12239170e-03,   0.00000000e+00,   1.83014351e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.20617785e-03,   0.00000000e+00,
         0.00000000e+00,  -6.44489970e-03,  -7.16876632e-03,
         7.48430151e-04,   0.00000000e+00,  -4.27802932e-03,
         0.00000000e+00,  -3.12087683e-03,   7.99412345e-04,
         1.89736696e-04,   1.49418998e-04,   0.00000000e+00,
         2.03815737e-05,  -1.19624003e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.83608975e-04,   0.00000000e+00,  -3.00954434e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.16568906e-04,   0.00000000e+00,
         0.00000000e+00,   1.43381712e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.51319549e-04,   0.00000000e+00,   4.05022124e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.94837783e-03,   0.00000000e+00,
         0.00000000e+00,  -3.79711474e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.48291654e-03,   0.00000000e+00,
        -4.62022810e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.45656683e-03,
         0.00000000e+00,   0.00000000e+00,   3.21823285e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.46567652e-03,   0.00000000e+00,  -8.50662664e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.98670731e-03,   0.00000000e+00,
         0.00000000e+00,   6.71270323e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.86397133e-02,  -9.00730272e-02,  -1.07710391e-01,
         1.37827528e-02,   2.26914586e-02,  -3.98520578e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.19272862e-02,  -1.63102477e-02,  -3.71989774e-02,
         9.17261753e-04,   0.00000000e+00,  -6.68379398e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.03056586e-02,   0.00000000e+00,  -1.92424256e-01,
         3.58060745e-03,   3.79258032e-03,  -5.72599309e-02,
         0.00000000e+00,  -5.13672247e-02,   0.00000000e+00,
        -1.63186821e-01,  -3.31302395e-02,  -9.59314042e-03,
        -2.65726258e-02,   0.00000000e+00,   5.17600876e-02,
         0.00000000e+00,  -1.04318343e-02,  -1.51935264e-01,
         1.45216017e-02,   8.95385511e-03,   5.34604505e-03,
         0.00000000e+00,  -1.20786073e-02,   0.00000000e+00,
         3.78279415e-03,   4.11904575e-02,  -1.69521625e-02,
        -6.74144688e-03,  -5.38264784e-03,   6.06080076e-03,
         0.00000000e+00,   8.23020198e-03,   0.00000000e+00,
         1.98849511e-02,  -9.64728903e-03,   1.46876937e-03,
        -1.08330369e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.48249972e-02,   0.00000000e+00,
         3.96932406e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.44368329e-02,
        -9.31461818e-03,  -1.11744129e-02,   1.32516969e-02,
         0.00000000e+00,   3.18629120e-03,   0.00000000e+00,
         3.21759520e-02,   5.12918743e-03,  -8.64943875e-04,
        -5.84443275e-03,   0.00000000e+00,  -1.86143008e-02,
        -1.28015823e-02,  -1.59700353e-02,  -4.41041573e-03,
         0.00000000e+00,  -2.05952228e-02,   0.00000000e+00,
        -3.18936030e-02,   4.66713094e-03,   4.99303032e-04,
         6.04775785e-03,   0.00000000e+00,   6.13640666e-03,
        -2.31023346e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.34363641e-02,   0.00000000e+00,
         1.71483312e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.10340542e-02,
         0.00000000e+00,   0.00000000e+00,  -1.97798516e-01,
        -4.55337738e-03,  -3.86011478e-03,   4.33949078e-02,
         0.00000000e+00,   4.13305124e-02,   0.00000000e+00,
         1.23231113e-01,   4.79256853e-03,  -1.69045929e-03,
        -2.18346717e-02,   0.00000000e+00,  -3.75053273e-02,
         3.78834712e-02,   0.00000000e+00,  -1.68676348e-01,
        -5.52972045e-04,  -2.15947125e-02,   2.71576907e-02,
         0.00000000e+00,  -5.48916869e-02,   0.00000000e+00,
         6.51663456e-03,   1.26445865e-01,  -3.41978378e-02,
         8.89101629e-03,   0.00000000e+00,  -1.15769532e-02,
        -1.53709199e-02,   0.00000000e+00,  -4.24067196e-03,
        -1.99068958e-01,   3.44863647e-02,   4.34808368e-02,
        -7.08433279e-03,   0.00000000e+00,   2.07320383e-02,
         0.00000000e+00,   7.86184280e-03,   2.92256163e-03,
        -4.22325165e-03,   1.67139958e-03,   0.00000000e+00,
         6.35121559e-03,   1.54323705e-02,   0.00000000e+00,
        -1.08750432e-02,   1.84508841e-02,  -3.79595934e-02,
         8.42731719e-02,   9.24627921e-02,  -1.89959526e-02,
         0.00000000e+00,   2.74834759e-02,   0.00000000e+00,
        -3.66209136e-03,   3.44476157e-02,  -1.67505217e-02,
         9.28127586e-03,   0.00000000e+00,   1.33787345e-02,
         1.95190681e-02,   0.00000000e+00,   6.33407599e-03,
        -8.79580833e-03,  -6.31169890e-02,  -1.74077055e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.66582846e-03,   1.74163830e-04,  -7.30596164e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.45346506e-04,   0.00000000e+00,
         1.45319295e-03,   2.47790178e-03,  -3.68879080e-03,
         0.00000000e+00,  -2.10274393e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.79869463e-03,   0.00000000e+00,  -8.92812694e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.06501757e-04,   0.00000000e+00,
        -7.68038727e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.73434145e-05,   0.00000000e+00,   1.21469427e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.10040300e-03,   0.00000000e+00,   2.26647681e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.63701071e-04,   1.06411072e-04,
         1.13081269e-03,   0.00000000e+00,   8.04355742e-04,
         0.00000000e+00,   3.86022659e-03,   6.89561112e-04,
        -1.23501021e-04,  -1.88424391e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.58056481e-03,   0.00000000e+00,   4.52190862e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.61268391e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.50849150e-03,   0.00000000e+00,  -3.71316536e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.66967104e-04,   0.00000000e+00,
         0.00000000e+00,  -1.52226952e-03,  -1.91403400e-03,
         7.64788231e-03,   0.00000000e+00,   5.02788119e-03,
         0.00000000e+00,   1.80683468e-02,   2.30413551e-03,
        -8.03711275e-04,  -1.39004655e-03,   0.00000000e+00,
        -2.35465476e-03,   1.75498746e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.34756196e-03,   0.00000000e+00,   1.77874125e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.23331517e-03,   0.00000000e+00,
         0.00000000e+00,  -6.94410481e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.12997024e-03,   0.00000000e+00,   2.93657720e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.96678785e-04,   0.00000000e+00,
         0.00000000e+00,  -1.41457504e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.77631694e-04,   0.00000000e+00,
         6.89918259e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.85567224e-04,
         0.00000000e+00,   0.00000000e+00,   3.33876282e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.68858320e-04,   0.00000000e+00,  -1.99775429e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.91732551e-04,   0.00000000e+00,
         0.00000000e+00,   1.91985905e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.82857607e-03,   2.78526662e-03,  -6.06674788e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.29074899e-04,   0.00000000e+00,
         5.40923838e-03,   7.50218692e-03,  -2.64981106e-03,
         0.00000000e+00,   5.82074761e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.00836757e-04,   0.00000000e+00,   5.18564257e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.93917235e-03,   0.00000000e+00,
        -7.10901167e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.18928120e-03,   0.00000000e+00,   1.56802572e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.77486812e-04,   0.00000000e+00,  -6.49416302e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.05248073e-03,  -2.16298285e-03,
         2.01106271e-03,   0.00000000e+00,  -3.54267396e-03,
         0.00000000e+00,  -1.00955196e-05,   2.92965127e-03,
         8.13135008e-05,  -5.84355787e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.75645111e-04,   0.00000000e+00,   1.62930665e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.63799922e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.82716100e-04,   0.00000000e+00,   3.40963402e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.40191768e-03,   0.00000000e+00,
         0.00000000e+00,  -2.77546032e-03,  -7.50579172e-03,
         4.71756630e-03,   0.00000000e+00,  -1.12067483e-02,
         0.00000000e+00,  -7.92132518e-04,   1.66788692e-02,
        -3.86358141e-03,   5.33426928e-04,   0.00000000e+00,
        -1.37256518e-03,  -2.41355375e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.59751391e-04,   0.00000000e+00,  -1.30735989e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.36998320e-04,   0.00000000e+00,
         0.00000000e+00,   3.81885944e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.06018904e-02,   0.00000000e+00,   2.09378500e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.75001083e-03,   0.00000000e+00,
         0.00000000e+00,  -9.29285124e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.73192204e-04,   0.00000000e+00,
        -5.69148953e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.64972071e-03,
         0.00000000e+00,   0.00000000e+00,   3.30062868e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.99478509e-03,   0.00000000e+00,  -4.20357394e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.73872049e-03,   0.00000000e+00,
         0.00000000e+00,   5.98706464e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.67028878e-04,  -7.26523612e-03,   2.27410162e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.58350528e-03,   0.00000000e+00,
        -1.14779532e-02,  -1.17216106e-02,   2.79246074e-03,
         0.00000000e+00,  -4.83352132e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.82965983e-04,   0.00000000e+00,   2.30511870e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.17367476e-03,   0.00000000e+00,
        -2.53361983e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.60103298e-03,   0.00000000e+00,   1.24516102e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.18180579e-03,   0.00000000e+00,  -4.21309144e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.97177231e-03,  -1.81491748e-03,
         1.03443651e-03,   0.00000000e+00,   6.05401678e-04,
         0.00000000e+00,  -2.82914651e-04,  -9.97302338e-05,
         1.53343527e-03,  -3.14741422e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.86449974e-03,   0.00000000e+00,  -2.74836292e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.43451625e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.23757753e-03,   0.00000000e+00,  -4.06034825e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.43398138e-03,   0.00000000e+00,
         0.00000000e+00,   1.43465690e-02,   1.70217004e-02,
        -2.64579432e-03,   0.00000000e+00,   4.61037055e-03,
         0.00000000e+00,   1.06511316e-03,   2.27888979e-03,
        -1.36404554e-03,   1.03550199e-03,   0.00000000e+00,
         3.86957865e-04,   1.17159804e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.19599140e-04,   0.00000000e+00,   7.37077130e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.15484025e-04,   0.00000000e+00,
         0.00000000e+00,   1.67183478e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.94604511e-04,   0.00000000e+00,  -3.69232766e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.38165792e-03,   0.00000000e+00,
         0.00000000e+00,   2.45138023e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.34486821e-02,   0.00000000e+00,
         5.67456303e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.83553425e-03,
         0.00000000e+00,   0.00000000e+00,  -5.78366458e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.25291402e-03,   0.00000000e+00,   2.22754580e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.59834076e-03,   0.00000000e+00,
         0.00000000e+00,  -1.10008344e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.47963063e-03,  -5.91105979e-03,   2.83010947e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.85764292e-03,   0.00000000e+00,
        -1.14089576e-02,  -1.28983422e-02,   3.06123452e-03,
         0.00000000e+00,  -5.16143300e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.03037880e-04,   0.00000000e+00,   6.46830248e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.49333589e-03,   0.00000000e+00,
        -3.32806916e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.62419922e-03,   0.00000000e+00,   3.07565778e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.41334061e-03,   0.00000000e+00,  -2.15080171e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.72141689e-03,   7.17961092e-03,
        -5.91046064e-04,   0.00000000e+00,   2.80904495e-04,
         0.00000000e+00,   1.77705654e-04,   2.78158583e-03,
         3.22834208e-04,  -1.07474569e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.69769935e-03,   0.00000000e+00,  -3.77824723e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.85136312e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.72626022e-03,   0.00000000e+00,  -5.83446261e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.55344855e-03,   0.00000000e+00,
         0.00000000e+00,   3.15544700e-02,   3.26465210e-02,
        -6.26101646e-03,   0.00000000e+00,   9.50079572e-03,
         0.00000000e+00,  -1.04000327e-03,   5.60177547e-03,
        -2.09741226e-03,   6.58357520e-04,   0.00000000e+00,
         1.82814855e-03,   2.41848357e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.50524255e-04,   0.00000000e+00,  -1.67807481e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.39421514e-04,   0.00000000e+00,
         0.00000000e+00,   6.85856520e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.62905835e-04,   0.00000000e+00,  -4.89451252e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.13155021e-03,   0.00000000e+00,
         0.00000000e+00,   9.16924118e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.42723787e-03,   0.00000000e+00,
         1.80165115e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.42010686e-04,
         0.00000000e+00,   0.00000000e+00,  -7.12402450e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.17597952e-02,   0.00000000e+00,   4.57837287e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.27825715e-03,   0.00000000e+00,
         0.00000000e+00,  -1.25410249e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.57612091e-02,   5.25354077e-03,   9.59312484e-03,
         1.67799871e-02,   4.06222722e-02,  -7.56278772e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.35299603e-03,  -3.16478192e-03,   2.35586917e-02,
        -3.72550729e-04,   0.00000000e+00,   1.31665269e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.18876602e-03,   0.00000000e+00,   1.18046759e-02,
         6.78433793e-02,   5.44325474e-02,  -5.85905784e-03,
         0.00000000e+00,   2.81918104e-02,   0.00000000e+00,
         5.77309686e-03,   2.68357293e-02,   3.41755720e-02,
         3.47300783e-03,   0.00000000e+00,   9.76544102e-03,
         0.00000000e+00,   6.24025872e-03,   1.86115604e-02,
        -1.11084607e-02,  -7.92290068e-03,  -3.77161949e-03,
         0.00000000e+00,   6.01370788e-05,   0.00000000e+00,
        -3.03437828e-03,  -5.53686673e-04,   8.03978323e-03,
        -3.42576394e-03,  -4.73461670e-03,  -6.74925580e-03,
         0.00000000e+00,   8.48908917e-04,   0.00000000e+00,
         4.54379961e-03,   7.55067520e-03,   5.02714628e-03,
         1.70440724e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.26986598e-03,   0.00000000e+00,
        -1.45821425e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.10175364e-03,
        -5.52327856e-04,  -1.13070019e-02,   7.78644120e-03,
         0.00000000e+00,   1.26085001e-03,   0.00000000e+00,
         3.75442622e-03,  -2.81371468e-03,  -8.05288072e-04,
         1.28090203e-03,   0.00000000e+00,  -8.34064131e-03,
        -4.21626095e-05,   8.86864763e-03,  -6.05835833e-03,
         0.00000000e+00,   6.78384427e-03,   0.00000000e+00,
         7.37081637e-03,  -6.88544687e-04,  -1.60067111e-03,
        -1.56283634e-03,   0.00000000e+00,  -1.08290166e-03,
         8.54311955e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.40758537e-03,   0.00000000e+00,
        -6.97436730e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.78456738e-03,
         0.00000000e+00,   0.00000000e+00,   1.25921098e-02,
        -1.38959102e-02,  -1.42512746e-02,   1.93148357e-03,
         0.00000000e+00,  -6.52126520e-03,   0.00000000e+00,
        -4.75863873e-03,  -8.13926217e-03,   6.28534274e-03,
        -4.16048605e-03,   0.00000000e+00,   1.13286325e-04,
        -1.41322003e-02,   0.00000000e+00,   5.57124270e-03,
        -6.19946127e-03,  -8.74103807e-03,   7.16787239e-03,
         0.00000000e+00,  -1.02325482e-03,   0.00000000e+00,
         2.24083294e-03,  -1.05554876e-02,   6.41499207e-03,
        -1.08847306e-04,   0.00000000e+00,  -7.15987870e-03,
        -5.21442062e-03,   0.00000000e+00,  -1.39003874e-02,
         2.62536705e-03,   3.97536209e-04,  -3.79976204e-03,
         2.15296951e-03,   0.00000000e+00,  -2.77840849e-03,
         0.00000000e+00,  -1.73690142e-02,  -3.10316218e-03,
         4.72193504e-03,   6.38166590e-03,   0.00000000e+00,
        -1.07861513e-02,  -3.61901438e-03,   0.00000000e+00,
         2.96355961e-02,   1.45694391e-02,   1.13530564e-02,
        -4.06456653e-03,  -3.05722400e-03,  -2.66074685e-03,
         0.00000000e+00,  -4.12075487e-03,   0.00000000e+00,
        -1.30243730e-02,  -1.42409014e-02,   4.74172950e-03,
         5.95240672e-03,   0.00000000e+00,   1.87421536e-02,
        -1.82619018e-02,   0.00000000e+00,   6.54017574e-02,
         2.97328454e-02,   9.84578412e-03,   2.50597484e-02,
         6.65571374e-03,   1.98750132e-02,   9.01817117e-03,
        -6.45371673e-02,   2.36561442e-02,  -2.85982916e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.92219451e-02,  -3.00898431e-02,   3.57127993e-02,
        -1.72489062e-02,   0.00000000e+00,  -3.91475442e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.39324240e-02,   0.00000000e+00,   1.54754661e-02,
        -6.66899307e-03,  -6.87048478e-02,   3.52878115e-02,
         0.00000000e+00,   2.03125083e-02,   0.00000000e+00,
         1.09696696e-02,  -9.99940547e-03,  -7.82490244e-03,
         1.72940720e-02,   0.00000000e+00,  -2.67388863e-02,
         0.00000000e+00,   2.73306395e-03,   2.35135784e-02,
        -2.60390182e-03,  -8.85793231e-04,  -3.09059162e-02,
         0.00000000e+00,   1.64810844e-02,   0.00000000e+00,
         5.58958480e-03,   1.18471540e-02,   2.04581209e-02,
         2.03845062e-03,  -8.48272987e-03,  -4.10550946e-02,
         0.00000000e+00,   1.03962268e-02,   0.00000000e+00,
         1.10760586e-02,   1.36283480e-02,   6.46147754e-03,
         5.49308330e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.75036573e-02,   0.00000000e+00,
        -1.41826131e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.18081638e-02,
         8.85559636e-03,  -8.52803297e-03,   7.38642873e-03,
         0.00000000e+00,   2.01105737e-02,   0.00000000e+00,
        -1.69969614e-02,  -2.68607409e-03,  -1.23892132e-02,
         1.62653816e-02,   0.00000000e+00,  -5.30308140e-02,
        -4.76120885e-03,   1.77261057e-03,  -4.86943263e-03,
         0.00000000e+00,   2.38519658e-03,   0.00000000e+00,
         3.50125480e-03,   8.33676416e-03,  -2.02161694e-03,
         3.08867375e-03,   0.00000000e+00,   4.25001253e-03,
        -5.06702135e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.97552923e-03,   0.00000000e+00,
        -8.88357262e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.25855214e-02,
         0.00000000e+00,   0.00000000e+00,   2.58123466e-02,
         1.08565439e-03,   8.32653084e-03,  -2.93688019e-03,
         0.00000000e+00,   1.22874073e-03,   0.00000000e+00,
        -9.30002474e-03,   2.57284331e-03,  -1.56081336e-03,
        -2.51594910e-03,   0.00000000e+00,   2.76069653e-02,
        -1.24227704e-02,   0.00000000e+00,   2.04647642e-02,
         5.28008769e-03,   4.95804134e-03,   4.02813340e-04,
         0.00000000e+00,   1.33276474e-03,   0.00000000e+00,
        -7.34298617e-03,  -1.16421379e-02,   5.33488401e-03,
         3.34073314e-03,   0.00000000e+00,   6.06157033e-04,
         1.55040783e-02,   0.00000000e+00,   1.24404940e-02,
         3.85053668e-02,   8.29104739e-03,  -1.27719428e-02,
         1.33697609e-02,   0.00000000e+00,   5.55288659e-03,
         0.00000000e+00,  -3.22658030e-03,  -3.21760419e-03,
        -1.99724473e-03,   7.92391829e-03,   0.00000000e+00,
        -5.71844647e-02,   2.08186465e-02,   0.00000000e+00,
         9.50291102e-04,  -1.10338485e-02,  -1.46973434e-02,
        -8.07611496e-03,  -1.58193921e-03,   4.90268494e-03,
         0.00000000e+00,  -5.62484692e-03,   0.00000000e+00,
         4.31785662e-03,   1.76124718e-03,   3.57462851e-03,
        -1.19919288e-03,   0.00000000e+00,   6.43324871e-03,
        -6.66615465e-03,   0.00000000e+00,  -4.82780600e-02,
        -1.25259456e-02,   1.08052170e-02,   1.87375681e-02,
         2.50276102e-02,   1.70462078e-01,   2.95557552e-02,
        -3.73737194e-02,  -4.01497748e-02,  -1.02679336e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.59074253e-02,   1.66434795e-02,   8.06425594e-02,
        -1.55440287e-02,   0.00000000e+00,  -3.73969069e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.38584310e-01,   0.00000000e+00,   1.46557347e-01,
        -7.87001516e-03,  -2.61091801e-02,   1.37409964e-01,
         0.00000000e+00,   9.76046590e-02,   0.00000000e+00,
         1.44467694e-01,   4.06566347e-02,  -1.81374675e-02,
         6.46923821e-02,   0.00000000e+00,  -1.07906754e-01,
         0.00000000e+00,   3.63357565e-02,   1.26853912e-01,
        -7.60905810e-03,  -1.32016818e-02,  -4.20608879e-02,
         0.00000000e+00,   2.74888312e-02,   0.00000000e+00,
        -3.04964671e-03,  -4.97500256e-02,  -6.43071516e-02,
        -2.17581337e-03,   1.26316159e-02,  -1.28467102e-02,
         0.00000000e+00,  -1.17583942e-02,   0.00000000e+00,
        -1.58339346e-02,   7.42397526e-04,  -4.27117696e-02,
        -1.09413711e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.27611600e-02,   0.00000000e+00,
        -5.21377988e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.13272477e-01,
         6.12438974e-03,   2.51007514e-03,   1.77016172e-02,
         0.00000000e+00,   3.62388884e-02,   0.00000000e+00,
        -5.60678155e-02,   1.05193368e-02,  -2.18277523e-03,
         2.42035485e-02,   0.00000000e+00,  -1.21320786e-01,
        -1.81843577e-03,   4.74312913e-03,  -3.79163123e-02,
         0.00000000e+00,   2.63903339e-02,   0.00000000e+00,
         3.66084733e-02,   1.44225934e-02,  -3.36460635e-02,
        -2.28007589e-02,   0.00000000e+00,   3.43888280e-03,
        -1.08711993e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.16021532e-02,   0.00000000e+00,
        -7.36737386e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.60496843e-02,
         0.00000000e+00,   0.00000000e+00,   1.76093795e-01,
        -6.73928066e-04,   6.14308692e-03,  -3.42589706e-02,
         0.00000000e+00,  -2.22873000e-02,   0.00000000e+00,
        -6.99262436e-02,  -3.46768745e-03,  -7.48265975e-04,
         2.81016151e-02,   0.00000000e+00,   7.06352011e-02,
        -6.44537397e-02,   0.00000000e+00,   1.70247355e-01,
         9.40320936e-03,   2.30390906e-03,  -6.30307923e-03,
         0.00000000e+00,   1.80035019e-02,   0.00000000e+00,
        -1.03449343e-02,  -8.69144976e-02,   2.40270874e-02,
        -7.58133346e-03,   0.00000000e+00,   2.64166033e-02,
         3.22899583e-02,   0.00000000e+00,   2.51910749e-02,
         2.00080252e-01,   1.13593987e-02,  -5.57348003e-02,
         1.99363239e-02,   0.00000000e+00,  -1.02371917e-02,
         0.00000000e+00,  -5.79283781e-03,  -3.13152327e-02,
        -5.26509624e-03,  -4.02750932e-03,   0.00000000e+00,
        -3.43618814e-02,  -2.44136215e-02,   0.00000000e+00,
         2.17927766e-02,  -4.95658730e-02,  -8.05981415e-02,
        -4.63701449e-02,  -4.22949347e-02,   1.27881421e-02,
         0.00000000e+00,  -2.20332633e-02,   0.00000000e+00,
         4.39006521e-03,  -2.12170693e-02,   1.88599967e-02,
        -1.18454620e-02,   0.00000000e+00,  -1.20823945e-02,
        -2.86684727e-02,   0.00000000e+00,  -2.38211978e-02,
        -6.77955585e-03,   9.88350116e-02,   1.52453304e-01,
         1.56151761e-02,   1.14033151e-01,   1.55122248e-02,
        -2.77058330e-02,  -9.28257417e-03,  -6.22238604e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.70671153e-02,   6.32534725e-03,   7.06544156e-02,
        -1.01555912e-02,   0.00000000e+00,  -4.33062210e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.64481595e-02,   0.00000000e+00,   9.32990692e-02,
         1.22335016e-02,  -1.17170116e-02,   8.93708629e-02,
         0.00000000e+00,   9.60476608e-02,   0.00000000e+00,
         1.07642798e-01,   2.85824863e-02,  -2.18547061e-04,
         2.81778354e-02,   0.00000000e+00,  -7.23341307e-02,
         0.00000000e+00,   1.40140532e-02,   6.39358417e-02,
        -9.72441214e-04,  -1.85695099e-02,  -3.05866344e-02,
         0.00000000e+00,   2.23202790e-02,   0.00000000e+00,
         1.30531966e-03,  -2.12573333e-02,  -2.96075047e-02,
         5.40609361e-03,  -4.67349272e-03,  -2.25486197e-02,
         0.00000000e+00,  -5.16994235e-03,   0.00000000e+00,
        -6.77571819e-03,   5.71687742e-03,  -1.92912671e-02,
        -3.69144232e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.29757952e-02,   0.00000000e+00,
        -3.67935636e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.41785836e-02,
         5.32729891e-03,  -3.79535154e-03,   1.29990160e-02,
         0.00000000e+00,   3.09392622e-02,   0.00000000e+00,
        -4.09198995e-02,   1.06678681e-02,  -6.20783317e-03,
         2.25362771e-02,   0.00000000e+00,  -1.03867726e-01,
         1.77725527e-03,   5.90051026e-03,  -2.38882643e-02,
         0.00000000e+00,   2.11403260e-02,   0.00000000e+00,
         2.72685694e-02,   7.12532099e-03,  -2.25245967e-02,
        -1.21237305e-02,   0.00000000e+00,  -7.08855481e-03,
        -7.16417632e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.08176819e-02,   0.00000000e+00,
        -4.87355709e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.88374698e-02,
         0.00000000e+00,   0.00000000e+00,   1.15432439e-01,
        -2.18475881e-03,   2.95657167e-03,  -2.06701948e-02,
         0.00000000e+00,  -2.02213563e-02,   0.00000000e+00,
        -5.16800540e-02,   1.19962733e-04,  -4.78398484e-04,
         1.62265220e-02,   0.00000000e+00,   5.21392593e-02,
        -4.88535089e-02,   0.00000000e+00,   1.27579288e-01,
         5.29558401e-03,   1.27587720e-03,  -8.69720380e-04,
         0.00000000e+00,   1.02311351e-02,   0.00000000e+00,
         1.01723980e-03,  -5.13124923e-02,   1.49249081e-02,
        -4.87991546e-03,   0.00000000e+00,   1.28972385e-02,
         2.16707983e-02,   0.00000000e+00,  -2.11310839e-03,
         1.09884416e-01,   8.07687777e-03,  -4.10322552e-02,
         1.19082899e-02,   0.00000000e+00,  -4.40226800e-03,
         0.00000000e+00,  -7.70692542e-03,  -2.09851296e-02,
        -7.80115933e-03,  -6.97807691e-05,   0.00000000e+00,
        -3.59331040e-02,  -2.06202570e-02,   0.00000000e+00,
         2.63537692e-02,  -2.90846924e-02,  -5.81280345e-02,
        -3.09122785e-02,  -2.35353549e-02,   6.79339211e-03,
         0.00000000e+00,  -1.65761388e-02,   0.00000000e+00,
         1.51317949e-03,  -1.52629084e-02,   1.47057878e-02,
        -4.34992681e-03,   0.00000000e+00,  -1.16927816e-03,
        -2.10474788e-02,   0.00000000e+00,  -3.28085805e-03,
        -1.35260825e-03,   6.70273508e-02,   1.04412609e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.72366311e-03,   2.94647791e-03,   1.88953797e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.50303225e-03,   0.00000000e+00,
         2.05382246e-03,  -2.98220124e-03,   1.30507626e-02,
         0.00000000e+00,   5.20700334e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.35543039e-02,   0.00000000e+00,   2.35924537e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.64254603e-03,   0.00000000e+00,
         1.14247648e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.56505937e-03,   0.00000000e+00,  -3.26075767e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.02948570e-04,   0.00000000e+00,  -1.61001851e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.85915598e-03,  -2.45712859e-04,
         3.00719658e-04,   0.00000000e+00,  -1.04382213e-04,
         0.00000000e+00,  -3.47097131e-03,  -1.49424350e-03,
         1.50692557e-04,   1.41988984e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.12019241e-05,   0.00000000e+00,  -3.68948643e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.57465661e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.14269923e-04,   0.00000000e+00,   2.88241492e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.27961366e-04,   0.00000000e+00,
         0.00000000e+00,  -2.85579160e-04,  -5.12567295e-04,
        -2.46866293e-03,   0.00000000e+00,  -1.48197701e-03,
         0.00000000e+00,  -7.59389656e-03,  -3.50116521e-03,
         1.03576372e-03,   1.81919960e-03,   0.00000000e+00,
         5.58833786e-03,  -4.38328978e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.02688210e-03,   0.00000000e+00,  -7.04548366e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.09053045e-03,   0.00000000e+00,
         0.00000000e+00,   2.13725508e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.30528613e-04,   0.00000000e+00,  -4.43953108e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.99492259e-03,   0.00000000e+00,
         0.00000000e+00,   1.07747874e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.23400472e-03,   0.00000000e+00,
        -1.04925899e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.72859094e-03,
         0.00000000e+00,   0.00000000e+00,   1.81924370e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.51173445e-04,   0.00000000e+00,  -4.29585606e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.93102448e-03,   0.00000000e+00,
         0.00000000e+00,   3.60496792e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.84527650e-01,   3.29166627e-02,   5.75287086e-01,
         3.21468925e-02,  -4.03952234e-02,   5.74164973e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.54743672e-01,   5.55115703e-04,   4.87348289e-03,
         1.68333077e-02,   0.00000000e+00,   5.77654912e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.06713388e-02,   0.00000000e+00,   5.89032030e-01,
        -1.13207189e-02,   1.28591370e-02,   1.63592110e-02,
         0.00000000e+00,   1.07234570e-03,   0.00000000e+00,
         6.27577176e-01,   9.67028002e-03,   3.60234748e-02,
         1.85285859e-02,   0.00000000e+00,  -1.46049430e-03,
         0.00000000e+00,   1.18700086e-02,   5.77781786e-01,
        -2.66693726e-02,   1.78371646e-02,   6.27409122e-02,
         0.00000000e+00,  -1.11302000e-02,   0.00000000e+00,
        -2.53612915e-02,  -7.99784871e-02,   3.57222599e-01,
         4.99790452e-03,   1.04984572e-02,   3.25258312e-02,
         0.00000000e+00,   5.71836728e-03,   0.00000000e+00,
        -3.91423582e-02,   2.38459130e-02,   6.68374319e-02,
         3.89590913e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.97830941e-02,   0.00000000e+00,
         2.21220268e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.04795197e-01,
         1.10924867e-03,   3.39337562e-02,  -5.46252128e-02,
         0.00000000e+00,  -8.20762365e-02,   0.00000000e+00,
         2.04788491e-02,  -4.00600545e-02,  -6.32117599e-04,
        -1.62668301e-02,   0.00000000e+00,   5.32812456e-01,
         1.48617514e-02,   2.64963561e-02,   6.61802418e-02,
         0.00000000e+00,  -1.29805726e-02,   0.00000000e+00,
         1.38461219e-02,  -2.98472871e-02,   4.93271645e-02,
         1.52066717e-02,   0.00000000e+00,  -2.26023001e-02,
         5.21446227e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.12533848e-02,   0.00000000e+00,
        -1.15788611e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.99594290e-02,
         0.00000000e+00,   0.00000000e+00,   5.46575129e-01,
         9.31947422e-03,  -1.85206325e-03,  -2.05796256e-02,
         0.00000000e+00,  -3.04105449e-02,   0.00000000e+00,
        -1.19725393e-01,  -1.36924181e-02,   6.80087662e-04,
         3.33336320e-02,   0.00000000e+00,   1.43558289e-02,
        -1.52159926e-02,   0.00000000e+00,   5.72356994e-01,
        -3.65467445e-03,   2.91355907e-02,  -3.40842360e-02,
         0.00000000e+00,   5.25241248e-02,   0.00000000e+00,
        -1.03330018e-02,  -9.32133814e-02,   3.17537846e-02,
        -1.02067177e-02,   0.00000000e+00,  -2.07707636e-03,
        -1.69211117e-02,   0.00000000e+00,   1.34328597e-02,
         5.75717079e-01,  -7.43377285e-02,   1.73898719e-02,
        -1.53394385e-02,   0.00000000e+00,  -3.23181033e-02,
         0.00000000e+00,   5.64661658e-03,   3.11868252e-02,
         4.55235340e-02,  -3.42337460e-03,   0.00000000e+00,
         1.56945225e-02,  -3.58675504e-02,   0.00000000e+00,
        -7.86522803e-03,   1.52153198e-02,   5.25970333e-01,
        -4.22908206e-02,  -7.67046895e-02,   2.14495609e-02,
         0.00000000e+00,  -2.16286407e-02,   0.00000000e+00,
         9.91589140e-04,  -2.84404798e-02,   5.24537115e-03,
        -1.23892147e-02,   0.00000000e+00,  -2.16756065e-02,
        -9.80059919e-03,   0.00000000e+00,   3.92823933e-03,
         1.34073627e-02,   2.77002492e-02,   5.85391893e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.26687605e-02,   2.26667187e-02,  -2.46697746e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.56763437e-02,   0.00000000e+00,
         1.00527934e-02,  -1.15669441e-02,   8.08083073e-03,
         0.00000000e+00,   7.18197670e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.13892331e-02,   0.00000000e+00,  -1.39013559e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.93999535e-03,   0.00000000e+00,
        -5.08028955e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.56950781e-04,   0.00000000e+00,   9.77705086e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.10864704e-03,   0.00000000e+00,  -1.77043601e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.20497781e-03,  -5.39588617e-03,
         5.32483159e-03,   0.00000000e+00,   3.04799831e-03,
         0.00000000e+00,  -2.91835841e-03,  -2.87362150e-03,
        -3.00184874e-03,   4.92331166e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.06006452e-03,   0.00000000e+00,  -3.32573045e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.13135426e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.96653168e-03,   0.00000000e+00,   1.33791185e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.00716244e-02,   0.00000000e+00,
         0.00000000e+00,  -1.90486353e-04,  -1.35602052e-03,
         5.17984866e-04,   0.00000000e+00,   2.03669196e-03,
         0.00000000e+00,   1.09415161e-03,   1.50670706e-03,
        -5.76900001e-05,  -2.12677778e-03,   0.00000000e+00,
         3.05892069e-03,   5.35720088e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.92071471e-04,   0.00000000e+00,   2.67890331e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.03016583e-03,   0.00000000e+00,
         0.00000000e+00,  -7.60684166e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.30092379e-03,   0.00000000e+00,  -8.54452813e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.15960326e-03,   0.00000000e+00,
         0.00000000e+00,  -2.81209640e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.25087356e-03,   0.00000000e+00,
        -3.01297142e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.60864347e-02,
         0.00000000e+00,   0.00000000e+00,   4.44553009e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.88157669e-03,   0.00000000e+00,  -1.44621229e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.34907402e-03,   0.00000000e+00,
         0.00000000e+00,  -3.38403845e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.86858478e-03,   7.38615337e-02,  -9.84040090e-04,
         9.30866189e-03,  -1.66198795e-02,  -2.09598930e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.84863356e-02,   7.97875326e-03,   4.59879325e-02,
        -1.47554765e-02,   0.00000000e+00,  -4.05953798e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.71814152e-02,   0.00000000e+00,   5.53899377e-02,
         1.19533166e-02,   6.66455827e-03,   4.45412384e-02,
         0.00000000e+00,   5.03392685e-02,   0.00000000e+00,
         4.39590446e-02,   1.93686742e-02,  -1.20040740e-03,
         1.82447237e-02,   0.00000000e+00,  -5.09736112e-02,
         0.00000000e+00,   3.26478166e-02,   5.51883637e-02,
         8.41385188e-03,  -1.99012548e-02,  -1.61476545e-02,
         0.00000000e+00,   1.53639258e-02,   0.00000000e+00,
        -5.32907949e-03,  -2.11275466e-02,  -1.64375451e-02,
         1.18296723e-02,  -9.57155076e-03,  -7.57519424e-03,
         0.00000000e+00,  -3.39801882e-03,   0.00000000e+00,
        -2.68879797e-03,   2.86949017e-04,  -9.78525734e-03,
        -2.42007976e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.02204610e-02,   0.00000000e+00,
        -2.18477788e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.98766731e-02,
        -8.58770326e-04,  -1.13705291e-03,   6.77316697e-03,
         0.00000000e+00,   2.13151754e-02,   0.00000000e+00,
        -2.21219205e-02,   9.03503682e-03,  -1.27646889e-03,
         1.41833030e-02,   0.00000000e+00,  -7.42607200e-02,
         3.10287250e-03,  -1.87178269e-03,  -1.47247697e-02,
         0.00000000e+00,   1.05597520e-02,   0.00000000e+00,
         1.39816091e-02,   1.12828831e-03,  -1.76440281e-02,
        -6.26509602e-03,   0.00000000e+00,  -1.22504353e-02,
        -3.27414716e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.25125016e-02,   0.00000000e+00,
        -3.01471987e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.34406001e-02,
         0.00000000e+00,   0.00000000e+00,   6.85690175e-02,
        -3.66864386e-03,  -1.85261123e-03,  -9.71603319e-03,
         0.00000000e+00,  -1.18419530e-02,   0.00000000e+00,
        -2.55986900e-02,  -7.29929308e-03,   2.29523028e-03,
         6.10715040e-03,   0.00000000e+00,   2.58151971e-02,
        -2.08777403e-02,   0.00000000e+00,   5.93871273e-02,
         3.11770501e-04,  -8.74566799e-04,  -5.28760426e-03,
         0.00000000e+00,   4.80233813e-03,   0.00000000e+00,
        -2.60217149e-03,  -3.93683503e-02,   1.01403624e-02,
        -2.86538289e-03,   0.00000000e+00,   1.65846419e-02,
         6.35162745e-03,   0.00000000e+00,   1.25528278e-02,
         8.47551293e-02,   5.93912019e-03,  -2.58593733e-02,
        -3.86003636e-04,   0.00000000e+00,  -3.12136245e-03,
         0.00000000e+00,  -3.16281208e-03,  -1.54358828e-02,
        -1.12927080e-02,  -3.97209228e-03,   0.00000000e+00,
        -1.25876645e-02,  -3.12889516e-02,   0.00000000e+00,
         1.31862924e-02,  -1.76163202e-02,  -4.20180455e-02,
        -2.16953542e-02,  -1.58861953e-02,   3.26948635e-03,
         0.00000000e+00,  -1.29107142e-02,   0.00000000e+00,
        -7.70832609e-04,  -1.29605109e-02,   1.11072750e-02,
         4.60253535e-04,   0.00000000e+00,  -1.72912426e-03,
        -1.03935613e-02,   0.00000000e+00,   1.31465445e-02,
         2.86665149e-03,   4.22849142e-02,   5.98422424e-02,
        -4.07467456e-02,  -8.94524416e-03,  -2.67194151e-02,
        -2.09204328e-02,   1.46160294e-02,  -3.98544687e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.41051032e-02,   8.72484675e-03,  -1.52797175e-02,
        -1.09199957e-03,   0.00000000e+00,  -2.74775394e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.75922751e-03,   0.00000000e+00,  -3.91510132e-02,
        -4.23423835e-03,  -7.96979285e-03,  -1.01384377e-03,
         0.00000000e+00,  -4.13009891e-03,   0.00000000e+00,
        -3.83580675e-02,   5.57632200e-03,  -1.40870783e-02,
        -4.53203360e-03,   0.00000000e+00,   3.21550340e-03,
         0.00000000e+00,  -4.43869212e-03,  -3.93327014e-02,
         3.71834965e-03,  -4.45438761e-03,  -2.79360598e-02,
         0.00000000e+00,  -2.68961574e-03,   0.00000000e+00,
         1.39669461e-02,   2.06408376e-02,   2.11928637e-02,
         4.07636950e-03,  -9.42104075e-03,  -2.73809842e-02,
         0.00000000e+00,  -2.21719081e-03,   0.00000000e+00,
         1.55787935e-02,   7.06679225e-04,   2.28049117e-03,
         3.79155842e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.60222904e-02,   0.00000000e+00,
        -5.47132350e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.72862160e-02,
        -4.39642807e-03,   1.25213993e-03,   6.44310877e-03,
         0.00000000e+00,   1.17200317e-02,   0.00000000e+00,
        -4.40331818e-03,   7.34313843e-03,   2.55122391e-03,
         7.63599854e-03,   0.00000000e+00,  -2.29548046e-02,
        -8.60122237e-05,  -5.86372695e-03,  -1.31545101e-02,
         0.00000000e+00,   5.89991660e-03,   0.00000000e+00,
         3.21490039e-04,   7.36610939e-03,  -7.30571255e-03,
        -3.42637319e-03,   0.00000000e+00,   1.46200508e-02,
        -3.86152216e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.98726723e-04,   0.00000000e+00,
         1.22420277e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.74847853e-03,
         0.00000000e+00,   0.00000000e+00,  -3.54465256e-02,
         5.63070411e-05,   9.76626375e-04,   1.11482233e-03,
         0.00000000e+00,   4.84638109e-03,   0.00000000e+00,
         9.81217510e-03,   3.22933939e-03,  -1.72504469e-03,
        -1.02425098e-02,   0.00000000e+00,  -2.39553312e-04,
        -1.82833996e-03,   0.00000000e+00,  -3.55905292e-02,
         3.65233421e-03,  -3.88062687e-03,   3.33907403e-03,
         0.00000000e+00,  -4.59975486e-03,   0.00000000e+00,
         4.91958118e-04,   8.35279819e-03,  -4.27164858e-03,
         2.40462888e-03,   0.00000000e+00,  -6.59013449e-04,
         5.59219573e-03,   0.00000000e+00,  -2.06957287e-03,
        -4.23119167e-02,   1.39919037e-02,  -7.35749830e-03,
         1.86275440e-03,   0.00000000e+00,  -2.01580277e-03,
         0.00000000e+00,   2.13776720e-03,  -8.57387760e-03,
        -1.12102289e-02,  -2.73818861e-03,   0.00000000e+00,
         3.05081575e-03,   2.13903012e-02,   0.00000000e+00,
         5.63466945e-04,  -4.04026568e-03,  -2.59108753e-02,
         3.31923244e-03,   7.29402918e-03,  -1.66366507e-03,
         0.00000000e+00,   7.22016367e-03,   0.00000000e+00,
        -8.80225089e-04,   7.39561844e-03,   1.79801277e-04,
         4.65486937e-03,   0.00000000e+00,   2.70918515e-03,
        -1.48233570e-03,   0.00000000e+00,  -1.03066167e-02,
        -2.45744082e-03,  -5.36755632e-03,  -3.83681804e-02,
        -3.60242459e-02,  -1.38089420e-02,  -2.07000499e-02,
        -2.66184236e-02,   3.11331892e-02,  -2.87920475e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.51081501e-02,   7.99676156e-03,  -1.12657776e-02,
        -7.32062215e-03,   0.00000000e+00,  -3.41780994e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.14159989e-03,   0.00000000e+00,  -4.02011602e-02,
         7.73112113e-03,  -8.49269682e-03,  -6.24813427e-03,
         0.00000000e+00,   3.15533757e-04,   0.00000000e+00,
        -4.30651966e-02,   8.57929457e-03,  -1.20311587e-02,
        -5.10743920e-03,   0.00000000e+00,   2.87167468e-03,
         0.00000000e+00,   1.33298488e-03,  -3.51922203e-02,
         4.46734519e-03,  -7.47128642e-03,  -3.18071016e-02,
         0.00000000e+00,  -8.39250863e-04,   0.00000000e+00,
         1.38130029e-02,   2.20074215e-02,   2.59810301e-02,
         1.22234043e-02,  -2.25072162e-02,  -4.79740905e-02,
         0.00000000e+00,  -7.99707258e-04,   0.00000000e+00,
         2.67432828e-02,   7.00467600e-03,   2.03686793e-02,
         8.71590686e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.25466299e-02,   0.00000000e+00,
        -7.91066216e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.88337455e-02,
        -1.55828175e-03,  -6.27498213e-03,   9.76195939e-03,
         0.00000000e+00,   2.15445717e-02,   0.00000000e+00,
        -6.88817701e-03,   1.08991922e-02,   3.47352662e-03,
         1.19106576e-02,   0.00000000e+00,  -3.12501727e-02,
        -1.35850210e-03,  -5.97840386e-03,  -1.77559343e-02,
         0.00000000e+00,   8.35086642e-03,   0.00000000e+00,
        -1.08272970e-04,   1.08575680e-02,  -6.61313803e-03,
        -3.70895814e-03,   0.00000000e+00,   1.41561924e-02,
        -3.37023637e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.11514356e-04,   0.00000000e+00,
         1.56666499e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.14657172e-03,
         0.00000000e+00,   0.00000000e+00,  -3.60194297e-02,
        -4.46485387e-03,  -2.26225850e-04,   4.41518738e-03,
         0.00000000e+00,   4.51506434e-03,   0.00000000e+00,
         1.58261254e-02,   7.58834589e-04,  -3.08149304e-03,
        -1.77714215e-02,   0.00000000e+00,  -8.61821383e-04,
        -7.43155635e-04,   0.00000000e+00,  -3.89138219e-02,
         2.24271361e-03,  -6.36083372e-03,   4.52207092e-03,
         0.00000000e+00,  -6.48914210e-03,   0.00000000e+00,
         4.22547637e-04,   8.87588670e-03,  -2.93959988e-03,
         4.27327997e-03,   0.00000000e+00,   5.40396462e-04,
         5.24766559e-03,   0.00000000e+00,  -3.65116910e-04,
        -4.09208290e-02,   1.80504684e-02,  -1.07575726e-02,
         3.25735061e-03,   0.00000000e+00,   2.24428413e-03,
         0.00000000e+00,  -1.98239635e-03,  -8.73779155e-03,
        -9.49787458e-03,  -2.17483010e-03,   0.00000000e+00,
        -1.40006521e-03,   2.37618694e-02,   0.00000000e+00,
         4.92515037e-03,  -2.94816724e-03,  -2.48039672e-02,
         3.80339680e-03,   1.01224126e-02,  -5.19751788e-03,
         0.00000000e+00,   6.52747404e-03,   0.00000000e+00,
        -3.43254642e-03,   6.45507940e-03,   1.86150853e-03,
         8.07356121e-03,   0.00000000e+00,   7.17494719e-03,
        -3.16595388e-03,   0.00000000e+00,  -3.51230153e-03,
         1.04793813e-03,  -5.59248023e-03,  -3.70246881e-02,
         4.43020201e-02,  -7.89700435e-02,   4.15674440e-02,
         2.29013219e-02,   9.99755583e-03,   9.49980192e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.94750286e-02,  -9.97115729e-03,  -3.76959516e-02,
         6.20547401e-03,   0.00000000e+00,   8.29089452e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.05183868e-02,   0.00000000e+00,  -1.30861549e-02,
         1.79174321e-03,   1.36867097e-02,  -6.03660087e-02,
         0.00000000e+00,  -5.49523772e-02,   0.00000000e+00,
        -1.07048541e-02,  -2.75222286e-02,   1.34695551e-02,
        -2.29710199e-02,   0.00000000e+00,   5.58912288e-02,
         0.00000000e+00,  -1.54846699e-02,  -1.94666626e-04,
        -8.12112944e-03,   2.27012588e-02,   3.74635504e-02,
         0.00000000e+00,  -2.00434609e-02,   0.00000000e+00,
        -5.72462935e-03,   5.91682954e-03,   3.92591727e-02,
        -6.03855907e-03,   4.98324349e-03,   2.67001971e-02,
         0.00000000e+00,   1.04600891e-02,   0.00000000e+00,
        -6.11729041e-03,   3.87306172e-03,   2.62683082e-02,
         4.64243581e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.32094163e-02,   0.00000000e+00,
         4.84951761e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.05906291e-01,
        -7.36105852e-03,   1.65768193e-02,  -4.20441861e-02,
         0.00000000e+00,  -7.56940442e-02,   0.00000000e+00,
         6.09022873e-02,  -2.73398709e-02,  -2.48016753e-03,
        -2.32336773e-02,   0.00000000e+00,   1.10397524e-01,
         5.21381833e-03,   6.05210638e-03,   6.07507392e-02,
         0.00000000e+00,  -2.78369145e-02,   0.00000000e+00,
        -2.54456148e-02,  -2.02310073e-02,   4.14041805e-02,
         2.74655650e-02,   0.00000000e+00,   1.46507715e-03,
         9.66170567e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.24993460e-02,   0.00000000e+00,
         2.51065387e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.47648389e-02,
         0.00000000e+00,   0.00000000e+00,  -3.88715614e-02,
         5.83554312e-03,  -9.55397836e-03,   3.22967959e-02,
         0.00000000e+00,   1.89984780e-02,   0.00000000e+00,
         2.28985064e-02,   1.60010919e-03,   4.38149011e-03,
        -2.40413337e-03,   0.00000000e+00,  -2.91840622e-02,
         2.71428405e-02,   0.00000000e+00,  -3.77081498e-02,
        -1.10020509e-02,   2.07994971e-03,  -9.75538921e-04,
         0.00000000e+00,  -6.46443589e-04,   0.00000000e+00,
         3.04002871e-03,   4.21058272e-02,  -1.04797074e-02,
         2.63878568e-03,   0.00000000e+00,  -1.49146162e-02,
        -2.00833435e-02,   0.00000000e+00,  -6.29601479e-03,
        -3.84976976e-02,  -3.90939177e-02,   5.95992684e-02,
        -1.87879000e-02,   0.00000000e+00,  -6.99388589e-03,
         0.00000000e+00,   1.05023018e-02,   2.30265444e-02,
         1.56352691e-02,   7.74848984e-03,   0.00000000e+00,
         1.74045586e-02,   8.85037197e-03,   0.00000000e+00,
        -1.25110326e-02,   2.56257756e-02,   9.33217538e-02,
         3.24273561e-02,   7.34610125e-03,   1.41569223e-03,
         0.00000000e+00,   1.04212279e-02,   0.00000000e+00,
        -5.19387772e-03,   3.50732028e-03,  -8.05147105e-03,
         2.66380057e-03,   0.00000000e+00,   3.83349954e-04,
         6.85751122e-03,   0.00000000e+00,   9.32115080e-03,
         3.13600120e-05,  -4.57742594e-02,  -2.53232791e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.07380420e-02,   9.22754148e-03,  -9.14049288e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.50080591e-03,   0.00000000e+00,
         3.33135791e-03,  -6.65426524e-03,   6.39160550e-03,
         0.00000000e+00,   3.55849185e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.31912084e-03,   0.00000000e+00,  -1.99091931e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.72410346e-03,   0.00000000e+00,
        -3.41927701e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.88403923e-04,   0.00000000e+00,  -1.61928233e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.72767338e-03,   0.00000000e+00,   5.00209682e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.39242256e-03,  -7.21820886e-03,
         1.05268124e-02,   0.00000000e+00,   7.56384785e-03,
         0.00000000e+00,  -7.84149441e-03,  -1.81724373e-03,
         5.75912759e-05,   1.95518456e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.23209510e-02,   0.00000000e+00,  -7.12510339e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.18436138e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.80816337e-03,   0.00000000e+00,   3.27300481e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.80364678e-03,   0.00000000e+00,
         0.00000000e+00,  -1.36398411e-03,   8.31547341e-04,
        -3.19365427e-03,   0.00000000e+00,  -1.09862852e-03,
         0.00000000e+00,  -1.91691372e-03,  -1.12052754e-03,
         1.70978533e-04,   2.56815439e-04,   0.00000000e+00,
         1.63365791e-03,  -6.88794132e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.39151785e-03,   0.00000000e+00,  -6.99764623e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.14186624e-03,   0.00000000e+00,
         0.00000000e+00,   2.62948926e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.00229888e-03,   0.00000000e+00,  -2.68904354e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.10975052e-03,   0.00000000e+00,
         0.00000000e+00,   1.33183369e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.00141139e-03,   0.00000000e+00,
        -5.11753271e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.06694185e-02,
         0.00000000e+00,   0.00000000e+00,   6.38278058e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.47821854e-03,   0.00000000e+00,   5.83542460e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.68913769e-03,   0.00000000e+00,
         0.00000000e+00,  -2.15056702e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.82239729e-03,   2.01144785e-02,   3.14809980e-03,
        -3.45202620e-03,  -2.80434829e-03,  -1.77566660e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.22334626e-02,   9.79455430e-03,   8.06315844e-03,
         2.92958884e-03,   0.00000000e+00,  -3.22189625e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.66999290e-02,   0.00000000e+00,   1.61761000e-02,
         4.63228607e-03,   7.06382473e-03,   1.41397051e-02,
         0.00000000e+00,   1.28935861e-02,   0.00000000e+00,
         1.82618981e-02,   7.05822566e-03,  -4.67013937e-03,
         9.16578640e-03,   0.00000000e+00,  -1.27546870e-02,
         0.00000000e+00,   3.11814081e-03,   1.07793454e-02,
        -7.37205751e-04,  -2.37163341e-03,  -8.28866811e-03,
         0.00000000e+00,   2.56303472e-03,   0.00000000e+00,
         1.30510725e-03,  -5.15478025e-03,  -8.74795467e-03,
         7.96684764e-04,  -2.14371395e-03,  -6.13745433e-03,
         0.00000000e+00,  -4.01753318e-04,   0.00000000e+00,
        -8.07792263e-04,   2.10013841e-03,  -3.38280941e-03,
        -9.70324706e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.07928677e-03,   0.00000000e+00,
        -8.76016633e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.60472064e-02,
        -1.46720753e-03,   2.85573701e-03,   6.58444586e-03,
         0.00000000e+00,  -2.26574791e-03,   0.00000000e+00,
        -5.96454946e-03,  -3.78186695e-04,   4.93025853e-03,
         6.86107443e-03,   0.00000000e+00,  -1.29072916e-02,
        -4.44059860e-03,   5.26349894e-03,  -1.87227675e-02,
         0.00000000e+00,   2.57099166e-03,   0.00000000e+00,
         1.30674551e-02,   4.44713187e-03,  -1.02833065e-02,
        -6.09409520e-03,   0.00000000e+00,  -1.13875101e-03,
        -1.75223839e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.85842401e-03,   0.00000000e+00,
        -1.03799357e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.82278705e-03,
         0.00000000e+00,   0.00000000e+00,   2.07853877e-02,
        -4.79883305e-03,  -2.66160087e-03,  -9.19687026e-03,
         0.00000000e+00,  -5.93304386e-03,   0.00000000e+00,
        -1.16079932e-02,   1.47797622e-03,  -2.55655159e-03,
         1.01329652e-03,   0.00000000e+00,   5.77858342e-03,
        -9.44411642e-03,   0.00000000e+00,   2.20278652e-02,
         9.41037832e-04,  -2.16235806e-03,   2.25050054e-03,
         0.00000000e+00,   2.33977284e-03,   0.00000000e+00,
         1.16544671e-03,  -1.01520106e-02,   3.02886090e-03,
        -5.33613663e-04,   0.00000000e+00,   2.43642850e-03,
         6.30248251e-03,   0.00000000e+00,   7.49741244e-04,
         2.17598320e-02,   3.75047766e-03,  -8.65031714e-03,
         5.00598647e-03,   0.00000000e+00,  -7.58285786e-03,
         0.00000000e+00,  -2.79233348e-03,  -9.76394649e-03,
         2.37109665e-03,   1.55748335e-03,   0.00000000e+00,
         9.63807947e-04,  -3.61940770e-03,   0.00000000e+00,
         5.62410149e-03,  -8.93387159e-03,  -1.29397747e-02,
        -9.86117845e-03,  -6.27949703e-03,  -3.28427721e-03,
         0.00000000e+00,  -2.50050714e-03,   0.00000000e+00,
        -3.35401236e-03,  -3.19044563e-03,   1.24647186e-03,
        -5.74853730e-04,   0.00000000e+00,  -2.78438460e-03,
        -4.79499849e-03,   0.00000000e+00,   6.31065701e-03,
        -2.60810482e-04,   1.20192973e-02,   1.71951108e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.07626059e-04,  -7.07506432e-04,  -9.34834021e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.45050667e-04,   0.00000000e+00,
        -1.04630048e-03,  -3.37453991e-04,  -2.77337468e-03,
         0.00000000e+00,  -1.58456702e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.96075331e-03,   0.00000000e+00,  -7.45192424e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.54307841e-03,   0.00000000e+00,
        -3.49044692e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.04656578e-04,   0.00000000e+00,   1.06509497e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.75220627e-04,   0.00000000e+00,   1.72632697e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.86609399e-03,  -1.48876417e-03,
         3.93028317e-03,   0.00000000e+00,   2.14170396e-03,
         0.00000000e+00,   8.84249209e-04,   1.16615462e-03,
         3.02872837e-04,  -3.28738758e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.88482182e-03,   0.00000000e+00,   1.62817833e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.80977656e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.78792444e-03,   0.00000000e+00,  -1.96901255e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.17897734e-04,   0.00000000e+00,
         0.00000000e+00,   1.14413657e-04,  -1.69389116e-04,
         5.28191483e-03,   0.00000000e+00,   1.53106574e-03,
         0.00000000e+00,   1.32109597e-02,   5.84310494e-03,
        -1.84714929e-03,  -7.06382545e-04,   0.00000000e+00,
        -2.23817819e-03,   1.59248015e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.50234114e-03,   0.00000000e+00,   1.30008429e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.08284775e-03,   0.00000000e+00,
         0.00000000e+00,  -5.79009474e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.07092100e-03,   0.00000000e+00,   6.11682710e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.77633248e-04,   0.00000000e+00,
         0.00000000e+00,  -3.09184233e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.90176890e-03,   0.00000000e+00,
        -4.63046001e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.11083352e-03,
         0.00000000e+00,   0.00000000e+00,  -9.84559337e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.68081205e-04,   0.00000000e+00,   1.00839537e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.11049100e-04,   0.00000000e+00,
         0.00000000e+00,  -1.09630516e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.29973942e-02,  -5.07335328e-02,  -9.60460986e-02,
         8.42766864e-03,   1.18560279e-02,  -5.59767154e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.69543440e-02,  -4.11601708e-03,  -2.24302739e-02,
         1.70808038e-03,   0.00000000e+00,  -7.33891556e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.94072809e-02,   0.00000000e+00,  -1.32416040e-01,
         1.00081807e-03,   4.59156344e-03,  -3.80625669e-02,
         0.00000000e+00,  -3.20295424e-02,   0.00000000e+00,
        -1.39402822e-01,  -1.84816946e-02,  -1.26155767e-02,
        -1.58550834e-02,   0.00000000e+00,   2.52718861e-02,
         0.00000000e+00,  -8.45677741e-03,  -1.21895080e-01,
         1.39776202e-02,   1.34527145e-03,  -2.25174741e-03,
         0.00000000e+00,  -3.93632583e-03,   0.00000000e+00,
         4.42464498e-03,   3.01402551e-02,  -2.56463600e-02,
        -3.66258446e-03,  -4.38207128e-03,   3.31136121e-03,
         0.00000000e+00,   3.14376966e-03,   0.00000000e+00,
         1.79583189e-02,  -9.24351257e-03,  -8.10872120e-03,
        -2.90658624e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.94437164e-02,   0.00000000e+00,
         1.01879769e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.90247122e-02,
        -3.66693652e-03,  -1.39562354e-02,   2.53212643e-02,
         0.00000000e+00,   2.37945934e-02,   0.00000000e+00,
         1.34830519e-02,   1.38095058e-02,   1.30571036e-03,
        -6.70984190e-04,   0.00000000e+00,  -3.95671749e-02,
        -1.24769816e-02,  -1.27822890e-02,  -2.57847539e-02,
         0.00000000e+00,  -9.02067911e-03,   0.00000000e+00,
        -2.13210460e-02,   8.75565765e-03,  -1.23784130e-02,
        -3.93338742e-03,   0.00000000e+00,   2.29411947e-03,
        -4.03930811e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.47096029e-02,   0.00000000e+00,
         9.39555431e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.32689195e-02,
         0.00000000e+00,   0.00000000e+00,  -1.33681405e-01,
        -6.33500901e-03,  -1.87307447e-03,   3.22774195e-02,
         0.00000000e+00,   3.04408500e-02,   0.00000000e+00,
         1.13487634e-01,   1.11395437e-02,  -5.47125749e-03,
        -1.82395740e-02,   0.00000000e+00,  -2.90503601e-02,
         2.78624637e-02,   0.00000000e+00,  -1.34101151e-01,
         8.25255462e-04,  -1.77474026e-02,   2.42327690e-02,
         0.00000000e+00,  -3.83960788e-02,   0.00000000e+00,
         1.26315099e-02,   8.65628212e-02,  -2.39612937e-02,
         5.44830467e-03,   0.00000000e+00,  -4.96356764e-03,
        -4.99002597e-03,   0.00000000e+00,  -5.54731083e-03,
        -1.48066402e-01,   3.60235048e-02,   1.63201220e-02,
         1.34594931e-03,   0.00000000e+00,   1.91269778e-02,
         0.00000000e+00,   3.33081775e-03,  -4.12146758e-03,
        -6.69597987e-03,  -4.41679824e-04,   0.00000000e+00,
         7.04679557e-03,   8.99947884e-03,   0.00000000e+00,
        -6.54436674e-03,   5.73895249e-03,  -5.59235677e-02,
         5.28763336e-02,   6.73721518e-02,  -1.67942105e-02,
         0.00000000e+00,   1.84611424e-02,   0.00000000e+00,
        -1.73638985e-03,   2.45160272e-02,  -1.11506322e-02,
         5.85975856e-03,   0.00000000e+00,   8.84722684e-03,
         1.42565344e-02,   0.00000000e+00,   5.01834509e-03,
        -7.56199391e-03,  -3.79377269e-02,  -1.32384821e-01,
        -2.26673604e-02,  -2.01616139e-02,  -2.71587793e-02,
         9.66314230e-03,   2.45806619e-03,  -4.31671919e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.49703267e-03,  -3.43270791e-03,  -7.31937233e-03,
         6.56609650e-04,   0.00000000e+00,  -1.61956404e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.75641446e-02,   0.00000000e+00,  -3.98676721e-02,
         8.84913011e-04,   5.58264062e-03,  -1.66256330e-02,
         0.00000000e+00,  -7.06594556e-03,   0.00000000e+00,
        -3.71952013e-02,  -8.29917958e-03,  -9.39179251e-04,
        -1.22122469e-02,   0.00000000e+00,   1.14328588e-02,
         0.00000000e+00,  -6.51924044e-03,  -4.06377224e-02,
         6.11845487e-03,  -8.52896563e-04,   3.70920759e-03,
         0.00000000e+00,  -2.47259830e-03,   0.00000000e+00,
         1.59409732e-03,   9.87587302e-03,  -4.50712902e-03,
         5.12832200e-04,  -3.67130083e-03,   2.82862470e-03,
         0.00000000e+00,   9.56340879e-04,   0.00000000e+00,
         3.80358816e-03,  -2.37772998e-03,   1.05434655e-03,
        -1.29540344e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.42725926e-03,   0.00000000e+00,
         7.61001271e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.36333505e-03,
        -3.93057223e-03,  -3.49502868e-03,   3.21368835e-03,
         0.00000000e+00,   1.35938945e-03,   0.00000000e+00,
         7.97662882e-03,   6.41269390e-03,  -1.24809265e-03,
        -1.37288209e-03,   0.00000000e+00,  -6.40816701e-03,
        -1.14804076e-04,  -5.14236179e-03,   1.56971979e-03,
         0.00000000e+00,  -3.14928770e-03,   0.00000000e+00,
        -6.19048304e-03,  -1.05116700e-03,   1.05151613e-04,
         1.51616412e-03,   0.00000000e+00,  -9.59710125e-04,
        -8.66765250e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.31995576e-02,   0.00000000e+00,
         3.13032458e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.85036847e-03,
         0.00000000e+00,   0.00000000e+00,  -4.26640809e-02,
        -3.57395149e-03,  -6.54043353e-03,   1.36359564e-02,
         0.00000000e+00,   2.02532825e-03,   0.00000000e+00,
         2.74437904e-02,   1.08986681e-02,  -2.72756224e-03,
        -4.50615372e-03,   0.00000000e+00,  -9.56282324e-03,
         9.47520745e-03,   0.00000000e+00,  -3.83118034e-02,
        -1.41435848e-03,  -8.17155735e-03,   1.25542725e-02,
         0.00000000e+00,  -1.47127802e-02,   0.00000000e+00,
         1.59332524e-02,   4.18907727e-02,  -1.19225388e-02,
         6.80169734e-04,   0.00000000e+00,  -3.50881461e-03,
        -2.63683535e-03,   0.00000000e+00,  -8.04379092e-03,
        -5.36652679e-02,   8.24575602e-03,   8.95591500e-03,
        -6.35716304e-03,   0.00000000e+00,   4.33310965e-03,
         0.00000000e+00,  -5.08399494e-04,  -5.71919086e-04,
        -3.02589605e-03,  -1.29447691e-03,   0.00000000e+00,
         3.93180424e-03,  -2.58782561e-03,   0.00000000e+00,
        -2.69084349e-03,   4.22023598e-03,  -9.17454395e-03,
         1.90188019e-02,   2.13183836e-02,  -5.21953126e-03,
         0.00000000e+00,   4.43443884e-03,   0.00000000e+00,
        -5.02159921e-03,   6.30901206e-03,  -2.80531620e-03,
         3.45517861e-03,   0.00000000e+00,   3.01084690e-03,
         4.96980899e-03,   0.00000000e+00,   3.27518649e-03,
        -2.13291935e-03,  -1.46942204e-02,  -4.27678174e-02,
         1.75348405e-02,  -1.32022175e-02,   1.44770729e-02,
         1.10172983e-02,  -1.31305924e-02,   3.76368843e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.16736179e-02,  -3.01059158e-03,  -1.45465329e-02,
         2.18040767e-03,   0.00000000e+00,   2.50945221e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.52435708e-02,   0.00000000e+00,   6.96788275e-03,
        -1.70211111e-02,  -4.34166927e-03,  -1.16950959e-02,
         0.00000000e+00,  -1.54408294e-02,   0.00000000e+00,
         1.00401667e-02,  -6.79328886e-03,  -1.23534341e-03,
        -9.60973770e-03,   0.00000000e+00,   6.97028030e-03,
         0.00000000e+00,  -3.45341608e-03,   4.41063546e-03,
         4.02725829e-03,   1.46963886e-03,   9.83990254e-03,
         0.00000000e+00,  -6.31727670e-03,   0.00000000e+00,
         9.41507262e-04,  -3.94318712e-03,   7.68451791e-03,
         4.69601790e-03,  -2.04468071e-03,   7.87186919e-03,
         0.00000000e+00,   2.67601157e-03,   0.00000000e+00,
        -3.17833186e-03,  -1.61184922e-03,   5.29085360e-03,
         1.04970616e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.07448761e-02,   0.00000000e+00,
         1.30282117e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.04983504e-02,
        -1.13726012e-02,   1.89982130e-02,  -1.37377469e-02,
         0.00000000e+00,  -1.99153232e-02,   0.00000000e+00,
         1.42184722e-02,  -4.82508428e-03,   3.14064978e-04,
        -1.90758087e-03,   0.00000000e+00,   3.29252091e-02,
         5.09301282e-03,  -5.44275574e-03,   1.62813441e-02,
         0.00000000e+00,  -1.01193127e-02,   0.00000000e+00,
        -7.81500326e-03,  -1.07709980e-02,   1.03510141e-02,
         7.64389609e-03,   0.00000000e+00,  -2.50140127e-03,
         2.56465166e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.83437577e-03,   0.00000000e+00,
         3.39464246e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.79283245e-03,
         0.00000000e+00,   0.00000000e+00,  -1.01001853e-04,
         1.22384626e-02,   5.28879964e-03,   6.99107830e-03,
         0.00000000e+00,   8.82469442e-03,   0.00000000e+00,
         1.71338647e-03,   1.99156268e-04,   3.34369018e-04,
         2.22218110e-03,   0.00000000e+00,  -4.81376621e-03,
         7.67882270e-03,   0.00000000e+00,   2.63368431e-03,
         3.58686596e-03,   4.80986470e-03,  -5.96887048e-03,
         0.00000000e+00,  -5.86163592e-04,   0.00000000e+00,
        -6.99535406e-04,   5.66951124e-03,  -3.00855808e-03,
        -1.23517259e-03,   0.00000000e+00,  -1.11142941e-03,
        -7.66124379e-03,   0.00000000e+00,  -1.16713487e-03,
         7.59521835e-04,  -5.19151715e-03,   1.12943070e-02,
        -1.57653028e-02,   0.00000000e+00,  -1.18079101e-02,
         0.00000000e+00,   1.83362173e-02,   4.44335214e-03,
        -4.68995977e-04,  -4.76154491e-03,   0.00000000e+00,
         1.08843006e-02,  -7.37942213e-03,   0.00000000e+00,
        -1.11539363e-02,   4.41211286e-03,   2.38494460e-02,
         7.31892134e-03,   2.41786566e-03,   1.00350661e-02,
         0.00000000e+00,   6.39181710e-03,   0.00000000e+00,
         8.23497417e-03,   6.97525747e-03,  -2.71665571e-03,
         8.74407740e-05,   0.00000000e+00,  -6.66562140e-03,
         6.06978927e-03,   0.00000000e+00,  -1.11301326e-02,
        -3.93174374e-03,  -1.04669771e-02,   3.62153621e-03,
        -1.00184863e-02,   1.20378856e-03,  -1.01332699e-02,
         1.15108981e-03,  -7.50978639e-03,  -2.30211606e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.61796454e-03,  -5.62816607e-04,   2.57457043e-03,
        -3.13900760e-03,   0.00000000e+00,  -1.26051018e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.07590222e-04,   0.00000000e+00,  -7.89001553e-03,
        -8.53160457e-03,  -9.55114848e-03,   3.17801986e-03,
         0.00000000e+00,  -1.72731273e-03,   0.00000000e+00,
        -7.63223971e-03,  -9.29762972e-03,  -8.93266561e-03,
         2.81433980e-04,   0.00000000e+00,  -4.79669612e-03,
         0.00000000e+00,  -1.33429029e-03,  -1.14053989e-02,
         4.67764624e-03,   5.75640570e-04,   2.77814813e-03,
         0.00000000e+00,   3.86368360e-03,   0.00000000e+00,
         1.06206675e-03,   2.40091500e-03,  -8.27439646e-03,
         2.77905524e-03,   1.58521140e-03,  -1.17548568e-05,
         0.00000000e+00,  -1.03415117e-04,   0.00000000e+00,
        -1.40229412e-03,  -2.64846142e-04,   3.66180901e-04,
        -7.60182255e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.44969674e-03,   0.00000000e+00,
        -2.79969625e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.61633958e-03,
         1.01478488e-02,  -1.37248177e-03,   3.20175516e-03,
         0.00000000e+00,   6.77586309e-03,   0.00000000e+00,
        -6.34530820e-03,   2.12031793e-03,   2.26820053e-03,
         9.31198860e-04,   0.00000000e+00,  -1.08378846e-02,
        -9.31066251e-03,  -3.79497123e-03,  -1.15891288e-02,
         0.00000000e+00,  -1.01293549e-03,   0.00000000e+00,
        -2.99517131e-03,  -7.16311433e-04,  -5.16794445e-03,
        -3.51160386e-03,   0.00000000e+00,  -3.94589733e-03,
        -8.53581906e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.23871820e-03,   0.00000000e+00,
         5.51605747e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.61153893e-04,
         0.00000000e+00,   0.00000000e+00,  -7.43657952e-03,
         1.82889276e-02,   2.37221328e-02,  -6.59571392e-03,
         0.00000000e+00,   6.11812711e-03,   0.00000000e+00,
         4.69563306e-03,   3.67024529e-03,  -2.36073268e-03,
        -9.90923887e-04,   0.00000000e+00,   3.58740818e-04,
         3.95057124e-03,   0.00000000e+00,  -5.63789720e-03,
         9.80133176e-03,   9.38563068e-03,   5.00904523e-05,
         0.00000000e+00,  -1.03078841e-05,   0.00000000e+00,
        -3.38402918e-03,   4.25806573e-03,  -9.04805637e-04,
         2.49233141e-03,   0.00000000e+00,   3.18658239e-03,
        -1.12221923e-03,   0.00000000e+00,   6.58533322e-04,
        -6.18929473e-03,   5.48473018e-03,   1.02207700e-04,
         1.14544610e-02,   0.00000000e+00,   8.74837526e-03,
         0.00000000e+00,   7.96048211e-03,   5.15616798e-03,
        -1.66688510e-03,   1.21554769e-04,   0.00000000e+00,
        -1.58272712e-03,  -3.14048255e-03,   0.00000000e+00,
        -5.82546610e-03,  -5.30378333e-03,  -1.10964122e-02,
         4.85789929e-03,   5.32951013e-03,   8.93396531e-03,
         0.00000000e+00,   4.75348056e-03,   0.00000000e+00,
         3.31594150e-02,   1.46371512e-02,  -4.72478449e-03,
        -1.57356775e-03,   0.00000000e+00,  -4.12574431e-03,
         5.12611036e-03,   0.00000000e+00,  -7.44964230e-03,
        -1.21882578e-02,  -4.62246835e-04,  -1.15986141e-02])
  elif name == "BA MO 2E INTEGRALS":
    dimens = (norbtt,nrorb,noa)
    arr = np.array([  6.55673096e-01,   7.91531247e-03,   5.81721657e-01,
         4.39310904e-02,   1.51459169e-02,   5.85844796e-01,
        -5.95889259e-02,  -1.78309422e-02,  -2.95722068e-03,
         6.01198067e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.12545337e-01,
         2.57612091e-02,   6.65571374e-03,   2.50276102e-02,
         1.56151761e-02,   0.00000000e+00,   5.84527650e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.08402784e-02,   0.00000000e+00,
         5.70516936e-01,   1.60416289e-02,  -8.80168776e-02,
         1.18095912e-02,  -1.62823417e-02,   0.00000000e+00,
         6.86858478e-03,   0.00000000e+00,   6.24009316e-01,
        -2.78802665e-02,  -3.94460126e-02,   5.75279164e-02,
         1.41114435e-03,   0.00000000e+00,  -4.07467456e-02,
         0.00000000e+00,  -7.30042342e-02,   3.78456444e-01,
        -7.82306167e-04,  -2.50168128e-02,   2.19395325e-02,
        -2.10578754e-03,   0.00000000e+00,  -3.60242459e-02,
         0.00000000e+00,   4.47964467e-02,   7.14810904e-02,
         4.19386096e-01,   5.79518241e-03,  -7.46929643e-03,
        -5.04193413e-02,  -5.24334900e-02,   0.00000000e+00,
         4.43020201e-02,   0.00000000e+00,  -6.32796467e-02,
        -2.35317997e-02,  -1.47225958e-02,   5.41156994e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.28412507e-02,   0.00000000e+00,
         1.04626512e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.74477515e-01,
         2.31829235e-02,  -2.63189723e-02,   4.72997086e-02,
        -6.39357811e-03,   0.00000000e+00,  -1.82239729e-03,
         0.00000000e+00,  -8.59280679e-02,   6.25513309e-02,
         1.69392935e-02,  -8.44509193e-03,   0.00000000e+00,
         5.41510941e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.86397133e-02,
         0.00000000e+00,   5.85181583e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.56963610e-02,   0.00000000e+00,   5.63256380e-01,
         7.56883871e-03,   1.57170224e-03,  -2.68293126e-02,
        -5.18132627e-02,   0.00000000e+00,  -9.29973942e-02,
         0.00000000e+00,  -5.80780052e-03,   5.14040093e-03,
         3.20533611e-02,   2.49790287e-02,   0.00000000e+00,
        -1.07866911e-02,   0.00000000e+00,   5.50300930e-01,
         9.36230322e-03,  -3.29442168e-02,  -5.22210563e-02,
         6.57188057e-02,   0.00000000e+00,  -2.26673604e-02,
         0.00000000e+00,  -4.64515977e-02,   1.91961425e-02,
        -1.49701883e-02,  -1.69448966e-02,   0.00000000e+00,
        -2.92853124e-02,   0.00000000e+00,  -2.22916538e-03,
         5.67902318e-01,  -5.80176274e-02,  -4.64048730e-02,
        -3.05048779e-03,  -3.03550830e-02,   0.00000000e+00,
         1.75348405e-02,   0.00000000e+00,   3.11402742e-02,
         6.03068849e-02,   5.23770203e-03,  -3.16873495e-02,
         0.00000000e+00,  -4.30569716e-02,   0.00000000e+00,
         3.60445085e-04,   5.31879270e-02,   5.82404967e-01,
        -5.57346959e-02,   4.90002669e-02,   1.67383160e-02,
        -1.08424449e-03,   0.00000000e+00,  -1.00184863e-02,
         0.00000000e+00,  -5.24616053e-02,   6.54157443e-03,
        -1.50266409e-02,   9.61972241e-04,   0.00000000e+00,
        -6.60972011e-03,   0.00000000e+00,  -1.68530428e-03,
         3.97574255e-02,   1.86085273e-02,   6.12252380e-01,
         1.77229866e-01,  -1.49207054e-01,  -1.19876374e-01,
        -1.64761316e-02,   8.48294146e-02,   3.51401173e-03,
         5.62626923e-03,  -8.19477141e-02,  -5.50759514e-03,
         1.38762892e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.33962968e-01,
         5.25354077e-03,   1.98750132e-02,   1.70462078e-01,
         1.14033151e-01,   0.00000000e+00,   3.29166627e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.04952455e-02,   0.00000000e+00,
        -1.57131639e-01,   7.03214767e-02,   1.96102635e-02,
         8.84173212e-02,  -1.32328495e-01,   0.00000000e+00,
         7.38615337e-02,   0.00000000e+00,  -3.00735466e-02,
        -8.47188734e-03,   4.32288378e-02,  -4.79346086e-02,
         3.38508283e-02,   0.00000000e+00,  -8.94524416e-03,
         0.00000000e+00,  -1.45379892e-02,  -9.53628884e-02,
         1.25513203e-02,   7.03540145e-03,  -4.91230779e-03,
        -2.21004511e-02,   0.00000000e+00,  -1.38089420e-02,
         0.00000000e+00,  -1.28140699e-03,  -4.81048551e-02,
        -1.28486614e-01,   1.78652272e-03,  -4.97251517e-03,
         1.42642468e-02,   6.71910218e-03,   0.00000000e+00,
        -7.89700435e-02,   0.00000000e+00,   3.33374834e-02,
         1.04451684e-02,   3.48297188e-02,  -1.32004847e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.71854085e-02,   0.00000000e+00,
        -9.07107100e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.62958287e-01,
         6.35930908e-03,   8.20233205e-04,  -3.87660433e-02,
         3.77265200e-02,   0.00000000e+00,   2.01144785e-02,
         0.00000000e+00,   3.19820733e-02,  -5.18380119e-02,
        -2.21865088e-02,  -2.27792553e-02,   0.00000000e+00,
        -1.34658454e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.00730272e-02,
         0.00000000e+00,   2.20230027e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.96510613e-02,   0.00000000e+00,   1.99381348e-01,
         2.15696928e-03,  -6.33256261e-03,  -4.37186641e-02,
        -5.42612084e-02,   0.00000000e+00,  -5.07335328e-02,
         0.00000000e+00,  -5.39207901e-03,  -2.04689412e-03,
         2.99462611e-02,   9.38984240e-02,   0.00000000e+00,
        -4.16559967e-02,   0.00000000e+00,   1.82406130e-01,
         5.29264873e-03,  -6.28124659e-03,  -2.81472963e-02,
         4.75609810e-02,   0.00000000e+00,  -2.01616139e-02,
         0.00000000e+00,  -8.26658217e-02,   2.20178260e-02,
        -1.63311718e-02,   2.24381534e-02,   0.00000000e+00,
         7.05249821e-02,   0.00000000e+00,   8.88588741e-03,
         1.99843672e-01,  -1.39344597e-02,   6.99370738e-02,
         4.78659256e-03,   6.67021471e-03,   0.00000000e+00,
        -1.32022175e-02,   0.00000000e+00,  -5.53224818e-02,
        -1.72491431e-02,  -1.67701849e-02,  -3.06560391e-03,
         0.00000000e+00,  -5.92770620e-02,   0.00000000e+00,
         1.55621819e-02,  -3.76980896e-02,  -1.16408919e-01,
        -6.93151342e-02,   1.82971317e-02,   6.48227876e-03,
        -5.37287390e-03,   0.00000000e+00,   1.20378856e-03,
         0.00000000e+00,  -3.66119314e-02,   2.66528809e-02,
        -1.16787004e-02,  -1.01704362e-02,   0.00000000e+00,
        -2.66375773e-02,   0.00000000e+00,  -9.57588130e-03,
        -1.76138871e-03,   1.30719155e-01,   1.65395036e-01,
         5.98564508e-03,   1.72283196e-02,  -1.49631661e-02,
         6.93350222e-02,   4.69856562e-02,   2.38318488e-02,
         1.46929718e-02,   3.24437950e-03,   1.30943614e-02,
        -5.90435668e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.43779452e-02,
         1.67799871e-02,  -6.45371673e-02,  -3.73737194e-02,
        -2.77058330e-02,   0.00000000e+00,   3.21468925e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.71475113e-02,   0.00000000e+00,
         4.68286224e-02,  -8.48791505e-03,  -2.39711608e-02,
        -2.53141354e-02,   2.12194204e-02,   0.00000000e+00,
         9.30866189e-03,   0.00000000e+00,   3.03436213e-02,
         9.85240024e-03,   1.44434519e-02,   3.04425083e-02,
         2.12783968e-04,   0.00000000e+00,  -2.09204328e-02,
         0.00000000e+00,  -2.60754743e-02,  -2.10785824e-02,
         1.54944640e-03,  -6.87294176e-03,   4.04138249e-02,
         3.23506577e-03,   0.00000000e+00,  -2.66184236e-02,
         0.00000000e+00,  -1.39428227e-02,  -2.51121884e-03,
        -5.75004870e-02,  -1.91699661e-03,  -5.14336520e-03,
        -1.62451977e-04,  -8.90425920e-03,   0.00000000e+00,
         2.29013219e-02,   0.00000000e+00,  -7.63211299e-03,
         9.36212953e-03,  -1.10564951e-02,   5.28434768e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.73991133e-03,   0.00000000e+00,
         2.44500224e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.00800426e-02,
         3.13802551e-03,   1.00691816e-02,   5.25215251e-03,
        -7.52861591e-03,   0.00000000e+00,  -3.45202620e-03,
         0.00000000e+00,  -2.70591360e-02,   7.38889074e-05,
        -6.20630278e-03,  -1.73506419e-02,   0.00000000e+00,
         5.19475824e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.37827528e-02,
         0.00000000e+00,   2.99327730e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.22045999e-02,   0.00000000e+00,  -1.37526541e-02,
        -6.63002002e-04,   5.31380815e-03,   7.93646154e-03,
         5.16239096e-03,   0.00000000e+00,   8.42766864e-03,
         0.00000000e+00,  -8.27224500e-03,   3.18601620e-03,
         4.34419484e-03,  -2.48588235e-02,   0.00000000e+00,
         6.25364211e-03,   0.00000000e+00,  -1.08111323e-02,
        -1.64873971e-03,   2.39080672e-04,   4.67601570e-03,
        -5.56865353e-03,   0.00000000e+00,   9.66314230e-03,
         0.00000000e+00,   1.04218575e-02,  -2.95424770e-03,
        -2.55747992e-03,   5.25020351e-03,   0.00000000e+00,
        -2.83322800e-02,   0.00000000e+00,  -5.86476462e-03,
        -1.35186129e-02,  -1.29303347e-03,  -1.45745927e-02,
        -1.44956100e-02,  -3.32367594e-03,   0.00000000e+00,
         1.10172983e-02,   0.00000000e+00,   1.58173982e-02,
        -5.16756053e-03,  -7.87520499e-03,   4.55749820e-02,
         0.00000000e+00,  -4.51910877e-02,   0.00000000e+00,
        -2.09245402e-03,   2.25006046e-02,   2.14324376e-02,
         1.39806867e-02,  -1.48161978e-03,   1.72330121e-03,
        -1.17037670e-03,   0.00000000e+00,   1.15108981e-03,
         0.00000000e+00,  -7.93371180e-03,  -3.36478770e-04,
         1.33605594e-03,  -5.87621355e-03,   0.00000000e+00,
         1.44975302e-02,   0.00000000e+00,   4.81949556e-02,
         1.04249550e-02,  -1.00564379e-02,  -1.04379772e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.55281672e-02,  -4.84384302e-03,
         1.37987717e-03,   1.10705779e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.72366311e-03,   0.00000000e+00,
         2.78069020e-02,   8.99221828e-02,   1.59119295e-02,
         1.26910596e-02,   0.00000000e+00,  -2.26687605e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.62439901e-03,
         0.00000000e+00,  -3.38960987e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.88552741e-03,   0.00000000e+00,
        -6.50118675e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.02760552e-03,   0.00000000e+00,
        -2.37823836e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.31796890e-03,
         0.00000000e+00,  -8.87029191e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.95671897e-03,   2.29689045e-02,   2.09116859e-03,
         9.06466680e-03,   0.00000000e+00,  -1.07380420e-02,
         0.00000000e+00,  -1.72503876e-02,  -2.10379080e-02,
         1.69563552e-03,  -7.24722309e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.33888712e-04,   0.00000000e+00,
        -3.98097061e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.31466212e-03,
         0.00000000e+00,  -9.52951707e-04,   5.55873472e-03,
         5.19639930e-03,  -4.05748059e-03,   0.00000000e+00,
         4.07626059e-04,   0.00000000e+00,  -1.20253655e-02,
         1.08750032e-03,  -1.08693757e-03,  -5.40560488e-03,
         0.00000000e+00,  -9.66737927e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.66582846e-03,   0.00000000e+00,
         4.14182592e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.09007247e-03,
         0.00000000e+00,  -3.08664413e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.82857607e-03,   0.00000000e+00,
        -7.68328177e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.49683502e-02,
         0.00000000e+00,  -2.06682282e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.67028878e-04,
         0.00000000e+00,   4.52555986e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.15566923e-02,   0.00000000e+00,   2.82572287e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.47963063e-03,   0.00000000e+00,
        -1.04749767e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.70108639e-02,
         0.00000000e+00,   5.34167522e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.76658696e-02,  -4.17168348e-02,  -2.92546378e-02,
        -2.39871363e-02,   4.33030300e-03,  -2.71301352e-02,
         7.62232312e-02,   4.71802906e-03,  -1.70802036e-03,
         4.50786236e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.50163094e-03,
        -3.16478192e-03,  -3.00898431e-02,   1.66434795e-02,
         6.32534725e-03,   0.00000000e+00,   5.55115703e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.79531872e-02,   0.00000000e+00,
        -4.31765855e-02,   1.37923792e-02,   7.46732231e-02,
         2.41499402e-02,  -1.17759129e-02,   0.00000000e+00,
         7.97875326e-03,   0.00000000e+00,  -6.62157761e-02,
         5.43882932e-04,  -8.85024292e-03,  -1.07810079e-02,
        -6.73639992e-03,   0.00000000e+00,   8.72484675e-03,
         0.00000000e+00,  -2.17911188e-03,  -1.92208263e-02,
         4.04768184e-03,   9.37432158e-03,  -3.96424469e-03,
        -1.45981143e-02,   0.00000000e+00,   7.99676156e-03,
         0.00000000e+00,  -2.05253923e-02,  -4.23502589e-03,
        -2.69728899e-02,  -3.76841072e-03,  -9.24296315e-03,
         3.68243212e-04,  -6.42321417e-03,   0.00000000e+00,
        -9.97115729e-03,   0.00000000e+00,   1.81329122e-02,
         1.47628997e-02,   2.93767103e-03,  -3.22990798e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.10661990e-03,   0.00000000e+00,
        -2.06365835e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.85044103e-02,
        -3.47659291e-03,  -1.33722155e-02,  -1.52310414e-02,
         1.30290485e-02,   0.00000000e+00,   9.79455430e-03,
         0.00000000e+00,   3.48914918e-02,  -6.05586531e-03,
        -6.10106250e-03,   3.61009499e-03,   0.00000000e+00,
        -2.87265015e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.63102477e-02,
         0.00000000e+00,  -6.14929292e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.84358223e-03,   0.00000000e+00,   8.11992747e-03,
        -3.89902769e-03,   2.70882482e-03,  -1.11888992e-02,
        -7.64304253e-03,   0.00000000e+00,  -4.11601708e-03,
         0.00000000e+00,  -9.44294495e-04,  -2.01055265e-03,
        -3.07336934e-03,   1.69324228e-03,   0.00000000e+00,
        -9.62049736e-03,   0.00000000e+00,   7.74757598e-03,
         3.98742267e-03,  -6.01822866e-04,  -6.39267198e-03,
         1.35730119e-02,   0.00000000e+00,  -3.43270791e-03,
         0.00000000e+00,  -8.47545818e-03,  -3.61197696e-03,
         2.53604480e-04,   1.46230708e-02,   0.00000000e+00,
         2.72989455e-02,   0.00000000e+00,   1.41671981e-03,
         1.11528318e-02,  -2.72768906e-03,   1.38864906e-02,
         2.33243483e-03,  -1.29261969e-03,   0.00000000e+00,
        -3.01059158e-03,   0.00000000e+00,  -2.27407697e-02,
        -2.64764470e-03,  -2.99908975e-03,   4.81428492e-02,
         0.00000000e+00,   3.21571294e-02,   0.00000000e+00,
         8.90804824e-03,  -4.51314586e-02,  -5.29082418e-02,
        -1.59816093e-02,   6.68211921e-03,  -4.22197562e-03,
        -2.13963455e-04,   0.00000000e+00,  -5.62816607e-04,
         0.00000000e+00,   1.63958556e-02,  -2.58231148e-03,
         3.32750012e-03,  -7.98652350e-03,   0.00000000e+00,
        -2.03592048e-02,   0.00000000e+00,   2.59179436e-02,
        -3.25767772e-02,   2.12627249e-02,  -2.09983497e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.89484411e-02,  -4.58307160e-02,
        -1.15666990e-02,   5.29878575e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.05382246e-03,   0.00000000e+00,
        -3.15470598e-02,  -1.85074064e-02,   2.38938795e-03,
        -1.13535762e-02,   0.00000000e+00,   1.00527934e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.14618323e-02,
         0.00000000e+00,   3.94613311e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.85393508e-03,   0.00000000e+00,
         7.93521454e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.79209594e-03,   0.00000000e+00,
         6.60290482e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.38578885e-03,
         0.00000000e+00,   1.65330897e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.28209037e-04,  -1.96497573e-02,  -6.65164047e-03,
         7.76969318e-04,   0.00000000e+00,   3.33135791e-03,
         0.00000000e+00,   1.01906761e-02,   4.23885170e-03,
         3.30191961e-03,   6.07469249e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.56273286e-03,   0.00000000e+00,
        -4.72093950e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.66918383e-03,
         0.00000000e+00,  -2.03418295e-02,   9.20163976e-03,
         1.24599887e-03,  -1.89448354e-04,   0.00000000e+00,
        -1.04630048e-03,   0.00000000e+00,  -8.81161671e-03,
         6.93138163e-03,  -4.12319408e-03,  -2.78898684e-03,
         0.00000000e+00,  -1.14607224e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.45319295e-03,   0.00000000e+00,
        -2.39802328e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.90058743e-03,
         0.00000000e+00,  -4.13239445e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.40923838e-03,   0.00000000e+00,
         6.16696517e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.75800121e-03,
         0.00000000e+00,  -1.15010059e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.14779532e-02,
         0.00000000e+00,   1.30842519e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.64855186e-02,   0.00000000e+00,   3.66061140e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.14089576e-02,   0.00000000e+00,
         7.69736664e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.57043427e-02,
         0.00000000e+00,   6.90216995e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.46935968e-03,   9.15936745e-03,   1.56383239e-02,
         3.62710086e-02,  -3.36904063e-02,  -2.22475569e-03,
         5.06839970e-02,  -3.36231942e-02,  -1.05620305e-02,
         2.24217387e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.05224192e-03,
         6.78433793e-02,  -6.66899307e-03,  -7.87001516e-03,
         1.22335016e-02,   0.00000000e+00,  -1.13207189e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.64369502e-03,   0.00000000e+00,
         2.75130576e-03,  -8.20841827e-03,  -1.64280901e-02,
         6.51224303e-03,   1.54636475e-02,   0.00000000e+00,
         1.19533166e-02,   0.00000000e+00,   1.02526936e-02,
        -2.09406853e-03,  -2.03675720e-03,  -1.63313969e-03,
        -3.06999466e-03,   0.00000000e+00,  -4.23423835e-03,
         0.00000000e+00,   6.85386661e-03,   8.41323812e-03,
        -6.83465837e-03,   5.19113001e-03,  -5.79307558e-03,
         2.19206873e-03,   0.00000000e+00,   7.73112113e-03,
         0.00000000e+00,   8.04189164e-03,   8.41656540e-03,
         2.24560869e-02,  -3.17763895e-03,   1.66823786e-02,
         7.55789698e-03,   1.73370664e-03,   0.00000000e+00,
         1.79174321e-03,   0.00000000e+00,  -8.71431060e-03,
        -1.89399828e-03,  -2.28228430e-03,  -8.18377604e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.56193775e-03,   0.00000000e+00,
         1.37250525e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.82956104e-03,
         3.20033455e-03,  -3.63717318e-03,   9.87581191e-04,
         4.75180570e-03,   0.00000000e+00,   4.63228607e-03,
         0.00000000e+00,  -2.25779738e-03,   6.86643844e-04,
         8.46017486e-04,  -5.98675335e-03,   0.00000000e+00,
         9.55074972e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.58060745e-03,
         0.00000000e+00,   6.00116828e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.14434443e-04,   0.00000000e+00,  -3.40049330e-03,
        -1.77471840e-02,   6.94697694e-03,   4.61170842e-03,
         3.12683759e-03,   0.00000000e+00,   1.00081807e-03,
         0.00000000e+00,  -9.68298403e-03,   7.36016353e-03,
        -6.68538157e-03,  -1.35358180e-03,   0.00000000e+00,
        -1.04413179e-02,   0.00000000e+00,  -1.14870160e-02,
         1.56100532e-03,  -1.99656052e-03,   6.51456227e-03,
         1.17741813e-03,   0.00000000e+00,   8.84913011e-04,
         0.00000000e+00,   3.88941378e-03,   1.73842461e-03,
         3.55477842e-03,  -2.74726846e-03,   0.00000000e+00,
        -2.47306861e-03,   0.00000000e+00,  -1.18413099e-02,
        -2.28327591e-04,  -3.84499378e-04,  -4.40050461e-03,
        -6.22851861e-05,  -5.09353368e-03,   0.00000000e+00,
        -1.70211111e-02,   0.00000000e+00,   6.02071238e-03,
         5.22571158e-03,   1.07941507e-02,  -1.33066261e-02,
         0.00000000e+00,  -6.76767597e-03,   0.00000000e+00,
         3.22933366e-02,   1.88191944e-03,   1.42799458e-02,
         3.44542962e-03,  -1.36517503e-03,  -3.15804711e-03,
        -8.85417507e-03,   0.00000000e+00,  -8.53160457e-03,
         0.00000000e+00,  -1.64743152e-03,  -1.79544272e-04,
         8.42631315e-03,   2.76001194e-02,   0.00000000e+00,
        -1.09507383e-02,   0.00000000e+00,   6.54381800e-02,
        -2.64041329e-03,  -3.19746318e-04,  -9.46568386e-04,
         6.46831057e-02,  -2.95858951e-02,  -3.77234454e-02,
         3.10921737e-02,  -8.61836583e-03,  -6.75712702e-03,
        -3.71085320e-02,   9.57393096e-03,   6.50674977e-03,
         3.30967394e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.04217849e-02,
         2.68357293e-02,  -9.99940547e-03,   4.06566347e-02,
         2.85824863e-02,   0.00000000e+00,   9.67028002e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.15252531e-02,   0.00000000e+00,
        -4.42825849e-02,   7.64493449e-02,   1.14487960e-02,
         2.23143472e-02,  -3.17965030e-02,   0.00000000e+00,
         1.93686742e-02,   0.00000000e+00,  -5.43707177e-03,
        -1.47219442e-02,   1.37131041e-02,  -1.97062577e-02,
         6.75577604e-03,   0.00000000e+00,   5.57632200e-03,
         0.00000000e+00,  -6.84564452e-03,  -6.56232165e-03,
         9.14840577e-03,   8.15013191e-03,  -8.81353994e-03,
        -9.24125141e-03,   0.00000000e+00,   8.57929457e-03,
         0.00000000e+00,  -2.34175924e-03,  -1.05152399e-02,
        -6.76758631e-03,  -4.52093440e-03,  -7.22845256e-03,
         8.46752032e-03,   8.79176309e-03,   0.00000000e+00,
        -2.75222286e-02,   0.00000000e+00,   1.75666000e-02,
         8.59240895e-03,   1.53137795e-02,  -3.35940479e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.75338922e-04,   0.00000000e+00,
        -4.04540187e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.99856475e-02,
        -6.26037210e-03,  -4.25114967e-03,  -2.35821555e-02,
         1.53837083e-02,   0.00000000e+00,   7.05822566e-03,
         0.00000000e+00,   2.53138663e-02,  -1.65728601e-02,
        -8.13927609e-03,  -3.78854024e-03,   0.00000000e+00,
        -3.64181478e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.31302395e-02,
         0.00000000e+00,   4.34349275e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.60852022e-02,   0.00000000e+00,   4.82552153e-02,
        -2.25688986e-03,  -5.38216956e-04,  -1.73952926e-02,
        -1.99976340e-02,   0.00000000e+00,  -1.84816946e-02,
         0.00000000e+00,  -1.42935736e-03,  -1.45503261e-03,
         3.90513773e-03,   2.41966788e-02,   0.00000000e+00,
        -1.57610122e-02,   0.00000000e+00,   4.27085541e-02,
        -1.32015439e-02,   1.19650530e-02,  -6.20483402e-03,
         1.61265902e-02,   0.00000000e+00,  -8.29917958e-03,
         0.00000000e+00,  -4.36510914e-02,   1.17752448e-02,
        -6.22189202e-03,   1.63250429e-03,   0.00000000e+00,
         6.37610420e-03,   0.00000000e+00,  -2.89836137e-03,
         2.07677023e-02,  -5.44984883e-04,   3.32901611e-02,
         2.57880743e-03,   4.90245954e-05,   0.00000000e+00,
        -6.79328886e-03,   0.00000000e+00,  -3.54908690e-02,
        -2.93723115e-03,  -9.43948531e-03,   1.21118200e-02,
         0.00000000e+00,   8.53599149e-03,   0.00000000e+00,
         7.82990107e-03,   1.24201816e-02,  -3.38255719e-02,
        -2.92372955e-02,   3.06361552e-03,  -1.27962647e-02,
         1.55700784e-02,   0.00000000e+00,  -9.29762972e-03,
         0.00000000e+00,  -2.50756443e-02,   1.23755504e-02,
        -4.57307320e-03,  -2.30617490e-03,   0.00000000e+00,
        -7.89069530e-03,   0.00000000e+00,   5.19401298e-03,
         5.32153377e-02,   4.29524763e-02,   6.37596310e-02,
        -4.03912616e-02,  -5.50117505e-03,  -4.27029191e-02,
        -4.04548820e-03,   1.74416115e-02,  -2.06614184e-02,
         1.36592129e-02,  -7.20674034e-03,   1.91750673e-03,
        -3.43103136e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.33825610e-02,
        -1.11084607e-02,  -2.60390182e-03,  -7.60905810e-03,
        -9.72441214e-04,   0.00000000e+00,  -2.66693726e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.85332881e-04,   0.00000000e+00,
        -3.53698355e-02,  -1.47778574e-02,   7.29566541e-03,
        -8.75154623e-03,  -2.58866145e-03,   0.00000000e+00,
         8.41385188e-03,   0.00000000e+00,  -3.94873557e-02,
         1.28877972e-02,   2.31074841e-02,  -1.05627603e-02,
         4.56149961e-03,   0.00000000e+00,   3.71834965e-03,
         0.00000000e+00,   9.36883150e-03,  -9.61733408e-03,
         4.23622097e-03,   1.70425750e-02,  -6.89466640e-03,
         4.44121916e-03,   0.00000000e+00,   4.46734519e-03,
         0.00000000e+00,  -4.79191181e-03,  -4.68210266e-03,
        -1.87977939e-03,  -1.82292905e-03,  -3.26050393e-03,
         8.80106637e-03,   8.51427127e-03,   0.00000000e+00,
        -8.12112944e-03,   0.00000000e+00,   1.25942038e-02,
         3.40171732e-03,   5.50668269e-03,  -2.87959145e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.88436029e-03,   0.00000000e+00,
        -1.98696396e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.79407015e-02,
         6.55300400e-04,   1.36200642e-02,  -9.47865211e-03,
         2.76054637e-03,   0.00000000e+00,  -7.37205751e-04,
         0.00000000e+00,   6.92737544e-03,  -1.50162911e-02,
        -4.21805698e-03,  -6.51798387e-03,   0.00000000e+00,
        -3.01226168e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.45216017e-02,
         0.00000000e+00,  -7.91865647e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.89307555e-05,   0.00000000e+00,  -2.86275116e-02,
         5.40084848e-04,  -5.23751161e-04,   5.33653438e-03,
         6.94575009e-03,   0.00000000e+00,   1.39776202e-02,
         0.00000000e+00,  -1.61202350e-03,  -1.32773478e-03,
        -5.37460514e-03,  -3.06200740e-03,   0.00000000e+00,
         3.92804082e-03,   0.00000000e+00,  -2.42984770e-02,
         5.43753187e-03,   7.90361814e-04,   5.65056301e-03,
        -1.02019289e-02,   0.00000000e+00,   6.11845487e-03,
         0.00000000e+00,   7.96590216e-03,  -2.80388006e-03,
         2.22052547e-03,   6.41795628e-03,   0.00000000e+00,
         3.52652324e-03,   0.00000000e+00,   1.04830646e-03,
        -2.33184086e-02,   1.10533960e-02,   1.40075648e-02,
        -6.71266269e-03,   4.10434396e-03,   0.00000000e+00,
         4.02725829e-03,   0.00000000e+00,  -6.96460754e-04,
        -1.74762890e-02,  -7.39108292e-03,   8.43626049e-03,
         0.00000000e+00,  -1.65233625e-02,   0.00000000e+00,
        -3.26232903e-03,  -7.83921679e-03,  -3.95604582e-02,
         1.03798587e-02,  -9.41171985e-03,   3.72147144e-03,
        -5.91931483e-03,   0.00000000e+00,   4.67764624e-03,
         0.00000000e+00,   1.05331695e-02,   6.64455569e-04,
         5.35354010e-03,  -2.45609874e-03,   0.00000000e+00,
         6.40373794e-03,   0.00000000e+00,   6.74849641e-05,
        -1.51060237e-02,  -1.63194662e-03,  -3.65402319e-02,
         2.22487505e-03,  -8.33123100e-03,  -1.11250628e-02,
         5.12886761e-04,   1.06840718e-03,   1.08430467e-02,
        -3.75620790e-04,   2.32262443e-03,   1.34769713e-03,
        -2.38907749e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.01946304e-03,
        -3.42576394e-03,   2.03845062e-03,  -2.17581337e-03,
         5.40609361e-03,   0.00000000e+00,   4.99790452e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.16609771e-03,   0.00000000e+00,
        -2.16734767e-02,   9.79149299e-03,   9.88897368e-03,
        -2.84775946e-03,  -1.03706887e-02,   0.00000000e+00,
         1.18296723e-02,   0.00000000e+00,  -1.15907047e-02,
         3.99351572e-03,   1.69708190e-02,  -1.01904646e-02,
         5.00175876e-03,   0.00000000e+00,   4.07636950e-03,
         0.00000000e+00,   3.15225613e-03,   7.85549444e-03,
         1.07173079e-02,   2.77726622e-02,  -1.98088400e-02,
         1.54835031e-03,   0.00000000e+00,   1.22234043e-02,
         0.00000000e+00,   2.13727047e-03,   1.01593692e-02,
         4.33399401e-02,   1.62682038e-04,  -4.72181959e-03,
         9.39696083e-04,   1.26849606e-03,   0.00000000e+00,
        -6.03855907e-03,   0.00000000e+00,   9.06655742e-03,
         4.01103581e-03,   6.34273661e-03,  -1.28728708e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.46801189e-05,   0.00000000e+00,
        -1.24226548e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.37673487e-02,
        -3.97739295e-04,   5.44671364e-03,  -7.85157431e-03,
         4.03310418e-03,   0.00000000e+00,   7.96684764e-04,
         0.00000000e+00,   5.74063636e-03,  -7.17653741e-03,
         6.21124281e-04,  -7.31072469e-03,   0.00000000e+00,
        -1.17579927e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.74144688e-03,
         0.00000000e+00,  -2.93359310e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.09866475e-03,   0.00000000e+00,   3.87017230e-03,
         4.16964156e-03,  -3.01796824e-03,  -1.87178357e-03,
        -5.01717987e-03,   0.00000000e+00,  -3.66258446e-03,
         0.00000000e+00,  -8.86283021e-04,  -2.09603168e-03,
        -5.63350270e-03,   2.80782584e-03,   0.00000000e+00,
        -1.22320544e-04,   0.00000000e+00,   6.35733003e-03,
        -1.48162969e-03,   1.67858754e-03,  -2.71553072e-03,
         3.04327311e-03,   0.00000000e+00,   5.12832200e-04,
         0.00000000e+00,  -7.15276660e-03,   1.52654766e-03,
         1.41446604e-03,   6.23198814e-03,   0.00000000e+00,
         2.92797447e-03,   0.00000000e+00,   1.31986277e-03,
         3.10439298e-03,   1.00118421e-03,   1.11839814e-02,
        -4.20938920e-03,   2.41479716e-03,   0.00000000e+00,
         4.69601790e-03,   0.00000000e+00,  -7.93579038e-03,
        -1.00628055e-02,  -4.13669472e-03,   1.00016145e-02,
         0.00000000e+00,  -6.07740721e-03,   0.00000000e+00,
        -1.84281801e-03,  -2.54770758e-03,  -1.90617680e-02,
        -6.38103955e-03,   1.42778262e-04,   7.72162048e-04,
         4.44344824e-03,   0.00000000e+00,   2.77905524e-03,
         0.00000000e+00,  -1.84255788e-03,   4.48455973e-03,
         3.07092251e-03,  -3.81085332e-03,   0.00000000e+00,
         1.37397740e-03,   0.00000000e+00,  -1.43760980e-03,
         2.58362385e-03,   8.75400473e-03,   3.27622879e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.69987390e-03,   6.39015720e-04,
         2.33915645e-03,  -3.26520279e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.85915598e-03,   0.00000000e+00,
        -3.03101306e-03,  -1.21960500e-02,  -2.39760774e-03,
        -2.63163347e-03,   0.00000000e+00,   4.20497781e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.34225164e-03,
         0.00000000e+00,   7.22316022e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.13813131e-03,   0.00000000e+00,
         7.44819619e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.05589957e-04,   0.00000000e+00,
         6.09728566e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.02514280e-04,
         0.00000000e+00,   2.67160565e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.44172825e-02,  -2.50218888e-02,  -3.88866529e-03,
        -3.93267631e-03,   0.00000000e+00,   6.39242256e-03,
         0.00000000e+00,   9.58081363e-03,   1.24847558e-03,
         8.38628267e-03,   2.91362038e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.08070613e-03,   0.00000000e+00,
        -1.47728855e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.85578339e-04,
         0.00000000e+00,   5.93845559e-03,  -8.10209229e-03,
        -4.11877592e-04,  -1.71244523e-03,   0.00000000e+00,
         1.86609399e-03,   0.00000000e+00,   3.04346959e-03,
        -9.72020324e-05,   1.74187257e-03,  -2.47086244e-04,
         0.00000000e+00,  -1.27705153e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.63701071e-04,   0.00000000e+00,
        -2.33974272e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.46909624e-03,
         0.00000000e+00,  -1.14289977e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.05248073e-03,   0.00000000e+00,
         5.42858178e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.42319551e-03,
         0.00000000e+00,   4.66450733e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.97177231e-03,
         0.00000000e+00,   2.76563846e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.30506467e-02,   0.00000000e+00,   1.95745136e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.72141689e-03,   0.00000000e+00,
        -1.18878925e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.00539683e-03,
         0.00000000e+00,   5.49373867e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.90253672e-03,  -1.10105211e-03,   4.72600656e-03,
        -2.41285893e-03,   3.67138082e-04,   5.94492875e-03,
        -8.58040759e-04,  -4.11228980e-03,  -1.65135287e-03,
        -2.26177000e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.02743112e-03,
        -5.52327856e-04,   8.85559636e-03,   6.12438974e-03,
         5.32729891e-03,   0.00000000e+00,   1.10924867e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.10023610e-03,   0.00000000e+00,
        -1.21713371e-03,  -5.02484187e-03,  -9.26937785e-03,
        -1.11221353e-03,   7.68698912e-04,   0.00000000e+00,
        -8.58770326e-04,   0.00000000e+00,   1.50702815e-02,
        -1.51788109e-03,  -2.64686953e-03,   4.37848864e-03,
         3.02722948e-03,   0.00000000e+00,  -4.39642807e-03,
         0.00000000e+00,   1.46268795e-03,  -3.41829649e-03,
         7.17141070e-04,  -3.90860491e-03,  -1.70888596e-04,
        -2.38587198e-03,   0.00000000e+00,  -1.55828175e-03,
         0.00000000e+00,   3.24961966e-03,   2.96563479e-03,
        -4.09688043e-04,   1.32702338e-02,   1.93068687e-02,
         2.80785759e-04,   1.95408834e-05,   0.00000000e+00,
        -7.36105852e-03,   0.00000000e+00,  -5.84212060e-03,
        -2.41211776e-04,  -5.49882922e-03,   7.36165706e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.99280520e-03,   0.00000000e+00,
         2.13155401e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.37288227e-03,
         3.62958467e-03,   6.18103296e-03,  -8.01657909e-05,
         8.50359654e-04,   0.00000000e+00,  -1.46720753e-03,
         0.00000000e+00,  -3.31356312e-03,   5.40971533e-04,
        -4.03204571e-03,  -2.82357524e-04,   0.00000000e+00,
         1.22003567e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.31461818e-03,
         0.00000000e+00,   2.35753261e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.70886923e-05,   0.00000000e+00,   6.27805334e-03,
         6.77650196e-03,  -6.27789842e-03,  -5.28587358e-03,
        -7.45198569e-03,   0.00000000e+00,  -3.66693652e-03,
         0.00000000e+00,   8.98628681e-04,   2.72782239e-04,
         8.41257878e-04,   1.18616152e-03,   0.00000000e+00,
         1.45681462e-03,   0.00000000e+00,   7.06671260e-03,
        -2.56865987e-03,  -6.37593237e-03,  -3.22981761e-03,
         7.94708674e-03,   0.00000000e+00,  -3.93057223e-03,
         0.00000000e+00,  -2.16731110e-04,   1.91244651e-03,
         2.89775407e-03,   3.13475452e-04,   0.00000000e+00,
        -1.72267183e-03,   0.00000000e+00,   2.55291906e-03,
         5.40832616e-03,  -9.54531273e-03,  -6.62430014e-03,
         6.86624599e-03,   1.29930352e-02,   0.00000000e+00,
        -1.13726012e-02,   0.00000000e+00,   1.86031026e-02,
         1.29018626e-03,   6.57108300e-03,  -9.33862659e-03,
         0.00000000e+00,  -4.76998042e-03,   0.00000000e+00,
         9.50815576e-04,   1.83540715e-03,   4.09954077e-03,
        -4.89866613e-03,   6.43633657e-03,   2.06987913e-03,
         2.33274546e-03,   0.00000000e+00,   1.01478488e-02,
         0.00000000e+00,  -8.07725989e-03,   1.30399761e-03,
        -3.14694678e-03,   2.38954820e-03,   0.00000000e+00,
         3.12024361e-03,   0.00000000e+00,  -1.03738763e-03,
        -3.76676107e-03,   2.42767597e-03,   3.99427775e-03,
         1.47196640e-02,  -1.47657046e-03,   7.81354104e-03,
         2.87147500e-03,   8.93317620e-03,   1.09611452e-02,
         1.00647034e-03,  -5.52344802e-03,  -2.26274993e-04,
         1.70815895e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.51066621e-02,
        -4.21626095e-05,  -4.76120885e-03,  -1.81843577e-03,
         1.77725527e-03,   0.00000000e+00,   1.48617514e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.48859841e-03,   0.00000000e+00,
         1.10379738e-02,  -4.50079362e-03,  -6.25715934e-03,
        -6.98708010e-03,   1.87985176e-03,   0.00000000e+00,
         3.10287250e-03,   0.00000000e+00,   2.51052436e-02,
         1.94397038e-03,   8.97604177e-03,  -3.88130906e-03,
         1.10646133e-03,   0.00000000e+00,  -8.60122237e-05,
         0.00000000e+00,  -2.78395188e-03,   5.78541960e-03,
         1.55353590e-04,   4.20440191e-03,  -1.78038178e-03,
         3.43327765e-04,   0.00000000e+00,  -1.35850210e-03,
         0.00000000e+00,   1.54493894e-04,  -7.84512085e-04,
         1.20136770e-02,  -4.72776507e-03,  -4.45600387e-03,
        -9.24886927e-03,  -5.81754832e-03,   0.00000000e+00,
         5.21381833e-03,   0.00000000e+00,  -4.49964210e-04,
        -3.51907188e-03,  -3.97941571e-03,   1.02882514e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.06606515e-03,   0.00000000e+00,
         8.36315649e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.32571504e-02,
         1.53324681e-02,   1.77875807e-02,   1.07324118e-02,
         6.38407972e-03,   0.00000000e+00,  -4.44059860e-03,
         0.00000000e+00,  -1.25627057e-02,   3.79686791e-03,
        -5.19004440e-04,   7.46761805e-03,   0.00000000e+00,
         1.35346807e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.28015823e-02,
         0.00000000e+00,   4.49211004e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.95069068e-04,   0.00000000e+00,   1.33890670e-02,
        -4.95307304e-03,   5.88116074e-03,  -1.62251321e-03,
        -5.92309706e-03,   0.00000000e+00,  -1.24769816e-02,
         0.00000000e+00,  -4.04921388e-03,   2.61429097e-03,
         1.74190126e-03,   2.25319508e-03,   0.00000000e+00,
         2.12691838e-04,   0.00000000e+00,   1.10376927e-02,
        -8.65262135e-04,  -7.75610328e-03,  -1.13305068e-02,
         7.76178866e-03,   0.00000000e+00,  -1.14804076e-04,
         0.00000000e+00,  -1.43398930e-03,  -1.19677026e-03,
        -1.87537634e-03,  -2.02082315e-03,   0.00000000e+00,
        -1.49708379e-03,   0.00000000e+00,  -3.34697928e-03,
         1.37042521e-02,  -9.07524670e-03,   2.77496959e-03,
        -1.80721700e-02,  -1.18927053e-03,   0.00000000e+00,
         5.09301282e-03,   0.00000000e+00,   1.31766250e-02,
        -1.15065633e-02,  -6.74793342e-03,   1.58160635e-03,
         0.00000000e+00,  -1.32656193e-02,   0.00000000e+00,
        -7.10426397e-04,   3.50752544e-03,   1.28989978e-02,
        -7.52815543e-03,   5.80844982e-03,   3.22386357e-03,
        -6.73859850e-03,   0.00000000e+00,  -9.31066251e-03,
         0.00000000e+00,  -7.18019885e-03,   5.28852897e-03,
         2.25620627e-03,   1.35812354e-03,   0.00000000e+00,
         4.44151311e-03,   0.00000000e+00,   1.63472529e-04,
        -3.84322175e-03,   1.61167850e-03,   1.21835786e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.57361527e-02,   9.65896548e-03,
         3.35516425e-03,  -2.02032649e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.85579160e-04,   0.00000000e+00,
         8.40944632e-03,   1.61585140e-03,   2.12422297e-03,
        -1.10356755e-03,   0.00000000e+00,  -1.90486353e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.61781993e-03,
         0.00000000e+00,  -3.01673659e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.51817228e-03,   0.00000000e+00,
        -1.91759551e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.23948975e-03,   0.00000000e+00,
        -3.90372723e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.19722374e-03,
         0.00000000e+00,  -4.88846143e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.96819648e-03,   5.89967217e-03,   3.27887328e-04,
         1.14767633e-03,   0.00000000e+00,  -1.36398411e-03,
         0.00000000e+00,  -2.99700814e-03,  -7.30041037e-04,
        -5.78245116e-04,   6.43602308e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.44489970e-03,   0.00000000e+00,
        -7.90970195e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.94764561e-03,
         0.00000000e+00,   2.92683031e-02,  -1.13331794e-02,
        -2.88066132e-03,   1.56690239e-03,   0.00000000e+00,
         1.14413657e-04,   0.00000000e+00,   5.85493624e-03,
        -1.85050161e-03,   4.58552385e-04,   7.25065473e-04,
         0.00000000e+00,   2.41845184e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.52226952e-03,   0.00000000e+00,
         7.59667632e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.21156680e-04,
         0.00000000e+00,   7.08070660e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.77546032e-03,   0.00000000e+00,
         2.07825831e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.12242044e-03,
         0.00000000e+00,   7.75019245e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.43465690e-02,
         0.00000000e+00,  -5.20517120e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.71031697e-03,   0.00000000e+00,  -6.50077055e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.15544700e-02,   0.00000000e+00,
        -6.83381883e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.98873764e-03,
         0.00000000e+00,  -1.16423077e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.88435776e-03,   7.66952764e-04,   8.66617144e-03,
        -3.82475339e-03,   7.25493258e-03,   1.18317234e-02,
        -1.01876461e-02,   7.49615024e-03,   9.39913207e-04,
         6.64372957e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.31998452e-03,
        -1.38959102e-02,   1.08565439e-03,  -6.73928066e-04,
        -2.18475881e-03,   0.00000000e+00,   9.31947422e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.22732738e-04,   0.00000000e+00,
         1.30133963e-02,  -5.44723247e-04,  -1.48577297e-03,
        -5.59249674e-03,  -3.47586195e-03,   0.00000000e+00,
        -3.66864386e-03,   0.00000000e+00,   1.17630017e-02,
        -2.66860153e-04,  -2.16686321e-03,   6.23314313e-03,
         1.45413357e-03,   0.00000000e+00,   5.63070411e-05,
         0.00000000e+00,  -4.92494882e-03,   1.40984774e-03,
         4.27676152e-03,  -3.65418021e-03,   3.31858091e-03,
        -2.67466693e-03,   0.00000000e+00,  -4.46485387e-03,
         0.00000000e+00,  -2.74215688e-04,   1.51183952e-03,
        -2.61070571e-03,   8.35316053e-03,  -5.81870407e-03,
        -6.08816969e-03,  -7.10627284e-03,   0.00000000e+00,
         5.83554312e-03,   0.00000000e+00,  -1.76851320e-03,
        -2.44752289e-04,  -2.88809198e-03,   1.04702904e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.10222965e-03,   0.00000000e+00,
         9.57123542e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.53443896e-02,
        -2.32939934e-03,   2.47397051e-03,   2.47591452e-03,
        -4.67039924e-03,   0.00000000e+00,  -4.79883305e-03,
         0.00000000e+00,  -7.47981960e-03,   5.11503699e-03,
         1.19967535e-03,   1.97599449e-04,   0.00000000e+00,
         1.39467086e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.55337738e-03,
         0.00000000e+00,   2.96716437e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.55737839e-03,   0.00000000e+00,   6.98984472e-03,
         2.68762711e-02,  -9.89357812e-03,  -4.32418663e-03,
        -1.12049622e-03,   0.00000000e+00,  -6.33500901e-03,
         0.00000000e+00,   5.70906287e-03,  -4.56917617e-04,
         2.64839649e-03,   4.36843322e-04,   0.00000000e+00,
         2.30495769e-03,   0.00000000e+00,   7.31466846e-03,
        -3.31845212e-03,  -1.37049566e-03,  -3.96412770e-03,
         1.40812982e-03,   0.00000000e+00,  -3.57395149e-03,
         0.00000000e+00,  -5.97405958e-04,  -9.25009286e-05,
         3.25668646e-04,   2.34722790e-03,   0.00000000e+00,
        -4.12832799e-03,   0.00000000e+00,  -6.21498993e-04,
         7.73578157e-03,  -3.34638128e-03,  -6.13884996e-03,
         1.89267254e-03,   7.84058190e-03,   0.00000000e+00,
         1.22384626e-02,   0.00000000e+00,   3.53804097e-03,
         7.85940992e-04,  -1.22200722e-03,   2.73480056e-03,
         0.00000000e+00,  -1.19936038e-03,   0.00000000e+00,
        -7.23797451e-03,   1.34736180e-03,   9.84486721e-03,
        -3.43238921e-03,   3.34931936e-03,   1.38478940e-02,
         2.05176582e-02,   0.00000000e+00,   1.82889276e-02,
         0.00000000e+00,  -3.32083745e-03,   1.88044592e-04,
        -2.83318786e-03,  -5.56328534e-03,   0.00000000e+00,
         2.68525995e-03,   0.00000000e+00,  -1.05285875e-02,
         8.04777474e-04,  -1.42122354e-03,   7.38794850e-03,
         1.50729174e-03,  -8.06563727e-03,  -5.29303988e-03,
        -1.01833252e-02,   7.61585845e-03,   8.69008540e-04,
         9.65065917e-03,  -9.50574738e-03,  -2.69066829e-03,
         5.93373605e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.77177716e-03,
        -6.19946127e-03,   5.28008769e-03,   9.40320936e-03,
         5.29558401e-03,   0.00000000e+00,  -3.65467445e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.88148571e-03,   0.00000000e+00,
        -1.16785640e-02,  -1.17266345e-02,   9.32458778e-03,
         5.27734662e-04,  -1.38273596e-03,   0.00000000e+00,
         3.11770501e-04,   0.00000000e+00,  -1.54734235e-02,
         5.38742854e-03,   3.85001667e-03,  -3.75385744e-03,
        -5.77472846e-04,   0.00000000e+00,   3.65233421e-03,
         0.00000000e+00,   3.50976081e-03,  -2.65805270e-03,
        -1.27204282e-03,   3.11011697e-03,  -3.80991806e-03,
         8.22245456e-04,   0.00000000e+00,   2.24271361e-03,
         0.00000000e+00,  -2.37193663e-03,  -2.99718301e-03,
        -4.16534088e-04,  -4.98194091e-04,  -3.70538768e-03,
         6.15850596e-03,   7.73409837e-03,   0.00000000e+00,
        -1.10020509e-02,   0.00000000e+00,   6.58543498e-03,
         2.72769994e-03,   7.16586208e-03,  -1.04371063e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.05233782e-03,   0.00000000e+00,
        -1.78751247e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.64228424e-02,
        -6.88517435e-04,  -3.30021599e-03,  -1.29821524e-02,
         6.33882283e-03,   0.00000000e+00,   9.41037832e-04,
         0.00000000e+00,   7.08390149e-03,  -7.57597369e-03,
        -3.24951476e-03,  -1.79269488e-03,   0.00000000e+00,
        -1.09131553e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.52972045e-04,
         0.00000000e+00,  -1.04599269e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.94135671e-03,   0.00000000e+00,   4.34883786e-03,
         2.70717713e-03,  -2.49188965e-03,  -3.06447119e-03,
         2.68607690e-04,   0.00000000e+00,   8.25255462e-04,
         0.00000000e+00,  -2.55052357e-04,  -9.78881069e-04,
         1.99461340e-05,   5.91430124e-03,   0.00000000e+00,
        -2.72071072e-03,   0.00000000e+00,   3.35620277e-03,
         2.96446222e-02,  -8.62383508e-03,  -2.65599691e-03,
         2.59570251e-03,   0.00000000e+00,  -1.41435848e-03,
         0.00000000e+00,  -4.64570552e-03,   5.50427128e-04,
         3.93092768e-04,   8.93359150e-04,   0.00000000e+00,
         4.09662031e-03,   0.00000000e+00,   8.62567095e-04,
         3.89751470e-03,   9.89521802e-03,   1.55176646e-02,
         9.37742761e-03,  -8.88691413e-03,   0.00000000e+00,
         3.58686596e-03,   0.00000000e+00,  -2.30621973e-03,
        -3.72798083e-03,  -2.95595823e-03,  -7.55261991e-04,
         0.00000000e+00,  -1.51470971e-03,   0.00000000e+00,
        -3.03952243e-04,  -7.72590579e-03,  -1.08844390e-02,
         7.67889130e-03,  -1.96344391e-04,   1.35128733e-02,
        -1.61759430e-02,   0.00000000e+00,   9.80133176e-03,
         0.00000000e+00,   2.09503520e-02,  -4.01299270e-03,
         2.39698861e-03,  -1.56139928e-03,   0.00000000e+00,
        -4.14166558e-03,   0.00000000e+00,  -3.24865648e-03,
        -1.81552684e-02,   4.49420069e-03,  -1.61512707e-03,
        -5.75390366e-02,  -9.58683794e-03,  -7.99868107e-02,
        -5.19970420e-03,  -2.32153631e-03,  -6.72013212e-02,
        -2.45146780e-03,  -6.15846398e-03,  -1.62392400e-03,
        -5.86211121e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.28453209e-02,
         3.97536209e-04,   8.29104739e-03,   1.13593987e-02,
         8.07687777e-03,   0.00000000e+00,  -7.43377285e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.80638887e-04,   0.00000000e+00,
        -7.65285531e-02,   6.97150077e-03,   1.95950731e-02,
         4.25522323e-03,  -9.64953666e-03,   0.00000000e+00,
         5.93912019e-03,   0.00000000e+00,  -8.56496527e-02,
         8.83358446e-03,   2.49261655e-02,  -2.65871600e-02,
         5.11181356e-03,   0.00000000e+00,   1.39919037e-02,
         0.00000000e+00,   1.83225709e-02,  -3.14623255e-02,
         1.53589822e-03,   1.43292603e-02,  -1.66908701e-02,
         2.92777349e-03,   0.00000000e+00,   1.80504684e-02,
         0.00000000e+00,  -7.89553830e-03,  -1.99722720e-02,
        -2.25356845e-02,  -7.08061760e-03,  -3.50038007e-03,
         3.29180946e-02,   3.49176273e-02,   0.00000000e+00,
        -3.90939177e-02,   0.00000000e+00,   3.61168372e-02,
         7.81718757e-03,   2.10171265e-02,  -8.57859601e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.42966091e-02,   0.00000000e+00,
        -7.40904947e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.01799249e-01,
        -1.30645976e-02,   1.49946813e-02,  -3.79362990e-02,
         1.09721894e-02,   0.00000000e+00,   3.75047766e-03,
         0.00000000e+00,   4.64787746e-02,  -3.68321087e-02,
        -1.45298871e-02,  -2.54883838e-03,   0.00000000e+00,
        -9.01503732e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.44863647e-02,
         0.00000000e+00,  -2.40867064e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.78859244e-03,   0.00000000e+00,  -4.97855553e-02,
        -1.80569998e-03,  -2.24796044e-03,   5.60225769e-03,
         1.69542331e-02,   0.00000000e+00,   3.60235048e-02,
         0.00000000e+00,   1.11410677e-03,  -4.51111463e-03,
        -1.01260964e-02,   6.37133291e-03,   0.00000000e+00,
        -1.71570279e-03,   0.00000000e+00,  -4.92687214e-02,
         5.86334058e-03,   1.69818978e-02,   2.42958100e-02,
        -2.91615778e-02,   0.00000000e+00,   8.24575602e-03,
         0.00000000e+00,   1.04619012e-03,   3.14359071e-04,
         2.20806726e-03,   5.36371670e-03,   0.00000000e+00,
         1.40927859e-02,   0.00000000e+00,  -3.81529866e-04,
        -5.30289433e-02,   4.01191931e-02,   5.26985702e-02,
         1.43102081e-03,   8.98171754e-03,   0.00000000e+00,
        -5.19151715e-03,   0.00000000e+00,  -2.68206079e-02,
        -1.99642866e-02,  -1.51714074e-02,  -1.30630697e-03,
         0.00000000e+00,   1.68681344e-03,   0.00000000e+00,
         2.70991902e-03,  -1.05035321e-02,  -8.56702062e-02,
         2.02438233e-02,  -3.07440186e-02,  -2.16821286e-03,
        -1.93628240e-03,   0.00000000e+00,   5.48473018e-03,
         0.00000000e+00,   2.04325859e-02,   4.67683284e-04,
         6.78249073e-03,   2.50990398e-03,   0.00000000e+00,
         2.35897546e-03,   0.00000000e+00,  -3.85664724e-03,
         2.62388583e-03,   7.29704840e-03,  -5.29314746e-02,
        -7.60731832e-02,   4.10257830e-02,  -5.06654428e-03,
         8.75783600e-03,  -1.35366342e-02,  -2.82765108e-02,
        -6.09149791e-04,   1.80529709e-02,   2.83855256e-03,
        -6.81899533e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.20691736e-02,
        -4.06456653e-03,  -8.07611496e-03,  -4.63701449e-02,
        -3.09122785e-02,   0.00000000e+00,  -4.22908206e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.68592848e-02,   0.00000000e+00,
         6.28131294e-03,  -3.12966256e-02,  -5.47600027e-03,
        -3.32306345e-02,   4.29896812e-02,   0.00000000e+00,
        -2.16953542e-02,   0.00000000e+00,  -2.57697529e-02,
         9.60451574e-03,  -7.56724917e-03,   1.42854941e-02,
        -1.08151092e-02,   0.00000000e+00,   3.31923244e-03,
         0.00000000e+00,   7.43651020e-03,   4.14916339e-03,
        -6.37322945e-03,  -2.26998972e-03,   7.05938933e-03,
         1.23675594e-02,   0.00000000e+00,   3.80339680e-03,
         0.00000000e+00,  -4.91667556e-03,   6.57762680e-03,
         2.82318793e-03,  -1.60611628e-03,   3.55047712e-03,
         5.53747322e-03,   7.27470994e-03,   0.00000000e+00,
         3.24273561e-02,   0.00000000e+00,  -8.65813960e-03,
        -1.81313216e-03,  -9.53143799e-03,   1.18359815e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.91035499e-02,   0.00000000e+00,
         2.65715932e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.67708910e-02,
        -7.75375928e-03,   5.91505612e-03,   1.05890483e-02,
        -2.16196815e-02,   0.00000000e+00,  -9.86117845e-03,
         0.00000000e+00,  -9.34279265e-03,   1.01353768e-02,
         6.12815597e-03,   5.93917756e-03,   0.00000000e+00,
         1.80177587e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.42731719e-02,
         0.00000000e+00,  -1.70638917e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.64472739e-02,   0.00000000e+00,  -8.87691816e-02,
        -2.08049176e-03,   2.78904564e-03,   3.94574248e-02,
         4.94328371e-02,   0.00000000e+00,   5.28763336e-02,
         0.00000000e+00,   2.75510527e-03,  -4.50088404e-04,
        -9.83585240e-03,  -2.95997310e-02,   0.00000000e+00,
         1.39438211e-02,   0.00000000e+00,  -8.14532519e-02,
         4.15855269e-03,   1.48206842e-02,   3.36197919e-02,
        -4.85260260e-02,   0.00000000e+00,   1.90188019e-02,
         0.00000000e+00,   5.35988230e-02,  -1.31714120e-02,
         6.44522829e-03,  -6.21717594e-03,   0.00000000e+00,
        -2.44378736e-02,   0.00000000e+00,  -2.81271567e-03,
        -9.31156489e-02,   2.44099823e-02,  -3.00533102e-02,
        -2.97449495e-04,   1.09099147e-03,   0.00000000e+00,
         7.31892134e-03,   0.00000000e+00,   2.06569823e-02,
        -5.02456490e-04,   5.34043423e-03,   1.84994914e-03,
         0.00000000e+00,   7.68553555e-03,   0.00000000e+00,
        -5.28966129e-03,   9.69219717e-03,   1.63394685e-03,
         7.38205861e-02,  -2.09398795e-02,   6.24600241e-04,
        -5.79299105e-03,   0.00000000e+00,   4.85789929e-03,
         0.00000000e+00,   2.68360392e-02,  -1.12067211e-02,
         4.38773951e-03,   2.41625905e-03,   0.00000000e+00,
         1.05865600e-02,   0.00000000e+00,   4.05141198e-03,
        -7.36984075e-03,  -3.99995821e-02,  -8.22868810e-02,
         1.77229866e-01,  -1.49207054e-01,  -1.19876374e-01,
        -1.64761316e-02,   8.48294146e-02,   3.51401173e-03,
         5.62626923e-03,  -8.19477141e-02,  -5.50759514e-03,
         1.38762892e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.33962968e-01,
         5.25354077e-03,   1.98750132e-02,   1.70462078e-01,
         1.14033151e-01,   0.00000000e+00,   3.29166627e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.04952455e-02,   0.00000000e+00,
        -1.57131639e-01,   7.03214767e-02,   1.96102635e-02,
         8.84173212e-02,  -1.32328495e-01,   0.00000000e+00,
         7.38615337e-02,   0.00000000e+00,  -3.00735466e-02,
        -8.47188734e-03,   4.32288378e-02,  -4.79346086e-02,
         3.38508283e-02,   0.00000000e+00,  -8.94524416e-03,
         0.00000000e+00,  -1.45379892e-02,  -9.53628884e-02,
         1.25513203e-02,   7.03540145e-03,  -4.91230779e-03,
        -2.21004511e-02,   0.00000000e+00,  -1.38089420e-02,
         0.00000000e+00,  -1.28140699e-03,  -4.81048551e-02,
        -1.28486614e-01,   1.78652272e-03,  -4.97251517e-03,
         1.42642468e-02,   6.71910218e-03,   0.00000000e+00,
        -7.89700435e-02,   0.00000000e+00,   3.33374834e-02,
         1.04451684e-02,   3.48297188e-02,  -1.32004847e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.71854085e-02,   0.00000000e+00,
        -9.07107100e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.62958287e-01,
         6.35930908e-03,   8.20233205e-04,  -3.87660433e-02,
         3.77265200e-02,   0.00000000e+00,   2.01144785e-02,
         0.00000000e+00,   3.19820733e-02,  -5.18380119e-02,
        -2.21865088e-02,  -2.27792553e-02,   0.00000000e+00,
        -1.34658454e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.00730272e-02,
         0.00000000e+00,   2.20230027e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.96510613e-02,   0.00000000e+00,   1.99381348e-01,
         2.15696928e-03,  -6.33256261e-03,  -4.37186641e-02,
        -5.42612084e-02,   0.00000000e+00,  -5.07335328e-02,
         0.00000000e+00,  -5.39207901e-03,  -2.04689412e-03,
         2.99462611e-02,   9.38984240e-02,   0.00000000e+00,
        -4.16559967e-02,   0.00000000e+00,   1.82406130e-01,
         5.29264873e-03,  -6.28124659e-03,  -2.81472963e-02,
         4.75609810e-02,   0.00000000e+00,  -2.01616139e-02,
         0.00000000e+00,  -8.26658217e-02,   2.20178260e-02,
        -1.63311718e-02,   2.24381534e-02,   0.00000000e+00,
         7.05249821e-02,   0.00000000e+00,   8.88588741e-03,
         1.99843672e-01,  -1.39344597e-02,   6.99370738e-02,
         4.78659256e-03,   6.67021471e-03,   0.00000000e+00,
        -1.32022175e-02,   0.00000000e+00,  -5.53224818e-02,
        -1.72491431e-02,  -1.67701849e-02,  -3.06560391e-03,
         0.00000000e+00,  -5.92770620e-02,   0.00000000e+00,
         1.55621819e-02,  -3.76980896e-02,  -1.16408919e-01,
        -6.93151342e-02,   1.82971317e-02,   6.48227876e-03,
        -5.37287390e-03,   0.00000000e+00,   1.20378856e-03,
         0.00000000e+00,  -3.66119314e-02,   2.66528809e-02,
        -1.16787004e-02,  -1.01704362e-02,   0.00000000e+00,
        -2.66375773e-02,   0.00000000e+00,  -9.57588130e-03,
        -1.76138871e-03,   1.30719155e-01,   1.65395036e-01,
         6.07151084e-01,  -1.00088383e-02,   5.88379150e-01,
        -2.40001806e-03,  -6.23654751e-03,   5.64383188e-01,
        -1.21624855e-02,  -4.43317986e-03,  -8.51101921e-03,
         5.91204248e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.97080516e-01,
         9.59312484e-03,   9.01817117e-03,   2.95557552e-02,
         1.55122248e-02,   0.00000000e+00,   5.75287086e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.92845185e-02,   0.00000000e+00,
         5.48152891e-01,   1.59763858e-02,  -2.94173128e-02,
         2.55592033e-02,  -1.63896379e-02,   0.00000000e+00,
        -9.84040090e-04,   0.00000000e+00,   5.77040013e-01,
        -2.97258515e-02,  -5.83177925e-02,   4.71492832e-02,
        -7.82621518e-03,   0.00000000e+00,  -2.67194151e-02,
         0.00000000e+00,  -6.49564898e-02,   3.86723054e-01,
         4.55078868e-04,  -1.77343462e-02,   5.76751532e-03,
        -1.14482924e-02,   0.00000000e+00,  -2.07000499e-02,
         0.00000000e+00,   3.59366961e-02,   7.70304276e-02,
         4.39140014e-01,   5.54559854e-03,  -1.14767660e-02,
        -5.53371170e-02,  -5.85265325e-02,   0.00000000e+00,
         4.15674440e-02,   0.00000000e+00,  -5.50504165e-02,
        -1.86740977e-02,  -1.49022662e-02,   5.21512803e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.89501954e-02,   0.00000000e+00,
         9.88161582e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.49971420e-01,
         2.09020649e-02,  -3.95046371e-02,   4.41874701e-02,
        -9.50405026e-04,   0.00000000e+00,   3.14809980e-03,
         0.00000000e+00,  -6.11699439e-02,   6.86310097e-02,
         1.92514274e-02,   4.48560792e-03,   0.00000000e+00,
         5.27312012e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.07710391e-01,
         0.00000000e+00,   5.21836896e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.35171129e-02,   0.00000000e+00,   5.54028406e-01,
         6.95390170e-03,   1.81206537e-03,  -3.30273877e-02,
        -5.43635735e-02,   0.00000000e+00,  -9.60460986e-02,
         0.00000000e+00,  -2.09612500e-03,   2.73391097e-03,
         2.56947499e-02,   2.35321998e-02,   0.00000000e+00,
        -1.31864909e-02,   0.00000000e+00,   5.42559294e-01,
         1.11239657e-02,  -3.52302267e-02,  -5.84716992e-02,
         7.49304627e-02,   0.00000000e+00,  -2.71587793e-02,
         0.00000000e+00,  -4.49464630e-02,   1.43368772e-02,
        -1.18413002e-02,  -1.10429330e-02,   0.00000000e+00,
        -8.63385844e-03,   0.00000000e+00,   1.40913596e-03,
         5.62633130e-01,  -6.22921332e-02,  -4.47669330e-02,
         2.53663464e-03,  -2.98349829e-02,   0.00000000e+00,
         1.44770729e-02,   0.00000000e+00,   2.00583872e-02,
         6.32203154e-02,   9.17677421e-03,  -1.46561204e-02,
         0.00000000e+00,   2.63856959e-03,   0.00000000e+00,
         2.84858050e-03,   1.63394743e-02,   5.57806618e-01,
        -6.61729264e-02,   5.49094939e-02,   1.35537011e-02,
         5.10743807e-04,   0.00000000e+00,  -1.01332699e-02,
         0.00000000e+00,  -3.47984086e-02,   1.45603666e-03,
        -1.26370610e-02,  -2.99500734e-03,   0.00000000e+00,
        -2.20511004e-02,   0.00000000e+00,  -5.46320307e-03,
         9.02285841e-03,   1.95080445e-02,   5.80181814e-01,
        -5.13230384e-02,   4.74507966e-02,   5.28980702e-02,
         3.72251613e-03,  -8.79895514e-02,  -1.37038837e-02,
         6.15138909e-03,   1.40880355e-02,  -1.18592711e-02,
        -4.69162302e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.99035341e-02,
         4.06222722e-02,   2.36561442e-02,  -4.01497748e-02,
        -9.28257417e-03,   0.00000000e+00,  -4.03952234e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.11741534e-02,   0.00000000e+00,
         1.81516748e-02,  -2.33809276e-03,  -7.34930001e-04,
        -1.68334491e-02,   3.93459663e-02,   0.00000000e+00,
        -1.66198795e-02,   0.00000000e+00,  -1.60065179e-03,
        -7.10428527e-03,  -2.03318777e-02,  -3.55118007e-03,
        -1.35056391e-02,   0.00000000e+00,   1.46160294e-02,
         0.00000000e+00,   2.17449084e-02,   5.83002293e-02,
        -4.88282315e-03,   1.17109461e-02,  -2.97949390e-02,
         5.31982466e-03,   0.00000000e+00,   3.11331892e-02,
         0.00000000e+00,   1.16346034e-02,   2.54346323e-02,
         1.05135506e-01,  -2.03508832e-03,   1.40807355e-02,
         3.25448940e-03,   8.01975181e-03,   0.00000000e+00,
         9.99755583e-03,   0.00000000e+00,  -6.82867233e-03,
        -7.49291942e-03,  -2.56570656e-03,  -2.80881434e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.02407352e-03,   0.00000000e+00,
         8.13219479e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.86487532e-02,
        -5.23589583e-03,  -9.16888102e-03,   6.17684940e-03,
        -3.68277558e-03,   0.00000000e+00,  -2.80434829e-03,
         0.00000000e+00,   7.99346767e-03,   1.75767863e-02,
         1.21738444e-02,   1.04080898e-02,   0.00000000e+00,
         2.48824018e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.26914586e-02,
         0.00000000e+00,  -9.08348934e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.03558506e-02,   0.00000000e+00,  -6.11894849e-02,
        -1.03707295e-02,   3.27015431e-03,   1.27968330e-02,
         1.52145395e-02,   0.00000000e+00,   1.18560279e-02,
         0.00000000e+00,   5.95177083e-04,   3.28412059e-03,
        -1.86356341e-02,  -1.52453357e-02,   0.00000000e+00,
         2.59986819e-03,   0.00000000e+00,  -6.24523564e-02,
        -3.84366607e-03,   6.74496383e-03,   1.26348663e-02,
        -1.14854519e-02,   0.00000000e+00,   2.45806619e-03,
         0.00000000e+00,   1.64696946e-02,  -2.70843108e-03,
         8.51908535e-03,  -1.19593352e-02,   0.00000000e+00,
        -1.49286507e-02,   0.00000000e+00,  -9.35823367e-03,
        -6.94409124e-02,   7.45347691e-03,  -1.16940208e-02,
         7.94656132e-03,  -3.09200824e-03,   0.00000000e+00,
        -1.31305924e-02,   0.00000000e+00,   5.63054638e-03,
         1.10126708e-02,   1.53811376e-02,  -2.94791732e-02,
         0.00000000e+00,   4.71371179e-02,   0.00000000e+00,
         1.82739954e-02,   9.43853800e-03,   3.04329873e-02,
         1.60413979e-02,  -6.48338992e-03,  -8.98760802e-03,
         3.25621553e-03,   0.00000000e+00,  -7.50978639e-03,
         0.00000000e+00,   9.85585228e-03,  -6.10582010e-03,
         8.14810598e-03,   2.43484797e-02,   0.00000000e+00,
        -6.25028054e-03,   0.00000000e+00,   1.94098288e-02,
         1.28464725e-02,  -3.24247282e-02,  -4.66217248e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.18547177e-02,  -3.31410896e-02,
        -8.67864250e-03,   3.07296914e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.94647791e-03,   0.00000000e+00,
        -3.98100172e-02,  -7.03578599e-02,  -2.69799197e-03,
        -2.09555548e-02,   0.00000000e+00,   2.26667187e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.16093853e-02,
         0.00000000e+00,   1.60166727e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.13162958e-03,   0.00000000e+00,
         1.40793756e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.42149812e-03,   0.00000000e+00,
         2.12102854e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.49761717e-03,
         0.00000000e+00,   7.81411143e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.19579564e-03,  -2.95668284e-02,  -5.29692727e-03,
        -5.86745712e-03,   0.00000000e+00,   9.22754148e-03,
         0.00000000e+00,   1.49321979e-02,   1.85887123e-02,
         1.96017907e-03,   1.17833760e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.51681272e-03,   0.00000000e+00,
         5.63397694e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.62891301e-03,
         0.00000000e+00,  -1.27196446e-02,   4.32880716e-03,
        -1.11322778e-03,   1.37050883e-03,   0.00000000e+00,
        -7.07506432e-04,   0.00000000e+00,   3.95254820e-04,
         5.20092657e-03,  -2.78021406e-03,   1.55659253e-03,
         0.00000000e+00,  -1.94119972e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.74163830e-04,   0.00000000e+00,
        -4.64881691e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.50144630e-03,
         0.00000000e+00,  -2.64434516e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.78526662e-03,   0.00000000e+00,
         8.92510413e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.44762510e-03,
         0.00000000e+00,  -8.44756911e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.26523612e-03,
         0.00000000e+00,   9.54578896e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.17908672e-02,   0.00000000e+00,   2.81591873e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.91105979e-03,   0.00000000e+00,
         1.16649910e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.05413569e-02,
         0.00000000e+00,   2.27100002e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.04525968e-02,  -6.76269296e-02,  -4.11071735e-02,
        -1.20842730e-02,   4.04958545e-02,   1.21949312e-02,
         3.33835549e-02,  -8.91568176e-02,  -1.33229833e-02,
         7.18638329e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.18696722e-01,
         2.35586917e-02,   3.57127993e-02,   8.06425594e-02,
         7.06544156e-02,   0.00000000e+00,   4.87348289e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.24888132e-02,   0.00000000e+00,
        -6.72846206e-02,  -1.20389317e-02,  -3.00701680e-02,
         4.68090422e-02,  -6.74493879e-02,   0.00000000e+00,
         4.59879325e-02,   0.00000000e+00,   6.68893357e-05,
         2.99187879e-03,   2.67315516e-02,  -2.27277405e-02,
         2.34071631e-02,   0.00000000e+00,  -1.52797175e-02,
         0.00000000e+00,   6.20211528e-03,  -4.90330679e-02,
        -1.70843854e-03,   4.34365885e-03,  -5.46979291e-03,
        -2.02824671e-03,   0.00000000e+00,  -1.12657776e-02,
         0.00000000e+00,   1.55811507e-02,  -1.99898728e-02,
        -5.27008791e-02,   3.03278225e-03,   1.48396176e-02,
         8.22714344e-03,   5.07189181e-03,   0.00000000e+00,
        -3.76959516e-02,   0.00000000e+00,   5.62458665e-03,
        -7.86379328e-03,   1.38202871e-02,  -7.35942542e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.00164183e-02,   0.00000000e+00,
        -3.36207826e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.84055942e-02,
         1.12864464e-02,   6.11121291e-03,  -8.19999679e-03,
         1.85379796e-02,   0.00000000e+00,   8.06315844e-03,
         0.00000000e+00,  -1.08244829e-03,  -2.68648851e-02,
        -6.69667771e-03,  -2.37600549e-02,   0.00000000e+00,
        -7.03698527e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.71989774e-02,
         0.00000000e+00,   1.40803913e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.30509667e-02,   0.00000000e+00,   1.02926512e-01,
        -5.93766071e-03,  -2.11260538e-03,  -1.43648322e-02,
        -2.29850129e-02,   0.00000000e+00,  -2.24302739e-02,
         0.00000000e+00,  -7.69899566e-03,   4.18275935e-03,
         1.43297123e-02,   5.04252538e-02,   0.00000000e+00,
        -2.11476096e-02,   0.00000000e+00,   9.03785187e-02,
         1.10498303e-02,  -1.57235209e-02,  -1.18153728e-02,
         2.09119584e-02,   0.00000000e+00,  -7.31937233e-03,
         0.00000000e+00,  -2.75114473e-02,   1.13106184e-02,
        -4.97170089e-03,   9.32979824e-03,   0.00000000e+00,
         4.06290449e-02,   0.00000000e+00,  -4.31605165e-04,
         1.24491517e-01,  -8.59411742e-03,   2.46233105e-02,
         4.68847983e-04,   3.27427576e-03,   0.00000000e+00,
        -1.45465329e-02,   0.00000000e+00,  -6.42792527e-03,
        -7.91897553e-03,   1.64238274e-03,  -4.07741898e-02,
         0.00000000e+00,  -6.23516101e-02,   0.00000000e+00,
         2.17908613e-02,  -2.15593297e-02,  -3.83736139e-02,
        -2.74854457e-02,   5.24239122e-03,   1.21663400e-02,
        -1.93081162e-02,   0.00000000e+00,   2.57457043e-03,
         0.00000000e+00,  -1.47314489e-02,   1.18612387e-02,
        -3.31320223e-04,   1.41548130e-02,   0.00000000e+00,
        -1.29613850e-02,   0.00000000e+00,   1.41336975e-02,
        -2.99617681e-02,   5.57269378e-02,   7.85876752e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.10655058e-01,  -3.88252973e-02,
        -1.34852267e-02,   1.22178054e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.98220124e-03,   0.00000000e+00,
        -3.18764741e-03,   5.86622918e-02,   1.11147041e-02,
         4.64115876e-03,   0.00000000e+00,  -1.15669441e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.52882008e-02,
         0.00000000e+00,  -1.63028126e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.14164794e-03,   0.00000000e+00,
        -3.52793470e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.96526810e-04,   0.00000000e+00,
        -1.45025912e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.92549045e-03,
         0.00000000e+00,  -6.24398177e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.12805859e-02,   6.45233738e-03,  -3.18662112e-03,
         8.41399045e-03,   0.00000000e+00,  -6.65426524e-03,
         0.00000000e+00,  -5.78421232e-03,  -1.44888363e-02,
         2.24185298e-03,  -4.25950246e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.34707821e-03,   0.00000000e+00,
        -6.54346000e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.27751904e-03,
         0.00000000e+00,  -1.87254900e-02,   1.14971027e-02,
         4.93551639e-03,  -3.49473997e-03,   0.00000000e+00,
        -3.37453991e-04,   0.00000000e+00,  -1.40376658e-02,
         4.85129243e-03,  -3.17210220e-03,  -6.57574199e-03,
         0.00000000e+00,  -1.71054076e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.47790178e-03,   0.00000000e+00,
         1.89489058e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.25739163e-03,
         0.00000000e+00,  -3.60396970e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.50218692e-03,   0.00000000e+00,
        -3.40479837e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.15920055e-03,
         0.00000000e+00,  -1.77034179e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.17216106e-02,
         0.00000000e+00,   6.10015082e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.09542138e-02,   0.00000000e+00,   2.68087640e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.28983422e-02,   0.00000000e+00,
        -8.53473951e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.28690547e-03,
         0.00000000e+00,   8.83237330e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.48757991e-02,  -2.95532501e-04,  -1.21364621e-02,
         5.72222937e-02,   6.29782500e-03,  -1.12472425e-02,
         7.41937347e-02,  -1.11678686e-02,   2.18962740e-03,
         1.29295968e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.30235179e-02,
         5.44325474e-02,  -6.87048478e-02,  -2.61091801e-02,
        -1.17170116e-02,   0.00000000e+00,   1.28591370e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.82748021e-03,   0.00000000e+00,
         1.45839976e-02,   2.79062726e-03,   1.58809529e-02,
         2.06350436e-04,   2.11653482e-02,   0.00000000e+00,
         6.66455827e-03,   0.00000000e+00,  -3.98263126e-03,
         2.15534506e-03,  -8.81376049e-04,   1.22169506e-02,
        -7.74050277e-03,   0.00000000e+00,  -7.96979285e-03,
         0.00000000e+00,  -1.52112217e-02,  -1.69226540e-02,
        -4.25182901e-03,  -1.69688446e-03,   2.27311183e-02,
        -4.70673480e-03,   0.00000000e+00,  -8.49269682e-03,
         0.00000000e+00,  -1.50738898e-02,  -1.00177341e-03,
        -4.07496403e-02,  -9.62849330e-03,  -1.29910505e-03,
         4.65669922e-03,  -8.32360189e-03,   0.00000000e+00,
         1.36867097e-02,   0.00000000e+00,  -1.57149423e-03,
         1.28345694e-02,  -7.46670342e-03,   2.23968288e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.75059951e-04,   0.00000000e+00,
         7.43369659e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.46010050e-02,
         2.78607218e-03,  -4.29004329e-03,  -2.87127207e-03,
         4.90645102e-03,   0.00000000e+00,   7.06382473e-03,
         0.00000000e+00,  -3.76403792e-04,  -7.01563445e-04,
        -7.42105848e-03,  -5.06648242e-03,   0.00000000e+00,
         2.59956576e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.79258032e-03,
         0.00000000e+00,  -1.49308793e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.40324656e-03,   0.00000000e+00,  -1.10492519e-02,
        -1.64795463e-02,   1.10843400e-02,   2.54813401e-03,
         2.11789991e-03,   0.00000000e+00,   4.59156344e-03,
         0.00000000e+00,  -1.02303276e-02,   4.94685820e-03,
        -2.25993113e-03,  -1.90322026e-02,   0.00000000e+00,
        -9.35008528e-03,   0.00000000e+00,  -1.52574236e-02,
         8.65352527e-04,   1.12209393e-03,   4.18844375e-03,
         3.76963007e-03,   0.00000000e+00,   5.58264062e-03,
         0.00000000e+00,   4.11755419e-03,  -3.15564203e-03,
        -1.40308374e-03,   3.11799959e-03,   0.00000000e+00,
        -6.20755940e-03,   0.00000000e+00,  -1.80378912e-02,
        -9.36867760e-03,  -9.65066965e-04,  -4.56724188e-03,
        -9.49810406e-03,  -9.57935164e-03,   0.00000000e+00,
        -4.34166927e-03,   0.00000000e+00,  -5.64296145e-04,
         1.97252534e-04,  -1.78227284e-03,   4.80762817e-02,
         0.00000000e+00,  -8.30983196e-03,   0.00000000e+00,
         2.30518729e-02,  -4.97135486e-03,   5.56952979e-04,
         3.49866054e-03,   1.59178854e-03,  -5.97710662e-03,
        -6.04158109e-03,   0.00000000e+00,  -9.55114848e-03,
         0.00000000e+00,   2.36549182e-03,  -2.41351488e-03,
         6.99092463e-03,   8.42510633e-03,   0.00000000e+00,
        -8.31424454e-03,   0.00000000e+00,   8.51058682e-02,
        -5.02472729e-03,   2.32514664e-03,  -1.26358107e-02,
         6.79950678e-02,   3.24942871e-02,   3.71756849e-02,
         5.81140451e-02,  -1.57208966e-02,   3.62032823e-02,
        -6.03903596e-02,   1.14822250e-02,   1.56411148e-02,
         2.10189045e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.13843451e-02,
         3.41755720e-02,  -7.82490244e-03,  -1.81374675e-02,
        -2.18547061e-04,   0.00000000e+00,   3.60234748e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.21748280e-02,   0.00000000e+00,
         6.47318618e-02,   3.08133758e-02,  -6.32924430e-02,
        -1.37681270e-02,   1.19578518e-02,   0.00000000e+00,
        -1.20040740e-03,   0.00000000e+00,   7.22952434e-02,
        -1.24421431e-02,   1.09619307e-03,   1.80690005e-02,
         2.99155679e-03,   0.00000000e+00,  -1.40870783e-02,
         0.00000000e+00,  -1.09831294e-02,   1.91777698e-02,
        -6.67172698e-04,  -1.17376873e-02,   1.39802429e-02,
         5.66385643e-03,   0.00000000e+00,  -1.20311587e-02,
         0.00000000e+00,   1.34330924e-02,   6.84635164e-03,
         1.64698448e-02,   1.20355677e-03,   5.13676422e-03,
        -5.93527751e-03,  -3.46423720e-03,   0.00000000e+00,
         1.34695551e-02,   0.00000000e+00,  -1.74974383e-02,
        -8.14486242e-03,  -6.07026391e-03,   5.40038201e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.29698795e-03,   0.00000000e+00,
         2.65796711e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.91205470e-02,
         1.83117331e-03,  -6.75706202e-04,   1.17398957e-02,
        -6.45559487e-03,   0.00000000e+00,  -4.67013937e-03,
         0.00000000e+00,  -2.64651409e-02,   9.50231279e-03,
         4.41581958e-03,  -1.06346405e-02,   0.00000000e+00,
         4.60777545e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.59314042e-03,
         0.00000000e+00,   1.18722412e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.38922235e-03,   0.00000000e+00,   2.32727335e-02,
        -1.44604229e-03,   1.06501138e-03,  -1.25386213e-04,
        -6.91090338e-03,   0.00000000e+00,  -1.26155767e-02,
         0.00000000e+00,  -3.03336193e-03,   3.68699069e-03,
         5.91317642e-03,  -3.69947028e-03,   0.00000000e+00,
         2.41892319e-04,   0.00000000e+00,   2.00429846e-02,
        -1.76268915e-02,   2.98139868e-03,  -9.22366198e-04,
         3.17810980e-03,   0.00000000e+00,  -9.39179251e-04,
         0.00000000e+00,  -9.59771781e-03,   7.59788343e-03,
        -2.96712681e-03,  -1.20369051e-02,   0.00000000e+00,
        -3.19823551e-02,   0.00000000e+00,  -8.40572055e-03,
        -9.61358656e-03,  -1.15635285e-02,  -1.47375265e-02,
        -3.69930261e-03,  -2.54955365e-03,   0.00000000e+00,
        -1.23534341e-03,   0.00000000e+00,   9.29286560e-03,
         1.19729550e-02,   3.15512978e-03,  -1.64975685e-02,
         0.00000000e+00,  -1.92918238e-02,   0.00000000e+00,
         2.58864506e-03,   5.02295824e-02,   6.29432316e-02,
        -6.13681025e-03,   3.69646781e-04,  -8.04414460e-03,
         1.24914897e-02,   0.00000000e+00,  -8.93266561e-03,
         0.00000000e+00,  -3.16322590e-02,   5.62032646e-03,
        -5.08419274e-03,   7.94192866e-03,   0.00000000e+00,
         1.14624447e-02,   0.00000000e+00,   1.07193003e-02,
         5.83560461e-02,  -6.91962675e-03,   5.92987109e-02,
        -6.80187375e-03,   1.76385882e-02,   5.56935372e-02,
        -1.47783583e-02,  -1.33063308e-02,   1.82724377e-02,
         1.30987379e-02,   1.21976347e-02,  -5.99786194e-03,
         1.15410013e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.31831973e-03,
        -7.92290068e-03,  -8.85793231e-04,  -1.32016818e-02,
        -1.85695099e-02,   0.00000000e+00,   1.78371646e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.08411038e-02,   0.00000000e+00,
         4.97849367e-02,  -1.98957379e-02,   6.17500494e-03,
        -2.74937151e-03,   2.07237675e-02,   0.00000000e+00,
        -1.99012548e-02,   0.00000000e+00,   2.64363316e-02,
        -4.96839587e-03,  -3.64682598e-02,   2.39574989e-02,
        -1.26082898e-02,   0.00000000e+00,  -4.45438761e-03,
         0.00000000e+00,  -1.10351109e-02,   8.37261993e-03,
        -8.22701203e-03,  -2.25134841e-02,   1.50527839e-02,
        -2.71435905e-03,   0.00000000e+00,  -7.47128642e-03,
         0.00000000e+00,  -2.15936318e-03,   8.80343229e-03,
        -6.65541690e-03,   2.69413414e-03,   2.44264497e-03,
        -1.07728768e-02,  -1.22251198e-02,   0.00000000e+00,
         2.27012588e-02,   0.00000000e+00,  -1.74388189e-02,
        -3.82583766e-03,  -1.21713126e-02,   4.25703661e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.89734996e-03,   0.00000000e+00,
         3.66409823e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.49421740e-02,
        -2.09166187e-03,  -1.70685222e-02,   1.87510673e-02,
        -1.19443538e-02,   0.00000000e+00,  -2.37163341e-03,
         0.00000000e+00,  -1.29799757e-02,   2.52008449e-02,
         8.11695134e-03,   1.02367297e-02,   0.00000000e+00,
         5.05843534e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.95385511e-03,
         0.00000000e+00,   2.15250685e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.41155983e-02,   0.00000000e+00,  -4.69034355e-03,
         9.46407634e-04,   1.55240866e-03,   5.40820019e-03,
         7.69459144e-03,   0.00000000e+00,   1.34527145e-03,
         0.00000000e+00,   3.35776482e-03,   7.81400534e-04,
         2.95618843e-03,  -1.18129157e-02,   0.00000000e+00,
         4.42903832e-03,   0.00000000e+00,  -3.65326590e-03,
         3.11176887e-03,  -2.89642072e-03,   1.06002059e-04,
        -5.63930868e-04,   0.00000000e+00,  -8.52896563e-04,
         0.00000000e+00,   1.59740797e-02,  -5.26314823e-03,
         4.23305155e-04,  -4.64425841e-03,   0.00000000e+00,
        -5.94456424e-03,   0.00000000e+00,   2.03069758e-03,
         5.63374951e-03,  -6.44829212e-03,  -2.99471412e-02,
         7.87063662e-03,  -5.47967255e-03,   0.00000000e+00,
         1.46963886e-03,   0.00000000e+00,   1.23624065e-02,
         2.13597367e-02,   1.12536311e-02,  -1.11711371e-03,
         0.00000000e+00,   2.42656275e-02,   0.00000000e+00,
        -2.18387972e-03,  -5.27464450e-03,   4.64689625e-02,
         9.47751927e-03,   7.05270302e-03,   1.44762776e-03,
        -8.37209308e-04,   0.00000000e+00,   5.75640570e-04,
         0.00000000e+00,   8.85065120e-03,  -9.71244691e-03,
        -3.56700610e-03,  -7.09827535e-04,   0.00000000e+00,
        -5.45081110e-03,   0.00000000e+00,  -1.99364184e-03,
        -1.42589833e-02,  -1.99806552e-02,  -7.00975453e-03,
         1.84447457e-02,   1.11217915e-03,   1.07129213e-02,
         3.07494335e-03,   1.28435991e-02,   4.39815235e-04,
        -8.91686449e-03,   3.49457605e-03,   1.06508920e-03,
         1.61039641e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.60071347e-02,
        -4.73461670e-03,  -8.48272987e-03,   1.26316159e-02,
        -4.67349272e-03,   0.00000000e+00,   1.04984572e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.39827996e-03,   0.00000000e+00,
         2.92597467e-02,  -6.12943011e-04,  -1.01903369e-02,
         5.53709366e-03,   3.21523445e-03,   0.00000000e+00,
        -9.57155076e-03,   0.00000000e+00,   2.35531361e-02,
        -6.91182109e-03,  -2.12802446e-02,   1.86560148e-02,
        -4.01311379e-03,   0.00000000e+00,  -9.42104075e-03,
         0.00000000e+00,  -1.35872172e-02,  -1.62540490e-02,
        -9.16045014e-03,  -3.92929749e-02,   3.35803064e-02,
        -6.81705475e-03,   0.00000000e+00,  -2.25072162e-02,
         0.00000000e+00,  -7.68393489e-03,  -1.60217065e-02,
        -7.48564166e-02,   4.09003322e-03,   2.69038413e-03,
        -4.14430711e-03,  -5.88706409e-03,   0.00000000e+00,
         4.98324349e-03,   0.00000000e+00,  -9.64287832e-03,
        -2.46356527e-03,  -8.94332812e-03,   2.07907512e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.01315872e-03,   0.00000000e+00,
         1.58157489e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.21757886e-02,
        -7.43375238e-04,  -7.79822433e-03,   9.19522224e-03,
        -4.77869473e-03,   0.00000000e+00,  -2.14371395e-03,
         0.00000000e+00,  -8.74758184e-03,   9.70635695e-03,
        -2.66996801e-03,   5.15571751e-03,   0.00000000e+00,
         2.32303359e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.38264784e-03,
         0.00000000e+00,   4.46479498e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.04890200e-03,   0.00000000e+00,   1.46010939e-02,
         4.57410939e-03,   5.49414736e-04,  -4.83900014e-03,
        -2.33242229e-03,   0.00000000e+00,  -4.38207128e-03,
         0.00000000e+00,   2.56056847e-03,   2.25725121e-03,
         1.20299024e-02,   4.20109108e-04,   0.00000000e+00,
         3.27928213e-04,   0.00000000e+00,   1.17617744e-02,
        -2.36950162e-03,  -2.50555915e-03,  -1.93616189e-03,
         3.80973863e-03,   0.00000000e+00,  -3.67130083e-03,
         0.00000000e+00,  -4.58207727e-04,  -1.89279931e-04,
        -3.78307196e-03,  -3.24989874e-03,   0.00000000e+00,
        -4.44234646e-03,   0.00000000e+00,   2.21608200e-03,
         1.37417582e-02,  -7.10499687e-03,  -1.32468058e-02,
         6.12561837e-03,   5.93915718e-04,   0.00000000e+00,
        -2.04468071e-03,   0.00000000e+00,   7.05345369e-03,
         1.37165038e-02,   3.18200152e-03,  -2.21706263e-03,
         0.00000000e+00,   4.05303739e-03,   0.00000000e+00,
        -2.69765870e-03,   4.48363804e-03,   2.39425020e-02,
        -3.22761540e-03,   4.88575093e-03,   1.54558254e-03,
         3.65175128e-03,   0.00000000e+00,   1.58521140e-03,
         0.00000000e+00,  -6.07853872e-03,  -3.47391764e-03,
        -8.10544386e-03,  -2.10968434e-03,   0.00000000e+00,
        -9.56670778e-04,   0.00000000e+00,  -3.68159077e-03,
         3.39752419e-03,  -1.84847145e-03,   1.61177989e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.04833930e-02,   8.47097110e-03,
         3.21539285e-03,  -1.50862006e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.45712859e-04,   0.00000000e+00,
         9.26675313e-03,   1.36857395e-02,   1.84897498e-03,
         4.17266196e-03,   0.00000000e+00,  -5.39588617e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.01822223e-03,
         0.00000000e+00,  -7.21409379e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.67527983e-04,   0.00000000e+00,
        -8.68487936e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.81053355e-04,   0.00000000e+00,
        -1.73108453e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.10758252e-03,
         0.00000000e+00,  -4.51557649e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.55342946e-03,   2.72745682e-02,   1.36804436e-03,
         6.30299131e-03,   0.00000000e+00,  -7.21820886e-03,
         0.00000000e+00,  -6.16111091e-03,  -4.13514870e-03,
        -8.75222529e-03,  -3.97164083e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.03304132e-03,   0.00000000e+00,
        -3.65306961e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.26767623e-03,
         0.00000000e+00,   7.75040940e-03,   2.94958330e-03,
        -8.64952548e-04,   2.32163907e-03,   0.00000000e+00,
        -1.48876417e-03,   0.00000000e+00,   5.70791346e-04,
        -1.16943221e-03,  -1.59253838e-03,   5.54037984e-04,
         0.00000000e+00,   2.51740880e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.06411072e-04,   0.00000000e+00,
         2.37428352e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.49296644e-03,
         0.00000000e+00,   1.31521945e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.16298285e-03,   0.00000000e+00,
        -2.62241581e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.78608508e-03,
         0.00000000e+00,   1.76986112e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.81491748e-03,
         0.00000000e+00,  -2.73422691e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.58684575e-02,   0.00000000e+00,  -6.50302876e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.17961092e-03,   0.00000000e+00,
         7.47845730e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.52192869e-03,
         0.00000000e+00,  -9.20112778e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.63108195e-02,  -4.64487762e-03,   2.07900240e-02,
        -2.83603640e-03,   9.86853148e-03,   2.43402692e-02,
        -4.45757023e-03,   9.53591384e-03,   4.68178043e-03,
         2.77980067e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.95773980e-02,
        -1.13070019e-02,  -8.52803297e-03,   2.51007514e-03,
        -3.79535154e-03,   0.00000000e+00,   3.39337562e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.97636590e-03,   0.00000000e+00,
         2.55723139e-02,   6.28758060e-03,   6.06721450e-03,
         1.83057640e-03,  -3.26511931e-03,   0.00000000e+00,
        -1.13705291e-03,   0.00000000e+00,   1.57940136e-02,
        -1.48316057e-03,  -4.49761657e-03,   4.28095710e-03,
        -3.50728440e-03,   0.00000000e+00,   1.25213993e-03,
         0.00000000e+00,  -1.12954686e-02,   9.76996134e-03,
         2.41969324e-03,  -1.45891842e-03,   5.10297734e-03,
        -1.33754325e-03,   0.00000000e+00,  -6.27498213e-03,
         0.00000000e+00,  -1.05526623e-03,   2.02817032e-03,
         1.35597743e-03,  -4.79849338e-03,  -2.34295064e-02,
        -1.03392759e-02,  -1.59002271e-02,   0.00000000e+00,
         1.65768193e-02,   0.00000000e+00,  -7.72886368e-03,
         1.41989754e-03,   1.05407786e-03,   2.80007728e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.04448450e-03,   0.00000000e+00,
         1.66143637e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.93359423e-02,
        -1.13420682e-03,  -1.26473883e-02,   6.87469441e-03,
        -6.60466527e-03,   0.00000000e+00,   2.85573701e-03,
         0.00000000e+00,  -1.42282052e-02,   9.62179331e-03,
         6.88356436e-03,   1.97078375e-03,   0.00000000e+00,
         1.74716441e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.11744129e-02,
         0.00000000e+00,   7.11423421e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.63508155e-03,   0.00000000e+00,   2.63133930e-02,
         7.98770851e-03,   1.20822540e-03,  -3.33157878e-03,
        -2.69489446e-03,   0.00000000e+00,  -1.39562354e-02,
         0.00000000e+00,   2.09108136e-03,  -4.68519735e-04,
         4.89178702e-03,   2.01051326e-03,   0.00000000e+00,
        -2.00244100e-03,   0.00000000e+00,   2.60598835e-02,
         2.70245364e-03,  -1.25311601e-03,  -8.86886874e-03,
         7.53352210e-03,   0.00000000e+00,  -3.49502868e-03,
         0.00000000e+00,  -6.03847842e-03,  -6.13638589e-04,
        -3.34322893e-03,   7.46938228e-04,   0.00000000e+00,
        -2.31286794e-03,   0.00000000e+00,   1.91287148e-03,
         2.35346658e-02,  -5.35185670e-03,  -6.19576464e-03,
        -3.38392409e-03,  -1.23341619e-02,   0.00000000e+00,
         1.89982130e-02,   0.00000000e+00,  -1.37180634e-02,
         5.66912517e-03,  -2.92287764e-03,   1.29563160e-02,
         0.00000000e+00,   2.38564170e-03,   0.00000000e+00,
        -6.49360686e-03,  -1.33879027e-03,   2.09999555e-02,
        -7.98158499e-03,   5.36288402e-03,   6.46310790e-03,
         7.00035136e-03,   0.00000000e+00,  -1.37248177e-03,
         0.00000000e+00,   1.03893057e-03,  -1.15346748e-03,
        -1.25622029e-03,  -8.40959593e-03,   0.00000000e+00,
        -4.19386337e-03,   0.00000000e+00,  -7.71280083e-03,
         1.50742517e-03,   5.97946796e-04,   2.77300764e-02,
         3.06705894e-02,  -2.89655102e-03,   3.43981797e-02,
        -2.24107000e-03,  -9.88488730e-03,   2.25963993e-02,
         7.90869380e-03,  -3.36567983e-03,  -1.12265761e-03,
         3.32122419e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.44067291e-02,
         8.86864763e-03,   1.77261057e-03,   4.74312913e-03,
         5.90051026e-03,   0.00000000e+00,   2.64963561e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.00350092e-03,   0.00000000e+00,
         2.31154298e-02,   3.21936034e-03,  -2.67882200e-03,
         1.00417787e-02,  -2.84101027e-03,   0.00000000e+00,
        -1.87178269e-03,   0.00000000e+00,   2.03814154e-02,
        -7.36906145e-03,  -1.88474612e-02,   1.12550914e-02,
        -4.09268589e-03,   0.00000000e+00,  -5.86372695e-03,
         0.00000000e+00,  -6.91764608e-03,   1.17048290e-02,
        -3.53660658e-03,  -9.29733247e-03,   6.29597747e-03,
        -2.66782378e-03,   0.00000000e+00,  -5.97840386e-03,
         0.00000000e+00,   4.68237045e-03,   8.14610756e-03,
         2.83848816e-03,   8.47077227e-04,   3.33257704e-03,
        -5.97624575e-03,  -9.36356673e-03,   0.00000000e+00,
         6.05210638e-03,   0.00000000e+00,  -1.38995543e-02,
        -1.63188335e-03,  -1.83693070e-03,   2.58333677e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.91750850e-03,   0.00000000e+00,
         1.82755091e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.01461462e-02,
        -2.09283775e-03,  -2.78125088e-02,   1.16772967e-02,
        -5.92185561e-03,   0.00000000e+00,   5.26349894e-03,
         0.00000000e+00,  -1.25678346e-02,   1.48336780e-02,
         9.15179516e-03,  -4.26082470e-03,   0.00000000e+00,
         2.56914292e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.59700353e-02,
         0.00000000e+00,   9.02900075e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.56307039e-03,   0.00000000e+00,   3.06054660e-02,
        -6.38361008e-03,   4.09208453e-04,  -5.10678131e-03,
        -9.16935901e-03,   0.00000000e+00,  -1.27822890e-02,
         0.00000000e+00,  -6.32060102e-04,   6.91711782e-04,
         4.63040426e-03,   1.57033737e-03,   0.00000000e+00,
        -4.25429097e-03,   0.00000000e+00,   2.81785640e-02,
         4.01926116e-03,  -4.46481943e-03,  -7.96854232e-03,
         1.44323118e-02,   0.00000000e+00,  -5.14236179e-03,
         0.00000000e+00,  -6.92667407e-03,   1.69072892e-03,
        -2.22230285e-03,  -3.58482882e-03,   0.00000000e+00,
         7.97885771e-04,   0.00000000e+00,  -1.60216665e-03,
         2.88071427e-02,  -1.22130899e-02,  -1.83381260e-02,
         1.35863931e-02,  -1.14857652e-02,   0.00000000e+00,
        -5.44275574e-03,   0.00000000e+00,  -5.60371011e-03,
         1.96269510e-02,   1.16734246e-02,  -5.64460983e-03,
         0.00000000e+00,   1.05752323e-02,   0.00000000e+00,
         4.92803833e-03,  -2.18742344e-03,   3.00655715e-02,
        -1.05132045e-02,   1.05722131e-02,  -4.64413686e-03,
        -4.41284360e-03,   0.00000000e+00,  -3.79497123e-03,
         0.00000000e+00,  -2.21154239e-03,  -4.15061166e-03,
        -3.66416066e-03,   9.44376871e-04,   0.00000000e+00,
        -9.74699995e-03,   0.00000000e+00,   6.46516969e-03,
        -1.24183819e-03,   1.83081007e-03,   3.08117929e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.18225857e-02,   1.20035087e-02,
         3.38134335e-03,  -1.91912577e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.12567295e-04,   0.00000000e+00,
         8.52289038e-03,   2.14230225e-03,  -6.59634510e-04,
         1.91885476e-03,   0.00000000e+00,  -1.35602052e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.14278543e-03,
         0.00000000e+00,   1.98206624e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.81746989e-03,   0.00000000e+00,
         2.00821121e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.44504954e-03,   0.00000000e+00,
        -1.83981392e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.21624090e-03,
         0.00000000e+00,   7.25737969e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.86768162e-03,  -6.64004642e-04,   9.43055072e-04,
        -1.57688344e-03,   0.00000000e+00,   8.31547341e-04,
         0.00000000e+00,  -1.14330747e-03,  -1.27020555e-03,
         2.24315314e-03,  -8.88856716e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.16876632e-03,   0.00000000e+00,
         1.78152205e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.43092434e-04,
         0.00000000e+00,   3.04146383e-02,  -1.61742107e-02,
        -5.19125619e-03,   3.64486727e-03,   0.00000000e+00,
        -1.69389116e-04,   0.00000000e+00,   5.10482884e-03,
        -2.20603834e-03,   1.73215849e-03,   6.05351077e-04,
         0.00000000e+00,   2.42963351e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.91403400e-03,   0.00000000e+00,
         4.28602693e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.41280185e-04,
         0.00000000e+00,   7.73046154e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.50579172e-03,   0.00000000e+00,
         2.82515809e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.89622456e-03,
         0.00000000e+00,   1.77006130e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.70217004e-02,
         0.00000000e+00,   3.01611273e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.57643282e-03,   0.00000000e+00,  -9.54032880e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.26465210e-02,   0.00000000e+00,
        -1.17005315e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.11321341e-03,
         0.00000000e+00,  -1.53824739e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.89654491e-03,  -5.35199143e-03,  -8.33791215e-03,
        -8.66092491e-03,   6.43490782e-03,   6.46987065e-04,
        -1.33254246e-02,   3.66541580e-03,   1.69557839e-03,
        -1.05177247e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.00578669e-03,
        -1.42512746e-02,   8.32653084e-03,   6.14308692e-03,
         2.95657167e-03,   0.00000000e+00,  -1.85206325e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.43299268e-03,   0.00000000e+00,
        -1.06190943e-02,   3.27964201e-03,   7.27145872e-04,
         7.59604006e-04,  -9.65501348e-03,   0.00000000e+00,
        -1.85261123e-03,   0.00000000e+00,  -5.55594051e-03,
         3.14292676e-06,   2.61781128e-03,   2.01993650e-04,
         4.81811870e-03,   0.00000000e+00,   9.76626375e-04,
         0.00000000e+00,   6.02478266e-04,  -6.65758921e-03,
         5.42095193e-03,   1.27281030e-03,  -3.72472683e-03,
        -1.43683194e-03,   0.00000000e+00,  -2.26225850e-04,
         0.00000000e+00,   1.69128103e-03,   7.34576575e-04,
        -1.74454672e-03,   1.07515865e-02,   7.38384442e-04,
         1.49459991e-03,   3.24262723e-03,   0.00000000e+00,
        -9.55397836e-03,   0.00000000e+00,   4.67441991e-03,
         1.60050436e-03,   2.49958663e-03,  -6.06654442e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.18977538e-04,   0.00000000e+00,
        -8.37312039e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.22539766e-02,
        -6.05406079e-03,   1.28069111e-03,  -6.72471430e-03,
        -2.97954952e-03,   0.00000000e+00,  -2.66160087e-03,
         0.00000000e+00,   3.61236242e-03,  -4.08135579e-03,
        -1.72329549e-03,  -3.41068293e-03,   0.00000000e+00,
        -8.66995899e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.86011478e-03,
         0.00000000e+00,  -2.01806335e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.84339996e-03,   0.00000000e+00,   4.25047901e-03,
         2.75898682e-02,  -1.58524858e-02,  -8.88566161e-03,
        -6.20776777e-04,   0.00000000e+00,  -1.87307447e-03,
         0.00000000e+00,   4.37001469e-03,  -2.35630414e-03,
         7.75628368e-04,   3.36467049e-03,   0.00000000e+00,
         1.48776521e-03,   0.00000000e+00,   5.92145689e-03,
        -1.75826952e-03,   1.06473151e-03,  -2.67295829e-03,
        -3.32222266e-03,   0.00000000e+00,  -6.54043353e-03,
         0.00000000e+00,  -4.32036611e-03,   1.96318498e-03,
         1.19668232e-03,   3.23276875e-03,   0.00000000e+00,
         1.52684046e-03,   0.00000000e+00,   5.41131628e-04,
         3.63073875e-03,   2.02622855e-03,   3.12768689e-03,
         9.20872867e-03,   1.22925085e-02,   0.00000000e+00,
         5.28879964e-03,   0.00000000e+00,  -1.63565048e-03,
        -3.31080673e-04,  -1.07495024e-03,  -2.47238077e-03,
         0.00000000e+00,  -9.94456425e-04,   0.00000000e+00,
        -6.97979334e-03,  -1.17250655e-03,  -1.02630084e-02,
        -3.83680276e-03,  -5.55439870e-05,   1.16171451e-02,
         2.02300300e-02,   0.00000000e+00,   2.37221328e-02,
         0.00000000e+00,  -1.74602022e-03,   3.00539847e-04,
        -3.58148932e-03,  -6.28365093e-03,   0.00000000e+00,
         2.98454575e-03,   0.00000000e+00,  -1.36448809e-02,
         1.50271543e-03,   4.76485852e-03,   3.20280046e-03,
         2.27624084e-02,  -4.07473171e-03,   3.22730636e-02,
        -1.29279196e-02,   1.06046129e-02,   3.12427915e-02,
         1.54346158e-02,  -1.10113423e-02,  -2.73820138e-03,
         3.06009164e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.01029257e-02,
        -8.74103807e-03,   4.95804134e-03,   2.30390906e-03,
         1.27587720e-03,   0.00000000e+00,   2.91355907e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.67243813e-03,   0.00000000e+00,
         2.91828483e-02,  -2.01353033e-02,  -1.99121357e-03,
         1.12881868e-03,  -5.97959267e-04,   0.00000000e+00,
        -8.74566799e-04,   0.00000000e+00,   2.27782977e-02,
         2.65056229e-03,  -4.52797574e-03,   6.12385999e-03,
        -1.80216620e-04,   0.00000000e+00,  -3.88062687e-03,
         0.00000000e+00,  -1.19001652e-03,   1.07981050e-02,
        -2.14278296e-03,  -2.83187209e-03,   2.68311866e-03,
        -5.54037840e-04,   0.00000000e+00,  -6.36083372e-03,
         0.00000000e+00,   2.38917754e-03,   4.59477202e-03,
         1.16133653e-02,   4.01900369e-03,  -8.55208103e-05,
        -9.08698912e-03,  -6.34804098e-03,   0.00000000e+00,
         2.07994971e-03,   0.00000000e+00,  -7.53856650e-03,
        -2.61663649e-03,  -3.17211948e-03,   2.65816756e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.90555613e-03,   0.00000000e+00,
         1.19358222e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.17879882e-02,
         8.19213860e-03,  -5.57148044e-03,   1.89796614e-03,
         5.98009957e-03,   0.00000000e+00,  -2.16235806e-03,
         0.00000000e+00,  -1.25925453e-02,   6.12404912e-03,
         1.39793391e-03,  -2.45807707e-03,   0.00000000e+00,
         2.50597986e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.15947125e-02,
         0.00000000e+00,   8.80755774e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.29013785e-03,   0.00000000e+00,   2.65246060e-02,
         4.87401681e-03,  -2.54171521e-03,  -9.37450962e-03,
        -1.05801837e-02,   0.00000000e+00,  -1.77474026e-02,
         0.00000000e+00,  -1.63227348e-03,   1.52631840e-03,
         4.08943810e-03,   2.53030170e-03,   0.00000000e+00,
        -7.29112585e-04,   0.00000000e+00,   2.49293801e-02,
         2.85692668e-02,  -2.35181038e-02,  -2.05541456e-02,
         2.33381512e-02,   0.00000000e+00,  -8.17155735e-03,
         0.00000000e+00,  -1.00033206e-02,   1.86306062e-03,
        -4.27736352e-05,  -4.32263761e-04,   0.00000000e+00,
         6.27174067e-04,   0.00000000e+00,   1.14265115e-03,
         3.24477397e-02,  -1.01648591e-02,  -2.85833339e-03,
         6.87913850e-03,  -1.03559971e-02,   0.00000000e+00,
         4.80986470e-03,   0.00000000e+00,   1.50415661e-02,
         2.05041789e-03,   2.70625451e-03,  -3.45538475e-03,
         0.00000000e+00,  -6.17721597e-03,   0.00000000e+00,
        -1.45502998e-03,  -5.12947626e-03,   2.77613891e-02,
        -7.76085420e-03,   1.26672963e-02,   1.71053487e-02,
        -1.72258778e-02,   0.00000000e+00,   9.38563068e-03,
         0.00000000e+00,   1.27312055e-02,  -3.89864066e-03,
         4.55141232e-04,  -1.24519747e-03,   0.00000000e+00,
        -3.38833563e-03,   0.00000000e+00,  -2.50038185e-03,
        -2.51412300e-02,  -9.44507065e-04,   2.10374898e-02,
        -2.97101542e-02,   4.91207827e-02,   6.28857571e-02,
         1.06224696e-02,  -1.60423853e-02,   2.51900153e-02,
        -1.19567160e-03,   2.47593150e-02,   1.23507806e-03,
        -1.80377612e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.24141033e-02,
        -3.79976204e-03,  -1.27719428e-02,  -5.57348003e-02,
        -4.10322552e-02,   0.00000000e+00,   1.73898719e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.83535687e-02,   0.00000000e+00,
         7.27279461e-02,  -3.05857917e-02,  -1.79472456e-02,
        -2.80237059e-02,   4.28975098e-02,   0.00000000e+00,
        -2.58593733e-02,   0.00000000e+00,   4.15199466e-02,
        -4.63648920e-04,  -3.07450309e-02,   3.41926937e-02,
        -1.36204453e-02,   0.00000000e+00,  -7.35749830e-03,
         0.00000000e+00,  -7.82289187e-03,   3.22734434e-02,
        -6.64534287e-03,  -1.53152816e-02,   1.97455379e-02,
         8.33934186e-03,   0.00000000e+00,  -1.07575726e-02,
         0.00000000e+00,   3.59327888e-03,   2.29728191e-02,
         2.20206894e-02,   2.52530319e-03,   2.00458835e-03,
        -2.03773574e-02,  -2.20874931e-02,   0.00000000e+00,
         5.95992684e-02,   0.00000000e+00,  -3.56093101e-02,
        -7.18241138e-03,  -2.31447857e-02,   8.07422210e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.05421950e-03,   0.00000000e+00,
         8.11172023e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.88595718e-02,
        -3.73949551e-03,  -1.57160322e-02,   3.87328770e-02,
        -3.13215660e-02,   0.00000000e+00,  -8.65031714e-03,
         0.00000000e+00,  -4.11002676e-02,   3.90508689e-02,
         1.93698298e-02,   5.90047719e-03,   0.00000000e+00,
         8.35497253e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.34808368e-02,
         0.00000000e+00,   3.56244398e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.27887693e-02,   0.00000000e+00,  -4.62660911e-02,
         2.51877220e-03,   2.29063754e-03,   2.67738894e-02,
         2.79972825e-02,   0.00000000e+00,   1.63201220e-02,
         0.00000000e+00,   3.53579118e-03,   2.39107690e-03,
        -2.00001489e-03,  -3.44481123e-02,   0.00000000e+00,
         1.45201341e-02,   0.00000000e+00,  -4.02335672e-02,
        -8.89277931e-03,   5.23715069e-03,   1.23282193e-02,
        -2.13528410e-02,   0.00000000e+00,   8.95591500e-03,
         0.00000000e+00,   4.32739148e-02,  -1.10848931e-02,
         3.41381044e-03,  -9.41906200e-03,   0.00000000e+00,
        -3.02263191e-02,   0.00000000e+00,  -2.25673480e-03,
        -3.75872082e-02,  -8.05394627e-03,  -6.87742522e-02,
         2.12959229e-03,  -7.20527182e-03,   0.00000000e+00,
         1.12943070e-02,   0.00000000e+00,   2.66995200e-02,
         2.15080066e-02,   1.75934865e-02,   2.02400430e-03,
         0.00000000e+00,   1.34939063e-02,   0.00000000e+00,
        -7.68125667e-03,   1.56149310e-02,   7.20467010e-02,
         3.88434857e-02,   4.53963454e-03,  -1.76615486e-03,
         6.51506453e-03,   0.00000000e+00,   1.02207700e-04,
         0.00000000e+00,   4.64075934e-03,  -1.14479106e-02,
        -1.96008484e-03,  -7.86492648e-04,   0.00000000e+00,
         5.82474939e-03,   0.00000000e+00,   5.94995831e-03,
        -2.25036767e-03,  -4.51977217e-02,  -3.55810592e-02,
        -1.04391187e-01,   3.54273809e-02,  -4.46303596e-02,
         4.79577612e-03,  -1.47386513e-02,  -6.24936380e-02,
        -1.39834724e-03,   1.25076656e-02,   6.57805697e-03,
        -1.00237120e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.14628808e-01,
        -3.05722400e-03,  -1.58193921e-03,  -4.22949347e-02,
        -2.35353549e-02,   0.00000000e+00,  -7.67046895e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.68739477e-02,   0.00000000e+00,
        -2.25187373e-02,  -2.60147228e-02,  -4.31564970e-03,
        -2.65913880e-02,   3.29607879e-02,   0.00000000e+00,
        -1.58861953e-02,   0.00000000e+00,  -7.08420710e-02,
         1.32232557e-02,   8.03899102e-03,   5.52994129e-05,
        -5.29351826e-03,   0.00000000e+00,   7.29402918e-03,
         0.00000000e+00,   1.89205168e-02,  -1.34884006e-02,
        -5.31309331e-03,   4.08391802e-03,  -5.24123149e-04,
         1.38285988e-02,   0.00000000e+00,   1.01224126e-02,
         0.00000000e+00,  -6.40762559e-03,  -5.53122783e-03,
        -1.15650696e-02,  -4.98394164e-03,   1.92668623e-03,
         2.29686311e-02,   2.48690077e-02,   0.00000000e+00,
         7.34610125e-03,   0.00000000e+00,   1.09455040e-02,
        -7.70274443e-05,   1.74813691e-03,  -3.24622999e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.94559533e-02,   0.00000000e+00,
        -1.50576871e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.07512802e-02,
        -1.36558196e-02,   1.26469403e-02,  -9.10766409e-03,
        -1.43997964e-02,   0.00000000e+00,  -6.27949703e-03,
         0.00000000e+00,   1.51977171e-02,  -1.20443220e-02,
        -1.47607461e-03,  -1.14801726e-03,   0.00000000e+00,
        -3.64103738e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.24627921e-02,
         0.00000000e+00,  -2.95279634e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.26811515e-02,   0.00000000e+00,  -1.08444704e-01,
        -3.97525324e-03,   1.55932653e-03,   3.72295397e-02,
         5.18078716e-02,   0.00000000e+00,   6.73721518e-02,
         0.00000000e+00,   2.51856723e-03,  -2.56614024e-03,
        -1.44324237e-02,  -2.62375291e-02,   0.00000000e+00,
         1.34850790e-02,   0.00000000e+00,  -1.01014856e-01,
        -1.25568529e-04,   2.10258248e-02,   4.22866858e-02,
        -5.79457147e-02,   0.00000000e+00,   2.13183836e-02,
         0.00000000e+00,   4.92750037e-02,  -1.10296961e-02,
         7.47063959e-03,  -2.27374429e-03,   0.00000000e+00,
        -1.49499140e-02,   0.00000000e+00,  -2.98223333e-03,
        -1.18693470e-01,   4.09327287e-02,   1.45792011e-03,
        -2.12023647e-03,   8.22235627e-03,   0.00000000e+00,
         2.41786566e-03,   0.00000000e+00,   4.18754900e-03,
        -9.88992202e-03,  -2.73283441e-03,  -2.95433677e-03,
         0.00000000e+00,   3.60419731e-03,   0.00000000e+00,
        -3.04965931e-03,   4.54966898e-03,  -4.06210229e-02,
         7.15476877e-02,  -4.00258302e-02,  -3.83924649e-03,
        -3.53222740e-03,   0.00000000e+00,   5.32951013e-03,
         0.00000000e+00,   3.20028480e-02,  -9.97873951e-03,
         7.98889780e-03,   5.38635943e-03,   0.00000000e+00,
         1.34330013e-02,   0.00000000e+00,   2.12655869e-03,
        -3.93603585e-03,  -3.81034944e-02,  -1.02489151e-01,
         5.98564508e-03,   1.72283196e-02,  -1.49631661e-02,
         6.93350222e-02,   4.69856562e-02,   2.38318488e-02,
         1.46929718e-02,   3.24437950e-03,   1.30943614e-02,
        -5.90435668e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.43779452e-02,
         1.67799871e-02,  -6.45371673e-02,  -3.73737194e-02,
        -2.77058330e-02,   0.00000000e+00,   3.21468925e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.71475113e-02,   0.00000000e+00,
         4.68286224e-02,  -8.48791505e-03,  -2.39711608e-02,
        -2.53141354e-02,   2.12194204e-02,   0.00000000e+00,
         9.30866189e-03,   0.00000000e+00,   3.03436213e-02,
         9.85240024e-03,   1.44434519e-02,   3.04425083e-02,
         2.12783968e-04,   0.00000000e+00,  -2.09204328e-02,
         0.00000000e+00,  -2.60754743e-02,  -2.10785824e-02,
         1.54944640e-03,  -6.87294176e-03,   4.04138249e-02,
         3.23506577e-03,   0.00000000e+00,  -2.66184236e-02,
         0.00000000e+00,  -1.39428227e-02,  -2.51121884e-03,
        -5.75004870e-02,  -1.91699661e-03,  -5.14336520e-03,
        -1.62451977e-04,  -8.90425920e-03,   0.00000000e+00,
         2.29013219e-02,   0.00000000e+00,  -7.63211299e-03,
         9.36212953e-03,  -1.10564951e-02,   5.28434768e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.73991133e-03,   0.00000000e+00,
         2.44500224e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.00800426e-02,
         3.13802551e-03,   1.00691816e-02,   5.25215251e-03,
        -7.52861591e-03,   0.00000000e+00,  -3.45202620e-03,
         0.00000000e+00,  -2.70591360e-02,   7.38889074e-05,
        -6.20630278e-03,  -1.73506419e-02,   0.00000000e+00,
         5.19475824e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.37827528e-02,
         0.00000000e+00,   2.99327730e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.22045999e-02,   0.00000000e+00,  -1.37526541e-02,
        -6.63002002e-04,   5.31380815e-03,   7.93646154e-03,
         5.16239096e-03,   0.00000000e+00,   8.42766864e-03,
         0.00000000e+00,  -8.27224500e-03,   3.18601620e-03,
         4.34419484e-03,  -2.48588235e-02,   0.00000000e+00,
         6.25364211e-03,   0.00000000e+00,  -1.08111323e-02,
        -1.64873971e-03,   2.39080672e-04,   4.67601570e-03,
        -5.56865353e-03,   0.00000000e+00,   9.66314230e-03,
         0.00000000e+00,   1.04218575e-02,  -2.95424770e-03,
        -2.55747992e-03,   5.25020351e-03,   0.00000000e+00,
        -2.83322800e-02,   0.00000000e+00,  -5.86476462e-03,
        -1.35186129e-02,  -1.29303347e-03,  -1.45745927e-02,
        -1.44956100e-02,  -3.32367594e-03,   0.00000000e+00,
         1.10172983e-02,   0.00000000e+00,   1.58173982e-02,
        -5.16756053e-03,  -7.87520499e-03,   4.55749820e-02,
         0.00000000e+00,  -4.51910877e-02,   0.00000000e+00,
        -2.09245402e-03,   2.25006046e-02,   2.14324376e-02,
         1.39806867e-02,  -1.48161978e-03,   1.72330121e-03,
        -1.17037670e-03,   0.00000000e+00,   1.15108981e-03,
         0.00000000e+00,  -7.93371180e-03,  -3.36478770e-04,
         1.33605594e-03,  -5.87621355e-03,   0.00000000e+00,
         1.44975302e-02,   0.00000000e+00,   4.81949556e-02,
         1.04249550e-02,  -1.00564379e-02,  -1.04379772e-03,
        -5.13230384e-02,   4.74507966e-02,   5.28980702e-02,
         3.72251613e-03,  -8.79895514e-02,  -1.37038837e-02,
         6.15138909e-03,   1.40880355e-02,  -1.18592711e-02,
        -4.69162302e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.99035341e-02,
         4.06222722e-02,   2.36561442e-02,  -4.01497748e-02,
        -9.28257417e-03,   0.00000000e+00,  -4.03952234e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.11741534e-02,   0.00000000e+00,
         1.81516748e-02,  -2.33809276e-03,  -7.34930001e-04,
        -1.68334491e-02,   3.93459663e-02,   0.00000000e+00,
        -1.66198795e-02,   0.00000000e+00,  -1.60065179e-03,
        -7.10428527e-03,  -2.03318777e-02,  -3.55118007e-03,
        -1.35056391e-02,   0.00000000e+00,   1.46160294e-02,
         0.00000000e+00,   2.17449084e-02,   5.83002293e-02,
        -4.88282315e-03,   1.17109461e-02,  -2.97949390e-02,
         5.31982466e-03,   0.00000000e+00,   3.11331892e-02,
         0.00000000e+00,   1.16346034e-02,   2.54346323e-02,
         1.05135506e-01,  -2.03508832e-03,   1.40807355e-02,
         3.25448940e-03,   8.01975181e-03,   0.00000000e+00,
         9.99755583e-03,   0.00000000e+00,  -6.82867233e-03,
        -7.49291942e-03,  -2.56570656e-03,  -2.80881434e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.02407352e-03,   0.00000000e+00,
         8.13219479e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.86487532e-02,
        -5.23589583e-03,  -9.16888102e-03,   6.17684940e-03,
        -3.68277558e-03,   0.00000000e+00,  -2.80434829e-03,
         0.00000000e+00,   7.99346767e-03,   1.75767863e-02,
         1.21738444e-02,   1.04080898e-02,   0.00000000e+00,
         2.48824018e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.26914586e-02,
         0.00000000e+00,  -9.08348934e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.03558506e-02,   0.00000000e+00,  -6.11894849e-02,
        -1.03707295e-02,   3.27015431e-03,   1.27968330e-02,
         1.52145395e-02,   0.00000000e+00,   1.18560279e-02,
         0.00000000e+00,   5.95177083e-04,   3.28412059e-03,
        -1.86356341e-02,  -1.52453357e-02,   0.00000000e+00,
         2.59986819e-03,   0.00000000e+00,  -6.24523564e-02,
        -3.84366607e-03,   6.74496383e-03,   1.26348663e-02,
        -1.14854519e-02,   0.00000000e+00,   2.45806619e-03,
         0.00000000e+00,   1.64696946e-02,  -2.70843108e-03,
         8.51908535e-03,  -1.19593352e-02,   0.00000000e+00,
        -1.49286507e-02,   0.00000000e+00,  -9.35823367e-03,
        -6.94409124e-02,   7.45347691e-03,  -1.16940208e-02,
         7.94656132e-03,  -3.09200824e-03,   0.00000000e+00,
        -1.31305924e-02,   0.00000000e+00,   5.63054638e-03,
         1.10126708e-02,   1.53811376e-02,  -2.94791732e-02,
         0.00000000e+00,   4.71371179e-02,   0.00000000e+00,
         1.82739954e-02,   9.43853800e-03,   3.04329873e-02,
         1.60413979e-02,  -6.48338992e-03,  -8.98760802e-03,
         3.25621553e-03,   0.00000000e+00,  -7.50978639e-03,
         0.00000000e+00,   9.85585228e-03,  -6.10582010e-03,
         8.14810598e-03,   2.43484797e-02,   0.00000000e+00,
        -6.25028054e-03,   0.00000000e+00,   1.94098288e-02,
         1.28464725e-02,  -3.24247282e-02,  -4.66217248e-02,
         4.94651961e-01,   8.02284255e-02,   6.08018195e-01,
         4.54525479e-02,  -7.87441727e-03,   5.90368346e-01,
        -2.83271047e-02,   4.61013635e-02,   1.44914746e-02,
         4.82232031e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.34020564e-01,
        -7.56278772e-03,  -2.85982916e-02,  -1.02679336e-01,
        -6.22238604e-02,   0.00000000e+00,   5.74164973e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.83953866e-02,   0.00000000e+00,
         6.15859373e-01,  -2.97095339e-02,  -5.99880746e-02,
        -5.23129317e-02,   5.66683079e-02,   0.00000000e+00,
        -2.09598930e-02,   0.00000000e+00,   5.81386095e-01,
        -6.57453075e-03,  -4.27567447e-02,   8.89938514e-02,
        -1.44126239e-02,   0.00000000e+00,  -3.98544687e-02,
         0.00000000e+00,  -6.34087340e-02,   4.31163466e-01,
         7.38881119e-03,   4.18346296e-03,   2.37451193e-02,
         1.27111610e-02,   0.00000000e+00,  -2.87920475e-02,
         0.00000000e+00,   2.84696528e-02,   1.06665110e-01,
         5.02455009e-01,   5.02799606e-03,  -1.43969955e-02,
        -6.44788971e-02,  -5.86300472e-02,   0.00000000e+00,
         9.49980192e-02,   0.00000000e+00,  -6.50675008e-02,
        -2.21871812e-02,  -3.64599430e-02,   6.16783119e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.11706272e-02,   0.00000000e+00,
         1.44077001e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.27684414e-01,
         1.67070039e-02,  -2.26415372e-02,   6.43738943e-02,
        -2.59642889e-02,   0.00000000e+00,  -1.77566660e-02,
         0.00000000e+00,  -9.27067184e-02,   8.59678238e-02,
         3.10892374e-02,  -1.88378123e-02,   0.00000000e+00,
         6.13767320e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.98520578e-02,
         0.00000000e+00,   3.78989285e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.88558032e-02,   0.00000000e+00,   4.13568748e-01,
         1.19423842e-02,   1.93646417e-03,   8.92825532e-04,
        -1.88417782e-02,   0.00000000e+00,  -5.59767154e-02,
         0.00000000e+00,  -4.61359707e-03,   3.76451304e-03,
         8.96138223e-03,  -4.54996599e-02,   0.00000000e+00,
         2.42392404e-02,   0.00000000e+00,   4.31541315e-01,
         8.46825065e-03,  -2.87264481e-02,  -3.82717412e-02,
         3.49745071e-02,   0.00000000e+00,  -4.31671919e-03,
         0.00000000e+00,   8.21633084e-03,   2.41584135e-05,
        -3.40083043e-03,  -1.14014381e-02,   0.00000000e+00,
        -6.84118945e-02,   0.00000000e+00,  -5.17667838e-04,
         4.24463773e-01,  -4.75516387e-02,  -8.16143393e-02,
        -1.39548543e-02,  -3.05099889e-02,   0.00000000e+00,
         3.76368843e-02,   0.00000000e+00,   5.74940776e-02,
         5.26395805e-02,   7.44935573e-03,   1.75735425e-02,
         0.00000000e+00,  -1.46314811e-02,   0.00000000e+00,
        -1.96983134e-02,   5.59656589e-02,   6.00986656e-01,
        -1.21620036e-02,   3.62575060e-02,   1.36052900e-02,
         3.05100865e-03,   0.00000000e+00,  -2.30211606e-03,
         0.00000000e+00,  -1.78618013e-02,  -9.94432566e-03,
        -4.16247065e-03,  -1.07226344e-02,   0.00000000e+00,
         1.45744914e-02,   0.00000000e+00,   7.77897233e-03,
         1.79286185e-02,  -5.73862235e-02,   4.71011326e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.33285982e-04,   7.25296904e-03,
         1.22026471e-02,   2.08204108e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.88953797e-03,   0.00000000e+00,
         1.28631098e-02,   1.68850296e-02,   2.39391247e-02,
         6.92925517e-03,   0.00000000e+00,  -2.46697746e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.87191784e-03,
         0.00000000e+00,  -1.24469821e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.95392511e-03,   0.00000000e+00,
         8.28010490e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.87797039e-04,   0.00000000e+00,
         3.75130091e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.32359270e-03,
         0.00000000e+00,  -4.73413486e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.87391280e-03,   7.82171533e-03,   8.65624433e-03,
         2.81814406e-03,   0.00000000e+00,  -9.14049288e-03,
         0.00000000e+00,  -6.12538650e-03,   3.46368258e-03,
         4.56800393e-03,  -2.00004462e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.70927364e-03,   0.00000000e+00,
         2.62219823e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.81600326e-02,
         0.00000000e+00,   4.84222560e-03,   1.59144202e-04,
         1.24772989e-03,  -8.78295231e-04,   0.00000000e+00,
        -9.34834021e-04,   0.00000000e+00,  -1.92563817e-03,
         9.57765378e-04,   1.84885076e-03,  -2.52889839e-03,
         0.00000000e+00,   2.79625680e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.30596164e-04,   0.00000000e+00,
         5.51336543e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.70100819e-03,
         0.00000000e+00,   8.53345457e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.06674788e-05,   0.00000000e+00,
        -2.78386052e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.83896543e-03,
         0.00000000e+00,   3.84416837e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.27410162e-03,
         0.00000000e+00,  -3.87048050e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.94472812e-02,   0.00000000e+00,  -4.47099988e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.83010947e-03,   0.00000000e+00,
        -3.52209003e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.06402038e-03,
         0.00000000e+00,  -2.14201981e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.14906622e-02,   1.50673797e-03,  -9.44916860e-03,
         3.66582461e-03,   3.29135861e-03,  -1.37641934e-02,
        -1.00149870e-04,   9.95399988e-03,   1.87929759e-02,
         7.65466578e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.17983765e-02,
        -3.72550729e-04,  -1.72489062e-02,  -1.55440287e-02,
        -1.01555912e-02,   0.00000000e+00,   1.68333077e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.45764494e-03,   0.00000000e+00,
         1.32288192e-03,   1.06326944e-02,   2.04715306e-03,
         1.00496998e-02,   5.18315972e-03,   0.00000000e+00,
        -1.47554765e-02,   0.00000000e+00,  -1.51604717e-02,
        -1.92771571e-03,   1.73384714e-03,  -9.58596884e-04,
         1.46909458e-03,   0.00000000e+00,  -1.09199957e-03,
         0.00000000e+00,   3.72933840e-03,  -9.18350434e-03,
        -8.85425236e-04,  -1.53375636e-03,   6.25682778e-03,
         2.53313507e-03,   0.00000000e+00,  -7.32062215e-03,
         0.00000000e+00,   1.34968578e-04,  -3.57192240e-03,
        -1.35648940e-02,  -3.53067865e-03,  -5.66613035e-03,
        -3.22953968e-03,  -2.68765666e-03,   0.00000000e+00,
         6.20547401e-03,   0.00000000e+00,   3.76799875e-04,
        -3.53231900e-04,  -4.01208633e-03,   2.86655091e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.07311490e-03,   0.00000000e+00,
        -9.18691913e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.97168230e-04,
        -3.07239071e-03,  -4.18451239e-03,  -6.30980425e-03,
         2.04792209e-03,   0.00000000e+00,   2.92958884e-03,
         0.00000000e+00,   9.33537510e-03,  -7.46206112e-03,
        -3.89980514e-03,  -2.08489973e-03,   0.00000000e+00,
        -1.71225270e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.17261753e-04,
         0.00000000e+00,  -2.38246420e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.83893193e-03,   0.00000000e+00,  -9.46928102e-03,
        -2.37753768e-03,  -6.56518466e-04,  -2.01766682e-03,
        -9.05546781e-04,   0.00000000e+00,   1.70808038e-03,
         0.00000000e+00,   1.26235744e-03,  -1.56080448e-03,
         1.88791967e-03,  -1.03047692e-02,   0.00000000e+00,
        -2.13543702e-03,   0.00000000e+00,   5.59663454e-04,
        -3.04200332e-03,   1.75616042e-03,   2.26923023e-03,
        -1.73425007e-03,   0.00000000e+00,   6.56609650e-04,
         0.00000000e+00,  -7.91663355e-04,   8.57386395e-04,
        -8.66060545e-04,  -2.66835150e-03,   0.00000000e+00,
         1.03873531e-03,   0.00000000e+00,  -4.92781555e-03,
        -2.02997757e-02,   1.05894788e-03,   2.21342057e-03,
        -1.49271211e-03,  -2.84150942e-03,   0.00000000e+00,
         2.18040767e-03,   0.00000000e+00,  -6.73846207e-03,
         1.15221347e-03,  -2.94234353e-03,   1.38797725e-02,
         0.00000000e+00,   3.96731632e-03,   0.00000000e+00,
        -2.64654093e-03,   1.71782612e-03,  -5.07822520e-03,
        -1.48082669e-03,  -4.77900669e-03,  -3.94407924e-03,
         2.99654293e-03,   0.00000000e+00,  -3.13900760e-03,
         0.00000000e+00,   1.95259352e-03,  -1.50758137e-03,
        -9.56940723e-04,  -4.74589069e-03,   0.00000000e+00,
         8.45924272e-04,   0.00000000e+00,   3.79305422e-03,
         6.32219718e-03,  -2.45156761e-03,  -4.61284968e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.35449318e-02,   9.97646787e-03,
         9.74383034e-03,   1.97085156e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.30507626e-02,   0.00000000e+00,
         3.96278096e-04,  -1.10977426e-02,  -1.46981788e-02,
        -3.55692360e-03,   0.00000000e+00,   8.08083073e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.14013395e-04,
         0.00000000e+00,   5.15411709e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.13753850e-04,   0.00000000e+00,
        -4.03333338e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.52783723e-03,   0.00000000e+00,
        -1.07167231e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.85287381e-03,
         0.00000000e+00,   4.02496593e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.82619044e-03,  -1.75169306e-03,  -3.02319759e-03,
        -1.80380190e-03,   0.00000000e+00,   6.39160550e-03,
         0.00000000e+00,   2.92453872e-03,  -1.56092517e-03,
        -3.36441636e-03,   7.74405683e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.45793894e-03,   0.00000000e+00,
        -1.41981762e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.59007667e-03,
         0.00000000e+00,   3.55763458e-03,  -3.20699700e-03,
        -3.52178911e-03,  -6.51439586e-04,   0.00000000e+00,
        -2.77337468e-03,   0.00000000e+00,   1.98320001e-03,
        -1.51167740e-03,   1.29085564e-03,   6.25582409e-03,
         0.00000000e+00,   7.65220943e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.68879080e-03,   0.00000000e+00,
         1.04243068e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.42802818e-03,
         0.00000000e+00,   1.02477970e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.64981106e-03,   0.00000000e+00,
         2.12692992e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.70132499e-03,
         0.00000000e+00,   8.37370505e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.79246074e-03,
         0.00000000e+00,   8.49697400e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.07288204e-02,   0.00000000e+00,  -5.44429437e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.06123452e-03,   0.00000000e+00,
         1.12449479e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.29377738e-04,
         0.00000000e+00,  -1.87846121e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.21425546e-01,  -9.50246629e-02,  -6.47825543e-02,
        -2.82106041e-02,   4.64412448e-02,   2.35403900e-03,
        -1.20695532e-02,  -5.14169249e-02,  -4.66818501e-03,
         9.06233225e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.49604084e-01,
        -5.85905784e-03,   3.52878115e-02,   1.37409964e-01,
         8.93708629e-02,   0.00000000e+00,   1.63592110e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.64449689e-02,   0.00000000e+00,
        -9.45800412e-02,   4.06525333e-02,   6.92269771e-03,
         5.66569368e-02,  -8.24559207e-02,   0.00000000e+00,
         4.45412384e-02,   0.00000000e+00,  -1.18098479e-02,
        -8.83215153e-03,   1.68296949e-02,  -3.25157309e-02,
         1.73695173e-02,   0.00000000e+00,  -1.01384377e-03,
         0.00000000e+00,  -8.24150176e-03,  -5.99394665e-02,
         4.09801673e-03,  -8.35706302e-03,  -7.23662065e-03,
        -1.75056777e-02,   0.00000000e+00,  -6.24813427e-03,
         0.00000000e+00,   1.52046744e-03,  -3.44261557e-02,
        -8.61612839e-02,   5.86772208e-03,  -3.06413739e-04,
         1.16796518e-02,   5.73341161e-03,   0.00000000e+00,
        -6.03660087e-02,   0.00000000e+00,   1.76798421e-02,
         5.07804452e-03,   2.65391552e-02,  -1.01190209e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.12815260e-02,   0.00000000e+00,
        -5.57155127e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.00385457e-01,
         3.76578428e-03,  -8.72741374e-04,  -2.29360954e-02,
         2.17282300e-02,   0.00000000e+00,   1.41397051e-02,
         0.00000000e+00,   1.89239711e-02,  -2.95803554e-02,
        -1.38858457e-02,  -4.66383212e-03,   0.00000000e+00,
        -8.64932737e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.72599309e-02,
         0.00000000e+00,   1.47232457e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.74173497e-02,   0.00000000e+00,   1.30476195e-01,
         5.06641616e-03,  -5.22558393e-03,  -3.20197469e-02,
        -3.68680500e-02,   0.00000000e+00,  -3.80625669e-02,
         0.00000000e+00,  -1.17425494e-03,  -1.73706608e-03,
         2.27332391e-02,   7.60967859e-02,   0.00000000e+00,
        -2.93501839e-02,   0.00000000e+00,   1.36813305e-01,
         5.80264997e-03,  -4.95328875e-03,  -1.76335320e-02,
         2.92997155e-02,   0.00000000e+00,  -1.66256330e-02,
         0.00000000e+00,  -5.15756009e-02,   1.47143448e-02,
        -9.38684958e-03,   1.17757803e-02,   0.00000000e+00,
         4.58454347e-02,   0.00000000e+00,   1.37460341e-02,
         1.32913692e-01,  -9.55394440e-03,   4.38099508e-02,
         9.78316594e-03,   6.62324060e-03,   0.00000000e+00,
        -1.16950959e-02,   0.00000000e+00,  -3.25230045e-02,
        -5.35735215e-03,  -7.06073250e-03,  -2.24382342e-02,
         0.00000000e+00,  -2.93671680e-02,   0.00000000e+00,
         9.04895008e-03,  -2.41684425e-02,  -6.72339541e-02,
        -4.31531182e-02,   1.26574307e-02,   6.89697010e-03,
        -3.03814129e-03,   0.00000000e+00,   3.17801986e-03,
         0.00000000e+00,  -2.26858376e-02,   1.63726802e-02,
        -1.01651528e-02,  -3.73912513e-03,   0.00000000e+00,
        -1.92028338e-02,   0.00000000e+00,  -2.69027747e-02,
        -2.46343940e-03,   8.31012376e-02,   1.13881461e-01,
         5.27484323e-02,  -4.78250439e-02,  -1.81919384e-02,
        -2.12207718e-02,   1.90126565e-02,   5.19557180e-03,
         1.78197455e-02,  -3.07077841e-02,  -7.18798850e-03,
         4.46553979e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.27349193e-02,
         3.47300783e-03,   1.72940720e-02,   6.46923821e-02,
         2.81778354e-02,   0.00000000e+00,   1.85285859e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.80867802e-02,   0.00000000e+00,
        -4.26938058e-02,   1.20386041e-02,   1.29614578e-02,
         4.93465867e-02,  -3.71514731e-02,   0.00000000e+00,
         1.82447237e-02,   0.00000000e+00,  -8.96993765e-03,
        -6.16837612e-03,  -3.67750052e-03,  -1.43836415e-02,
         7.34601478e-03,   0.00000000e+00,  -4.53203360e-03,
         0.00000000e+00,  -2.62769799e-03,  -3.66202106e-02,
        -1.35863586e-03,  -8.01860230e-03,  -4.99434428e-04,
        -7.36666523e-03,   0.00000000e+00,  -5.10743920e-03,
         0.00000000e+00,   2.69633588e-03,  -1.42401630e-02,
        -4.82650312e-02,   2.32245115e-03,   2.37519950e-03,
         2.87383647e-03,   3.93075266e-04,   0.00000000e+00,
        -2.29710199e-02,   0.00000000e+00,   3.40625418e-03,
         5.76319920e-04,   7.23415891e-03,  -3.28768723e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.62197148e-03,   0.00000000e+00,
        -2.44658702e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.59707196e-02,
        -2.73703015e-03,  -9.93051872e-03,  -1.27263912e-02,
         1.03041779e-02,   0.00000000e+00,   9.16578640e-03,
         0.00000000e+00,   1.69068026e-02,  -1.37845531e-02,
        -6.84990015e-03,  -1.83395341e-03,   0.00000000e+00,
        -4.71730899e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.65726258e-02,
         0.00000000e+00,   5.87882323e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.66132103e-02,   0.00000000e+00,   6.43967246e-02,
        -2.48025568e-03,  -2.65667484e-03,  -1.59089862e-02,
        -1.35318240e-02,   0.00000000e+00,  -1.58550834e-02,
         0.00000000e+00,  -2.42364260e-03,   1.46355265e-04,
         1.01241030e-02,   2.92226352e-02,   0.00000000e+00,
        -1.47266002e-02,   0.00000000e+00,   6.11957361e-02,
         5.07827259e-03,  -4.37614712e-03,  -8.50294953e-03,
         1.49891959e-02,   0.00000000e+00,  -1.22122469e-02,
         0.00000000e+00,  -2.44623354e-02,   7.55351012e-03,
        -3.08334226e-03,   8.49839852e-03,   0.00000000e+00,
         3.08170689e-02,   0.00000000e+00,   1.45604952e-02,
         8.01958038e-02,  -3.94285542e-03,   1.66300407e-02,
         9.19367157e-03,   1.83140443e-04,   0.00000000e+00,
        -9.60973770e-03,   0.00000000e+00,  -1.83408275e-02,
         6.43094804e-03,   1.50685289e-03,  -9.13667042e-03,
         0.00000000e+00,  -5.13346429e-03,   0.00000000e+00,
         8.21278713e-03,  -2.25841546e-02,  -2.80177686e-02,
        -2.23843212e-02,   6.52150419e-03,   3.46873952e-03,
        -4.41865267e-03,   0.00000000e+00,   2.81433980e-04,
         0.00000000e+00,  -4.71528031e-03,   3.80324472e-03,
        -4.37157380e-03,   8.99270618e-04,   0.00000000e+00,
        -1.70810747e-02,   0.00000000e+00,  -1.76272106e-03,
        -1.30641861e-02,   3.83938948e-02,   4.93493311e-02,
         3.05857272e-02,   3.22261438e-02,   7.12737944e-02,
         2.76897069e-02,   1.22785483e-02,   6.14907479e-02,
        -3.63740285e-03,   1.89421425e-02,   8.67412922e-03,
         3.32242253e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.21345752e-02,
        -3.77161949e-03,  -3.09059162e-02,  -4.20608879e-02,
        -3.05866344e-02,   0.00000000e+00,   6.27409122e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.93205737e-02,   0.00000000e+00,
         9.81682556e-02,  -1.68542646e-02,  -2.65444644e-02,
        -2.10440022e-02,   2.62768265e-02,   0.00000000e+00,
        -1.61476545e-02,   0.00000000e+00,   7.05248419e-02,
        -3.49698680e-03,  -3.17810998e-02,   5.64303200e-02,
        -8.35194791e-03,   0.00000000e+00,  -2.79360598e-02,
         0.00000000e+00,  -3.38729801e-02,  -2.85700428e-03,
        -5.16784480e-03,  -2.94850966e-02,   4.49704886e-02,
         5.04022496e-04,   0.00000000e+00,  -3.18071016e-02,
         0.00000000e+00,  -5.44177107e-03,   1.32239850e-02,
        -3.29018753e-02,   4.90402408e-03,   2.45151268e-03,
        -1.75791746e-02,  -1.88394563e-02,   0.00000000e+00,
         3.74635504e-02,   0.00000000e+00,  -2.47938897e-02,
        -5.14527817e-03,  -2.17187461e-02,   1.02036584e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.56893493e-03,   0.00000000e+00,
         5.61024306e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.07690166e-01,
         5.43438318e-04,  -1.42839634e-02,   2.79888282e-02,
        -1.75492708e-02,   0.00000000e+00,  -8.28866811e-03,
         0.00000000e+00,  -3.56956733e-02,   3.28416257e-02,
         7.99052087e-03,  -1.12775296e-02,   0.00000000e+00,
         1.05343205e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.34604505e-03,
         0.00000000e+00,   9.15279504e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.93481340e-02,   0.00000000e+00,   1.18869217e-02,
         5.45699314e-03,   1.02329567e-03,   6.11995952e-03,
         2.58596287e-03,   0.00000000e+00,  -2.25174741e-03,
         0.00000000e+00,   4.05417548e-04,   2.35560260e-03,
         1.08100860e-02,  -2.63829850e-02,   0.00000000e+00,
         1.19488610e-02,   0.00000000e+00,   1.47242588e-02,
        -2.23739340e-03,  -4.89719925e-03,  -2.54581740e-03,
         1.63627478e-03,   0.00000000e+00,   3.70920759e-03,
         0.00000000e+00,   1.60585193e-02,  -4.31665071e-03,
        -3.74912126e-03,  -3.97135514e-03,   0.00000000e+00,
        -2.88537093e-02,   0.00000000e+00,  -4.26885306e-03,
         1.19682745e-02,  -1.40790375e-02,  -4.17865684e-02,
        -2.46197956e-04,  -6.18741133e-03,   0.00000000e+00,
         9.83990254e-03,   0.00000000e+00,   2.60473319e-02,
         2.75929704e-02,   7.96066053e-03,   1.71048216e-02,
         0.00000000e+00,  -7.85153621e-03,   0.00000000e+00,
        -8.29356255e-03,   1.96570694e-02,   8.48359736e-02,
         9.05278721e-03,   8.32446000e-03,   1.72319980e-03,
         3.21327583e-03,   0.00000000e+00,   2.77814813e-03,
         0.00000000e+00,  -5.82262342e-03,  -9.42773203e-03,
        -7.86653535e-03,  -7.54747850e-03,   0.00000000e+00,
         8.22512764e-03,   0.00000000e+00,   1.41281510e-02,
         4.61136761e-03,  -2.59229399e-02,   2.47712098e-02,
         1.58687935e-02,   7.41878374e-03,   3.39160369e-03,
         2.85789492e-02,   4.32700018e-02,   1.59496871e-02,
         2.34830168e-03,   4.51984128e-03,   1.09486157e-02,
         1.75418020e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.67175540e-03,
        -6.74925580e-03,  -4.10550946e-02,  -1.28467102e-02,
        -2.25486197e-02,   0.00000000e+00,   3.25258312e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.18904350e-03,   0.00000000e+00,
         4.69226813e-02,  -1.17532496e-02,  -2.08345138e-02,
        -4.38610029e-03,   1.03714406e-02,   0.00000000e+00,
        -7.57519424e-03,   0.00000000e+00,   3.11588870e-02,
        -8.52885853e-04,  -2.01173525e-02,   4.35835061e-02,
        -3.64757251e-03,   0.00000000e+00,  -2.73809842e-02,
         0.00000000e+00,  -2.84354351e-02,  -3.16823216e-02,
        -1.05667012e-02,  -5.01577907e-02,   6.83000703e-02,
        -3.57001354e-03,   0.00000000e+00,  -4.79740905e-02,
         0.00000000e+00,  -1.86928068e-02,  -2.41496597e-02,
        -1.31615673e-01,   1.05273797e-03,  -2.68118277e-03,
        -1.05084154e-02,  -1.40109238e-02,   0.00000000e+00,
         2.67001971e-02,   0.00000000e+00,  -1.66492243e-02,
        -2.71734578e-03,  -1.96687013e-02,   5.93038714e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.94676803e-03,   0.00000000e+00,
         3.57104362e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.70934637e-02,
         1.20653241e-04,  -8.93734738e-03,   1.85601810e-02,
        -1.16110364e-02,   0.00000000e+00,  -6.13745433e-03,
         0.00000000e+00,  -2.54893154e-02,   1.43432097e-02,
        -1.56012191e-03,  -1.04757446e-02,   0.00000000e+00,
         5.17830920e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.06080076e-03,
         0.00000000e+00,   6.72296979e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.34507814e-03,   0.00000000e+00,   6.92071287e-03,
         1.98839463e-03,   4.85061642e-03,   3.06173757e-03,
         4.90789905e-03,   0.00000000e+00,   3.31136121e-03,
         0.00000000e+00,  -1.60164085e-04,   4.65786145e-03,
         1.92785453e-02,  -1.58682777e-02,   0.00000000e+00,
         6.88124810e-03,   0.00000000e+00,   7.56189757e-03,
        -1.26162315e-03,  -3.71574839e-03,   7.27523957e-06,
        -8.05570199e-04,   0.00000000e+00,   2.82862470e-03,
         0.00000000e+00,   9.32280155e-03,  -4.04669103e-03,
        -7.44861419e-03,  -7.42113155e-05,   0.00000000e+00,
        -1.66252727e-02,   0.00000000e+00,  -4.77366543e-04,
         1.01708057e-02,  -8.88125510e-03,  -2.84099225e-02,
        -2.02778463e-03,  -5.03378471e-03,   0.00000000e+00,
         7.87186919e-03,   0.00000000e+00,   1.51957760e-02,
         1.48416162e-02,   2.38779184e-03,   2.20575521e-02,
         0.00000000e+00,  -1.84708014e-02,   0.00000000e+00,
        -7.44000237e-03,   1.14978691e-02,   3.52612372e-02,
         8.17629452e-03,   3.87505596e-03,   2.46037239e-03,
        -1.17480418e-03,   0.00000000e+00,  -1.17548568e-05,
         0.00000000e+00,  -5.90657676e-03,  -6.87703163e-03,
        -1.06097648e-02,  -9.49220960e-03,   0.00000000e+00,
         6.12535489e-03,   0.00000000e+00,   1.46437326e-02,
         2.03714253e-04,  -9.40258850e-03,   1.11547324e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.07162406e-03,  -3.46028349e-03,
        -1.33422916e-03,   9.40783881e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.00719658e-04,   0.00000000e+00,
        -3.96682533e-03,  -5.44129853e-03,  -3.70282029e-03,
        -1.81765823e-03,   0.00000000e+00,   5.32483159e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.29283718e-03,
         0.00000000e+00,   3.13949920e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.20800945e-04,   0.00000000e+00,
        -2.84787935e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.91804861e-04,   0.00000000e+00,
        -1.74127188e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.05921002e-03,
         0.00000000e+00,   1.09773858e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.54778318e-03,  -4.82059405e-03,  -1.33218790e-02,
        -2.92203579e-03,   0.00000000e+00,   1.05268124e-02,
         0.00000000e+00,   5.43884503e-03,  -3.81952913e-03,
        -4.12067042e-03,   4.95015160e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.44329228e-03,   0.00000000e+00,
        -1.06547689e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.17441351e-03,
         0.00000000e+00,  -1.07969213e-03,   1.24319253e-04,
        -1.19345982e-03,   1.02491535e-04,   0.00000000e+00,
         3.93028317e-03,   0.00000000e+00,   1.09371887e-03,
        -2.75468036e-04,  -1.00376114e-03,   3.20241656e-04,
         0.00000000e+00,  -2.04606489e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.13081269e-03,   0.00000000e+00,
        -5.12804682e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.42702542e-03,
         0.00000000e+00,  -1.27578108e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.01106271e-03,   0.00000000e+00,
         3.35518400e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.22111305e-03,
         0.00000000e+00,  -2.17727054e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.03443651e-03,
         0.00000000e+00,   6.51580542e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.11169564e-03,   0.00000000e+00,   3.68679018e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.91046064e-04,   0.00000000e+00,
        -1.93620280e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.02175356e-03,
         0.00000000e+00,   4.16596927e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.87648960e-02,  -9.13434957e-03,  -5.37528147e-02,
         7.88951390e-04,   1.47436702e-05,  -4.68538425e-02,
         4.70524401e-04,  -1.28334012e-02,  -4.17790482e-03,
        -3.35990708e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.55620346e-02,
         7.78644120e-03,   7.38642873e-03,   1.77016172e-02,
         1.29990160e-02,   0.00000000e+00,  -5.46252128e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.82862716e-03,   0.00000000e+00,
        -5.35800770e-02,   2.51698845e-03,   2.30195135e-03,
         4.22100571e-03,  -8.19326602e-03,   0.00000000e+00,
         6.77316697e-03,   0.00000000e+00,  -4.58357414e-02,
         4.14639463e-03,   1.30849998e-02,  -1.38907634e-02,
         2.33498837e-03,   0.00000000e+00,   6.44310877e-03,
         0.00000000e+00,   7.11278663e-03,  -2.59511237e-02,
        -1.43484246e-03,   1.69897330e-03,  -6.38447887e-03,
        -8.95103573e-04,   0.00000000e+00,   9.76195939e-03,
         0.00000000e+00,  -4.97694085e-03,  -1.54934971e-02,
        -3.43981611e-02,   6.99059959e-05,   8.75795366e-03,
         3.44464694e-02,   2.83095538e-02,   0.00000000e+00,
        -4.20441861e-02,   0.00000000e+00,   2.05168926e-02,
         7.98919068e-03,   1.69332404e-02,  -6.27172332e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.15170245e-02,   0.00000000e+00,
        -4.22718439e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.60854856e-02,
        -5.54345632e-03,   4.85550069e-03,  -1.97108321e-02,
         2.48847651e-03,   0.00000000e+00,   6.58444586e-03,
         0.00000000e+00,   1.73135099e-02,  -2.26102558e-02,
        -1.04193112e-02,  -1.50248009e-03,   0.00000000e+00,
        -5.18476631e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.32516969e-02,
         0.00000000e+00,  -1.13839029e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.78245950e-03,   0.00000000e+00,  -2.43843833e-02,
        -5.25370641e-03,  -2.09379127e-03,  -6.95390392e-04,
         4.22830787e-03,   0.00000000e+00,   2.53212643e-02,
         0.00000000e+00,  -2.22149350e-03,  -3.32091167e-03,
        -4.68144974e-03,   7.10253051e-03,   0.00000000e+00,
        -2.81588065e-03,   0.00000000e+00,  -2.47621256e-02,
         1.72198246e-03,   7.89144145e-03,   1.25140842e-02,
        -1.08744072e-02,   0.00000000e+00,   3.21368835e-03,
         0.00000000e+00,  -5.76075365e-04,   1.38339899e-03,
         5.35255300e-04,   1.63756382e-03,   0.00000000e+00,
         8.03681517e-03,   0.00000000e+00,  -9.83936647e-04,
        -2.58403108e-02,   1.81209775e-02,   2.75828759e-02,
         5.73863205e-03,   8.79866009e-03,   0.00000000e+00,
        -1.37377469e-02,   0.00000000e+00,  -1.01989512e-02,
        -7.31777996e-03,  -2.50403678e-03,  -9.34302300e-03,
         0.00000000e+00,  -6.61807129e-03,   0.00000000e+00,
         4.67315864e-03,  -4.97542800e-03,  -5.41786023e-02,
         7.53687055e-03,  -1.56772752e-02,  -3.98678968e-03,
        -4.91904840e-03,   0.00000000e+00,   3.20175516e-03,
         0.00000000e+00,   5.22762411e-03,  -4.17303457e-04,
         7.17948649e-04,   5.33735429e-03,   0.00000000e+00,
         1.65065993e-03,   0.00000000e+00,   3.38843443e-03,
         1.47698112e-03,   7.99086711e-03,  -2.62850675e-02,
         3.32909870e-02,   3.26187624e-02,   9.55305464e-02,
         3.24892357e-03,  -8.13613841e-03,   6.81048707e-02,
        -6.82145550e-03,   1.37591642e-02,  -1.03823532e-04,
         3.98583845e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.68773102e-02,
        -6.05835833e-03,  -4.86943263e-03,  -3.79163123e-02,
        -2.38882643e-02,   0.00000000e+00,   6.61802418e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.46332246e-02,   0.00000000e+00,
         9.61224668e-02,  -2.28771457e-02,  -2.60542922e-02,
        -2.01152809e-02,   2.59020885e-02,   0.00000000e+00,
        -1.47247697e-02,   0.00000000e+00,   8.86948734e-02,
        -5.55415881e-03,  -2.97615324e-02,   3.36273634e-02,
        -1.07657948e-02,   0.00000000e+00,  -1.31545101e-02,
         0.00000000e+00,  -1.80651710e-02,   4.73016241e-02,
        -4.98597264e-03,  -1.60656892e-02,   1.91908158e-02,
         2.91971201e-03,   0.00000000e+00,  -1.77559343e-02,
         0.00000000e+00,   6.68502873e-03,   2.45753752e-02,
         4.06752623e-02,  -2.44626518e-03,  -5.76641232e-03,
        -4.44828033e-02,  -3.48130045e-02,   0.00000000e+00,
         6.07507392e-02,   0.00000000e+00,  -3.38252214e-02,
        -2.01903871e-02,  -2.82897068e-02,   1.01588082e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.72596208e-02,   0.00000000e+00,
         8.62161645e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.24453650e-01,
         1.44029615e-02,  -1.14957194e-02,   6.44688475e-02,
        -1.81049932e-02,   0.00000000e+00,  -1.87227675e-02,
         0.00000000e+00,  -5.96126576e-02,   5.36753010e-02,
         2.71803159e-02,   7.47396774e-03,   0.00000000e+00,
         1.08478276e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.41041573e-03,
         0.00000000e+00,   1.76720567e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.24580405e-02,   0.00000000e+00,   1.78256081e-02,
         8.02538636e-04,   6.22554112e-03,   1.18762319e-02,
         2.99919538e-04,   0.00000000e+00,  -2.57847539e-02,
         0.00000000e+00,  -1.68909444e-03,   7.73516611e-03,
         8.45004968e-03,  -1.78170520e-02,   0.00000000e+00,
         1.00371229e-02,   0.00000000e+00,   1.85515563e-02,
        -8.54969002e-03,  -9.94932648e-03,  -1.67103702e-02,
         7.50497540e-03,   0.00000000e+00,   1.56971979e-03,
         0.00000000e+00,   2.07122888e-02,  -8.39189345e-03,
        -3.18203319e-03,  -9.49554025e-03,   0.00000000e+00,
        -2.43888490e-02,   0.00000000e+00,  -2.74177498e-03,
         2.69072366e-02,  -3.01303323e-02,  -6.25505260e-02,
        -1.16378967e-02,  -1.41369461e-02,   0.00000000e+00,
         1.62813441e-02,   0.00000000e+00,   3.06496985e-02,
         1.74443385e-02,   1.07068752e-02,  -5.75893492e-03,
         0.00000000e+00,   3.95622970e-03,   0.00000000e+00,
        -7.70670677e-03,   1.61572302e-02,   1.05912547e-01,
         2.26116514e-03,   2.14998588e-02,   5.28670255e-03,
         2.54517721e-03,   0.00000000e+00,  -1.15891288e-02,
         0.00000000e+00,  -1.25438533e-02,  -3.06124942e-03,
        -2.45349240e-03,   4.32018749e-04,   0.00000000e+00,
         2.04963102e-03,   0.00000000e+00,  -5.00298139e-03,
        -3.27791442e-03,  -3.02849237e-02,   2.58135917e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.10922212e-03,  -2.51082249e-03,
        -2.05290337e-03,  -9.98642898e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.46866293e-03,   0.00000000e+00,
         8.23312629e-05,   3.65789369e-03,   1.60457988e-03,
         2.28358695e-04,   0.00000000e+00,   5.17984866e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.85178207e-04,
         0.00000000e+00,  -1.91424477e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.72235520e-04,   0.00000000e+00,
         6.84381716e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.09761315e-03,   0.00000000e+00,
        -4.40266873e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.34428381e-03,
         0.00000000e+00,  -2.31975947e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.72369112e-03,  -2.76925682e-04,   2.23813734e-04,
         4.33579643e-05,   0.00000000e+00,  -3.19365427e-03,
         0.00000000e+00,  -1.24738123e-03,  -1.18823886e-04,
         6.44502407e-04,  -3.31068592e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.48430151e-04,   0.00000000e+00,
         1.03442276e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.66528100e-03,
         0.00000000e+00,  -5.94203736e-03,   3.92523139e-03,
         6.55226215e-03,   1.70369312e-03,   0.00000000e+00,
         5.28191483e-03,   0.00000000e+00,   2.15324745e-05,
         6.10800696e-05,  -4.80987056e-04,  -1.03418366e-03,
         0.00000000e+00,  -7.80264646e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.64788231e-03,   0.00000000e+00,
        -7.18484358e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.10259404e-04,
         0.00000000e+00,  -2.34793791e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.71756630e-03,   0.00000000e+00,
        -1.50333025e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.01773520e-04,
         0.00000000e+00,  -9.16845207e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.64579432e-03,
         0.00000000e+00,   5.78487262e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.50079007e-03,   0.00000000e+00,   1.82731530e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.26101646e-03,   0.00000000e+00,
         1.81943924e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.48805753e-04,
         0.00000000e+00,   5.16648214e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.89277877e-02,   2.72050496e-02,   8.19113810e-03,
         7.14699683e-03,  -1.24397686e-02,  -7.96595625e-03,
         4.25621181e-04,   8.25276889e-03,  -1.10538201e-03,
        -3.61098497e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.01872660e-02,
         1.93148357e-03,  -2.93688019e-03,  -3.42589706e-02,
        -2.06701948e-02,   0.00000000e+00,  -2.05796256e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.64832328e-02,   0.00000000e+00,
         1.38407272e-02,  -1.87945627e-02,  -8.11651393e-03,
        -1.96657420e-02,   2.34610377e-02,   0.00000000e+00,
        -9.71603319e-03,   0.00000000e+00,  -4.39981483e-03,
         5.30939895e-03,  -3.81994295e-03,   7.77143154e-03,
        -6.16980674e-03,   0.00000000e+00,   1.11482233e-03,
         0.00000000e+00,   3.91392457e-03,   1.13153742e-02,
        -3.30521606e-03,   3.34421304e-03,   1.79767336e-03,
         9.46497941e-03,   0.00000000e+00,   4.41518738e-03,
         0.00000000e+00,   1.02812970e-03,   9.08728834e-03,
         2.07271102e-02,  -5.26672455e-03,  -1.40704454e-03,
        -3.15032321e-03,  -2.89490630e-04,   0.00000000e+00,
         3.22967959e-02,   0.00000000e+00,  -8.23678745e-03,
        -6.04648667e-03,  -8.30144080e-03,   1.39039313e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.84447062e-03,   0.00000000e+00,
         2.47146849e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.26300099e-02,
        -1.87706838e-03,   3.42453090e-03,   1.46659238e-02,
        -1.28993026e-02,   0.00000000e+00,  -9.19687026e-03,
         0.00000000e+00,  -1.23607282e-02,   1.15203679e-02,
         8.83948872e-03,   2.69354173e-03,   0.00000000e+00,
         1.79345835e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.33949078e-02,
         0.00000000e+00,  -6.78493664e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.71422720e-02,   0.00000000e+00,  -4.76005529e-02,
        -7.40215234e-03,   6.91452871e-03,   3.28122164e-02,
         3.31767870e-02,   0.00000000e+00,   3.22774195e-02,
         0.00000000e+00,   1.56200770e-03,   9.97721177e-04,
        -6.59481351e-03,  -1.86681775e-02,   0.00000000e+00,
         8.77127961e-03,   0.00000000e+00,  -4.82596294e-02,
        -3.26893280e-03,   8.25207932e-03,   1.74542115e-02,
        -2.33388938e-02,   0.00000000e+00,   1.36359564e-02,
         0.00000000e+00,   3.04817159e-02,  -7.54597017e-03,
         2.87565241e-03,  -4.32426563e-03,   0.00000000e+00,
        -1.51670910e-02,   0.00000000e+00,  -2.63122122e-03,
        -4.58779175e-02,   9.89923473e-03,  -2.24130709e-02,
        -6.87797216e-03,  -3.02911933e-03,   0.00000000e+00,
         6.99107830e-03,   0.00000000e+00,   1.14710690e-02,
        -3.63172393e-04,   2.68294867e-03,  -1.58569211e-03,
         0.00000000e+00,   2.24698464e-03,   0.00000000e+00,
        -1.44805710e-03,   7.95991290e-03,   1.27062592e-02,
         3.85994680e-02,  -1.08879247e-02,  -2.84546127e-03,
        -3.58699705e-03,   0.00000000e+00,  -6.59571392e-03,
         0.00000000e+00,   1.08468797e-02,  -4.12367815e-03,
         4.77385871e-03,   4.64191310e-03,   0.00000000e+00,
         5.41109137e-03,   0.00000000e+00,   3.88583887e-03,
        -1.81736713e-03,  -2.60098263e-02,  -4.13906933e-02,
        -2.95541687e-02,   7.27578156e-03,  -2.36162143e-02,
         6.35816426e-03,  -9.28470931e-03,  -2.95628677e-02,
        -1.76976282e-03,   1.27105270e-03,   5.61376408e-04,
        -3.07388760e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.34838404e-02,
         7.16787239e-03,   4.02813340e-04,  -6.30307923e-03,
        -8.69720380e-04,   0.00000000e+00,  -3.40842360e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.12301907e-03,   0.00000000e+00,
        -2.11864335e-02,  -2.11844369e-04,  -1.38499470e-03,
        -3.92360328e-03,   5.50366389e-03,   0.00000000e+00,
        -5.28760426e-03,   0.00000000e+00,  -2.78588038e-02,
         1.42529695e-03,   1.21840228e-03,  -1.90213946e-03,
        -5.84120022e-04,   0.00000000e+00,   3.33907403e-03,
         0.00000000e+00,   6.77485258e-03,  -1.04054200e-02,
        -1.45748260e-03,  -4.37232646e-04,  -4.43546100e-04,
         1.83979466e-03,   0.00000000e+00,   4.52207092e-03,
         0.00000000e+00,  -9.43383195e-04,  -4.05554284e-03,
        -1.32216294e-02,   2.11018043e-04,   5.92703877e-03,
         1.26560990e-02,   7.42533167e-03,   0.00000000e+00,
        -9.75538921e-04,   0.00000000e+00,   4.13881032e-03,
         1.62773332e-03,   1.99956870e-03,  -2.34056719e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.80879517e-03,   0.00000000e+00,
        -1.06766439e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.43160304e-02,
        -8.81484761e-03,   1.20716587e-03,  -7.60647497e-03,
        -3.74805238e-03,   0.00000000e+00,   2.25050054e-03,
         0.00000000e+00,   1.16115647e-02,  -7.89791991e-03,
        -2.90978682e-03,  -8.95752187e-04,   0.00000000e+00,
        -2.18568929e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.71576907e-02,
         0.00000000e+00,  -9.06779032e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.99616970e-03,   0.00000000e+00,  -3.20076351e-02,
        -3.38279299e-03,   2.40196535e-03,   1.46891179e-02,
         1.07001898e-02,   0.00000000e+00,   2.42327690e-02,
         0.00000000e+00,   5.58549976e-03,  -1.76490202e-03,
        -4.13915420e-03,  -4.48428617e-03,   0.00000000e+00,
         3.40982034e-04,   0.00000000e+00,  -3.15493442e-02,
        -6.72676123e-03,   1.34777257e-02,   2.47415438e-02,
        -1.80614438e-02,   0.00000000e+00,   1.25542725e-02,
         0.00000000e+00,   1.54556438e-02,  -2.28472134e-03,
         2.31794975e-03,  -1.08984028e-03,   0.00000000e+00,
        -1.00792054e-03,   0.00000000e+00,  -3.21562725e-03,
        -3.65705784e-02,   1.38467094e-02,   1.17181820e-03,
         3.37769610e-03,   5.33682616e-03,   0.00000000e+00,
        -5.96887048e-03,   0.00000000e+00,  -4.98509030e-03,
        -6.56310599e-06,   2.00042928e-03,  -3.02155144e-03,
         0.00000000e+00,   3.43239930e-03,   0.00000000e+00,
         3.05279116e-03,   8.82145547e-04,  -2.23189147e-02,
         1.96118449e-02,  -1.26036710e-02,  -5.95570068e-03,
         3.21403215e-03,   0.00000000e+00,   5.00904523e-05,
         0.00000000e+00,   3.99137409e-03,  -1.59447221e-03,
         1.34852111e-03,   4.12105767e-03,   0.00000000e+00,
         8.38432364e-04,   0.00000000e+00,   4.57153469e-03,
         6.03855139e-03,  -5.30921034e-03,  -3.09091976e-02,
         1.73123046e-03,  -1.02098528e-02,  -9.19773817e-03,
        -1.01013656e-02,  -9.34481189e-03,  -1.25642009e-02,
        -5.25598633e-04,  -3.11112023e-03,  -3.75318960e-03,
        -2.18433918e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.28822957e-03,
         2.15296951e-03,   1.33697609e-02,   1.99363239e-02,
         1.19082899e-02,   0.00000000e+00,  -1.53394385e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.43188994e-03,   0.00000000e+00,
        -2.13701513e-02,   8.13405291e-03,   6.78846787e-03,
         1.26291635e-02,  -9.50149607e-03,   0.00000000e+00,
        -3.86003636e-04,   0.00000000e+00,  -1.79688821e-02,
        -4.99061259e-03,  -8.94035404e-03,  -2.57247728e-03,
         8.14171401e-04,   0.00000000e+00,   1.86275440e-03,
         0.00000000e+00,   6.13245971e-03,  -2.68348919e-03,
        -1.17521168e-03,  -7.05955328e-03,  -2.81784126e-03,
        -4.41976654e-03,   0.00000000e+00,   3.25735061e-03,
         0.00000000e+00,   1.95023486e-03,  -1.13342618e-03,
        -1.01722615e-02,   9.36132245e-03,   1.48024803e-02,
         8.96392996e-03,   8.16182120e-03,   0.00000000e+00,
        -1.87879000e-02,   0.00000000e+00,   1.14751290e-03,
         3.52311598e-03,   5.28555788e-03,  -2.39368451e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.18770321e-03,   0.00000000e+00,
        -1.66507930e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.44881416e-02,
        -9.74326481e-03,  -1.75305837e-02,  -1.13058392e-02,
         4.08047181e-04,   0.00000000e+00,   5.00598647e-03,
         0.00000000e+00,   1.38317593e-02,  -4.99232875e-03,
        -1.84647031e-03,  -3.36731632e-03,   0.00000000e+00,
        -1.79950389e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.08433279e-03,
         0.00000000e+00,  -6.12026323e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.79204463e-03,   0.00000000e+00,   6.64337865e-03,
         3.83548701e-03,  -8.49949116e-03,  -7.91785871e-03,
        -5.23836960e-03,   0.00000000e+00,   1.34594931e-03,
         0.00000000e+00,   2.64391847e-03,  -2.06514718e-03,
        -1.58198786e-05,   7.87254627e-03,   0.00000000e+00,
        -4.37275404e-03,   0.00000000e+00,   5.32632192e-03,
         5.25325984e-03,   5.28271038e-04,   1.36472435e-03,
         5.38451373e-03,   0.00000000e+00,  -6.35716304e-03,
         0.00000000e+00,  -1.00358300e-02,   4.13785882e-03,
         1.67116555e-03,   4.34765579e-04,   0.00000000e+00,
         7.80202966e-03,   0.00000000e+00,   2.96501501e-03,
         3.31744614e-03,   1.09893247e-03,   1.53649752e-03,
         2.51397259e-02,   4.14874683e-03,   0.00000000e+00,
        -1.57653028e-02,   0.00000000e+00,  -8.69411303e-03,
         9.74386197e-03,   8.71282533e-03,  -1.14756690e-02,
         0.00000000e+00,   1.53086085e-02,   0.00000000e+00,
         4.14303146e-03,  -6.56937005e-03,  -1.61975427e-02,
        -5.22121272e-03,   2.47003687e-03,  -3.26661786e-03,
         1.66572066e-03,   0.00000000e+00,   1.14544610e-02,
         0.00000000e+00,   2.48528114e-03,  -2.61686745e-03,
        -3.75960174e-03,   1.00456816e-03,   0.00000000e+00,
        -7.43022010e-03,   0.00000000e+00,  -3.73920087e-03,
         2.23847705e-04,   9.59822925e-03,   3.37553415e-03,
         3.35298821e-02,  -8.36624104e-03,   1.25402193e-02,
        -1.41611084e-03,   1.01227483e-02,   2.16619210e-02,
        -3.88751343e-03,  -8.15368832e-03,  -1.63695046e-03,
         2.82544082e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.42595348e-02,
        -2.66074685e-03,   4.90268494e-03,   1.27881421e-02,
         6.79339211e-03,   0.00000000e+00,   2.14495609e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.38037295e-03,   0.00000000e+00,
         8.59682383e-03,  -5.56763500e-04,  -6.63519380e-03,
         5.06060194e-03,  -9.37388839e-03,   0.00000000e+00,
         3.26948635e-03,   0.00000000e+00,   2.28436738e-02,
        -8.93259834e-04,   1.45382525e-03,   5.94605543e-04,
         2.79461655e-03,   0.00000000e+00,  -1.66366507e-03,
         0.00000000e+00,  -5.60331778e-03,  -5.42738302e-05,
         2.20982083e-03,  -2.11889899e-03,   1.34544293e-03,
        -2.35744280e-03,   0.00000000e+00,  -5.19751788e-03,
         0.00000000e+00,   2.60530590e-03,  -1.34143748e-03,
        -2.00364787e-03,   3.41143963e-03,  -6.92177057e-03,
        -6.80084242e-03,  -7.31826817e-03,   0.00000000e+00,
         1.41569223e-03,   0.00000000e+00,  -2.27573228e-03,
        -3.17054782e-03,  -1.03732904e-03,   1.05987723e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.31091868e-03,   0.00000000e+00,
         5.37723634e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.17370860e-02,
         3.74278138e-03,   2.72268287e-03,   3.78789787e-03,
         2.35201737e-03,   0.00000000e+00,  -3.28427721e-03,
         0.00000000e+00,  -1.07395801e-02,   2.79195430e-03,
         7.23063627e-04,   2.45972057e-04,   0.00000000e+00,
         8.91829822e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.89959526e-02,
         0.00000000e+00,   8.10825158e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.49090904e-03,   0.00000000e+00,   3.06389237e-02,
         1.57075913e-02,  -4.47570591e-03,  -7.51049553e-03,
        -9.19795239e-03,   0.00000000e+00,  -1.67942105e-02,
         0.00000000e+00,   1.36366088e-03,   1.64938587e-03,
         5.85535658e-03,   9.23597366e-03,   0.00000000e+00,
        -3.40750664e-03,   0.00000000e+00,   2.81029595e-02,
         5.15392756e-03,  -7.68327180e-03,  -1.01886088e-02,
         1.12900092e-02,   0.00000000e+00,  -5.21953126e-03,
         0.00000000e+00,  -9.64849607e-03,   2.39277492e-03,
        -1.75777188e-03,   1.55123853e-03,   0.00000000e+00,
         1.28209328e-03,   0.00000000e+00,   6.84736116e-04,
         3.47899176e-02,  -6.76077346e-03,   1.48261642e-03,
        -2.01437773e-03,  -3.78912532e-04,   0.00000000e+00,
         1.00350661e-02,   0.00000000e+00,   2.63581001e-03,
        -6.51579178e-04,  -2.06987369e-03,  -3.54855577e-03,
         0.00000000e+00,  -1.03488220e-02,   0.00000000e+00,
        -1.76383895e-03,   6.05535328e-04,   1.40900671e-02,
        -1.19591893e-02,   7.67905421e-03,   1.59961986e-02,
         7.35926447e-03,   0.00000000e+00,   8.93396531e-03,
         0.00000000e+00,  -4.98306211e-03,   2.55366098e-03,
        -1.59424449e-03,  -7.48053385e-04,   0.00000000e+00,
        -2.07272127e-03,   0.00000000e+00,  -4.91265192e-03,
        -2.54466049e-03,   8.49698600e-03,   2.95674236e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.55281672e-02,  -4.84384302e-03,
         1.37987717e-03,   1.10705779e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.72366311e-03,   0.00000000e+00,
         2.78069020e-02,   8.99221828e-02,   1.59119295e-02,
         1.26910596e-02,   0.00000000e+00,  -2.26687605e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.62439901e-03,
         0.00000000e+00,  -3.38960987e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.88552741e-03,   0.00000000e+00,
        -6.50118675e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.02760552e-03,   0.00000000e+00,
        -2.37823836e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.31796890e-03,
         0.00000000e+00,  -8.87029191e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.95671897e-03,   2.29689045e-02,   2.09116859e-03,
         9.06466680e-03,   0.00000000e+00,  -1.07380420e-02,
         0.00000000e+00,  -1.72503876e-02,  -2.10379080e-02,
         1.69563552e-03,  -7.24722309e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.33888712e-04,   0.00000000e+00,
        -3.98097061e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.31466212e-03,
         0.00000000e+00,  -9.52951707e-04,   5.55873472e-03,
         5.19639930e-03,  -4.05748059e-03,   0.00000000e+00,
         4.07626059e-04,   0.00000000e+00,  -1.20253655e-02,
         1.08750032e-03,  -1.08693757e-03,  -5.40560488e-03,
         0.00000000e+00,  -9.66737927e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.66582846e-03,   0.00000000e+00,
         4.14182592e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.09007247e-03,
         0.00000000e+00,  -3.08664413e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.82857607e-03,   0.00000000e+00,
        -7.68328177e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.49683502e-02,
         0.00000000e+00,  -2.06682282e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.67028878e-04,
         0.00000000e+00,   4.52555986e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.15566923e-02,   0.00000000e+00,   2.82572287e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.47963063e-03,   0.00000000e+00,
        -1.04749767e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.70108639e-02,
         0.00000000e+00,   5.34167522e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.18547177e-02,  -3.31410896e-02,
        -8.67864250e-03,   3.07296914e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.94647791e-03,   0.00000000e+00,
        -3.98100172e-02,  -7.03578599e-02,  -2.69799197e-03,
        -2.09555548e-02,   0.00000000e+00,   2.26667187e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.16093853e-02,
         0.00000000e+00,   1.60166727e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.13162958e-03,   0.00000000e+00,
         1.40793756e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.42149812e-03,   0.00000000e+00,
         2.12102854e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.49761717e-03,
         0.00000000e+00,   7.81411143e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.19579564e-03,  -2.95668284e-02,  -5.29692727e-03,
        -5.86745712e-03,   0.00000000e+00,   9.22754148e-03,
         0.00000000e+00,   1.49321979e-02,   1.85887123e-02,
         1.96017907e-03,   1.17833760e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.51681272e-03,   0.00000000e+00,
         5.63397694e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.62891301e-03,
         0.00000000e+00,  -1.27196446e-02,   4.32880716e-03,
        -1.11322778e-03,   1.37050883e-03,   0.00000000e+00,
        -7.07506432e-04,   0.00000000e+00,   3.95254820e-04,
         5.20092657e-03,  -2.78021406e-03,   1.55659253e-03,
         0.00000000e+00,  -1.94119972e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.74163830e-04,   0.00000000e+00,
        -4.64881691e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.50144630e-03,
         0.00000000e+00,  -2.64434516e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.78526662e-03,   0.00000000e+00,
         8.92510413e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.44762510e-03,
         0.00000000e+00,  -8.44756911e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.26523612e-03,
         0.00000000e+00,   9.54578896e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.17908672e-02,   0.00000000e+00,   2.81591873e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.91105979e-03,   0.00000000e+00,
         1.16649910e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.05413569e-02,
         0.00000000e+00,   2.27100002e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.33285982e-04,   7.25296904e-03,
         1.22026471e-02,   2.08204108e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.88953797e-03,   0.00000000e+00,
         1.28631098e-02,   1.68850296e-02,   2.39391247e-02,
         6.92925517e-03,   0.00000000e+00,  -2.46697746e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.87191784e-03,
         0.00000000e+00,  -1.24469821e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.95392511e-03,   0.00000000e+00,
         8.28010490e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.87797039e-04,   0.00000000e+00,
         3.75130091e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.32359270e-03,
         0.00000000e+00,  -4.73413486e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.87391280e-03,   7.82171533e-03,   8.65624433e-03,
         2.81814406e-03,   0.00000000e+00,  -9.14049288e-03,
         0.00000000e+00,  -6.12538650e-03,   3.46368258e-03,
         4.56800393e-03,  -2.00004462e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.70927364e-03,   0.00000000e+00,
         2.62219823e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.81600326e-02,
         0.00000000e+00,   4.84222560e-03,   1.59144202e-04,
         1.24772989e-03,  -8.78295231e-04,   0.00000000e+00,
        -9.34834021e-04,   0.00000000e+00,  -1.92563817e-03,
         9.57765378e-04,   1.84885076e-03,  -2.52889839e-03,
         0.00000000e+00,   2.79625680e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.30596164e-04,   0.00000000e+00,
         5.51336543e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.70100819e-03,
         0.00000000e+00,   8.53345457e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.06674788e-05,   0.00000000e+00,
        -2.78386052e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.83896543e-03,
         0.00000000e+00,   3.84416837e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.27410162e-03,
         0.00000000e+00,  -3.87048050e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.94472812e-02,   0.00000000e+00,  -4.47099988e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.83010947e-03,   0.00000000e+00,
        -3.52209003e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.06402038e-03,
         0.00000000e+00,  -2.14201981e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.04799885e-01,   9.01760624e-02,   6.32438321e-01,
         4.69283100e-02,  -1.15625818e-02,   5.53767829e-01,
        -2.91720139e-02,   4.63854540e-02,   6.74658372e-03,
         4.92351299e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.59323789e-01,
         3.35299603e-03,  -3.92219451e-02,  -8.59074253e-02,
        -6.70671153e-02,   0.00000000e+00,   5.54743672e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.21135736e-02,   0.00000000e+00,
         7.08517667e-01,  -3.19846732e-02,  -7.53166503e-02,
        -4.28931571e-02,   6.60443385e-02,   0.00000000e+00,
        -3.84863356e-02,   0.00000000e+00,   6.01596937e-01,
        -1.87967741e-02,  -7.01402463e-02,   9.06452286e-02,
        -2.39765798e-02,   0.00000000e+00,  -3.41051032e-02,
         0.00000000e+00,  -6.81564627e-02,   4.12405068e-01,
        -1.03936956e-02,  -4.12306133e-02,   4.05988958e-02,
         4.68180775e-03,   0.00000000e+00,  -3.51081501e-02,
         0.00000000e+00,   3.05399292e-02,   9.12793577e-02,
         4.46553244e-01,   2.30173176e-03,  -1.60312259e-02,
        -6.21828572e-02,  -6.40209135e-02,   0.00000000e+00,
         9.94750286e-02,   0.00000000e+00,  -7.74405736e-02,
        -2.15597711e-02,  -3.96902325e-02,   6.19395729e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.73378620e-02,   0.00000000e+00,
         1.82763031e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.17769268e-01,
         1.74928226e-02,  -3.12443318e-02,   6.86053480e-02,
        -2.95255785e-02,   0.00000000e+00,  -1.22334626e-02,
         0.00000000e+00,  -9.81303816e-02,   9.33325369e-02,
         2.73712468e-02,   6.89207275e-03,   0.00000000e+00,
         6.16651539e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.19272862e-02,
         0.00000000e+00,   4.34059243e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.25577622e-02,   0.00000000e+00,   4.36758607e-01,
         8.63241987e-03,   8.47858678e-03,  -1.37470192e-03,
        -1.63205131e-02,   0.00000000e+00,  -5.69543440e-02,
         0.00000000e+00,  -2.11624711e-03,   5.04399414e-03,
         1.44231140e-02,  -4.43219974e-02,   0.00000000e+00,
         1.74859113e-02,   0.00000000e+00,   4.20234345e-01,
         5.87752633e-03,  -3.26594704e-02,  -3.63849358e-02,
         3.65331119e-02,   0.00000000e+00,  -7.49703267e-03,
         0.00000000e+00,   1.16425179e-02,   9.14744187e-04,
        -4.53667310e-03,  -2.32344452e-02,   0.00000000e+00,
        -6.92618181e-02,   0.00000000e+00,  -6.25981883e-03,
         4.26467789e-01,  -5.10665096e-02,  -9.21857680e-02,
        -8.49454804e-03,  -3.47582280e-02,   0.00000000e+00,
         3.16736179e-02,   0.00000000e+00,   6.17172879e-02,
         6.97260228e-02,   9.41250000e-03,   5.26668904e-03,
         0.00000000e+00,  -1.33196548e-03,   0.00000000e+00,
        -1.50734719e-02,   6.01131358e-02,   6.39807102e-01,
        -1.37311669e-02,   3.47456926e-02,   1.14927088e-02,
         2.31695793e-03,   0.00000000e+00,  -7.61796454e-03,
         0.00000000e+00,  -1.87381150e-02,  -1.38827940e-02,
        -5.46551483e-03,  -3.49023896e-03,   0.00000000e+00,
         8.33744935e-03,   0.00000000e+00,   1.19917088e-02,
         2.22808626e-02,  -6.94651319e-02,   4.84026230e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.36679449e-03,  -6.10363355e-03,
        -4.40542054e-03,   1.41065221e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.50303225e-03,   0.00000000e+00,
        -3.97080902e-03,   1.14157497e-02,  -7.18445554e-04,
         1.39243240e-02,   0.00000000e+00,  -1.56763437e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.80475089e-03,
         0.00000000e+00,   2.10355896e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.32978888e-03,   0.00000000e+00,
        -7.27743909e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.03974823e-04,   0.00000000e+00,
        -1.45880635e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.51617574e-04,
         0.00000000e+00,  -5.73208178e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.34468923e-03,   2.07937035e-03,  -7.06586563e-04,
         6.14909138e-03,   0.00000000e+00,  -5.50080591e-03,
         0.00000000e+00,   8.04667181e-03,  -5.01358025e-03,
         1.47206565e-03,  -1.98861357e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.74744051e-03,   0.00000000e+00,
        -5.01662022e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.58583624e-02,
         0.00000000e+00,  -5.68558073e-03,  -1.60236312e-04,
        -3.99234744e-04,  -8.66702128e-04,   0.00000000e+00,
        -7.45050667e-04,   0.00000000e+00,   1.45725546e-03,
        -7.07921497e-04,   1.97956212e-03,  -3.36564248e-03,
         0.00000000e+00,  -6.40247885e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.45346506e-04,   0.00000000e+00,
         9.99844124e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.24727247e-03,
         0.00000000e+00,   4.45850839e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.29074899e-04,   0.00000000e+00,
         1.02754936e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.46843804e-03,
         0.00000000e+00,  -8.58401504e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.58350528e-03,
         0.00000000e+00,   1.38973933e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.13240805e-03,   0.00000000e+00,   4.19138900e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.85764292e-03,   0.00000000e+00,
         1.53571773e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.35789581e-04,
         0.00000000e+00,   7.25953371e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.38510904e-01,  -1.23942507e-01,  -9.64843644e-02,
        -2.61923576e-02,   5.11242108e-02,  -4.46652190e-03,
         6.50247510e-03,  -7.15430680e-02,  -9.70566647e-03,
         1.01848132e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.10372914e-01,
         8.18876602e-03,   3.39324240e-02,   1.38584310e-01,
         9.64481595e-02,   0.00000000e+00,   1.06713388e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.59899621e-02,   0.00000000e+00,
        -1.62427869e-01,   5.62163134e-02,   1.97888741e-02,
         7.37746390e-02,  -1.05631611e-01,   0.00000000e+00,
         5.71814152e-02,   0.00000000e+00,  -3.46640307e-02,
        -7.48219310e-03,   3.49011402e-02,  -4.52649898e-02,
         2.70570790e-02,   0.00000000e+00,  -2.75922751e-03,
         0.00000000e+00,  -3.76291177e-03,  -7.03456509e-02,
         1.07805036e-02,   1.42712998e-02,  -1.69950987e-02,
        -1.58377808e-02,   0.00000000e+00,  -2.14159989e-03,
         0.00000000e+00,   2.97708831e-03,  -3.57124896e-02,
        -8.14372891e-02,   2.54764153e-03,   8.70696573e-04,
         1.45656006e-02,   1.09377026e-02,   0.00000000e+00,
        -7.05183868e-02,   0.00000000e+00,   2.92253658e-02,
         5.83036876e-03,   3.12147974e-02,  -1.24053686e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.35230146e-02,   0.00000000e+00,
        -9.48313395e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.69867311e-01,
         5.32264067e-03,  -4.26557552e-04,  -3.43891842e-02,
         3.29482487e-02,   0.00000000e+00,   1.66999290e-02,
         0.00000000e+00,   3.33264051e-02,  -4.38888851e-02,
        -1.64736256e-02,  -1.62632433e-02,   0.00000000e+00,
        -1.22754256e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.03056586e-02,
         0.00000000e+00,   1.76013959e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.56358466e-02,   0.00000000e+00,   1.79419375e-01,
         1.56979672e-04,  -6.86056082e-03,  -3.51326087e-02,
        -4.30320026e-02,   0.00000000e+00,  -3.94072809e-02,
         0.00000000e+00,  -3.48966873e-03,  -1.86668630e-03,
         2.06665109e-02,   8.01692688e-02,   0.00000000e+00,
        -3.49722034e-02,   0.00000000e+00,   1.40577307e-01,
         7.89977959e-03,  -3.90321342e-03,  -2.10734456e-02,
         3.74738741e-02,   0.00000000e+00,  -1.75641446e-02,
         0.00000000e+00,  -6.72075773e-02,   1.81457800e-02,
        -1.18453494e-02,   1.67759243e-02,   0.00000000e+00,
         6.25351602e-02,   0.00000000e+00,   7.57698354e-03,
         1.58153850e-01,  -8.78382125e-03,   6.27398355e-02,
         7.66542713e-03,   6.06506708e-03,   0.00000000e+00,
        -1.52435708e-02,   0.00000000e+00,  -4.74165279e-02,
        -1.46171706e-02,  -1.04352354e-02,  -1.60847902e-02,
         0.00000000e+00,  -4.00632805e-02,   0.00000000e+00,
         1.64611802e-02,  -3.52651496e-02,  -1.05957282e-01,
        -5.50474430e-02,   1.43059536e-02,   5.46116064e-03,
        -5.90268691e-03,   0.00000000e+00,   8.07590222e-04,
         0.00000000e+00,  -2.58964976e-02,   2.14496756e-02,
        -8.90103422e-03,  -3.42698487e-03,   0.00000000e+00,
        -2.51307602e-02,   0.00000000e+00,  -1.20232210e-02,
        -5.45768033e-03,   1.10690509e-01,   1.31314979e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.77802506e-03,  -1.03453241e-03,
         5.59433398e-03,   8.74816747e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.35543039e-02,   0.00000000e+00,
        -2.79074859e-03,  -9.18894455e-03,  -9.75757059e-03,
        -1.10053423e-02,   0.00000000e+00,   1.13892331e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.88711442e-04,
         0.00000000e+00,  -3.96760692e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.04224473e-04,   0.00000000e+00,
        -2.47857292e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.42709019e-03,   0.00000000e+00,
        -2.41411266e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.13943385e-03,
         0.00000000e+00,   5.81836425e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.28398084e-03,  -3.10628781e-03,  -2.91506251e-03,
        -2.37060256e-03,   0.00000000e+00,   7.31912084e-03,
         0.00000000e+00,  -1.47883943e-03,   2.18548190e-04,
        -3.52927251e-03,   1.30682012e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.03457476e-03,   0.00000000e+00,
        -1.05690164e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.67780551e-04,
         0.00000000e+00,   3.65136484e-04,   1.68462771e-04,
        -1.87705356e-03,  -2.75158189e-03,   0.00000000e+00,
        -2.96075331e-03,   0.00000000e+00,   2.10747732e-04,
        -1.69931023e-04,   5.57947221e-04,   6.82951969e-03,
         0.00000000e+00,  -1.56104409e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.79869463e-03,   0.00000000e+00,
         9.20381334e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.92437161e-03,
         0.00000000e+00,   1.10649088e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.00836757e-04,   0.00000000e+00,
         6.11786627e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.28776286e-04,
         0.00000000e+00,  -4.70340484e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.82965983e-04,
         0.00000000e+00,   1.05302308e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.20004902e-03,   0.00000000e+00,   2.73851835e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.03037880e-04,   0.00000000e+00,
         6.46571177e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.02380572e-03,
         0.00000000e+00,  -2.05981410e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.67190528e-03,  -4.24550918e-03,
         5.29579698e-03,  -7.17526369e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.64254603e-03,   0.00000000e+00,
        -1.31193686e-02,  -2.37194779e-02,  -8.06134693e-03,
         1.80477111e-03,   0.00000000e+00,   2.93999535e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.40819035e-02,
         0.00000000e+00,   1.64087545e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.63344136e-03,   0.00000000e+00,
         1.42279082e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.93843396e-03,   0.00000000e+00,
         5.29611138e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.54478174e-04,
         0.00000000e+00,   3.11499672e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.97640948e-03,  -1.24654098e-02,  -2.72483644e-03,
        -8.58903475e-04,   0.00000000e+00,   2.72410346e-03,
         0.00000000e+00,   1.26036549e-02,   2.44577221e-03,
         2.36111667e-03,  -2.58258692e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.10508226e-05,   0.00000000e+00,
        -2.61031740e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.73239035e-03,
         0.00000000e+00,  -4.98668763e-03,  -1.45940515e-03,
        -2.95037625e-03,   2.82535064e-03,   0.00000000e+00,
        -1.54307841e-03,   0.00000000e+00,  -1.47993927e-03,
         1.58330830e-03,  -3.71466353e-04,   9.79773688e-05,
         0.00000000e+00,  -8.89493223e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.06501757e-04,   0.00000000e+00,
        -1.09910546e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.39099012e-03,
         0.00000000e+00,   1.10689746e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.93917235e-03,   0.00000000e+00,
         6.54548130e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.75053212e-03,
         0.00000000e+00,   1.10831820e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.17367476e-03,
         0.00000000e+00,   8.28549947e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.16842678e-02,   0.00000000e+00,   5.78207786e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.49333589e-03,   0.00000000e+00,
         3.45754914e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.88394605e-03,
         0.00000000e+00,   2.72322128e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.95709145e-03,  -1.76118279e-03,
        -1.53495136e-04,   1.25012797e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.56505937e-03,   0.00000000e+00,
        -2.74706213e-03,  -1.24013814e-02,   7.45804087e-03,
        -3.94732259e-03,   0.00000000e+00,  -6.56950781e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.07355156e-03,
         0.00000000e+00,  -4.10805311e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.83061863e-03,   0.00000000e+00,
         1.01463258e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.31679310e-04,   0.00000000e+00,
         6.36098092e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.74001938e-05,
         0.00000000e+00,   4.50483147e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.01462629e-03,  -1.08242616e-02,   3.93245580e-03,
        -2.67486735e-03,   0.00000000e+00,  -3.88403923e-04,
         0.00000000e+00,  -1.21107938e-04,   5.68153912e-03,
         5.22498135e-03,  -1.61452463e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.83370583e-05,   0.00000000e+00,
         4.35759536e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.01895356e-02,
         0.00000000e+00,   1.95609890e-03,  -2.20165464e-03,
         1.17702199e-03,  -9.02138170e-04,   0.00000000e+00,
         4.04656578e-04,   0.00000000e+00,   1.55328021e-03,
         2.71803939e-04,   9.78638477e-04,  -5.92898142e-04,
         0.00000000e+00,   1.67712790e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.73434145e-05,   0.00000000e+00,
        -9.41310055e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.80000112e-04,
         0.00000000e+00,  -1.23699618e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.18928120e-03,   0.00000000e+00,
         3.75287328e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.48663409e-04,
         0.00000000e+00,  -2.43113519e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.60103298e-03,
         0.00000000e+00,   7.09251720e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.25043859e-03,   0.00000000e+00,   1.49954692e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.62419922e-03,   0.00000000e+00,
        -2.92389921e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.37194599e-03,
         0.00000000e+00,  -1.79787782e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.20425325e-03,  -4.26190748e-03,
         3.75377703e-04,  -5.37186663e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.02948570e-04,   0.00000000e+00,
        -9.47771552e-03,  -2.44055129e-02,   4.35877074e-03,
        -3.28826360e-03,   0.00000000e+00,   1.10864704e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.57147556e-03,
         0.00000000e+00,   5.45819732e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.48899343e-04,   0.00000000e+00,
         6.29312699e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.99075395e-03,   0.00000000e+00,
         1.24196330e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.05972788e-03,
         0.00000000e+00,  -3.07775569e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.52040193e-04,  -5.33255698e-03,   2.39205375e-03,
        -1.05320951e-03,   0.00000000e+00,  -1.72767338e-03,
         0.00000000e+00,   4.63813000e-03,   8.94208584e-03,
        -4.96071059e-04,  -4.08012663e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.85854687e-04,   0.00000000e+00,
         1.26650311e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.04307153e-03,
         0.00000000e+00,  -2.39497791e-03,   9.85531755e-04,
         2.19778555e-04,   2.38464733e-03,   0.00000000e+00,
        -2.75220627e-04,   0.00000000e+00,   1.28371898e-03,
         1.31935341e-03,  -8.51577049e-04,  -1.42774029e-04,
         0.00000000e+00,   2.77663738e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.10040300e-03,   0.00000000e+00,
        -1.46884593e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.55443155e-04,
         0.00000000e+00,   1.64397107e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.77486812e-04,   0.00000000e+00,
         2.21088331e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.87011992e-03,
         0.00000000e+00,  -3.63443045e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.18180579e-03,
         0.00000000e+00,  -2.75736808e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.18136734e-02,   0.00000000e+00,   4.37323748e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.41334061e-03,   0.00000000e+00,
         5.05940433e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.58920593e-03,
         0.00000000e+00,  -4.56783577e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.80746108e-02,  -3.81700063e-02,  -1.32320560e-01,
        -1.03155997e-02,   3.47997060e-03,  -9.54162523e-02,
         6.86053124e-04,  -2.06040692e-02,  -2.45039720e-03,
        -6.64564722e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.04800021e-02,
         5.26986598e-03,   1.75036573e-02,   4.27611600e-02,
         3.29757952e-02,   0.00000000e+00,  -9.97830941e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.84305398e-02,   0.00000000e+00,
        -1.49337825e-01,   2.44603530e-02,   2.95999779e-02,
         1.97743740e-02,  -3.22139401e-02,   0.00000000e+00,
         2.02204610e-02,   0.00000000e+00,  -1.21871049e-01,
         8.84098172e-03,   4.07733661e-02,  -4.34914857e-02,
         1.31708600e-02,   0.00000000e+00,   1.60222904e-02,
         0.00000000e+00,   2.54739249e-02,  -5.47274371e-02,
         4.86334720e-03,   2.02934287e-02,  -2.50533766e-02,
        -2.47600776e-03,   0.00000000e+00,   2.25466299e-02,
         0.00000000e+00,  -1.07349086e-02,  -3.50451369e-02,
        -4.76417011e-02,  -3.09431071e-03,   6.27397444e-03,
         4.49147552e-02,   4.71194170e-02,   0.00000000e+00,
        -7.32094163e-02,   0.00000000e+00,   5.14992517e-02,
         1.21266386e-02,   3.17963836e-02,  -1.45066529e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.20395816e-02,   0.00000000e+00,
        -1.46948745e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.93478090e-01,
        -1.25205457e-02,   1.97426419e-02,  -5.73208767e-02,
         2.57273921e-02,   0.00000000e+00,   9.07928677e-03,
         0.00000000e+00,   6.80811741e-02,  -5.77006297e-02,
        -2.50049295e-02,  -8.11419008e-03,   0.00000000e+00,
        -1.45278375e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.48249972e-02,
         0.00000000e+00,  -3.31889513e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.05003959e-02,   0.00000000e+00,  -3.85680855e-02,
        -4.15916766e-03,  -5.86939552e-03,  -9.16579238e-03,
         7.68198672e-04,   0.00000000e+00,   2.94437164e-02,
         0.00000000e+00,  -4.39707043e-04,  -5.23648187e-03,
        -9.67451854e-03,   2.43017956e-02,   0.00000000e+00,
        -9.20849443e-03,   0.00000000e+00,  -3.95560635e-02,
         7.72255751e-03,   1.51580602e-02,   1.92782789e-02,
        -1.65354078e-02,   0.00000000e+00,   2.42725926e-03,
         0.00000000e+00,  -2.09759730e-02,   6.04970706e-03,
         1.65427110e-03,   1.06928713e-02,   0.00000000e+00,
         3.02075423e-02,   0.00000000e+00,   1.81754937e-03,
        -4.76968012e-02,   4.21570022e-02,   8.53242034e-02,
         7.59720587e-03,   1.82424872e-02,   0.00000000e+00,
        -2.07448761e-02,   0.00000000e+00,  -3.92081088e-02,
        -3.01241647e-02,  -2.15582210e-02,  -5.78239798e-03,
         0.00000000e+00,  -4.79815787e-03,   0.00000000e+00,
         9.28011083e-03,  -2.04662458e-02,  -1.40364320e-01,
         9.51383860e-05,  -3.22426031e-02,  -5.34809729e-03,
        -5.26585760e-03,   0.00000000e+00,   8.44969674e-03,
         0.00000000e+00,   1.53961290e-02,   5.97104891e-03,
         7.52432698e-03,   4.18797878e-03,   0.00000000e+00,
        -7.80117764e-04,   0.00000000e+00,  -4.17273283e-03,
         4.26842350e-03,   3.17114801e-02,  -4.71818388e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.29204085e-03,  -3.45040793e-03,
        -1.91789853e-03,   1.11502717e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.12019241e-05,   0.00000000e+00,
        -5.63705487e-03,  -1.25934304e-02,  -2.80451896e-03,
        -5.00464705e-03,   0.00000000e+00,   8.06006452e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.71722106e-04,
         0.00000000e+00,   1.19163945e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.04666033e-04,   0.00000000e+00,
         1.67608463e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.12846974e-03,   0.00000000e+00,
         1.27434808e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.58775024e-03,
         0.00000000e+00,   1.67232280e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.60101463e-04,  -6.52137987e-03,  -5.22706058e-03,
        -1.00445709e-02,   0.00000000e+00,   1.23209510e-02,
         0.00000000e+00,  -7.32498767e-03,   3.62428116e-03,
        -2.82500925e-03,   9.00065490e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.60479983e-03,   0.00000000e+00,
         5.17153050e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.70663882e-03,
         0.00000000e+00,  -3.46004802e-03,  -5.59115279e-07,
        -1.65735063e-04,   1.85399241e-05,   0.00000000e+00,
         3.88482182e-03,   0.00000000e+00,  -1.67207647e-03,
         3.30730709e-04,  -2.94887473e-04,   1.54228143e-03,
         0.00000000e+00,   8.75284697e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.58056481e-03,   0.00000000e+00,
        -4.59279787e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.06331676e-03,
         0.00000000e+00,  -5.48549341e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.75645111e-04,   0.00000000e+00,
        -8.98307326e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.80913403e-04,
         0.00000000e+00,  -1.78809072e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.86449974e-03,
         0.00000000e+00,   2.88707994e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.18413062e-02,   0.00000000e+00,   1.34550118e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.69769935e-03,   0.00000000e+00,
         1.86989291e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.62238277e-03,
         0.00000000e+00,  -1.51986781e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.04726355e-04,  -1.60786789e-03,
        -9.78922745e-04,   1.63919147e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.14269923e-04,   0.00000000e+00,
        -9.51702327e-04,  -1.03467789e-03,   2.56679789e-03,
        -9.48851763e-04,   0.00000000e+00,  -1.96653168e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.57862108e-04,
         0.00000000e+00,  -1.56193029e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.74217728e-05,   0.00000000e+00,
         3.65455818e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.08059096e-04,   0.00000000e+00,
         1.65133107e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.40167067e-03,
         0.00000000e+00,  -4.28604922e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.71648223e-03,  -1.53228883e-03,   1.17337505e-02,
        -1.39106364e-03,   0.00000000e+00,  -4.80816337e-03,
         0.00000000e+00,  -8.07807630e-03,   7.42783948e-03,
         5.14399694e-03,  -1.21708317e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.12239170e-03,   0.00000000e+00,
         1.49313849e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.38362604e-03,
         0.00000000e+00,  -3.97019690e-03,   1.05552669e-03,
         1.53032383e-03,  -2.27216397e-03,   0.00000000e+00,
        -2.78792444e-03,   0.00000000e+00,  -2.10581579e-03,
         1.19580359e-03,   1.39002322e-03,  -8.83698124e-05,
         0.00000000e+00,   1.26997753e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.50849150e-03,   0.00000000e+00,
         3.64708002e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.82906077e-04,
         0.00000000e+00,  -1.62769086e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.82716100e-04,   0.00000000e+00,
        -4.06061068e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.77654009e-04,
         0.00000000e+00,  -2.33049369e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.23757753e-03,
         0.00000000e+00,  -1.35160216e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.79969504e-04,   0.00000000e+00,  -7.28854668e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.72626022e-03,   0.00000000e+00,
         2.95405022e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.70272387e-04,
         0.00000000e+00,  -3.65399210e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.22126364e-02,   2.90678045e-02,  -7.06016902e-03,
         8.09619399e-03,  -7.97329054e-03,  -2.10359010e-02,
        -3.77330545e-03,   9.88576233e-03,   1.95139156e-03,
        -4.86324625e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.19695276e-02,
        -1.40758537e-03,  -3.97552923e-03,  -3.16021532e-02,
        -2.08176819e-02,   0.00000000e+00,  -3.12533848e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.16884154e-02,   0.00000000e+00,
         4.25958446e-03,  -2.09272419e-02,  -9.36924820e-03,
        -2.01581560e-02,   2.53596873e-02,   0.00000000e+00,
        -1.25125016e-02,   0.00000000e+00,  -1.77784335e-02,
         6.38945211e-03,  -3.90133382e-03,   9.62231434e-03,
        -5.77471405e-03,   0.00000000e+00,   5.98726723e-04,
         0.00000000e+00,   4.65261145e-03,  -1.00968182e-03,
        -4.33761830e-03,  -1.87898567e-03,   5.82862748e-03,
         9.29205368e-03,   0.00000000e+00,   7.11514356e-04,
         0.00000000e+00,  -1.28246139e-03,   3.46434629e-03,
        -3.56894104e-03,  -2.40893531e-03,   9.15521747e-04,
         3.66399101e-03,   4.07821908e-03,   0.00000000e+00,
         2.24993460e-02,   0.00000000e+00,  -6.36125639e-03,
        -2.48435995e-03,  -5.82540162e-03,   5.83096132e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.64548395e-02,   0.00000000e+00,
         2.39231415e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.39606111e-02,
        -7.39209975e-03,   2.94212206e-03,   8.50914345e-03,
        -1.60716028e-02,   0.00000000e+00,  -5.85842401e-03,
         0.00000000e+00,  -7.74194474e-03,   5.91318342e-03,
         5.58342533e-03,   1.71333942e-03,   0.00000000e+00,
         6.98332384e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.34363641e-02,
         0.00000000e+00,  -1.33176044e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.97672952e-02,   0.00000000e+00,  -6.73346660e-02,
        -1.64146670e-03,   2.17231021e-03,   2.64173340e-02,
         3.23820332e-02,   0.00000000e+00,   3.47096029e-02,
         0.00000000e+00,   1.86976132e-03,  -2.10287437e-04,
        -6.04099956e-03,  -1.98741390e-02,   0.00000000e+00,
         9.69304083e-03,   0.00000000e+00,  -5.69982366e-02,
        -3.10288686e-03,   1.25292410e-02,   2.39231485e-02,
        -3.40575788e-02,   0.00000000e+00,   1.31995576e-02,
         0.00000000e+00,   3.54814182e-02,  -8.08255685e-03,
         3.60188131e-03,  -4.11066120e-03,   0.00000000e+00,
        -1.64122515e-02,   0.00000000e+00,  -1.84194244e-03,
        -6.10394080e-02,   1.73374008e-02,  -2.20372897e-02,
        -1.94982043e-03,   8.27507602e-04,   0.00000000e+00,
         5.83437577e-03,   0.00000000e+00,   1.04348239e-02,
         1.01636255e-03,   4.14669266e-03,  -1.68328945e-03,
         0.00000000e+00,   9.99904393e-04,   0.00000000e+00,
        -3.63206717e-03,   8.93379620e-03,  -2.90978612e-05,
         4.85594696e-02,  -1.66960208e-02,  -2.13215415e-03,
         2.57717035e-04,   0.00000000e+00,   1.23871820e-03,
         0.00000000e+00,   1.46865532e-02,  -6.96799387e-03,
         2.44102692e-03,   2.43013022e-03,   0.00000000e+00,
         8.44516303e-03,   0.00000000e+00,   2.76172351e-03,
        -1.05579702e-03,  -2.75982744e-02,  -5.50215986e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.83237789e-04,   8.66870441e-04,
        -1.49559475e-03,  -2.08718853e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.02688210e-03,   0.00000000e+00,
         2.36740102e-03,   6.41522103e-03,   8.48136978e-04,
         2.28350882e-03,   0.00000000e+00,  -8.92071471e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.20935723e-04,
         0.00000000e+00,  -1.87968186e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.00926474e-04,   0.00000000e+00,
        -1.22136580e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.51126083e-04,   0.00000000e+00,
        -1.63229828e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.67437487e-03,
         0.00000000e+00,  -4.76238846e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.37803882e-03,   4.55275440e-03,   2.35734657e-03,
         5.08742704e-04,   0.00000000e+00,  -5.39151785e-03,
         0.00000000e+00,  -1.89084392e-03,  -6.65127183e-04,
         4.84279604e-04,  -1.48457877e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.83608975e-04,   0.00000000e+00,
         2.23800177e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.70709276e-04,
         0.00000000e+00,  -4.13342498e-04,   7.80467885e-04,
         4.38461862e-03,   5.81456161e-03,   0.00000000e+00,
         4.50234114e-03,   0.00000000e+00,  -7.91385274e-04,
        -1.43664429e-04,  -3.22811324e-04,  -1.00762365e-03,
         0.00000000e+00,   3.58662723e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.34756196e-03,   0.00000000e+00,
         2.99069316e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.22508733e-03,
         0.00000000e+00,  -2.71200544e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.59751391e-04,   0.00000000e+00,
        -1.26601242e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.00211027e-03,
         0.00000000e+00,  -1.06595871e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.19599140e-04,
         0.00000000e+00,  -4.01421578e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.13838477e-03,   0.00000000e+00,  -1.31459763e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.50524255e-04,   0.00000000e+00,
         1.16275688e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.74141169e-03,
         0.00000000e+00,   7.83735468e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.21177476e-03,  -4.67953505e-03,
        -2.60504246e-03,   2.09206891e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.30528613e-04,   0.00000000e+00,
        -3.98912192e-03,  -7.11116817e-03,  -1.35608265e-04,
        -3.03840002e-03,   0.00000000e+00,   3.30092379e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.17143244e-03,
         0.00000000e+00,   4.45657448e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.43845258e-04,   0.00000000e+00,
         1.71073470e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.21516275e-04,   0.00000000e+00,
         1.61953620e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.48405552e-04,
         0.00000000e+00,  -1.92418423e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.25486697e-03,  -8.37504733e-03,  -4.12004146e-03,
         1.43448848e-03,   0.00000000e+00,   1.00229888e-03,
         0.00000000e+00,   4.67155629e-03,   7.60853108e-04,
         1.52688066e-03,   1.26640012e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.51319549e-04,   0.00000000e+00,
        -3.47472999e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.01930369e-05,
         0.00000000e+00,  -1.36923539e-03,   2.10544856e-03,
         4.67077115e-03,  -5.41943572e-03,   0.00000000e+00,
         3.07092100e-03,   0.00000000e+00,   5.17018516e-03,
        -4.33188265e-04,   9.66677917e-05,  -5.99924931e-04,
         0.00000000e+00,  -2.28049812e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.12997024e-03,   0.00000000e+00,
        -1.19621330e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.25763701e-04,
         0.00000000e+00,  -8.12606061e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.06018904e-02,   0.00000000e+00,
         1.15504560e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.39001570e-03,
         0.00000000e+00,  -3.11158905e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.94604511e-04,
         0.00000000e+00,   7.91988807e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.84158517e-03,   0.00000000e+00,   4.44939388e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.62905835e-04,   0.00000000e+00,
        -5.67570884e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.23000945e-03,
         0.00000000e+00,   4.11525831e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.17237303e-04,   1.09712553e-03,
         1.55459668e-03,  -2.80271243e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.23400472e-03,   0.00000000e+00,
        -1.02307614e-03,  -7.51762355e-03,  -2.16952651e-03,
        -2.75411883e-03,   0.00000000e+00,   4.25087356e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.09801878e-05,
         0.00000000e+00,   5.80949794e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.66498676e-03,   0.00000000e+00,
         8.65903111e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.37084567e-03,   0.00000000e+00,
        -2.27691827e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.54130452e-04,
         0.00000000e+00,   4.00386520e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.76064002e-02,  -3.25863180e-02,  -3.99588209e-03,
        -6.59700149e-03,   0.00000000e+00,   9.00141139e-03,
         0.00000000e+00,   9.60332071e-03,   1.87765985e-03,
         1.18185576e-02,   4.86322391e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.48291654e-03,   0.00000000e+00,
         7.84839200e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.13244493e-03,
         0.00000000e+00,   7.13401904e-03,  -1.14389514e-02,
        -6.94774882e-04,  -1.51471733e-03,   0.00000000e+00,
         2.90176890e-03,   0.00000000e+00,   2.38015844e-03,
         1.70903322e-04,   2.75557193e-03,  -4.41571483e-04,
         0.00000000e+00,  -1.80493546e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.77631694e-04,   0.00000000e+00,
        -2.89048460e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.00998395e-03,
         0.00000000e+00,  -6.56363993e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.73192204e-04,   0.00000000e+00,
         5.57633588e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.84750753e-03,
         0.00000000e+00,   3.93583071e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.34486821e-02,
         0.00000000e+00,   3.91609333e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.25531128e-02,   0.00000000e+00,   1.44070329e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.42723787e-03,   0.00000000e+00,
        -1.84630248e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.45768593e-04,
         0.00000000e+00,   1.55000467e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.88813728e-03,   1.95679926e-03,
         1.13008780e-03,  -1.08664613e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.51173445e-04,   0.00000000e+00,
        -1.01822144e-03,  -9.14991233e-03,  -8.04643873e-04,
        -1.27690166e-03,   0.00000000e+00,   1.88157669e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.76410816e-03,
         0.00000000e+00,   3.17352137e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.92900914e-04,   0.00000000e+00,
        -2.18752630e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.21447708e-04,   0.00000000e+00,
         3.72642799e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.90890669e-04,
         0.00000000e+00,  -2.05786856e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.85509567e-04,   9.63605474e-03,   8.65070367e-04,
         1.80414067e-03,   0.00000000e+00,  -2.47821854e-03,
         0.00000000e+00,  -2.53525261e-03,   1.90039164e-03,
        -3.74117965e-03,  -6.82014762e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.46567652e-03,   0.00000000e+00,
         1.24677385e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.07725062e-03,
         0.00000000e+00,   1.77936784e-02,  -4.83072067e-03,
        -1.96394538e-03,   2.10199123e-03,   0.00000000e+00,
        -6.68081205e-04,   0.00000000e+00,   3.78010781e-03,
        -7.31843464e-04,  -7.44961916e-04,   7.76402373e-04,
         0.00000000e+00,   1.75731267e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.68858320e-04,   0.00000000e+00,
         9.77684760e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.23233936e-05,
         0.00000000e+00,   3.75839736e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.99478509e-03,   0.00000000e+00,
         1.65776561e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.83648371e-03,
         0.00000000e+00,  -9.93002151e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.25291402e-03,
         0.00000000e+00,  -1.49707881e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.04812244e-03,   0.00000000e+00,  -1.69746932e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.17597952e-02,   0.00000000e+00,
         3.97432995e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.97474370e-03,
         0.00000000e+00,  -7.46851011e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.76658696e-02,  -4.17168348e-02,  -2.92546378e-02,
        -2.39871363e-02,   4.33030300e-03,  -2.71301352e-02,
         7.62232312e-02,   4.71802906e-03,  -1.70802036e-03,
         4.50786236e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.50163094e-03,
        -3.16478192e-03,  -3.00898431e-02,   1.66434795e-02,
         6.32534725e-03,   0.00000000e+00,   5.55115703e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.79531872e-02,   0.00000000e+00,
        -4.31765855e-02,   1.37923792e-02,   7.46732231e-02,
         2.41499402e-02,  -1.17759129e-02,   0.00000000e+00,
         7.97875326e-03,   0.00000000e+00,  -6.62157761e-02,
         5.43882932e-04,  -8.85024292e-03,  -1.07810079e-02,
        -6.73639992e-03,   0.00000000e+00,   8.72484675e-03,
         0.00000000e+00,  -2.17911188e-03,  -1.92208263e-02,
         4.04768184e-03,   9.37432158e-03,  -3.96424469e-03,
        -1.45981143e-02,   0.00000000e+00,   7.99676156e-03,
         0.00000000e+00,  -2.05253923e-02,  -4.23502589e-03,
        -2.69728899e-02,  -3.76841072e-03,  -9.24296315e-03,
         3.68243212e-04,  -6.42321417e-03,   0.00000000e+00,
        -9.97115729e-03,   0.00000000e+00,   1.81329122e-02,
         1.47628997e-02,   2.93767103e-03,  -3.22990798e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.10661990e-03,   0.00000000e+00,
        -2.06365835e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.85044103e-02,
        -3.47659291e-03,  -1.33722155e-02,  -1.52310414e-02,
         1.30290485e-02,   0.00000000e+00,   9.79455430e-03,
         0.00000000e+00,   3.48914918e-02,  -6.05586531e-03,
        -6.10106250e-03,   3.61009499e-03,   0.00000000e+00,
        -2.87265015e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.63102477e-02,
         0.00000000e+00,  -6.14929292e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.84358223e-03,   0.00000000e+00,   8.11992747e-03,
        -3.89902769e-03,   2.70882482e-03,  -1.11888992e-02,
        -7.64304253e-03,   0.00000000e+00,  -4.11601708e-03,
         0.00000000e+00,  -9.44294495e-04,  -2.01055265e-03,
        -3.07336934e-03,   1.69324228e-03,   0.00000000e+00,
        -9.62049736e-03,   0.00000000e+00,   7.74757598e-03,
         3.98742267e-03,  -6.01822866e-04,  -6.39267198e-03,
         1.35730119e-02,   0.00000000e+00,  -3.43270791e-03,
         0.00000000e+00,  -8.47545818e-03,  -3.61197696e-03,
         2.53604480e-04,   1.46230708e-02,   0.00000000e+00,
         2.72989455e-02,   0.00000000e+00,   1.41671981e-03,
         1.11528318e-02,  -2.72768906e-03,   1.38864906e-02,
         2.33243483e-03,  -1.29261969e-03,   0.00000000e+00,
        -3.01059158e-03,   0.00000000e+00,  -2.27407697e-02,
        -2.64764470e-03,  -2.99908975e-03,   4.81428492e-02,
         0.00000000e+00,   3.21571294e-02,   0.00000000e+00,
         8.90804824e-03,  -4.51314586e-02,  -5.29082418e-02,
        -1.59816093e-02,   6.68211921e-03,  -4.22197562e-03,
        -2.13963455e-04,   0.00000000e+00,  -5.62816607e-04,
         0.00000000e+00,   1.63958556e-02,  -2.58231148e-03,
         3.32750012e-03,  -7.98652350e-03,   0.00000000e+00,
        -2.03592048e-02,   0.00000000e+00,   2.59179436e-02,
        -3.25767772e-02,   2.12627249e-02,  -2.09983497e-02,
         9.04525968e-02,  -6.76269296e-02,  -4.11071735e-02,
        -1.20842730e-02,   4.04958545e-02,   1.21949312e-02,
         3.33835549e-02,  -8.91568176e-02,  -1.33229833e-02,
         7.18638329e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.18696722e-01,
         2.35586917e-02,   3.57127993e-02,   8.06425594e-02,
         7.06544156e-02,   0.00000000e+00,   4.87348289e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.24888132e-02,   0.00000000e+00,
        -6.72846206e-02,  -1.20389317e-02,  -3.00701680e-02,
         4.68090422e-02,  -6.74493879e-02,   0.00000000e+00,
         4.59879325e-02,   0.00000000e+00,   6.68893357e-05,
         2.99187879e-03,   2.67315516e-02,  -2.27277405e-02,
         2.34071631e-02,   0.00000000e+00,  -1.52797175e-02,
         0.00000000e+00,   6.20211528e-03,  -4.90330679e-02,
        -1.70843854e-03,   4.34365885e-03,  -5.46979291e-03,
        -2.02824671e-03,   0.00000000e+00,  -1.12657776e-02,
         0.00000000e+00,   1.55811507e-02,  -1.99898728e-02,
        -5.27008791e-02,   3.03278225e-03,   1.48396176e-02,
         8.22714344e-03,   5.07189181e-03,   0.00000000e+00,
        -3.76959516e-02,   0.00000000e+00,   5.62458665e-03,
        -7.86379328e-03,   1.38202871e-02,  -7.35942542e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.00164183e-02,   0.00000000e+00,
        -3.36207826e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.84055942e-02,
         1.12864464e-02,   6.11121291e-03,  -8.19999679e-03,
         1.85379796e-02,   0.00000000e+00,   8.06315844e-03,
         0.00000000e+00,  -1.08244829e-03,  -2.68648851e-02,
        -6.69667771e-03,  -2.37600549e-02,   0.00000000e+00,
        -7.03698527e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.71989774e-02,
         0.00000000e+00,   1.40803913e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.30509667e-02,   0.00000000e+00,   1.02926512e-01,
        -5.93766071e-03,  -2.11260538e-03,  -1.43648322e-02,
        -2.29850129e-02,   0.00000000e+00,  -2.24302739e-02,
         0.00000000e+00,  -7.69899566e-03,   4.18275935e-03,
         1.43297123e-02,   5.04252538e-02,   0.00000000e+00,
        -2.11476096e-02,   0.00000000e+00,   9.03785187e-02,
         1.10498303e-02,  -1.57235209e-02,  -1.18153728e-02,
         2.09119584e-02,   0.00000000e+00,  -7.31937233e-03,
         0.00000000e+00,  -2.75114473e-02,   1.13106184e-02,
        -4.97170089e-03,   9.32979824e-03,   0.00000000e+00,
         4.06290449e-02,   0.00000000e+00,  -4.31605165e-04,
         1.24491517e-01,  -8.59411742e-03,   2.46233105e-02,
         4.68847983e-04,   3.27427576e-03,   0.00000000e+00,
        -1.45465329e-02,   0.00000000e+00,  -6.42792527e-03,
        -7.91897553e-03,   1.64238274e-03,  -4.07741898e-02,
         0.00000000e+00,  -6.23516101e-02,   0.00000000e+00,
         2.17908613e-02,  -2.15593297e-02,  -3.83736139e-02,
        -2.74854457e-02,   5.24239122e-03,   1.21663400e-02,
        -1.93081162e-02,   0.00000000e+00,   2.57457043e-03,
         0.00000000e+00,  -1.47314489e-02,   1.18612387e-02,
        -3.31320223e-04,   1.41548130e-02,   0.00000000e+00,
        -1.29613850e-02,   0.00000000e+00,   1.41336975e-02,
        -2.99617681e-02,   5.57269378e-02,   7.85876752e-02,
        -1.14906622e-02,   1.50673797e-03,  -9.44916860e-03,
         3.66582461e-03,   3.29135861e-03,  -1.37641934e-02,
        -1.00149870e-04,   9.95399988e-03,   1.87929759e-02,
         7.65466578e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.17983765e-02,
        -3.72550729e-04,  -1.72489062e-02,  -1.55440287e-02,
        -1.01555912e-02,   0.00000000e+00,   1.68333077e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.45764494e-03,   0.00000000e+00,
         1.32288192e-03,   1.06326944e-02,   2.04715306e-03,
         1.00496998e-02,   5.18315972e-03,   0.00000000e+00,
        -1.47554765e-02,   0.00000000e+00,  -1.51604717e-02,
        -1.92771571e-03,   1.73384714e-03,  -9.58596884e-04,
         1.46909458e-03,   0.00000000e+00,  -1.09199957e-03,
         0.00000000e+00,   3.72933840e-03,  -9.18350434e-03,
        -8.85425236e-04,  -1.53375636e-03,   6.25682778e-03,
         2.53313507e-03,   0.00000000e+00,  -7.32062215e-03,
         0.00000000e+00,   1.34968578e-04,  -3.57192240e-03,
        -1.35648940e-02,  -3.53067865e-03,  -5.66613035e-03,
        -3.22953968e-03,  -2.68765666e-03,   0.00000000e+00,
         6.20547401e-03,   0.00000000e+00,   3.76799875e-04,
        -3.53231900e-04,  -4.01208633e-03,   2.86655091e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.07311490e-03,   0.00000000e+00,
        -9.18691913e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.97168230e-04,
        -3.07239071e-03,  -4.18451239e-03,  -6.30980425e-03,
         2.04792209e-03,   0.00000000e+00,   2.92958884e-03,
         0.00000000e+00,   9.33537510e-03,  -7.46206112e-03,
        -3.89980514e-03,  -2.08489973e-03,   0.00000000e+00,
        -1.71225270e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.17261753e-04,
         0.00000000e+00,  -2.38246420e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.83893193e-03,   0.00000000e+00,  -9.46928102e-03,
        -2.37753768e-03,  -6.56518466e-04,  -2.01766682e-03,
        -9.05546781e-04,   0.00000000e+00,   1.70808038e-03,
         0.00000000e+00,   1.26235744e-03,  -1.56080448e-03,
         1.88791967e-03,  -1.03047692e-02,   0.00000000e+00,
        -2.13543702e-03,   0.00000000e+00,   5.59663454e-04,
        -3.04200332e-03,   1.75616042e-03,   2.26923023e-03,
        -1.73425007e-03,   0.00000000e+00,   6.56609650e-04,
         0.00000000e+00,  -7.91663355e-04,   8.57386395e-04,
        -8.66060545e-04,  -2.66835150e-03,   0.00000000e+00,
         1.03873531e-03,   0.00000000e+00,  -4.92781555e-03,
        -2.02997757e-02,   1.05894788e-03,   2.21342057e-03,
        -1.49271211e-03,  -2.84150942e-03,   0.00000000e+00,
         2.18040767e-03,   0.00000000e+00,  -6.73846207e-03,
         1.15221347e-03,  -2.94234353e-03,   1.38797725e-02,
         0.00000000e+00,   3.96731632e-03,   0.00000000e+00,
        -2.64654093e-03,   1.71782612e-03,  -5.07822520e-03,
        -1.48082669e-03,  -4.77900669e-03,  -3.94407924e-03,
         2.99654293e-03,   0.00000000e+00,  -3.13900760e-03,
         0.00000000e+00,   1.95259352e-03,  -1.50758137e-03,
        -9.56940723e-04,  -4.74589069e-03,   0.00000000e+00,
         8.45924272e-04,   0.00000000e+00,   3.79305422e-03,
         6.32219718e-03,  -2.45156761e-03,  -4.61284968e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.36679449e-03,  -6.10363355e-03,
        -4.40542054e-03,   1.41065221e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.50303225e-03,   0.00000000e+00,
        -3.97080902e-03,   1.14157497e-02,  -7.18445554e-04,
         1.39243240e-02,   0.00000000e+00,  -1.56763437e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.80475089e-03,
         0.00000000e+00,   2.10355896e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.32978888e-03,   0.00000000e+00,
        -7.27743909e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.03974823e-04,   0.00000000e+00,
        -1.45880635e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.51617574e-04,
         0.00000000e+00,  -5.73208178e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.34468923e-03,   2.07937035e-03,  -7.06586563e-04,
         6.14909138e-03,   0.00000000e+00,  -5.50080591e-03,
         0.00000000e+00,   8.04667181e-03,  -5.01358025e-03,
         1.47206565e-03,  -1.98861357e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.74744051e-03,   0.00000000e+00,
        -5.01662022e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.58583624e-02,
         0.00000000e+00,  -5.68558073e-03,  -1.60236312e-04,
        -3.99234744e-04,  -8.66702128e-04,   0.00000000e+00,
        -7.45050667e-04,   0.00000000e+00,   1.45725546e-03,
        -7.07921497e-04,   1.97956212e-03,  -3.36564248e-03,
         0.00000000e+00,  -6.40247885e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.45346506e-04,   0.00000000e+00,
         9.99844124e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.24727247e-03,
         0.00000000e+00,   4.45850839e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.29074899e-04,   0.00000000e+00,
         1.02754936e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.46843804e-03,
         0.00000000e+00,  -8.58401504e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.58350528e-03,
         0.00000000e+00,   1.38973933e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.13240805e-03,   0.00000000e+00,   4.19138900e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.85764292e-03,   0.00000000e+00,
         1.53571773e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.35789581e-04,
         0.00000000e+00,   7.25953371e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.49266678e-01,   4.19607410e-02,   6.07604496e-01,
         3.23478315e-02,   4.12774740e-03,   5.54698804e-01,
        -3.09604090e-03,   1.50911948e-02,  -5.63196725e-03,
         5.72277680e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.04759969e-01,
         1.31665269e-02,  -3.91475442e-02,  -3.73969069e-02,
        -4.33062210e-02,   0.00000000e+00,   5.77654912e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.58690427e-02,   0.00000000e+00,
         5.98757423e-01,  -2.19700921e-02,  -3.74809964e-02,
        -1.13264264e-02,   4.33071286e-02,   0.00000000e+00,
        -4.05953798e-02,   0.00000000e+00,   6.16421801e-01,
        -2.08913329e-02,  -6.84710158e-02,   7.36830367e-02,
        -2.16840129e-02,   0.00000000e+00,  -2.74775394e-02,
         0.00000000e+00,  -7.92644467e-02,   3.93206085e-01,
        -9.24802490e-03,  -3.41270771e-02,   3.41643655e-02,
        -4.25919257e-03,   0.00000000e+00,  -3.41780994e-02,
         0.00000000e+00,   2.72321307e-02,   8.21052473e-02,
         4.21933735e-01,   1.22806396e-03,  -1.44676254e-02,
        -5.75050954e-02,  -7.00680106e-02,   0.00000000e+00,
         8.29089452e-02,   0.00000000e+00,  -7.75334229e-02,
        -1.33280110e-02,  -3.43741368e-02,   6.05255350e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.09600261e-02,   0.00000000e+00,
         1.37678222e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.11354731e-01,
         2.55095478e-02,  -2.97937256e-02,   6.14048959e-02,
        -1.91590790e-02,   0.00000000e+00,  -3.22189625e-04,
         0.00000000e+00,  -9.39178876e-02,   8.56789668e-02,
         1.66707966e-02,   2.62169520e-02,   0.00000000e+00,
         5.99399617e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.68379398e-02,
         0.00000000e+00,   4.63984406e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.96431733e-02,   0.00000000e+00,   4.75944744e-01,
         3.65638658e-03,   8.37077187e-03,  -1.35405605e-02,
        -3.22471491e-02,   0.00000000e+00,  -7.33891556e-02,
         0.00000000e+00,  -1.42004447e-03,   3.90640964e-03,
         2.23325615e-02,  -2.03622094e-02,   0.00000000e+00,
        -1.93013733e-03,   0.00000000e+00,   4.77008078e-01,
         1.45358102e-02,  -3.18707570e-02,  -4.62749040e-02,
         5.81364671e-02,   0.00000000e+00,  -1.61956404e-02,
         0.00000000e+00,  -8.88398770e-03,   3.13504201e-03,
        -1.10964405e-02,  -2.47204534e-02,   0.00000000e+00,
        -4.05515066e-02,   0.00000000e+00,  -1.26316775e-02,
         5.06101453e-01,  -5.52680900e-02,  -7.54921729e-02,
        -8.13639922e-03,  -3.62541641e-02,   0.00000000e+00,
         2.50945221e-02,   0.00000000e+00,   4.97313818e-02,
         6.35744405e-02,   7.81562734e-03,   1.22018912e-02,
         0.00000000e+00,  -8.00632753e-04,   0.00000000e+00,
        -4.78282180e-03,   3.39173956e-02,   6.01150971e-01,
        -3.06522780e-02,   5.33534244e-02,   1.60277387e-02,
        -3.92676346e-03,   0.00000000e+00,  -1.26051018e-02,
         0.00000000e+00,  -2.35480305e-02,  -8.54429915e-03,
        -1.02902933e-02,  -4.89840354e-03,   0.00000000e+00,
        -6.58409017e-03,   0.00000000e+00,   2.04455310e-02,
         5.13999478e-03,  -2.42833067e-02,   5.17273865e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.28149208e-02,  -2.04433960e-02,
        -7.36750418e-03,   1.99927478e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.20700334e-03,   0.00000000e+00,
        -9.38296307e-03,  -2.52073168e-03,   2.68608247e-03,
        -1.35925360e-02,   0.00000000e+00,   7.18197670e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.22381536e-03,
         0.00000000e+00,  -7.54408929e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.51733664e-04,   0.00000000e+00,
         3.93331934e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.32687937e-04,   0.00000000e+00,
         1.92208932e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.41972711e-04,
         0.00000000e+00,   3.94014952e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.68701073e-03,  -4.55584989e-03,  -1.55030603e-03,
        -3.39223955e-04,   0.00000000e+00,   3.55849185e-03,
         0.00000000e+00,  -4.24279983e-03,   2.71831560e-03,
        -1.23604712e-03,   8.87990788e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.18318370e-03,   0.00000000e+00,
         7.95542473e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.98493685e-03,
         0.00000000e+00,  -6.51505938e-03,   5.17951482e-03,
         1.67505907e-03,  -5.12273080e-03,   0.00000000e+00,
        -1.58456702e-03,   0.00000000e+00,  -9.96173510e-04,
         1.65434262e-03,  -2.21726852e-04,   2.86198870e-03,
         0.00000000e+00,  -6.06160908e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.10274393e-03,   0.00000000e+00,
         2.42506911e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.40944550e-03,
         0.00000000e+00,   6.74713282e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.82074761e-03,   0.00000000e+00,
        -1.89404383e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.44199561e-03,
         0.00000000e+00,  -1.88596862e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.83352132e-03,
         0.00000000e+00,   1.09829719e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.47821732e-03,   0.00000000e+00,   1.44855847e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.16143300e-03,   0.00000000e+00,
         2.00155046e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.24452873e-03,
         0.00000000e+00,   2.51856193e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.00579918e-01,  -8.58591255e-02,  -6.21437551e-02,
        -6.78956152e-03,   2.40614500e-02,  -5.10907668e-03,
         2.40145723e-02,  -6.76922976e-02,  -6.97307805e-03,
         9.29253774e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.28161780e-01,
         2.81918104e-02,   2.03125083e-02,   9.76046590e-02,
         9.60476608e-02,   0.00000000e+00,   1.07234570e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.13369627e-02,   0.00000000e+00,
        -9.42859796e-02,   3.65562750e-02,   4.38911573e-03,
         4.61045532e-02,  -8.47584260e-02,   0.00000000e+00,
         5.03392685e-02,   0.00000000e+00,  -2.82122111e-02,
        -5.39015240e-03,   2.58247884e-02,  -3.12064067e-02,
         2.02730849e-02,   0.00000000e+00,  -4.13009891e-03,
         0.00000000e+00,   5.24493391e-04,  -4.57649887e-02,
         4.87534298e-03,   1.19999816e-02,  -1.43420297e-02,
        -1.40183616e-02,   0.00000000e+00,   3.15533757e-04,
         0.00000000e+00,   4.69513266e-03,  -2.31928153e-02,
        -4.92391694e-02,  -1.92850652e-03,   5.42199466e-03,
         1.27391503e-02,   8.13962067e-03,   0.00000000e+00,
        -5.49523772e-02,   0.00000000e+00,   2.47412008e-02,
         1.88254831e-03,   2.57517010e-02,  -1.05516560e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.00538073e-03,   0.00000000e+00,
        -5.61182655e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.00834995e-01,
         6.17542968e-03,  -2.13849920e-03,  -2.10286098e-02,
         2.87692866e-02,   0.00000000e+00,   1.28935861e-02,
         0.00000000e+00,   2.20497175e-02,  -2.95233798e-02,
        -9.00093083e-03,  -2.27958461e-02,   0.00000000e+00,
        -8.44204501e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.13672247e-02,
         0.00000000e+00,   1.17473236e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.24028822e-02,   0.00000000e+00,   1.11981681e-01,
        -5.04321061e-03,  -8.51013634e-04,  -2.39429724e-02,
        -3.65410256e-02,   0.00000000e+00,  -3.20295424e-02,
         0.00000000e+00,  -4.02979601e-03,   8.06051193e-04,
         1.48479094e-02,   6.47728793e-02,   0.00000000e+00,
        -3.14866456e-02,   0.00000000e+00,   1.13491253e-01,
         4.90670010e-03,  -5.68030960e-03,  -1.35422979e-02,
         3.00112731e-02,   0.00000000e+00,  -7.06594556e-03,
         0.00000000e+00,  -4.78095865e-02,   1.36055314e-02,
        -9.24155906e-03,   9.98960971e-03,   0.00000000e+00,
         4.67181311e-02,   0.00000000e+00,  -1.31257913e-02,
         1.16674921e-01,  -7.30392884e-03,   4.35949653e-02,
         3.58206937e-03,   2.13029996e-03,   0.00000000e+00,
        -1.54408294e-02,   0.00000000e+00,  -3.20483301e-02,
        -9.34301824e-03,  -4.70126789e-03,  -1.81942256e-02,
         0.00000000e+00,  -3.47340895e-02,   0.00000000e+00,
         2.57965677e-02,  -2.58899776e-02,  -6.73705674e-02,
        -4.06012885e-02,   7.95762285e-03,   1.66407859e-03,
        -8.58065271e-03,   0.00000000e+00,  -1.72731273e-03,
         0.00000000e+00,  -1.97408036e-02,   1.60708840e-02,
        -2.34982930e-03,   6.84188366e-03,   0.00000000e+00,
        -2.09621614e-02,   0.00000000e+00,   1.37428701e-02,
        -5.87358771e-03,   7.72655367e-02,   9.63117157e-02,
        -9.28527978e-02,   1.03374819e-01,   7.81259302e-02,
         3.76461955e-02,  -5.33243785e-02,   4.95613789e-03,
        -2.05199181e-02,   6.34081468e-02,   1.76833397e-02,
        -9.13062173e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.34287919e-01,
         9.76544102e-03,  -2.67388863e-02,  -1.07906754e-01,
        -7.23341307e-02,   0.00000000e+00,  -1.46049430e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.83309524e-02,   0.00000000e+00,
         1.12075752e-01,  -3.18581146e-02,  -3.15288346e-02,
        -6.85505480e-02,   1.07962353e-01,   0.00000000e+00,
        -5.09736112e-02,   0.00000000e+00,   4.74116288e-02,
         2.01761137e-03,  -2.47211013e-02,   3.71508803e-02,
        -2.56488371e-02,   0.00000000e+00,   3.21550340e-03,
         0.00000000e+00,   1.77582211e-03,   6.36372098e-02,
        -8.25813611e-03,  -1.16107141e-02,   1.10085192e-02,
         1.44866215e-02,   0.00000000e+00,   2.87167468e-03,
         0.00000000e+00,  -5.31703558e-04,   3.01184574e-02,
         7.55920996e-02,   2.28919848e-03,   5.27946816e-03,
        -1.11723912e-02,  -8.99645439e-03,   0.00000000e+00,
         5.58912288e-02,   0.00000000e+00,  -3.16268888e-02,
        -3.98500514e-03,  -2.70622892e-02,   1.09899236e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.44250889e-03,   0.00000000e+00,
         6.55966144e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.22261624e-01,
         2.02201134e-03,   5.58121172e-03,   2.92254701e-02,
        -2.73090573e-02,   0.00000000e+00,  -1.27546870e-02,
         0.00000000e+00,  -3.37261972e-02,   3.67591399e-02,
         1.10447376e-02,   2.11085541e-02,   0.00000000e+00,
         1.13735070e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.17600876e-02,
         0.00000000e+00,  -9.06317914e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.74598454e-02,   0.00000000e+00,  -1.17946969e-01,
        -2.64774312e-03,   5.51281337e-03,   2.55932342e-02,
         3.19802861e-02,   0.00000000e+00,   2.52718861e-02,
         0.00000000e+00,   1.14081605e-04,   3.34750200e-03,
        -1.61034624e-02,  -6.15179647e-02,   0.00000000e+00,
         2.55589020e-02,   0.00000000e+00,  -1.05779706e-01,
        -8.07192333e-03,   5.69649551e-03,   1.80556743e-02,
        -3.12849220e-02,   0.00000000e+00,   1.14328588e-02,
         0.00000000e+00,   5.55648537e-02,  -1.39067334e-02,
         1.09113077e-02,  -1.90107496e-02,   0.00000000e+00,
        -6.51294014e-02,   0.00000000e+00,  -2.88439336e-03,
        -1.51928484e-01,   9.67134407e-04,  -4.99492651e-02,
        -6.93993020e-03,  -3.33810305e-03,   0.00000000e+00,
         6.97028030e-03,   0.00000000e+00,   4.48687520e-02,
         1.06868374e-02,   9.86033635e-03,   6.68214486e-03,
         0.00000000e+00,   3.01413985e-02,   0.00000000e+00,
        -9.19774940e-03,   4.44159534e-02,   9.10289048e-02,
         4.55715459e-02,  -8.27424856e-03,  -6.44381585e-03,
         7.55864199e-03,   0.00000000e+00,  -4.79669612e-03,
         0.00000000e+00,   1.17064153e-02,  -1.40431637e-02,
         5.33086219e-03,   8.88191930e-03,   0.00000000e+00,
         2.27191391e-02,   0.00000000e+00,   1.57281166e-02,
         2.02944762e-02,  -8.33104079e-02,  -8.73795417e-02,
         1.87423230e-02,  -2.67710943e-02,  -3.66579672e-02,
        -9.29966567e-03,   1.62230945e-02,  -1.12754182e-02,
        -1.09281377e-03,  -2.64473979e-02,  -2.44215928e-03,
         1.13600970e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.74177592e-02,
         6.01370788e-05,   1.64810844e-02,   2.74888312e-02,
         2.23202790e-02,   0.00000000e+00,  -1.11302000e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.61085873e-02,   0.00000000e+00,
        -4.47870151e-02,   4.68697238e-03,  -5.28639750e-03,
         2.07790292e-02,  -3.23336252e-02,   0.00000000e+00,
         1.53639258e-02,   0.00000000e+00,  -1.94726720e-02,
         1.24801830e-03,   1.80183797e-02,  -1.72164829e-02,
         1.44183025e-02,   0.00000000e+00,  -2.68961574e-03,
         0.00000000e+00,   1.12207258e-02,  -2.26243458e-02,
         2.45099876e-03,   7.60091144e-03,  -7.71007472e-03,
         4.51332951e-04,   0.00000000e+00,  -8.39250863e-04,
         0.00000000e+00,   6.33846156e-03,  -1.10466574e-02,
        -1.72107966e-02,   1.89672950e-03,   6.52422858e-03,
         4.28478574e-03,   7.77855630e-03,   0.00000000e+00,
        -2.00434609e-02,   0.00000000e+00,   1.06253642e-02,
        -1.21417800e-03,   6.64141686e-03,  -3.96605905e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.17432539e-04,   0.00000000e+00,
        -2.62916171e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.85775617e-02,
         9.23819986e-04,   8.41933862e-03,  -1.39456532e-02,
         1.13223028e-02,   0.00000000e+00,   2.56303472e-03,
         0.00000000e+00,   1.41375444e-02,  -1.90314300e-02,
        -6.61721352e-03,  -1.02654769e-02,   0.00000000e+00,
        -5.18016374e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.20786073e-02,
         0.00000000e+00,   9.04975728e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.66723975e-02,   0.00000000e+00,   2.32584504e-02,
         6.06790327e-04,  -3.96253255e-03,  -6.75989874e-03,
        -8.85567639e-03,   0.00000000e+00,  -3.93632583e-03,
         0.00000000e+00,  -2.33304539e-04,  -4.68192026e-04,
         2.75229756e-03,   1.68454188e-02,   0.00000000e+00,
        -5.79609265e-03,   0.00000000e+00,   2.02342095e-02,
         8.64252659e-04,  -3.15716136e-03,  -2.31799712e-03,
         5.37434795e-03,   0.00000000e+00,  -2.47259830e-03,
         0.00000000e+00,  -1.53405610e-02,   5.80755894e-03,
        -1.07486483e-03,   4.74493678e-03,   0.00000000e+00,
         1.95875423e-02,   0.00000000e+00,   7.15399348e-04,
         3.21807620e-02,   1.82059127e-03,   1.88943810e-02,
         9.69143566e-04,   6.26480497e-03,   0.00000000e+00,
        -6.31727670e-03,   0.00000000e+00,  -7.09255373e-03,
        -9.73317459e-03,  -3.17978115e-03,  -1.24718865e-02,
         0.00000000e+00,  -1.91620364e-02,   0.00000000e+00,
         3.19591854e-03,  -7.88471320e-03,  -3.64167453e-02,
        -1.16384453e-02,  -1.69407498e-03,   2.09585002e-03,
        -3.52016557e-03,   0.00000000e+00,   3.86368360e-03,
         0.00000000e+00,  -5.62520053e-03,   6.74874024e-03,
        -2.85559699e-04,   8.30250818e-04,   0.00000000e+00,
        -1.53752301e-03,   0.00000000e+00,  -5.79312658e-03,
        -4.52470441e-03,   2.33228645e-02,   1.57328640e-02,
         3.84741694e-03,   1.18895574e-02,   1.33060369e-02,
         5.02309815e-04,  -3.78931513e-03,   9.89854404e-03,
        -1.16784946e-02,  -3.75757004e-03,   2.81442439e-03,
        -3.49109166e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.31099646e-03,
         8.48908917e-04,   1.03962268e-02,  -1.17583942e-02,
        -5.16994235e-03,   0.00000000e+00,   5.71836728e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.90923401e-03,   0.00000000e+00,
         1.21845475e-02,  -9.57317439e-03,  -1.90054199e-02,
        -2.78235095e-03,   5.37182712e-03,   0.00000000e+00,
        -3.39801882e-03,   0.00000000e+00,   1.22914105e-02,
         1.42303574e-03,   3.91014135e-03,  -1.59594229e-04,
         2.58206668e-03,   0.00000000e+00,  -2.21719081e-03,
         0.00000000e+00,   6.28370872e-03,   9.15874382e-03,
        -1.01210243e-03,   4.94221111e-03,  -4.97202863e-03,
         8.86812498e-03,   0.00000000e+00,  -7.99707258e-04,
         0.00000000e+00,   1.16125359e-02,   6.36644692e-03,
         2.48631716e-02,  -4.26806722e-04,   9.33070707e-04,
        -3.62672369e-03,  -1.09429727e-03,   0.00000000e+00,
         1.04600891e-02,   0.00000000e+00,  -9.11673211e-03,
        -5.62551941e-03,  -7.45613660e-04,   1.79590449e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.35835523e-03,   0.00000000e+00,
         9.53667522e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.53486834e-02,
         5.12842986e-04,   1.54392302e-03,   3.79536438e-03,
        -5.49535840e-03,   0.00000000e+00,  -4.01753318e-04,
         0.00000000e+00,  -9.62276255e-03,   8.50301021e-04,
         5.35658272e-03,  -3.39079125e-03,   0.00000000e+00,
         1.46476340e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.23020198e-03,
         0.00000000e+00,   1.33797157e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.10825565e-03,   0.00000000e+00,  -3.62020468e-03,
        -1.15714297e-03,  -1.18002125e-03,   5.73212209e-03,
         6.68256231e-03,   0.00000000e+00,   3.14376966e-03,
         0.00000000e+00,  -3.51524666e-04,   1.11727793e-04,
        -1.42506522e-03,  -4.32045326e-03,   0.00000000e+00,
         2.95326584e-03,   0.00000000e+00,  -3.19327172e-03,
         2.75539797e-04,  -4.22140029e-04,   2.37167021e-03,
        -7.08073223e-03,   0.00000000e+00,   9.56340879e-04,
         0.00000000e+00,   7.01009848e-03,   3.71305928e-04,
         1.41859246e-03,  -3.95639627e-03,   0.00000000e+00,
        -4.86603642e-03,   0.00000000e+00,   5.07364437e-04,
        -3.94176231e-03,   1.14600708e-03,  -7.37532932e-03,
        -1.45382123e-03,  -2.18487736e-03,   0.00000000e+00,
         2.67601157e-03,   0.00000000e+00,   4.95369091e-03,
         9.89880132e-04,   2.23797973e-03,  -1.44332377e-02,
         0.00000000e+00,  -9.64504636e-03,   0.00000000e+00,
        -1.90502635e-03,   8.74856948e-03,   1.59074700e-02,
         7.45222686e-03,  -3.06064764e-03,   9.00896983e-04,
        -2.10778125e-03,   0.00000000e+00,  -1.03415117e-04,
         0.00000000e+00,  -6.53557388e-05,  -3.47024548e-04,
         1.73140774e-03,   2.51418911e-03,   0.00000000e+00,
         4.27184748e-03,   0.00000000e+00,  -5.19851853e-03,
         2.02781806e-03,  -9.18125823e-03,   1.26139608e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.17199867e-03,   3.53518394e-03,
         1.01217300e-03,  -2.10648200e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.04382213e-04,   0.00000000e+00,
         1.74772560e-03,  -2.57887756e-03,  -1.88547881e-04,
        -2.06425464e-03,   0.00000000e+00,   3.04799831e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.56764388e-03,
         0.00000000e+00,  -4.43847753e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.56580245e-04,   0.00000000e+00,
         2.54391235e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.23048055e-04,   0.00000000e+00,
        -9.39432903e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.61130494e-03,
         0.00000000e+00,   1.14987263e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.59779257e-04,  -3.14042516e-03,   1.35790170e-03,
        -9.15132687e-03,   0.00000000e+00,   7.56384785e-03,
         0.00000000e+00,  -1.11735555e-02,   3.62933756e-03,
         1.67409078e-04,   5.96234145e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.04429524e-03,   0.00000000e+00,
         1.02477341e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.13373483e-03,
         0.00000000e+00,   7.60263917e-04,  -2.47715117e-03,
        -5.28080669e-04,   6.89092919e-04,   0.00000000e+00,
         2.14170396e-03,   0.00000000e+00,  -2.58671411e-03,
         7.50681593e-06,   7.83943999e-04,   1.26788054e-03,
         0.00000000e+00,   2.66585172e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.04355742e-04,   0.00000000e+00,
        -2.03094667e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.36027944e-04,
         0.00000000e+00,  -2.43404159e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.54267396e-03,   0.00000000e+00,
        -2.82116436e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.77557989e-03,
         0.00000000e+00,   1.06242167e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.05401678e-04,
         0.00000000e+00,   1.94651881e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.23279325e-03,   0.00000000e+00,  -4.33448012e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.80904495e-04,   0.00000000e+00,
        -1.06993568e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.14739948e-03,
         0.00000000e+00,  -7.08717598e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.21972039e-02,  -3.08998177e-02,  -1.00476713e-01,
        -1.36970358e-02,  -3.32942051e-04,  -7.36357543e-02,
        -3.27473809e-03,  -1.68059546e-02,  -2.74478435e-03,
        -5.35355751e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.57063591e-02,
         1.26085001e-03,   2.01105737e-02,   3.62388884e-02,
         3.09392622e-02,   0.00000000e+00,  -8.20762365e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.55535035e-02,   0.00000000e+00,
        -1.08339754e-01,   2.15483974e-02,   2.20547565e-02,
         1.60274000e-02,  -3.11989346e-02,   0.00000000e+00,
         2.13151754e-02,   0.00000000e+00,  -9.90506461e-02,
         5.67832058e-03,   3.23044721e-02,  -3.63966686e-02,
         1.21722633e-02,   0.00000000e+00,   1.17200317e-02,
         0.00000000e+00,   2.42235973e-02,  -3.99764378e-02,
         3.85942968e-03,   1.61500402e-02,  -2.29481107e-02,
        -3.27227285e-03,   0.00000000e+00,   2.15445717e-02,
         0.00000000e+00,  -1.02839304e-02,  -2.61980264e-02,
        -2.98847601e-02,  -3.05426117e-03,   1.11896235e-02,
         3.72446636e-02,   5.26204584e-02,   0.00000000e+00,
        -7.56940442e-02,   0.00000000e+00,   5.90180580e-02,
         5.27970236e-03,   2.65323492e-02,  -1.23793613e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.77350313e-02,   0.00000000e+00,
        -9.24865031e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.37733485e-01,
        -7.40852506e-03,   2.06530809e-02,  -4.39248958e-02,
         2.97761253e-02,   0.00000000e+00,  -2.26574791e-03,
         0.00000000e+00,   6.54447076e-02,  -4.71538958e-02,
        -2.04649861e-02,  -1.07298040e-02,   0.00000000e+00,
        -1.18221997e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.18629120e-03,
         0.00000000e+00,  -1.91650995e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.25617980e-02,   0.00000000e+00,  -2.58367398e-02,
        -3.70616257e-03,  -6.90515459e-03,  -1.03603318e-02,
        -2.13249601e-03,   0.00000000e+00,   2.37945934e-02,
         0.00000000e+00,  -4.41822422e-03,  -3.98135790e-03,
        -7.83581548e-03,   2.22696538e-02,   0.00000000e+00,
        -5.46399173e-03,   0.00000000e+00,  -2.80517839e-02,
         7.79607418e-03,   7.94451286e-03,   9.19160171e-03,
        -1.24979896e-02,   0.00000000e+00,   1.35938945e-03,
         0.00000000e+00,  -2.26364811e-02,   6.53308071e-03,
         5.05528157e-04,   1.06422563e-02,   0.00000000e+00,
         2.76453761e-02,   0.00000000e+00,   1.38646974e-03,
        -3.60744639e-02,   3.08490923e-02,   6.95956089e-02,
         6.11501837e-03,   1.62851727e-02,   0.00000000e+00,
        -1.99153232e-02,   0.00000000e+00,  -2.39293462e-02,
        -2.63255861e-02,  -1.66578320e-02,  -8.55541188e-03,
         0.00000000e+00,   9.10118019e-04,   0.00000000e+00,
         5.63985242e-03,  -1.41236441e-02,  -1.10916638e-01,
        -3.79254661e-03,  -2.28912494e-02,  -4.02478251e-03,
        -5.79258890e-03,   0.00000000e+00,   6.77586309e-03,
         0.00000000e+00,   1.12420359e-02,   6.26670682e-03,
         3.90482487e-03,   4.53242193e-03,   0.00000000e+00,
         5.10348123e-04,   0.00000000e+00,  -9.15920045e-03,
         2.60273460e-03,   2.98406043e-02,  -3.54185529e-02,
         2.81722181e-03,  -2.81386043e-02,  -3.68495310e-02,
        -7.68978881e-03,   9.97017156e-04,  -2.34364792e-02,
         1.37335552e-02,  -1.11290424e-02,   2.37651969e-04,
         5.71480310e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.88713427e-02,
         6.78384427e-03,   2.38519658e-03,   2.63903339e-02,
         2.11403260e-02,   0.00000000e+00,  -1.29805726e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.52805891e-02,   0.00000000e+00,
        -4.63195144e-02,   2.04533096e-02,   2.22064730e-02,
         2.06615125e-02,  -2.20186942e-02,   0.00000000e+00,
         1.05597520e-02,   0.00000000e+00,  -3.75846251e-02,
        -1.22108646e-03,   1.34341628e-02,  -2.20454901e-02,
         7.38605778e-03,   0.00000000e+00,   5.89991660e-03,
         0.00000000e+00,   1.14898127e-02,  -1.70990985e-02,
         2.88259296e-03,   8.90003952e-03,  -1.18481598e-02,
        -6.49928443e-03,   0.00000000e+00,   8.35086642e-03,
         0.00000000e+00,  -4.34223081e-03,  -1.23048852e-02,
        -8.24244880e-03,  -1.79848336e-03,   2.84075690e-03,
         5.15173567e-03,   1.12953685e-02,   0.00000000e+00,
        -2.78369145e-02,   0.00000000e+00,   2.39282280e-02,
         2.20407645e-03,   7.60445457e-03,  -4.78878583e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.86351311e-03,   0.00000000e+00,
        -4.50617533e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.15677184e-02,
        -6.13938607e-04,   9.51509892e-03,  -2.96002863e-02,
         2.70478676e-02,   0.00000000e+00,   2.57099166e-03,
         0.00000000e+00,   4.29093164e-02,  -2.59418392e-02,
        -1.48684321e-02,  -3.17984998e-03,   0.00000000e+00,
        -5.69673294e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.05952228e-02,
         0.00000000e+00,  -3.93727561e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.71639456e-02,   0.00000000e+00,   1.67757150e-02,
        -4.00969230e-03,   3.97156363e-04,  -1.28745297e-02,
        -1.52797154e-02,   0.00000000e+00,  -9.02067911e-03,
         0.00000000e+00,   4.25146755e-04,  -6.72182870e-04,
        -5.23122127e-04,   1.72272096e-02,   0.00000000e+00,
        -1.03254396e-02,   0.00000000e+00,   1.39619129e-02,
         6.72791742e-03,  -3.21214444e-03,  -2.76382299e-03,
         1.26699214e-02,   0.00000000e+00,  -3.14928770e-03,
         0.00000000e+00,  -2.57067704e-02,   6.94792835e-03,
        -2.11482073e-04,   6.36909556e-03,   0.00000000e+00,
         2.23556834e-02,   0.00000000e+00,  -8.23933668e-04,
         1.11261053e-02,   5.79132686e-03,   3.82578605e-02,
         1.57599448e-03,   3.99739062e-03,   0.00000000e+00,
        -1.01193127e-02,   0.00000000e+00,  -1.42060672e-02,
        -1.26442472e-02,  -9.14537233e-03,   5.67465127e-03,
         0.00000000e+00,   6.26362759e-03,   0.00000000e+00,
         8.62327919e-03,  -1.34087717e-02,  -4.70563439e-02,
        -1.93772897e-02,  -1.52219868e-03,  -1.39883317e-03,
        -4.01428752e-03,   0.00000000e+00,  -1.01293549e-03,
         0.00000000e+00,   2.70130617e-03,   5.73624769e-03,
         2.15754549e-03,   2.05289462e-03,   0.00000000e+00,
        -7.40464130e-03,   0.00000000e+00,   3.65189871e-03,
        -1.86115339e-03,   2.71364637e-02,   7.36530936e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.18289107e-02,   3.82889185e-03,
         7.37715112e-04,  -4.36051477e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.48197701e-03,   0.00000000e+00,
        -1.09655441e-03,  -8.20917223e-03,  -1.90659817e-03,
         9.01749772e-04,   0.00000000e+00,   2.03669196e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.90786423e-04,
         0.00000000e+00,   2.76850939e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.44092064e-04,   0.00000000e+00,
        -3.79918149e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.20220163e-03,   0.00000000e+00,
         2.31141367e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.61997508e-04,
         0.00000000e+00,  -1.17211007e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.84757576e-03,   1.95913699e-03,   4.91211567e-04,
        -1.89663876e-03,   0.00000000e+00,  -1.09862852e-03,
         0.00000000e+00,   3.12834722e-03,   1.21239732e-03,
        -1.02044570e-03,  -3.78951877e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.27802932e-03,   0.00000000e+00,
        -1.98755743e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.20821678e-03,
         0.00000000e+00,   9.03255231e-03,  -6.36208743e-03,
        -3.24861337e-03,   1.10973279e-02,   0.00000000e+00,
         1.53106574e-03,   0.00000000e+00,  -1.16110404e-03,
         9.36903352e-06,  -6.10695839e-04,   1.69137054e-04,
         0.00000000e+00,   2.89191176e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.02788119e-03,   0.00000000e+00,
        -1.05961221e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.27555591e-04,
         0.00000000e+00,  -1.86654468e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.12067483e-02,   0.00000000e+00,
         3.17312141e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.23599418e-04,
         0.00000000e+00,   2.73639391e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.61037055e-03,
         0.00000000e+00,  -4.28483311e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.63695894e-03,   0.00000000e+00,  -2.60530538e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.50079572e-03,   0.00000000e+00,
        -1.13396786e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.46074555e-04,
         0.00000000e+00,  -8.77498407e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.68906023e-02,   2.09530266e-02,  -6.11583269e-03,
        -2.84863354e-03,  -1.07720510e-02,  -2.23049343e-02,
        -5.44915876e-03,   1.32615097e-02,  -1.18598648e-04,
        -4.54916944e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.33638266e-02,
        -6.52126520e-03,   1.22874073e-03,  -2.22873000e-02,
        -2.02213563e-02,   0.00000000e+00,  -3.04105449e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.38056368e-02,   0.00000000e+00,
        -1.16140786e-03,  -1.25554031e-02,   1.50888471e-03,
        -1.26704415e-02,   1.99133018e-02,   0.00000000e+00,
        -1.18419530e-02,   0.00000000e+00,  -2.19243565e-02,
         3.88608515e-03,  -4.67664254e-03,   2.94694024e-03,
        -5.40799733e-03,   0.00000000e+00,   4.84638109e-03,
         0.00000000e+00,   6.48579834e-03,   2.01341627e-03,
        -2.68428566e-03,  -1.91181060e-03,   1.11771075e-03,
         7.67804730e-03,   0.00000000e+00,   4.51506434e-03,
         0.00000000e+00,  -2.22545018e-03,   1.17930575e-03,
         1.89587087e-03,  -1.31883752e-03,  -4.55679361e-03,
         1.67109201e-03,   5.57443319e-03,   0.00000000e+00,
         1.89984780e-02,   0.00000000e+00,  -4.40328614e-03,
        -1.44236149e-03,  -3.59019787e-03,  -1.06090983e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.02218990e-02,   0.00000000e+00,
         8.72818684e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.46912423e-03,
        -7.85058993e-03,   2.70820696e-03,   1.26789514e-03,
        -1.44603073e-02,   0.00000000e+00,  -5.93304386e-03,
         0.00000000e+00,   1.72476164e-03,   3.24856973e-03,
         3.59175303e-03,   5.81806081e-03,   0.00000000e+00,
        -3.55736791e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.13305124e-02,
         0.00000000e+00,  -1.02159893e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.36076109e-02,   0.00000000e+00,  -5.05718790e-02,
         6.99276553e-03,  -3.53610610e-03,   1.85681574e-02,
         3.80786699e-02,   0.00000000e+00,   3.04408500e-02,
         0.00000000e+00,   7.31708626e-04,  -3.46883625e-04,
        -6.69483116e-03,  -1.49244849e-02,   0.00000000e+00,
         8.50306582e-03,   0.00000000e+00,  -5.07750428e-02,
        -2.69859595e-03,   1.11196485e-02,   1.44270784e-02,
        -3.33238362e-02,   0.00000000e+00,   2.02532825e-03,
         0.00000000e+00,   2.55607918e-02,  -6.16254800e-03,
         4.07558234e-03,  -2.08051979e-03,   0.00000000e+00,
        -1.01038720e-02,   0.00000000e+00,   1.25074427e-03,
        -5.16356628e-02,   1.59565815e-02,  -1.18278163e-02,
         2.28999785e-04,   3.85578402e-03,   0.00000000e+00,
         8.82469442e-03,   0.00000000e+00,   2.48320385e-03,
        -4.16193449e-05,   6.99820092e-04,  -1.81993653e-03,
         0.00000000e+00,   1.11691958e-02,   0.00000000e+00,
        -4.27050189e-03,   2.74993543e-03,  -5.18256473e-03,
         3.46425178e-02,  -1.37768328e-02,   1.28383779e-03,
         7.03627228e-03,   0.00000000e+00,   6.11812711e-03,
         0.00000000e+00,   1.41768508e-02,  -5.69933441e-03,
         1.63345288e-03,  -3.65391651e-04,   0.00000000e+00,
         5.10700616e-03,   0.00000000e+00,  -4.53012028e-03,
        -1.15239328e-03,  -2.12856953e-02,  -4.68494214e-02,
         5.98354722e-02,  -1.78934802e-02,   4.33809276e-02,
        -8.60979470e-03,   8.56607942e-03,   4.60728758e-02,
         1.13849541e-02,  -1.00219293e-02,  -6.25265718e-03,
         6.80135001e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.88169719e-02,
        -1.02325482e-03,   1.33276474e-03,   1.80035019e-02,
         1.02311351e-02,   0.00000000e+00,   5.25241248e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.29510552e-02,   0.00000000e+00,
         3.08453143e-02,   4.24719717e-03,   3.04354273e-03,
         1.34788286e-02,  -1.66487362e-02,   0.00000000e+00,
         4.80233813e-03,   0.00000000e+00,   5.29262708e-02,
        -5.95832481e-03,  -8.10105846e-03,   3.32970366e-03,
         1.91940205e-03,   0.00000000e+00,  -4.59975486e-03,
         0.00000000e+00,  -1.11357654e-02,   1.58359791e-02,
         1.47894498e-03,  -3.30051011e-03,   1.69606370e-03,
        -8.84842307e-03,   0.00000000e+00,  -6.48914210e-03,
         0.00000000e+00,   4.65286587e-03,   6.10750143e-03,
         1.63008629e-02,   5.60981062e-03,   7.13207142e-04,
        -1.44369245e-02,  -1.70876730e-02,   0.00000000e+00,
        -6.46443589e-04,   0.00000000e+00,  -1.12751570e-02,
        -7.68587970e-04,  -4.11132299e-03,   3.39597900e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.85393372e-02,   0.00000000e+00,
         1.42210417e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.63229590e-02,
         1.27529695e-02,  -9.05292312e-03,   5.35695403e-03,
         1.17017078e-02,   0.00000000e+00,   2.33977284e-03,
         0.00000000e+00,  -1.79195118e-02,   1.12597459e-02,
         8.79264677e-04,   1.94958084e-03,   0.00000000e+00,
         3.85163847e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.48916869e-02,
         0.00000000e+00,   1.73739713e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.21716015e-03,   0.00000000e+00,   6.56728824e-02,
         2.57965688e-03,   3.01993610e-04,  -1.94531025e-02,
        -3.21042725e-02,   0.00000000e+00,  -3.83960788e-02,
         0.00000000e+00,   3.81219067e-04,   1.46877821e-03,
         8.24073852e-03,   1.13249521e-02,   0.00000000e+00,
        -6.94763532e-03,   0.00000000e+00,   6.08119461e-02,
         1.19821367e-02,  -2.63932766e-02,  -3.59500412e-02,
         5.43585125e-02,   0.00000000e+00,  -1.47127802e-02,
         0.00000000e+00,  -3.47100258e-02,   7.49985853e-03,
        -4.15652327e-03,  -8.68374778e-04,   0.00000000e+00,
         6.45121003e-03,   0.00000000e+00,  -6.82405532e-04,
         7.66826577e-02,  -2.81237753e-02,  -2.77434458e-03,
         3.42289808e-03,  -8.17914122e-03,   0.00000000e+00,
        -5.86163592e-04,   0.00000000e+00,   9.66782805e-03,
         5.94884737e-03,   3.75604459e-03,   1.05916952e-03,
         0.00000000e+00,  -2.28547122e-03,   0.00000000e+00,
         1.88363533e-03,  -4.48480976e-03,   3.72501084e-02,
        -4.00812749e-02,   2.52902391e-02,   8.36765595e-03,
        -6.00231987e-03,   0.00000000e+00,  -1.03078841e-05,
         0.00000000e+00,  -1.00647895e-02,   2.83802967e-03,
        -3.40494657e-03,  -1.40237596e-03,   0.00000000e+00,
        -7.37534520e-03,   0.00000000e+00,  -3.62647191e-04,
        -9.64930690e-03,   1.53486575e-02,   6.29007709e-02,
        -3.73879844e-02,   1.03921415e-02,  -2.07003072e-02,
         7.20146830e-04,  -6.42904686e-05,  -2.26721113e-02,
        -1.65940267e-03,  -9.41992428e-04,  -1.13117569e-03,
        -3.98540946e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.15873507e-02,
        -2.77840849e-03,   5.55288659e-03,  -1.02371917e-02,
        -4.40226800e-03,   0.00000000e+00,  -3.23181033e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.31700736e-03,   0.00000000e+00,
        -1.38475458e-02,  -1.35995939e-02,  -1.10320899e-02,
        -1.14705863e-02,   8.78084659e-03,   0.00000000e+00,
        -3.12136245e-03,   0.00000000e+00,  -8.68797498e-03,
         4.17897583e-03,   5.67431998e-03,   9.54320304e-04,
         3.38617247e-03,   0.00000000e+00,  -2.01580277e-03,
         0.00000000e+00,   7.70097623e-03,  -1.32205627e-02,
        -2.81980422e-04,  -1.49407243e-03,  -1.79204996e-04,
         1.75687450e-03,   0.00000000e+00,   2.24428413e-03,
         0.00000000e+00,  -1.09105044e-03,  -2.29739173e-03,
        -9.51347799e-03,   1.01548555e-02,   2.15063288e-02,
         6.88668353e-03,   1.03038902e-02,   0.00000000e+00,
        -6.99388589e-03,   0.00000000e+00,   3.05415147e-03,
        -2.80293046e-03,  -6.99865706e-03,  -1.92853831e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.31813268e-03,   0.00000000e+00,
        -4.32951070e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.54854083e-02,
         2.99107939e-03,   2.42179968e-02,  -2.56571010e-04,
        -8.51756344e-04,   0.00000000e+00,  -7.58285786e-03,
         0.00000000e+00,   4.55507522e-03,  -6.93534972e-03,
        -7.33782399e-03,   1.40534463e-03,   0.00000000e+00,
        -6.43190165e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.07320383e-02,
         0.00000000e+00,  -9.00436433e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.17868945e-03,   0.00000000e+00,  -3.66958069e-02,
         5.06153562e-03,  -4.74206140e-03,   7.02124943e-03,
         1.04948531e-02,   0.00000000e+00,   1.91269778e-02,
         0.00000000e+00,  -4.82482653e-05,   3.41047989e-04,
        -4.36972743e-03,  -7.64449934e-03,   0.00000000e+00,
         7.84222416e-03,   0.00000000e+00,  -3.38367441e-02,
        -1.32995443e-02,   2.90854901e-03,   1.10753464e-02,
        -1.64013384e-02,   0.00000000e+00,   4.33310965e-03,
         0.00000000e+00,   1.90349012e-02,  -2.59690178e-03,
         5.02425242e-03,   1.04701710e-03,   0.00000000e+00,
        -4.23198318e-03,   0.00000000e+00,   3.14703381e-04,
        -3.40164205e-02,   3.02087645e-03,  -2.77593417e-03,
        -4.15553929e-03,   2.37637904e-02,   0.00000000e+00,
        -1.18079101e-02,   0.00000000e+00,   2.56656187e-02,
        -9.39044246e-03,   1.33365093e-03,  -9.83509478e-03,
         0.00000000e+00,  -9.80477126e-03,   0.00000000e+00,
        -6.73714998e-04,   3.74108235e-03,  -1.61263429e-02,
         1.48903192e-02,  -7.95563118e-03,  -1.41423567e-03,
         4.75414561e-03,   0.00000000e+00,   8.74837526e-03,
         0.00000000e+00,  -5.42503496e-03,   1.44196987e-03,
        -1.53059424e-04,   4.85846471e-03,   0.00000000e+00,
         1.18669864e-02,   0.00000000e+00,  -7.15920606e-04,
        -3.17644765e-03,  -9.36027104e-03,  -3.82393440e-02,
        -4.48798766e-02,   1.76125760e-02,  -4.71149836e-03,
        -4.39809078e-05,  -1.71963022e-02,  -2.25390040e-02,
        -5.07349357e-03,   2.26784426e-02,   3.99975271e-03,
        -3.85274293e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.91287992e-02,
        -4.12075487e-03,  -5.62484692e-03,  -2.20332633e-02,
        -1.65761388e-02,   0.00000000e+00,  -2.16286407e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.14634571e-02,   0.00000000e+00,
        -5.69207052e-04,   3.75640772e-03,   1.00153216e-02,
        -1.01164217e-02,   1.63620360e-02,   0.00000000e+00,
        -1.29107142e-02,   0.00000000e+00,  -2.12127356e-02,
        -2.17571014e-04,  -5.74744458e-03,   1.72122483e-03,
        -5.39063246e-03,   0.00000000e+00,   7.22016367e-03,
         0.00000000e+00,   3.47358637e-03,   5.88602953e-03,
         1.47250492e-03,   5.07234626e-04,  -2.01416913e-03,
         1.13834072e-03,   0.00000000e+00,   6.52747404e-03,
         0.00000000e+00,  -3.63568944e-03,   3.20326779e-03,
         8.34682494e-03,   1.55854977e-04,  -6.01890727e-03,
         2.08370156e-03,   1.44335237e-03,   0.00000000e+00,
         1.04212279e-02,   0.00000000e+00,   3.44416948e-03,
         1.76215233e-03,  -2.08420685e-03,   3.58893247e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.23145076e-03,   0.00000000e+00,
         3.62113777e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.54931262e-03,
        -9.93324844e-03,  -7.49370414e-04,  -2.67080222e-04,
        -8.90838173e-03,   0.00000000e+00,  -2.50050714e-03,
         0.00000000e+00,   8.39902116e-03,   3.43497881e-03,
         2.22291289e-03,   6.26738536e-03,   0.00000000e+00,
        -1.77854334e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.74834759e-02,
         0.00000000e+00,  -9.65206276e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.23100748e-02,   0.00000000e+00,  -4.33024535e-02,
         1.07392552e-02,  -3.23351638e-03,   9.88423144e-03,
         1.69477733e-02,   0.00000000e+00,   1.84611424e-02,
         0.00000000e+00,   5.44149398e-03,  -1.83187475e-03,
        -6.64689205e-03,  -1.39058796e-02,   0.00000000e+00,
         5.61933739e-03,   0.00000000e+00,  -3.94017764e-02,
        -1.51816163e-02,   1.41457263e-02,   1.35173210e-02,
        -1.86715132e-02,   0.00000000e+00,   4.43443884e-03,
         0.00000000e+00,   1.47795564e-02,  -4.29709157e-03,
         2.84067843e-03,  -4.53774348e-04,   0.00000000e+00,
        -7.79545303e-03,   0.00000000e+00,  -1.30481527e-03,
        -4.96421476e-02,   1.02099435e-02,  -6.65918605e-03,
        -4.00193457e-04,   6.76411269e-03,   0.00000000e+00,
         6.39181710e-03,   0.00000000e+00,  -6.89965369e-03,
         1.66987020e-03,  -5.89793626e-04,   8.39376079e-03,
         0.00000000e+00,   2.06422637e-02,   0.00000000e+00,
        -4.12295815e-03,   1.71881409e-03,  -7.69665623e-03,
         1.52081237e-02,  -1.12386495e-02,  -3.76700941e-03,
         2.20881610e-02,   0.00000000e+00,   4.75348056e-03,
         0.00000000e+00,   4.63098276e-03,  -3.21619570e-03,
         8.67641190e-04,  -1.29920470e-03,   0.00000000e+00,
         3.49757991e-03,   0.00000000e+00,  -2.33807845e-03,
         9.81653024e-03,  -1.68717866e-02,  -3.84128721e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.89484411e-02,  -4.58307160e-02,
        -1.15666990e-02,   5.29878575e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.05382246e-03,   0.00000000e+00,
        -3.15470598e-02,  -1.85074064e-02,   2.38938795e-03,
        -1.13535762e-02,   0.00000000e+00,   1.00527934e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.14618323e-02,
         0.00000000e+00,   3.94613311e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.85393508e-03,   0.00000000e+00,
         7.93521454e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.79209594e-03,   0.00000000e+00,
         6.60290482e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.38578885e-03,
         0.00000000e+00,   1.65330897e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.28209037e-04,  -1.96497573e-02,  -6.65164047e-03,
         7.76969318e-04,   0.00000000e+00,   3.33135791e-03,
         0.00000000e+00,   1.01906761e-02,   4.23885170e-03,
         3.30191961e-03,   6.07469249e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.56273286e-03,   0.00000000e+00,
        -4.72093950e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.66918383e-03,
         0.00000000e+00,  -2.03418295e-02,   9.20163976e-03,
         1.24599887e-03,  -1.89448354e-04,   0.00000000e+00,
        -1.04630048e-03,   0.00000000e+00,  -8.81161671e-03,
         6.93138163e-03,  -4.12319408e-03,  -2.78898684e-03,
         0.00000000e+00,  -1.14607224e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.45319295e-03,   0.00000000e+00,
        -2.39802328e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.90058743e-03,
         0.00000000e+00,  -4.13239445e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.40923838e-03,   0.00000000e+00,
         6.16696517e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.75800121e-03,
         0.00000000e+00,  -1.15010059e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.14779532e-02,
         0.00000000e+00,   1.30842519e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.64855186e-02,   0.00000000e+00,   3.66061140e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.14089576e-02,   0.00000000e+00,
         7.69736664e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.57043427e-02,
         0.00000000e+00,   6.90216995e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.10655058e-01,  -3.88252973e-02,
        -1.34852267e-02,   1.22178054e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.98220124e-03,   0.00000000e+00,
        -3.18764741e-03,   5.86622918e-02,   1.11147041e-02,
         4.64115876e-03,   0.00000000e+00,  -1.15669441e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.52882008e-02,
         0.00000000e+00,  -1.63028126e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.14164794e-03,   0.00000000e+00,
        -3.52793470e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.96526810e-04,   0.00000000e+00,
        -1.45025912e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.92549045e-03,
         0.00000000e+00,  -6.24398177e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.12805859e-02,   6.45233738e-03,  -3.18662112e-03,
         8.41399045e-03,   0.00000000e+00,  -6.65426524e-03,
         0.00000000e+00,  -5.78421232e-03,  -1.44888363e-02,
         2.24185298e-03,  -4.25950246e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.34707821e-03,   0.00000000e+00,
        -6.54346000e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.27751904e-03,
         0.00000000e+00,  -1.87254900e-02,   1.14971027e-02,
         4.93551639e-03,  -3.49473997e-03,   0.00000000e+00,
        -3.37453991e-04,   0.00000000e+00,  -1.40376658e-02,
         4.85129243e-03,  -3.17210220e-03,  -6.57574199e-03,
         0.00000000e+00,  -1.71054076e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.47790178e-03,   0.00000000e+00,
         1.89489058e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.25739163e-03,
         0.00000000e+00,  -3.60396970e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.50218692e-03,   0.00000000e+00,
        -3.40479837e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.15920055e-03,
         0.00000000e+00,  -1.77034179e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.17216106e-02,
         0.00000000e+00,   6.10015082e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.09542138e-02,   0.00000000e+00,   2.68087640e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.28983422e-02,   0.00000000e+00,
        -8.53473951e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.28690547e-03,
         0.00000000e+00,   8.83237330e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.35449318e-02,   9.97646787e-03,
         9.74383034e-03,   1.97085156e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.30507626e-02,   0.00000000e+00,
         3.96278096e-04,  -1.10977426e-02,  -1.46981788e-02,
        -3.55692360e-03,   0.00000000e+00,   8.08083073e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.14013395e-04,
         0.00000000e+00,   5.15411709e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.13753850e-04,   0.00000000e+00,
        -4.03333338e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.52783723e-03,   0.00000000e+00,
        -1.07167231e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.85287381e-03,
         0.00000000e+00,   4.02496593e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.82619044e-03,  -1.75169306e-03,  -3.02319759e-03,
        -1.80380190e-03,   0.00000000e+00,   6.39160550e-03,
         0.00000000e+00,   2.92453872e-03,  -1.56092517e-03,
        -3.36441636e-03,   7.74405683e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.45793894e-03,   0.00000000e+00,
        -1.41981762e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.59007667e-03,
         0.00000000e+00,   3.55763458e-03,  -3.20699700e-03,
        -3.52178911e-03,  -6.51439586e-04,   0.00000000e+00,
        -2.77337468e-03,   0.00000000e+00,   1.98320001e-03,
        -1.51167740e-03,   1.29085564e-03,   6.25582409e-03,
         0.00000000e+00,   7.65220943e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.68879080e-03,   0.00000000e+00,
         1.04243068e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.42802818e-03,
         0.00000000e+00,   1.02477970e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.64981106e-03,   0.00000000e+00,
         2.12692992e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.70132499e-03,
         0.00000000e+00,   8.37370505e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.79246074e-03,
         0.00000000e+00,   8.49697400e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.07288204e-02,   0.00000000e+00,  -5.44429437e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.06123452e-03,   0.00000000e+00,
         1.12449479e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.29377738e-04,
         0.00000000e+00,  -1.87846121e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.38510904e-01,  -1.23942507e-01,  -9.64843644e-02,
        -2.61923576e-02,   5.11242108e-02,  -4.46652190e-03,
         6.50247510e-03,  -7.15430680e-02,  -9.70566647e-03,
         1.01848132e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.10372914e-01,
         8.18876602e-03,   3.39324240e-02,   1.38584310e-01,
         9.64481595e-02,   0.00000000e+00,   1.06713388e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.59899621e-02,   0.00000000e+00,
        -1.62427869e-01,   5.62163134e-02,   1.97888741e-02,
         7.37746390e-02,  -1.05631611e-01,   0.00000000e+00,
         5.71814152e-02,   0.00000000e+00,  -3.46640307e-02,
        -7.48219310e-03,   3.49011402e-02,  -4.52649898e-02,
         2.70570790e-02,   0.00000000e+00,  -2.75922751e-03,
         0.00000000e+00,  -3.76291177e-03,  -7.03456509e-02,
         1.07805036e-02,   1.42712998e-02,  -1.69950987e-02,
        -1.58377808e-02,   0.00000000e+00,  -2.14159989e-03,
         0.00000000e+00,   2.97708831e-03,  -3.57124896e-02,
        -8.14372891e-02,   2.54764153e-03,   8.70696573e-04,
         1.45656006e-02,   1.09377026e-02,   0.00000000e+00,
        -7.05183868e-02,   0.00000000e+00,   2.92253658e-02,
         5.83036876e-03,   3.12147974e-02,  -1.24053686e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.35230146e-02,   0.00000000e+00,
        -9.48313395e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.69867311e-01,
         5.32264067e-03,  -4.26557552e-04,  -3.43891842e-02,
         3.29482487e-02,   0.00000000e+00,   1.66999290e-02,
         0.00000000e+00,   3.33264051e-02,  -4.38888851e-02,
        -1.64736256e-02,  -1.62632433e-02,   0.00000000e+00,
        -1.22754256e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.03056586e-02,
         0.00000000e+00,   1.76013959e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.56358466e-02,   0.00000000e+00,   1.79419375e-01,
         1.56979672e-04,  -6.86056082e-03,  -3.51326087e-02,
        -4.30320026e-02,   0.00000000e+00,  -3.94072809e-02,
         0.00000000e+00,  -3.48966873e-03,  -1.86668630e-03,
         2.06665109e-02,   8.01692688e-02,   0.00000000e+00,
        -3.49722034e-02,   0.00000000e+00,   1.40577307e-01,
         7.89977959e-03,  -3.90321342e-03,  -2.10734456e-02,
         3.74738741e-02,   0.00000000e+00,  -1.75641446e-02,
         0.00000000e+00,  -6.72075773e-02,   1.81457800e-02,
        -1.18453494e-02,   1.67759243e-02,   0.00000000e+00,
         6.25351602e-02,   0.00000000e+00,   7.57698354e-03,
         1.58153850e-01,  -8.78382125e-03,   6.27398355e-02,
         7.66542713e-03,   6.06506708e-03,   0.00000000e+00,
        -1.52435708e-02,   0.00000000e+00,  -4.74165279e-02,
        -1.46171706e-02,  -1.04352354e-02,  -1.60847902e-02,
         0.00000000e+00,  -4.00632805e-02,   0.00000000e+00,
         1.64611802e-02,  -3.52651496e-02,  -1.05957282e-01,
        -5.50474430e-02,   1.43059536e-02,   5.46116064e-03,
        -5.90268691e-03,   0.00000000e+00,   8.07590222e-04,
         0.00000000e+00,  -2.58964976e-02,   2.14496756e-02,
        -8.90103422e-03,  -3.42698487e-03,   0.00000000e+00,
        -2.51307602e-02,   0.00000000e+00,  -1.20232210e-02,
        -5.45768033e-03,   1.10690509e-01,   1.31314979e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.28149208e-02,  -2.04433960e-02,
        -7.36750418e-03,   1.99927478e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.20700334e-03,   0.00000000e+00,
        -9.38296307e-03,  -2.52073168e-03,   2.68608247e-03,
        -1.35925360e-02,   0.00000000e+00,   7.18197670e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.22381536e-03,
         0.00000000e+00,  -7.54408929e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.51733664e-04,   0.00000000e+00,
         3.93331934e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.32687937e-04,   0.00000000e+00,
         1.92208932e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.41972711e-04,
         0.00000000e+00,   3.94014952e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.68701073e-03,  -4.55584989e-03,  -1.55030603e-03,
        -3.39223955e-04,   0.00000000e+00,   3.55849185e-03,
         0.00000000e+00,  -4.24279983e-03,   2.71831560e-03,
        -1.23604712e-03,   8.87990788e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.18318370e-03,   0.00000000e+00,
         7.95542473e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.98493685e-03,
         0.00000000e+00,  -6.51505938e-03,   5.17951482e-03,
         1.67505907e-03,  -5.12273080e-03,   0.00000000e+00,
        -1.58456702e-03,   0.00000000e+00,  -9.96173510e-04,
         1.65434262e-03,  -2.21726852e-04,   2.86198870e-03,
         0.00000000e+00,  -6.06160908e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.10274393e-03,   0.00000000e+00,
         2.42506911e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.40944550e-03,
         0.00000000e+00,   6.74713282e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.82074761e-03,   0.00000000e+00,
        -1.89404383e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.44199561e-03,
         0.00000000e+00,  -1.88596862e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.83352132e-03,
         0.00000000e+00,   1.09829719e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.47821732e-03,   0.00000000e+00,   1.44855847e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.16143300e-03,   0.00000000e+00,
         2.00155046e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.24452873e-03,
         0.00000000e+00,   2.51856193e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.42505236e-01,  -1.21828908e-01,   4.88379685e-01,
        -6.66977772e-03,   7.40637659e-02,   5.56777083e-01,
        -7.54827159e-03,  -7.06494896e-02,  -9.93388043e-03,
         6.77020109e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.26434447e-01,
         1.18046759e-02,   1.54754661e-02,   1.46557347e-01,
         9.32990692e-02,   0.00000000e+00,   5.89032030e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.58226233e-02,   0.00000000e+00,
         4.51418833e-01,   6.10504920e-02,  -3.43593840e-02,
         8.42446919e-02,  -1.11615866e-01,   0.00000000e+00,
         5.53899377e-02,   0.00000000e+00,   5.53000225e-01,
        -3.35922137e-02,  -1.91999000e-02,   1.71185428e-02,
         1.95786637e-02,   0.00000000e+00,  -3.91510132e-02,
         0.00000000e+00,  -7.70213874e-02,   3.00514360e-01,
         7.97028001e-03,  -1.92147906e-02,   1.28937549e-02,
        -2.50284244e-02,   0.00000000e+00,  -4.02011602e-02,
         0.00000000e+00,   3.49962532e-02,   3.55624766e-02,
         3.15928842e-01,   7.82560676e-03,  -1.55629273e-02,
        -4.54719709e-02,  -5.42581095e-02,   0.00000000e+00,
        -1.30861549e-02,   0.00000000e+00,  -3.27379891e-02,
        -1.22088944e-02,   8.23591238e-03,   4.25327044e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.95944965e-02,   0.00000000e+00,
         3.97707512e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.51116148e-01,
         3.02988720e-02,  -3.51615508e-02,   1.78979542e-02,
         2.56180964e-02,   0.00000000e+00,   1.61761000e-02,
         0.00000000e+00,  -4.63436264e-02,   2.73180098e-02,
         1.80333785e-03,  -1.72329737e-02,   0.00000000e+00,
         4.24441578e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.92424256e-01,
         0.00000000e+00,   7.74377880e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.85116508e-02,   0.00000000e+00,   7.52071194e-01,
         9.56837814e-03,  -2.40822074e-03,  -6.43068413e-02,
        -9.41905239e-02,   0.00000000e+00,  -1.32416040e-01,
         0.00000000e+00,  -7.63978184e-03,   2.22861684e-03,
         5.04820900e-02,   8.92369958e-02,   0.00000000e+00,
        -4.13254918e-02,   0.00000000e+00,   6.68559581e-01,
         1.62182122e-02,  -4.38507400e-02,  -7.93952517e-02,
         1.08307349e-01,   0.00000000e+00,  -3.98676721e-02,
         0.00000000e+00,  -1.02352702e-01,   3.04914307e-02,
        -2.44925932e-02,   5.83782314e-03,   0.00000000e+00,
         3.92194480e-02,   0.00000000e+00,   7.27409355e-03,
         7.06652149e-01,  -7.63300707e-02,   4.76367080e-03,
         2.67956058e-03,  -2.50001073e-02,   0.00000000e+00,
         6.96788275e-03,   0.00000000e+00,  -1.42944701e-02,
         4.84072584e-02,  -5.52626998e-03,  -1.65847216e-02,
         0.00000000e+00,  -6.10529927e-02,   0.00000000e+00,
         1.17080999e-02,  -5.97724315e-03,   4.74406375e-01,
        -1.16231097e-01,   6.64138657e-02,   2.05950140e-02,
        -6.15018416e-03,   0.00000000e+00,  -7.89001553e-03,
         0.00000000e+00,  -6.50566302e-02,   2.19978468e-02,
        -2.14903400e-02,  -1.14362669e-02,   0.00000000e+00,
        -3.71429051e-02,   0.00000000e+00,  -9.22624648e-03,
         4.99934553e-03,   1.16437645e-01,   7.11566399e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.60535276e-03,   1.98009338e-03,
         1.72346656e-02,   2.45076173e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.35924537e-02,   0.00000000e+00,
         2.73760186e-03,   4.65973457e-03,   1.20346392e-03,
        -9.26119229e-04,   0.00000000e+00,  -1.39013559e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.15034660e-04,
         0.00000000e+00,   1.90714866e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.52800832e-04,   0.00000000e+00,
         3.71142150e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.62322442e-03,   0.00000000e+00,
         1.58626610e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.67536447e-03,
         0.00000000e+00,  -3.83682000e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.18316197e-04,   2.07818403e-03,   2.92902036e-03,
         3.99981320e-03,   0.00000000e+00,  -1.99091931e-05,
         0.00000000e+00,   5.84147440e-04,  -1.29214558e-04,
         1.32068100e-04,  -1.05326454e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.76895933e-03,   0.00000000e+00,
        -1.41476620e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.79281266e-03,
         0.00000000e+00,   8.37687631e-04,  -4.62267835e-04,
        -3.76230654e-03,  -6.42953382e-03,   0.00000000e+00,
        -7.45192424e-03,   0.00000000e+00,   1.90302417e-04,
        -1.17057550e-04,   3.99720197e-03,   6.25292683e-03,
         0.00000000e+00,  -4.27245950e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.92812694e-03,   0.00000000e+00,
         3.16361022e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.14299259e-03,
         0.00000000e+00,   2.85542170e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.18564257e-04,   0.00000000e+00,
        -4.50662743e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.10797517e-05,
         0.00000000e+00,  -1.14271529e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.30511870e-04,
         0.00000000e+00,  -6.70377194e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.76576578e-03,   0.00000000e+00,  -1.05419389e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.46830248e-04,   0.00000000e+00,
        -5.55356145e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.19365973e-03,
         0.00000000e+00,  -1.89109685e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.86781394e-02,   5.23056732e-03,
         1.83319464e-02,  -1.89568723e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.14247648e-02,   0.00000000e+00,
         6.62726140e-03,   1.43705819e-02,   1.17219534e-03,
         3.44314018e-03,   0.00000000e+00,  -5.08028955e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.00268299e-02,
         0.00000000e+00,  -1.68688539e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.30730697e-03,   0.00000000e+00,
         1.66979831e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.43586827e-04,   0.00000000e+00,
        -4.22009005e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.04276499e-04,
         0.00000000e+00,  -6.46126557e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.54049454e-03,   6.09999539e-03,   2.32213887e-03,
        -7.51880891e-04,   0.00000000e+00,  -3.41927701e-04,
         0.00000000e+00,  -3.00021055e-03,  -3.43456286e-03,
         5.69239465e-05,   1.50015946e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.17407548e-04,   0.00000000e+00,
        -2.30667129e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.44606408e-03,
         0.00000000e+00,  -4.63283535e-03,   2.37947024e-03,
        -3.05911376e-03,   4.08396751e-03,   0.00000000e+00,
        -3.49044692e-03,   0.00000000e+00,  -1.10150470e-02,
         2.91977651e-03,  -1.91683524e-03,   1.33703580e-03,
         0.00000000e+00,   2.39215653e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.68038727e-04,   0.00000000e+00,
         9.84567264e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.24431829e-04,
         0.00000000e+00,   3.93649590e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.10901167e-03,   0.00000000e+00,
         1.09400598e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.08099449e-02,
         0.00000000e+00,   2.52002061e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.53361983e-03,
         0.00000000e+00,  -1.43092797e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.67362815e-02,   0.00000000e+00,   1.12134456e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.32806916e-03,   0.00000000e+00,
        -9.36843751e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.03516731e-03,
         0.00000000e+00,   1.46958334e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.10540026e-03,   2.48314966e-03,
        -4.73619930e-03,   4.44719767e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.26075767e-03,   0.00000000e+00,
         3.09007294e-03,   6.12713555e-03,  -2.87457016e-03,
         1.28214652e-03,   0.00000000e+00,   9.77705086e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.70729415e-03,
         0.00000000e+00,   2.35074939e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.26084926e-04,   0.00000000e+00,
        -5.68650317e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.16432445e-03,   0.00000000e+00,
        -3.07693621e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.36653553e-04,
         0.00000000e+00,  -1.45380478e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.32455578e-03,   5.83332503e-03,  -2.24852077e-03,
         1.67788177e-03,   0.00000000e+00,  -1.61928233e-04,
         0.00000000e+00,  -9.82020962e-04,  -2.73813349e-03,
        -2.77813938e-03,   6.50766440e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.11113705e-04,   0.00000000e+00,
        -1.97666729e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.49164180e-03,
         0.00000000e+00,   3.91987675e-03,  -6.44061775e-04,
         4.33982578e-04,  -1.03948523e-03,   0.00000000e+00,
         1.06509497e-03,   0.00000000e+00,   3.19261147e-03,
        -1.44813976e-03,   2.02121980e-04,  -5.57635790e-05,
         0.00000000e+00,  -8.54327430e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.21469427e-04,   0.00000000e+00,
         4.04786016e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.13101889e-05,
         0.00000000e+00,  -1.36070836e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.56802572e-03,   0.00000000e+00,
        -1.19958163e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.80405378e-03,
         0.00000000e+00,  -5.97596272e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.24516102e-03,
         0.00000000e+00,  -4.55354190e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.96928629e-03,   0.00000000e+00,  -3.43885199e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.07565778e-03,   0.00000000e+00,
        -8.82820864e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.95154927e-03,
         0.00000000e+00,  -6.06641662e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.11546841e-03,   8.41805168e-04,
        -1.10780435e-03,  -2.55559781e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.61001851e-03,   0.00000000e+00,
         3.50304575e-03,   1.17076205e-02,  -1.76794941e-03,
         2.63125227e-03,   0.00000000e+00,  -1.77043601e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.27371545e-03,
         0.00000000e+00,  -2.70299500e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.04981703e-03,   0.00000000e+00,
        -3.13448561e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.95220284e-04,   0.00000000e+00,
        -5.91533522e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.52110424e-04,
         0.00000000e+00,   3.44132314e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.38103698e-03,   2.71729363e-03,  -1.66649864e-03,
        -3.43822864e-04,   0.00000000e+00,   5.00209682e-04,
         0.00000000e+00,  -1.98748733e-03,  -4.26230525e-03,
        -2.62437900e-05,   1.67404116e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.67697191e-04,   0.00000000e+00,
        -6.18693147e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.22988707e-03,
         0.00000000e+00,  -1.73326515e-03,   5.41978792e-04,
         8.31891845e-04,   1.33579506e-03,   0.00000000e+00,
         1.72632697e-03,   0.00000000e+00,  -2.07991819e-03,
        -2.46380357e-04,  -1.10623636e-04,  -6.56251470e-04,
         0.00000000e+00,  -1.14572234e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.26647681e-03,   0.00000000e+00,
        -3.30281189e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.42346530e-04,
         0.00000000e+00,  -2.40796291e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.49416302e-04,   0.00000000e+00,
        -9.11902203e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.70063042e-04,
         0.00000000e+00,   1.24232162e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.21309144e-04,
         0.00000000e+00,   1.05288228e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.02848297e-02,   0.00000000e+00,  -1.27162476e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.15080171e-03,   0.00000000e+00,
        -1.36233783e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.80560669e-03,
         0.00000000e+00,   4.39251260e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.97862305e-02,   4.82615578e-02,   6.09928108e-02,
         1.57678503e-02,  -1.40507570e-02,   2.78507775e-02,
        -7.59179868e-03,   2.43188715e-02,   3.93786987e-03,
        -1.23980458e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.94499735e-02,
        -1.45821425e-03,  -1.41826131e-02,  -5.21377988e-02,
        -3.67935636e-02,   0.00000000e+00,   2.21220268e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.10597283e-02,   0.00000000e+00,
         8.38557452e-02,  -2.41256277e-02,  -2.06849973e-02,
        -2.84156956e-02,   4.01086550e-02,   0.00000000e+00,
        -2.18477788e-02,   0.00000000e+00,   4.50653976e-02,
         1.72000393e-04,  -2.17156507e-02,   2.79355872e-02,
        -1.16014209e-02,   0.00000000e+00,  -5.47132350e-03,
         0.00000000e+00,  -7.36326120e-03,   3.21147863e-02,
        -5.36329531e-03,  -1.07769436e-02,   1.50269285e-02,
         8.00300027e-03,   0.00000000e+00,  -7.91066216e-03,
         0.00000000e+00,   3.42522785e-03,   2.01006459e-02,
         2.98590278e-02,  -6.86905367e-04,  -2.49241621e-03,
        -1.70207065e-02,  -1.67742018e-02,   0.00000000e+00,
         4.84951761e-02,   0.00000000e+00,  -2.69288291e-02,
        -6.61730134e-03,  -1.87908770e-02,   7.82552767e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.26877187e-03,   0.00000000e+00,
         7.95420311e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.07467366e-01,
        -2.93954526e-04,  -6.72856709e-03,   2.97192117e-02,
        -2.19235098e-02,   0.00000000e+00,  -8.76016633e-03,
         0.00000000e+00,  -3.45427549e-02,   3.07737783e-02,
         1.45728422e-02,   5.62090000e-03,   0.00000000e+00,
         7.81996409e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.96932406e-02,
         0.00000000e+00,   4.46655739e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.29985555e-02,   0.00000000e+00,  -4.36023085e-02,
         8.17212379e-04,   4.14556124e-03,   2.06467647e-02,
         2.07373539e-02,   0.00000000e+00,   1.01879769e-02,
         0.00000000e+00,   1.44175016e-03,   2.27088557e-03,
        -2.10053378e-03,  -3.03944617e-02,   0.00000000e+00,
         1.29722201e-02,   0.00000000e+00,  -3.24772118e-02,
        -4.61541698e-03,   9.62012330e-04,   6.95732122e-03,
        -1.48177771e-02,   0.00000000e+00,   7.61001271e-03,
         0.00000000e+00,   3.26468108e-02,  -8.01886199e-03,
         2.50049997e-03,  -9.25817035e-03,   0.00000000e+00,
        -3.06349362e-02,   0.00000000e+00,  -3.11779012e-03,
        -3.54216275e-02,  -5.88599952e-03,  -5.08809541e-02,
        -4.16979915e-03,  -8.50643899e-03,   0.00000000e+00,
         1.30282117e-02,   0.00000000e+00,   2.58300995e-02,
         1.45460249e-02,   1.12825511e-02,   3.25320128e-03,
         0.00000000e+00,   7.62318536e-03,   0.00000000e+00,
        -7.51488757e-03,   2.06351894e-02,   7.09039328e-02,
         3.05858456e-02,   2.30350131e-03,   3.09502319e-04,
         3.09080262e-03,   0.00000000e+00,  -2.79969625e-03,
         0.00000000e+00,   4.20921303e-03,  -8.56969579e-03,
        -5.03690186e-04,   3.53347784e-04,   0.00000000e+00,
         8.44873231e-03,   0.00000000e+00,   5.29843482e-03,
         3.37843147e-03,  -4.12760544e-02,  -2.43782384e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.69239156e-03,  -3.30254187e-03,
        -2.81368738e-03,  -9.88139908e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.68948643e-03,   0.00000000e+00,
        -7.46651893e-04,   5.37237963e-03,   2.42587900e-03,
         3.42791069e-03,   0.00000000e+00,  -3.32573045e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.97990735e-03,
         0.00000000e+00,   8.99663867e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.62395666e-04,   0.00000000e+00,
        -8.98659763e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.00606412e-03,   0.00000000e+00,
         1.87655878e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.71142577e-04,
         0.00000000e+00,  -8.23984352e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.25383986e-03,   3.05958772e-03,   1.60362594e-03,
         4.07120217e-03,   0.00000000e+00,  -7.12510339e-03,
         0.00000000e+00,   3.91999783e-03,  -1.20433478e-03,
         8.90405347e-04,  -5.49795970e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.59964326e-04,   0.00000000e+00,
        -2.69610011e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.67312711e-03,
         0.00000000e+00,  -4.21204474e-03,   2.80903371e-03,
         3.27582407e-03,   2.59266632e-03,   0.00000000e+00,
         1.62817833e-03,   0.00000000e+00,   2.19477208e-04,
         2.48289226e-04,  -6.19039275e-04,  -2.01106497e-03,
         0.00000000e+00,  -7.86041226e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.52190862e-03,   0.00000000e+00,
         9.21636599e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.05451055e-03,
         0.00000000e+00,  -3.21132159e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.62930665e-03,   0.00000000e+00,
        -2.79735339e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.94977676e-04,
         0.00000000e+00,  -1.05891022e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.74836292e-03,
         0.00000000e+00,  -2.30344030e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.34194361e-03,   0.00000000e+00,   1.96109314e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.77824723e-03,   0.00000000e+00,
         1.41214360e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.39139755e-05,
         0.00000000e+00,   6.75264345e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.03866981e-02,  -5.80017389e-03,
        -1.09290882e-03,   4.44094017e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.88241492e-03,   0.00000000e+00,
        -4.17760905e-03,  -3.83047963e-04,  -2.83650754e-03,
        -1.27061225e-03,   0.00000000e+00,   1.33791185e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.52115171e-03,
         0.00000000e+00,   1.77260337e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.47433328e-03,   0.00000000e+00,
        -2.33046455e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.09071547e-04,   0.00000000e+00,
        -3.86290446e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.54524980e-04,
         0.00000000e+00,   2.03355905e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.32157997e-03,   2.72205098e-05,  -5.17580128e-03,
         2.15337857e-03,   0.00000000e+00,   3.27300481e-03,
         0.00000000e+00,   4.25071491e-03,  -3.10946113e-03,
        -2.97625273e-03,   1.43543296e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.83014351e-03,   0.00000000e+00,
        -7.32983540e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.07677279e-03,
         0.00000000e+00,  -6.53445951e-03,   3.78057840e-03,
        -1.38986160e-03,  -3.93393960e-03,   0.00000000e+00,
        -1.96901255e-03,   0.00000000e+00,   4.22210613e-04,
        -9.77542385e-06,  -6.76351243e-04,   7.90750008e-04,
         0.00000000e+00,  -2.48081648e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.71316536e-03,   0.00000000e+00,
        -6.62383770e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.18449453e-03,
         0.00000000e+00,   2.57815096e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.40963402e-03,   0.00000000e+00,
         6.27759647e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.38301512e-03,
         0.00000000e+00,  -2.15243335e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.06034825e-03,
         0.00000000e+00,   3.06525635e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.25010097e-03,   0.00000000e+00,   4.42651869e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.83446261e-03,   0.00000000e+00,
         1.63648412e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.60041531e-03,
         0.00000000e+00,   7.83483478e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.76914533e-01,   6.25824982e-02,  -5.76342573e-02,
         6.54431241e-03,  -2.89064767e-02,  -9.51304057e-02,
         2.19975898e-03,   3.04926610e-02,   4.60805048e-03,
        -1.56761181e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.15584032e-01,
        -6.97436730e-03,  -8.88357262e-03,  -7.36737386e-02,
        -4.87355709e-02,   0.00000000e+00,  -1.15788611e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.07122494e-02,   0.00000000e+00,
        -3.16983713e-02,  -4.11142915e-02,   4.72835319e-03,
        -4.37557646e-02,   5.84428030e-02,   0.00000000e+00,
        -3.01471987e-02,   0.00000000e+00,  -9.85690018e-02,
         1.77915492e-02,   1.88429175e-04,   5.73405531e-03,
        -1.26518513e-02,   0.00000000e+00,   1.22420277e-02,
         0.00000000e+00,   2.43938904e-02,  -1.35770111e-02,
        -8.17396203e-03,   3.50122428e-03,   1.13199729e-03,
         1.81673501e-02,   0.00000000e+00,   1.56666499e-02,
         0.00000000e+00,  -1.15488672e-02,  -1.65812350e-03,
        -1.18994881e-02,  -6.42255235e-03,   4.83985401e-03,
         2.46264540e-02,   2.67836265e-02,   0.00000000e+00,
         2.51065387e-02,   0.00000000e+00,   7.98614649e-03,
         8.83198782e-04,  -5.03748186e-03,  -3.62272705e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.85311451e-02,   0.00000000e+00,
        -1.67911769e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.48350861e-02,
        -2.09685366e-02,   1.60005259e-02,  -2.17902058e-03,
        -2.63957532e-02,   0.00000000e+00,  -1.03799357e-02,
         0.00000000e+00,   1.56960024e-02,  -4.92359354e-03,
         2.02389124e-03,   6.76160064e-03,   0.00000000e+00,
        -3.45940777e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.71483312e-01,
         0.00000000e+00,  -5.04555404e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.73538022e-02,   0.00000000e+00,  -1.98940538e-01,
        -5.76331026e-03,   3.46759967e-03,   5.56248581e-02,
         7.51510825e-02,   0.00000000e+00,   9.39555431e-02,
         0.00000000e+00,   5.14147416e-03,  -3.14407826e-03,
        -2.30650028e-02,  -4.80913727e-02,   0.00000000e+00,
         2.32768306e-02,   0.00000000e+00,  -1.69554697e-01,
        -9.09806558e-03,   3.37364586e-02,   6.13368430e-02,
        -8.41613186e-02,   0.00000000e+00,   3.13032458e-02,
         0.00000000e+00,   7.85087384e-02,  -1.92025039e-02,
         1.17373299e-02,  -4.81245430e-03,   0.00000000e+00,
        -2.65352923e-02,   0.00000000e+00,  -3.71057618e-03,
        -1.85831973e-01,   5.47111681e-02,  -1.74395468e-02,
        -3.69369619e-03,   1.26885800e-02,   0.00000000e+00,
         3.39464246e-03,   0.00000000e+00,   1.23004642e-02,
        -1.02238913e-02,   4.74607413e-04,   3.70137453e-03,
         0.00000000e+00,   1.96688263e-02,   0.00000000e+00,
        -6.68110400e-03,   6.19385319e-03,  -5.26015100e-02,
         1.07726188e-01,  -5.20897119e-02,  -1.04904835e-02,
         1.26924155e-03,   0.00000000e+00,   5.51605747e-03,
         0.00000000e+00,   4.39133982e-02,  -1.62344172e-02,
         1.08733797e-02,   6.04818454e-03,   0.00000000e+00,
         1.96498840e-02,   0.00000000e+00,   5.08044751e-03,
        -6.08174154e-03,  -6.50008930e-02,  -1.73125229e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.40499014e-03,  -1.53098899e-03,
        -4.11212255e-03,  -6.34311751e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.04548366e-03,   0.00000000e+00,
        -2.06790533e-03,  -3.65948135e-03,   1.48604503e-03,
         1.38732950e-03,   0.00000000e+00,   2.67890331e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.70720817e-04,
         0.00000000e+00,   1.06017348e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.07653924e-04,   0.00000000e+00,
         6.92450517e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.80330779e-03,   0.00000000e+00,
         6.69168712e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.06530956e-03,
         0.00000000e+00,   1.59727405e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.46473717e-04,  -2.30573622e-03,  -3.90455324e-03,
        -4.22228889e-03,   0.00000000e+00,  -6.99764623e-04,
         0.00000000e+00,   1.15017240e-03,   6.21773007e-04,
        -2.14299323e-04,   7.90303701e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.00954434e-03,   0.00000000e+00,
        -6.02800301e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.15142711e-05,
         0.00000000e+00,  -1.77091548e-03,   1.09104284e-04,
         7.30466475e-03,   1.22287004e-02,   0.00000000e+00,
         1.30008429e-02,   0.00000000e+00,  -4.21178992e-04,
        -1.03426330e-04,  -1.76788696e-03,  -2.94494308e-03,
         0.00000000e+00,   1.54699706e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.77874125e-02,   0.00000000e+00,
        -5.60663790e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.29994559e-03,
         0.00000000e+00,  -7.03724320e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.30735989e-03,   0.00000000e+00,
         1.02521911e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.64930431e-04,
         0.00000000e+00,   4.39221543e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.37077130e-04,
         0.00000000e+00,   1.48940825e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.76633841e-03,   0.00000000e+00,   1.07570395e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.67807481e-03,   0.00000000e+00,
         1.75709630e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.58229005e-03,
         0.00000000e+00,   1.08736073e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.72382368e-03,  -3.77968438e-03,
        -6.57001250e-03,   7.55429485e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.43953108e-03,   0.00000000e+00,
         2.66312235e-03,   9.21487069e-03,   4.11537575e-03,
        -1.46561053e-03,   0.00000000e+00,  -8.54452813e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.71440034e-03,
         0.00000000e+00,  -2.57854249e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.46579376e-03,   0.00000000e+00,
        -6.52806372e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.07061863e-03,   0.00000000e+00,
        -1.74077180e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.48654982e-03,
         0.00000000e+00,  -1.11878796e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.52845964e-03,   1.60428356e-03,  -1.81067435e-03,
         3.46408126e-03,   0.00000000e+00,  -2.68904354e-03,
         0.00000000e+00,  -5.24947873e-03,  -9.71486832e-04,
        -2.77444831e-04,   1.72224148e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.05022124e-03,   0.00000000e+00,
        -8.57226139e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.17406038e-03,
         0.00000000e+00,  -5.27711441e-03,   8.01568526e-03,
         1.13355169e-02,  -1.19876852e-02,   0.00000000e+00,
         6.11682710e-03,   0.00000000e+00,   9.14546967e-03,
        -2.23732442e-03,   5.79397740e-04,  -1.12197470e-03,
         0.00000000e+00,  -2.20814511e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.93657720e-03,   0.00000000e+00,
        -2.60064878e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.27949955e-03,
         0.00000000e+00,  -1.33018180e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.09378500e-02,   0.00000000e+00,
        -6.42716145e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.39597999e-03,
         0.00000000e+00,  -1.06643441e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.69232766e-03,
         0.00000000e+00,  -4.00125411e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.86545360e-03,   0.00000000e+00,   2.02731921e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.89451252e-03,   0.00000000e+00,
         1.21931889e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.86602627e-04,
         0.00000000e+00,   3.74376771e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.87991880e-02,   1.07030304e-02,
         2.93674990e-03,  -1.64074410e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.04925899e-03,   0.00000000e+00,
         9.07291088e-03,   6.38005715e-03,   1.78668741e-03,
         2.13529578e-03,   0.00000000e+00,  -3.01297142e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.44189822e-03,
         0.00000000e+00,  -4.34866327e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.58074692e-03,   0.00000000e+00,
        -4.45589000e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.52965364e-04,   0.00000000e+00,
        -2.86872946e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.37457189e-03,
         0.00000000e+00,  -2.49447926e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.32989910e-03,   1.87670649e-02,   2.32781297e-03,
         3.01025850e-03,   0.00000000e+00,  -5.11753271e-03,
         0.00000000e+00,  -5.88086667e-03,  -2.23293893e-03,
        -5.27468567e-03,  -2.42217500e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.62022810e-03,   0.00000000e+00,
        -2.69089223e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.96592435e-04,
         0.00000000e+00,   1.79589678e-02,  -4.41394038e-03,
        -2.32904373e-03,   4.71320783e-03,   0.00000000e+00,
        -4.63046001e-04,   0.00000000e+00,   2.00883289e-03,
        -1.76651550e-03,  -5.76840527e-04,   5.62703922e-04,
         0.00000000e+00,   3.45175620e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.89918259e-04,   0.00000000e+00,
         1.48410823e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.75609157e-03,
         0.00000000e+00,   8.37329084e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.69148953e-03,   0.00000000e+00,
        -5.32679510e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.38499526e-03,
         0.00000000e+00,   9.45798508e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.67456303e-03,
         0.00000000e+00,  -2.01184771e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.76772918e-03,   0.00000000e+00,  -8.47146366e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.80165115e-02,   0.00000000e+00,
         1.96089423e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.59422885e-03,
         0.00000000e+00,  -1.53988582e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.47969868e-02,   1.10112687e-02,
         3.88930505e-03,  -2.53922637e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.29585606e-04,   0.00000000e+00,
         1.05946527e-02,   6.18353001e-03,   1.68014356e-03,
         5.92743265e-04,   0.00000000e+00,  -1.44621229e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.74175151e-03,
         0.00000000e+00,  -1.82443043e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.50454121e-03,   0.00000000e+00,
         1.24404114e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.40469145e-03,   0.00000000e+00,
        -2.91479009e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.54810849e-03,
         0.00000000e+00,   1.77409430e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.33211462e-02,  -1.06831079e-03,  -4.53528879e-04,
        -4.73310342e-04,   0.00000000e+00,   5.83542460e-04,
         0.00000000e+00,  -1.57431640e-03,  -2.19205978e-03,
         2.94858176e-03,   3.00353682e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.50662664e-03,   0.00000000e+00,
        -2.30485388e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.22202200e-03,
         0.00000000e+00,   4.04120790e-02,  -1.93876600e-02,
        -4.44828373e-03,   1.95949330e-03,   0.00000000e+00,
         1.00839537e-03,   0.00000000e+00,   8.51157792e-03,
        -2.83371558e-03,   1.74234790e-03,   6.00738141e-04,
         0.00000000e+00,   2.43032272e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.99775429e-03,   0.00000000e+00,
         2.39640877e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.55009654e-04,
         0.00000000e+00,   7.05469914e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.20357394e-03,   0.00000000e+00,
         3.09053594e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.69383020e-03,
         0.00000000e+00,   1.62818970e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.22754580e-02,
         0.00000000e+00,   5.36152419e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.20276403e-03,   0.00000000e+00,  -9.36392867e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.57837287e-02,   0.00000000e+00,
        -1.67199602e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.12335048e-03,
         0.00000000e+00,  -1.15872570e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.46935968e-03,   9.15936745e-03,   1.56383239e-02,
         3.62710086e-02,  -3.36904063e-02,  -2.22475569e-03,
         5.06839970e-02,  -3.36231942e-02,  -1.05620305e-02,
         2.24217387e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.05224192e-03,
         6.78433793e-02,  -6.66899307e-03,  -7.87001516e-03,
         1.22335016e-02,   0.00000000e+00,  -1.13207189e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.64369502e-03,   0.00000000e+00,
         2.75130576e-03,  -8.20841827e-03,  -1.64280901e-02,
         6.51224303e-03,   1.54636475e-02,   0.00000000e+00,
         1.19533166e-02,   0.00000000e+00,   1.02526936e-02,
        -2.09406853e-03,  -2.03675720e-03,  -1.63313969e-03,
        -3.06999466e-03,   0.00000000e+00,  -4.23423835e-03,
         0.00000000e+00,   6.85386661e-03,   8.41323812e-03,
        -6.83465837e-03,   5.19113001e-03,  -5.79307558e-03,
         2.19206873e-03,   0.00000000e+00,   7.73112113e-03,
         0.00000000e+00,   8.04189164e-03,   8.41656540e-03,
         2.24560869e-02,  -3.17763895e-03,   1.66823786e-02,
         7.55789698e-03,   1.73370664e-03,   0.00000000e+00,
         1.79174321e-03,   0.00000000e+00,  -8.71431060e-03,
        -1.89399828e-03,  -2.28228430e-03,  -8.18377604e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.56193775e-03,   0.00000000e+00,
         1.37250525e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.82956104e-03,
         3.20033455e-03,  -3.63717318e-03,   9.87581191e-04,
         4.75180570e-03,   0.00000000e+00,   4.63228607e-03,
         0.00000000e+00,  -2.25779738e-03,   6.86643844e-04,
         8.46017486e-04,  -5.98675335e-03,   0.00000000e+00,
         9.55074972e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.58060745e-03,
         0.00000000e+00,   6.00116828e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.14434443e-04,   0.00000000e+00,  -3.40049330e-03,
        -1.77471840e-02,   6.94697694e-03,   4.61170842e-03,
         3.12683759e-03,   0.00000000e+00,   1.00081807e-03,
         0.00000000e+00,  -9.68298403e-03,   7.36016353e-03,
        -6.68538157e-03,  -1.35358180e-03,   0.00000000e+00,
        -1.04413179e-02,   0.00000000e+00,  -1.14870160e-02,
         1.56100532e-03,  -1.99656052e-03,   6.51456227e-03,
         1.17741813e-03,   0.00000000e+00,   8.84913011e-04,
         0.00000000e+00,   3.88941378e-03,   1.73842461e-03,
         3.55477842e-03,  -2.74726846e-03,   0.00000000e+00,
        -2.47306861e-03,   0.00000000e+00,  -1.18413099e-02,
        -2.28327591e-04,  -3.84499378e-04,  -4.40050461e-03,
        -6.22851861e-05,  -5.09353368e-03,   0.00000000e+00,
        -1.70211111e-02,   0.00000000e+00,   6.02071238e-03,
         5.22571158e-03,   1.07941507e-02,  -1.33066261e-02,
         0.00000000e+00,  -6.76767597e-03,   0.00000000e+00,
         3.22933366e-02,   1.88191944e-03,   1.42799458e-02,
         3.44542962e-03,  -1.36517503e-03,  -3.15804711e-03,
        -8.85417507e-03,   0.00000000e+00,  -8.53160457e-03,
         0.00000000e+00,  -1.64743152e-03,  -1.79544272e-04,
         8.42631315e-03,   2.76001194e-02,   0.00000000e+00,
        -1.09507383e-02,   0.00000000e+00,   6.54381800e-02,
        -2.64041329e-03,  -3.19746318e-04,  -9.46568386e-04,
        -1.48757991e-02,  -2.95532501e-04,  -1.21364621e-02,
         5.72222937e-02,   6.29782500e-03,  -1.12472425e-02,
         7.41937347e-02,  -1.11678686e-02,   2.18962740e-03,
         1.29295968e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.30235179e-02,
         5.44325474e-02,  -6.87048478e-02,  -2.61091801e-02,
        -1.17170116e-02,   0.00000000e+00,   1.28591370e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.82748021e-03,   0.00000000e+00,
         1.45839976e-02,   2.79062726e-03,   1.58809529e-02,
         2.06350436e-04,   2.11653482e-02,   0.00000000e+00,
         6.66455827e-03,   0.00000000e+00,  -3.98263126e-03,
         2.15534506e-03,  -8.81376049e-04,   1.22169506e-02,
        -7.74050277e-03,   0.00000000e+00,  -7.96979285e-03,
         0.00000000e+00,  -1.52112217e-02,  -1.69226540e-02,
        -4.25182901e-03,  -1.69688446e-03,   2.27311183e-02,
        -4.70673480e-03,   0.00000000e+00,  -8.49269682e-03,
         0.00000000e+00,  -1.50738898e-02,  -1.00177341e-03,
        -4.07496403e-02,  -9.62849330e-03,  -1.29910505e-03,
         4.65669922e-03,  -8.32360189e-03,   0.00000000e+00,
         1.36867097e-02,   0.00000000e+00,  -1.57149423e-03,
         1.28345694e-02,  -7.46670342e-03,   2.23968288e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.75059951e-04,   0.00000000e+00,
         7.43369659e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.46010050e-02,
         2.78607218e-03,  -4.29004329e-03,  -2.87127207e-03,
         4.90645102e-03,   0.00000000e+00,   7.06382473e-03,
         0.00000000e+00,  -3.76403792e-04,  -7.01563445e-04,
        -7.42105848e-03,  -5.06648242e-03,   0.00000000e+00,
         2.59956576e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.79258032e-03,
         0.00000000e+00,  -1.49308793e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.40324656e-03,   0.00000000e+00,  -1.10492519e-02,
        -1.64795463e-02,   1.10843400e-02,   2.54813401e-03,
         2.11789991e-03,   0.00000000e+00,   4.59156344e-03,
         0.00000000e+00,  -1.02303276e-02,   4.94685820e-03,
        -2.25993113e-03,  -1.90322026e-02,   0.00000000e+00,
        -9.35008528e-03,   0.00000000e+00,  -1.52574236e-02,
         8.65352527e-04,   1.12209393e-03,   4.18844375e-03,
         3.76963007e-03,   0.00000000e+00,   5.58264062e-03,
         0.00000000e+00,   4.11755419e-03,  -3.15564203e-03,
        -1.40308374e-03,   3.11799959e-03,   0.00000000e+00,
        -6.20755940e-03,   0.00000000e+00,  -1.80378912e-02,
        -9.36867760e-03,  -9.65066965e-04,  -4.56724188e-03,
        -9.49810406e-03,  -9.57935164e-03,   0.00000000e+00,
        -4.34166927e-03,   0.00000000e+00,  -5.64296145e-04,
         1.97252534e-04,  -1.78227284e-03,   4.80762817e-02,
         0.00000000e+00,  -8.30983196e-03,   0.00000000e+00,
         2.30518729e-02,  -4.97135486e-03,   5.56952979e-04,
         3.49866054e-03,   1.59178854e-03,  -5.97710662e-03,
        -6.04158109e-03,   0.00000000e+00,  -9.55114848e-03,
         0.00000000e+00,   2.36549182e-03,  -2.41351488e-03,
         6.99092463e-03,   8.42510633e-03,   0.00000000e+00,
        -8.31424454e-03,   0.00000000e+00,   8.51058682e-02,
        -5.02472729e-03,   2.32514664e-03,  -1.26358107e-02,
         1.21425546e-01,  -9.50246629e-02,  -6.47825543e-02,
        -2.82106041e-02,   4.64412448e-02,   2.35403900e-03,
        -1.20695532e-02,  -5.14169249e-02,  -4.66818501e-03,
         9.06233225e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.49604084e-01,
        -5.85905784e-03,   3.52878115e-02,   1.37409964e-01,
         8.93708629e-02,   0.00000000e+00,   1.63592110e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.64449689e-02,   0.00000000e+00,
        -9.45800412e-02,   4.06525333e-02,   6.92269771e-03,
         5.66569368e-02,  -8.24559207e-02,   0.00000000e+00,
         4.45412384e-02,   0.00000000e+00,  -1.18098479e-02,
        -8.83215153e-03,   1.68296949e-02,  -3.25157309e-02,
         1.73695173e-02,   0.00000000e+00,  -1.01384377e-03,
         0.00000000e+00,  -8.24150176e-03,  -5.99394665e-02,
         4.09801673e-03,  -8.35706302e-03,  -7.23662065e-03,
        -1.75056777e-02,   0.00000000e+00,  -6.24813427e-03,
         0.00000000e+00,   1.52046744e-03,  -3.44261557e-02,
        -8.61612839e-02,   5.86772208e-03,  -3.06413739e-04,
         1.16796518e-02,   5.73341161e-03,   0.00000000e+00,
        -6.03660087e-02,   0.00000000e+00,   1.76798421e-02,
         5.07804452e-03,   2.65391552e-02,  -1.01190209e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.12815260e-02,   0.00000000e+00,
        -5.57155127e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.00385457e-01,
         3.76578428e-03,  -8.72741374e-04,  -2.29360954e-02,
         2.17282300e-02,   0.00000000e+00,   1.41397051e-02,
         0.00000000e+00,   1.89239711e-02,  -2.95803554e-02,
        -1.38858457e-02,  -4.66383212e-03,   0.00000000e+00,
        -8.64932737e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.72599309e-02,
         0.00000000e+00,   1.47232457e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.74173497e-02,   0.00000000e+00,   1.30476195e-01,
         5.06641616e-03,  -5.22558393e-03,  -3.20197469e-02,
        -3.68680500e-02,   0.00000000e+00,  -3.80625669e-02,
         0.00000000e+00,  -1.17425494e-03,  -1.73706608e-03,
         2.27332391e-02,   7.60967859e-02,   0.00000000e+00,
        -2.93501839e-02,   0.00000000e+00,   1.36813305e-01,
         5.80264997e-03,  -4.95328875e-03,  -1.76335320e-02,
         2.92997155e-02,   0.00000000e+00,  -1.66256330e-02,
         0.00000000e+00,  -5.15756009e-02,   1.47143448e-02,
        -9.38684958e-03,   1.17757803e-02,   0.00000000e+00,
         4.58454347e-02,   0.00000000e+00,   1.37460341e-02,
         1.32913692e-01,  -9.55394440e-03,   4.38099508e-02,
         9.78316594e-03,   6.62324060e-03,   0.00000000e+00,
        -1.16950959e-02,   0.00000000e+00,  -3.25230045e-02,
        -5.35735215e-03,  -7.06073250e-03,  -2.24382342e-02,
         0.00000000e+00,  -2.93671680e-02,   0.00000000e+00,
         9.04895008e-03,  -2.41684425e-02,  -6.72339541e-02,
        -4.31531182e-02,   1.26574307e-02,   6.89697010e-03,
        -3.03814129e-03,   0.00000000e+00,   3.17801986e-03,
         0.00000000e+00,  -2.26858376e-02,   1.63726802e-02,
        -1.01651528e-02,  -3.73912513e-03,   0.00000000e+00,
        -1.92028338e-02,   0.00000000e+00,  -2.69027747e-02,
        -2.46343940e-03,   8.31012376e-02,   1.13881461e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.77802506e-03,  -1.03453241e-03,
         5.59433398e-03,   8.74816747e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.35543039e-02,   0.00000000e+00,
        -2.79074859e-03,  -9.18894455e-03,  -9.75757059e-03,
        -1.10053423e-02,   0.00000000e+00,   1.13892331e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.88711442e-04,
         0.00000000e+00,  -3.96760692e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.04224473e-04,   0.00000000e+00,
        -2.47857292e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.42709019e-03,   0.00000000e+00,
        -2.41411266e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.13943385e-03,
         0.00000000e+00,   5.81836425e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.28398084e-03,  -3.10628781e-03,  -2.91506251e-03,
        -2.37060256e-03,   0.00000000e+00,   7.31912084e-03,
         0.00000000e+00,  -1.47883943e-03,   2.18548190e-04,
        -3.52927251e-03,   1.30682012e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.03457476e-03,   0.00000000e+00,
        -1.05690164e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.67780551e-04,
         0.00000000e+00,   3.65136484e-04,   1.68462771e-04,
        -1.87705356e-03,  -2.75158189e-03,   0.00000000e+00,
        -2.96075331e-03,   0.00000000e+00,   2.10747732e-04,
        -1.69931023e-04,   5.57947221e-04,   6.82951969e-03,
         0.00000000e+00,  -1.56104409e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.79869463e-03,   0.00000000e+00,
         9.20381334e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.92437161e-03,
         0.00000000e+00,   1.10649088e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.00836757e-04,   0.00000000e+00,
         6.11786627e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.28776286e-04,
         0.00000000e+00,  -4.70340484e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.82965983e-04,
         0.00000000e+00,   1.05302308e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.20004902e-03,   0.00000000e+00,   2.73851835e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.03037880e-04,   0.00000000e+00,
         6.46571177e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.02380572e-03,
         0.00000000e+00,  -2.05981410e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.00579918e-01,  -8.58591255e-02,  -6.21437551e-02,
        -6.78956152e-03,   2.40614500e-02,  -5.10907668e-03,
         2.40145723e-02,  -6.76922976e-02,  -6.97307805e-03,
         9.29253774e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.28161780e-01,
         2.81918104e-02,   2.03125083e-02,   9.76046590e-02,
         9.60476608e-02,   0.00000000e+00,   1.07234570e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.13369627e-02,   0.00000000e+00,
        -9.42859796e-02,   3.65562750e-02,   4.38911573e-03,
         4.61045532e-02,  -8.47584260e-02,   0.00000000e+00,
         5.03392685e-02,   0.00000000e+00,  -2.82122111e-02,
        -5.39015240e-03,   2.58247884e-02,  -3.12064067e-02,
         2.02730849e-02,   0.00000000e+00,  -4.13009891e-03,
         0.00000000e+00,   5.24493391e-04,  -4.57649887e-02,
         4.87534298e-03,   1.19999816e-02,  -1.43420297e-02,
        -1.40183616e-02,   0.00000000e+00,   3.15533757e-04,
         0.00000000e+00,   4.69513266e-03,  -2.31928153e-02,
        -4.92391694e-02,  -1.92850652e-03,   5.42199466e-03,
         1.27391503e-02,   8.13962067e-03,   0.00000000e+00,
        -5.49523772e-02,   0.00000000e+00,   2.47412008e-02,
         1.88254831e-03,   2.57517010e-02,  -1.05516560e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.00538073e-03,   0.00000000e+00,
        -5.61182655e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.00834995e-01,
         6.17542968e-03,  -2.13849920e-03,  -2.10286098e-02,
         2.87692866e-02,   0.00000000e+00,   1.28935861e-02,
         0.00000000e+00,   2.20497175e-02,  -2.95233798e-02,
        -9.00093083e-03,  -2.27958461e-02,   0.00000000e+00,
        -8.44204501e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.13672247e-02,
         0.00000000e+00,   1.17473236e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.24028822e-02,   0.00000000e+00,   1.11981681e-01,
        -5.04321061e-03,  -8.51013634e-04,  -2.39429724e-02,
        -3.65410256e-02,   0.00000000e+00,  -3.20295424e-02,
         0.00000000e+00,  -4.02979601e-03,   8.06051193e-04,
         1.48479094e-02,   6.47728793e-02,   0.00000000e+00,
        -3.14866456e-02,   0.00000000e+00,   1.13491253e-01,
         4.90670010e-03,  -5.68030960e-03,  -1.35422979e-02,
         3.00112731e-02,   0.00000000e+00,  -7.06594556e-03,
         0.00000000e+00,  -4.78095865e-02,   1.36055314e-02,
        -9.24155906e-03,   9.98960971e-03,   0.00000000e+00,
         4.67181311e-02,   0.00000000e+00,  -1.31257913e-02,
         1.16674921e-01,  -7.30392884e-03,   4.35949653e-02,
         3.58206937e-03,   2.13029996e-03,   0.00000000e+00,
        -1.54408294e-02,   0.00000000e+00,  -3.20483301e-02,
        -9.34301824e-03,  -4.70126789e-03,  -1.81942256e-02,
         0.00000000e+00,  -3.47340895e-02,   0.00000000e+00,
         2.57965677e-02,  -2.58899776e-02,  -6.73705674e-02,
        -4.06012885e-02,   7.95762285e-03,   1.66407859e-03,
        -8.58065271e-03,   0.00000000e+00,  -1.72731273e-03,
         0.00000000e+00,  -1.97408036e-02,   1.60708840e-02,
        -2.34982930e-03,   6.84188366e-03,   0.00000000e+00,
        -2.09621614e-02,   0.00000000e+00,   1.37428701e-02,
        -5.87358771e-03,   7.72655367e-02,   9.63117157e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.60535276e-03,   1.98009338e-03,
         1.72346656e-02,   2.45076173e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.35924537e-02,   0.00000000e+00,
         2.73760186e-03,   4.65973457e-03,   1.20346392e-03,
        -9.26119229e-04,   0.00000000e+00,  -1.39013559e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.15034660e-04,
         0.00000000e+00,   1.90714866e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.52800832e-04,   0.00000000e+00,
         3.71142150e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.62322442e-03,   0.00000000e+00,
         1.58626610e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.67536447e-03,
         0.00000000e+00,  -3.83682000e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.18316197e-04,   2.07818403e-03,   2.92902036e-03,
         3.99981320e-03,   0.00000000e+00,  -1.99091931e-05,
         0.00000000e+00,   5.84147440e-04,  -1.29214558e-04,
         1.32068100e-04,  -1.05326454e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.76895933e-03,   0.00000000e+00,
        -1.41476620e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.79281266e-03,
         0.00000000e+00,   8.37687631e-04,  -4.62267835e-04,
        -3.76230654e-03,  -6.42953382e-03,   0.00000000e+00,
        -7.45192424e-03,   0.00000000e+00,   1.90302417e-04,
        -1.17057550e-04,   3.99720197e-03,   6.25292683e-03,
         0.00000000e+00,  -4.27245950e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.92812694e-03,   0.00000000e+00,
         3.16361022e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.14299259e-03,
         0.00000000e+00,   2.85542170e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.18564257e-04,   0.00000000e+00,
        -4.50662743e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.10797517e-05,
         0.00000000e+00,  -1.14271529e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.30511870e-04,
         0.00000000e+00,  -6.70377194e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.76576578e-03,   0.00000000e+00,  -1.05419389e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.46830248e-04,   0.00000000e+00,
        -5.55356145e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.19365973e-03,
         0.00000000e+00,  -1.89109685e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.20779491e-01,  -1.09883052e-01,   4.91507005e-01,
        -6.69121626e-03,   6.90509136e-02,   5.71670228e-01,
        -1.12127093e-02,  -5.86240956e-02,   1.54201165e-02,
         6.93638742e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.24694620e-01,
         5.77309686e-03,   1.09696696e-02,   1.44467694e-01,
         1.07642798e-01,   0.00000000e+00,   6.27577176e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.36133499e-02,   0.00000000e+00,
         4.37656294e-01,   5.82211197e-02,  -2.91835111e-02,
         7.80637784e-02,  -9.81428019e-02,   0.00000000e+00,
         4.39590446e-02,   0.00000000e+00,   5.51242400e-01,
        -3.04278539e-02,  -1.82665920e-02,   1.93054917e-02,
         1.72668304e-02,   0.00000000e+00,  -3.83580675e-02,
         0.00000000e+00,  -7.44225005e-02,   3.11364503e-01,
         9.95681841e-03,  -1.18321857e-02,   9.33818023e-03,
        -2.42695018e-02,   0.00000000e+00,  -4.30651966e-02,
         0.00000000e+00,   3.43350840e-02,   4.14723158e-02,
         3.36120209e-01,   8.14461600e-03,  -1.70339667e-02,
        -5.07472699e-02,  -6.08483677e-02,   0.00000000e+00,
        -1.07048541e-02,   0.00000000e+00,  -3.48042385e-02,
        -1.22051020e-02,   6.46836454e-03,   4.53983380e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.87107739e-02,   0.00000000e+00,
         4.15432715e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.39150682e-01,
         2.82041962e-02,  -3.38475696e-02,   1.98007017e-02,
         2.53940783e-02,   0.00000000e+00,   1.82618981e-02,
         0.00000000e+00,  -4.62799741e-02,   2.81675757e-02,
         1.02373718e-03,  -1.92108641e-02,   0.00000000e+00,
         4.34672766e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.63186821e-01,
         0.00000000e+00,   6.66865415e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.99036066e-02,   0.00000000e+00,   6.70027959e-01,
         1.01146160e-02,  -3.66503120e-03,  -6.71164900e-02,
        -1.00449412e-01,   0.00000000e+00,  -1.39402822e-01,
         0.00000000e+00,  -6.54117310e-03,   9.88074311e-04,
         5.31566201e-02,   9.06746086e-02,   0.00000000e+00,
        -4.47474663e-02,   0.00000000e+00,   7.03178536e-01,
         1.57723909e-02,  -4.11583971e-02,  -7.58448996e-02,
         1.04163938e-01,   0.00000000e+00,  -3.71952013e-02,
         0.00000000e+00,  -9.54000454e-02,   2.85183053e-02,
        -2.33825484e-02,   3.74103466e-03,   0.00000000e+00,
         3.36562450e-02,   0.00000000e+00,   4.28248267e-03,
         6.83636134e-01,  -7.38243228e-02,   9.73061069e-04,
         1.04013477e-03,  -2.53516178e-02,   0.00000000e+00,
         1.00401667e-02,   0.00000000e+00,  -1.18612389e-02,
         4.65703699e-02,  -5.06397596e-03,  -8.02054327e-03,
         0.00000000e+00,  -5.52508854e-02,   0.00000000e+00,
         1.06041917e-02,  -3.65690234e-03,   4.75133192e-01,
        -1.09127834e-01,   6.48590217e-02,   2.00676706e-02,
        -3.95075027e-03,   0.00000000e+00,  -7.63223971e-03,
         0.00000000e+00,  -6.04758591e-02,   2.02825063e-02,
        -2.14083232e-02,  -1.43659834e-02,   0.00000000e+00,
        -3.33046298e-02,   0.00000000e+00,  -1.21578513e-02,
         6.19867850e-03,   1.06297357e-01,   6.90986663e-01,
         1.58468808e-02,  -2.42744603e-02,  -2.70038558e-02,
         4.66474131e-03,   1.52480485e-02,   1.32614127e-02,
         1.56195942e-02,  -9.61496844e-03,   1.65426845e-03,
        -1.37487302e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.51019378e-02,
         6.24025872e-03,   2.73306395e-03,   3.63357565e-02,
         1.40140532e-02,   0.00000000e+00,   1.18700086e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.25060460e-02,   0.00000000e+00,
        -2.94121341e-02,   9.68870312e-03,   7.77259863e-03,
         1.72423738e-02,  -8.80532310e-03,   0.00000000e+00,
         3.26478166e-02,   0.00000000e+00,  -1.94401403e-02,
         2.49090311e-03,   1.24523240e-02,  -1.05377511e-02,
         2.86210413e-03,   0.00000000e+00,  -4.43869212e-03,
         0.00000000e+00,  -1.36392094e-04,  -1.22817001e-02,
         4.95380022e-03,   8.86091887e-03,  -4.40707820e-03,
        -8.61223430e-04,   0.00000000e+00,   1.33298488e-03,
         0.00000000e+00,  -4.50886178e-03,  -4.88441682e-03,
        -1.33281196e-02,  -5.55506648e-05,  -2.46611023e-03,
         2.51957648e-03,   4.92240511e-03,   0.00000000e+00,
        -1.54846699e-02,   0.00000000e+00,   7.73731865e-03,
         4.64363788e-03,   7.29906276e-03,  -3.23125726e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.78136324e-04,   0.00000000e+00,
        -1.79965508e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.25114413e-02,
        -8.70434237e-04,   1.61953963e-03,  -8.59951121e-03,
         5.84118731e-03,   0.00000000e+00,   3.11814081e-03,
         0.00000000e+00,   1.03372209e-02,  -1.15177279e-02,
        -2.52277046e-03,  -1.04561303e-02,   0.00000000e+00,
        -2.53056766e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.04318343e-02,
         0.00000000e+00,   1.10461247e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.28883139e-02,   0.00000000e+00,   2.16371805e-02,
        -5.50002657e-03,   3.89927179e-04,  -9.21350189e-03,
        -3.21409415e-03,   0.00000000e+00,  -8.45677741e-03,
         0.00000000e+00,  -9.86557160e-03,   2.10017955e-03,
         5.21027258e-04,   1.55519281e-02,   0.00000000e+00,
        -2.83362544e-03,   0.00000000e+00,   2.69284826e-02,
         2.33489617e-03,  -4.13848629e-04,  -5.40330381e-03,
        -2.45272302e-04,   0.00000000e+00,  -6.51924044e-03,
         0.00000000e+00,  -1.11562027e-02,   2.64922227e-03,
         1.45578452e-03,   1.44336314e-02,   0.00000000e+00,
         6.79659952e-03,   0.00000000e+00,   2.43994579e-02,
         1.96599551e-02,  -4.13817287e-04,   1.41679827e-02,
        -1.53350796e-03,  -3.36513738e-04,   0.00000000e+00,
        -3.45341608e-03,   0.00000000e+00,  -1.14921369e-02,
        -6.65749839e-03,  -3.21023623e-03,   7.31439767e-03,
         0.00000000e+00,  -1.19378365e-02,   0.00000000e+00,
         4.49225510e-03,  -7.00550492e-03,  -2.85181028e-02,
        -8.67844170e-03,   4.09584209e-04,  -2.24454531e-04,
        -3.81117781e-03,   0.00000000e+00,  -1.33429029e-03,
         0.00000000e+00,  -2.58883436e-03,   4.57263036e-03,
         2.17488807e-03,   1.09329879e-03,   0.00000000e+00,
        -5.84599307e-03,   0.00000000e+00,   1.05816753e-02,
        -3.82669594e-03,   2.01172920e-02,   1.58907083e-02,
        -2.16810552e-02,   1.34219241e-03,  -1.18055273e-02,
        -8.47852569e-03,  -1.18782835e-02,  -2.21563815e-02,
        -4.56740389e-03,   4.99417148e-03,  -3.83353122e-03,
        -1.29126622e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.98374542e-02,
        -3.03437828e-03,   5.58958480e-03,  -3.04964671e-03,
         1.30531966e-03,   0.00000000e+00,  -2.53612915e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.79918394e-04,   0.00000000e+00,
        -1.80948663e-02,   4.12274268e-03,   1.21061669e-02,
        -5.50084614e-03,  -9.15361342e-04,   0.00000000e+00,
        -5.32907949e-03,   0.00000000e+00,  -1.77600408e-02,
         1.28603749e-03,   6.48153621e-03,  -1.44292528e-02,
        -7.61433609e-04,   0.00000000e+00,   1.39669461e-02,
         0.00000000e+00,   9.40731674e-03,   1.34811793e-02,
         2.17545671e-03,   1.03611118e-02,  -1.58995068e-02,
        -5.38758406e-04,   0.00000000e+00,   1.38130029e-02,
         0.00000000e+00,   8.83876675e-04,   1.27556381e-03,
         2.66216975e-02,  -1.64092205e-03,  -3.70030563e-03,
         5.84018106e-03,   4.11003054e-03,   0.00000000e+00,
        -5.72462935e-03,   0.00000000e+00,   6.75846797e-03,
         2.89444231e-03,   5.96888739e-03,  -2.19392632e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.28859788e-03,   0.00000000e+00,
        -1.12634385e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.06796207e-02,
        -1.32432157e-03,   3.39015955e-03,  -6.46651367e-03,
         1.80487337e-03,   0.00000000e+00,   1.30510725e-03,
         0.00000000e+00,   7.40908896e-03,  -5.08140024e-03,
        -6.35795869e-04,   8.30143675e-03,   0.00000000e+00,
        -1.78755506e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.78279415e-03,
         0.00000000e+00,  -4.39856892e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.16776273e-04,   0.00000000e+00,  -1.78908646e-02,
         2.92476026e-03,  -7.17527912e-04,   1.75097592e-03,
         1.54184995e-03,   0.00000000e+00,   4.42464498e-03,
         0.00000000e+00,   3.52699522e-03,  -1.93988072e-03,
        -6.23458520e-03,   8.95054229e-04,   0.00000000e+00,
        -1.45601417e-03,   0.00000000e+00,  -2.03711582e-02,
         5.78486739e-05,   3.55399030e-03,   3.09759729e-03,
        -1.63246901e-03,   0.00000000e+00,   1.59409732e-03,
         0.00000000e+00,  -4.69944291e-05,  -6.69023958e-04,
         1.49642547e-03,  -2.37346892e-03,   0.00000000e+00,
         3.04117341e-03,   0.00000000e+00,  -5.73319937e-03,
        -1.91994234e-02,   6.06039497e-03,   8.61078485e-03,
         5.67024373e-04,   1.64480448e-03,   0.00000000e+00,
         9.41507262e-04,   0.00000000e+00,  -6.55565968e-03,
        -8.00188150e-03,  -2.62774751e-03,  -1.91206105e-03,
         0.00000000e+00,   1.09676960e-02,   0.00000000e+00,
        -3.55196351e-04,  -3.41053219e-03,  -1.70873082e-02,
         1.63304398e-03,  -2.85141339e-03,   4.07419913e-05,
         3.33817669e-03,   0.00000000e+00,   1.06206675e-03,
         0.00000000e+00,   4.70323600e-03,   8.97960932e-04,
         2.91072332e-03,   6.71902200e-04,   0.00000000e+00,
        -3.13827552e-04,   0.00000000e+00,  -7.58306712e-03,
         1.69541890e-03,  -1.50921448e-03,  -1.88420813e-02,
        -4.70949393e-02,   1.40524238e-02,  -8.74899411e-03,
        -6.08138128e-03,  -2.91281816e-02,  -2.47771173e-02,
         9.77544345e-04,   9.83291858e-03,  -5.77502228e-03,
        -4.52332470e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.86017776e-02,
         4.54379961e-03,   1.10760586e-02,  -1.58339346e-02,
        -6.77571819e-03,   0.00000000e+00,  -3.91423582e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.47083158e-03,   0.00000000e+00,
        -2.05276671e-02,  -5.61620966e-04,   1.39017874e-02,
        -1.07505215e-02,   1.29335123e-02,   0.00000000e+00,
        -2.68879797e-03,   0.00000000e+00,  -3.07137266e-02,
         3.76418626e-03,   7.53929430e-03,  -1.63970588e-02,
        -3.56350861e-03,   0.00000000e+00,   1.55787935e-02,
         0.00000000e+00,   1.55993466e-02,   1.85916731e-02,
         3.28696392e-03,   2.30821613e-02,  -2.88154174e-02,
         4.58250808e-03,   0.00000000e+00,   2.67432828e-02,
         0.00000000e+00,   2.56750254e-03,   1.20158119e-02,
         6.25448802e-02,  -2.94162617e-03,   1.38394389e-03,
         1.04618515e-02,   1.33110334e-02,   0.00000000e+00,
        -6.11729041e-03,   0.00000000e+00,   1.01039786e-02,
         2.76368226e-03,   7.05602735e-03,  -2.89443249e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.98860690e-03,   0.00000000e+00,
        -1.50812434e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.59549249e-02,
        -3.71177435e-03,   6.25651886e-03,  -8.79850836e-03,
         5.17571779e-04,   0.00000000e+00,  -8.07792263e-04,
         0.00000000e+00,   1.50617839e-02,  -5.22635687e-03,
         6.77553734e-04,   7.43294768e-03,   0.00000000e+00,
        -1.93951272e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.98849511e-02,
         0.00000000e+00,  -1.08093407e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.69431815e-03,   0.00000000e+00,  -4.40345244e-02,
        -4.44589858e-03,   3.48242204e-06,   9.93345944e-03,
         1.42438644e-02,   0.00000000e+00,   1.79583189e-02,
         0.00000000e+00,  -5.53748218e-04,  -2.24609581e-03,
        -1.49959862e-02,  -6.43756627e-03,   0.00000000e+00,
         3.06113466e-03,   0.00000000e+00,  -4.56723592e-02,
         5.32667186e-05,   7.45974672e-03,   9.47472862e-03,
        -1.37851487e-02,   0.00000000e+00,   3.80358816e-03,
         0.00000000e+00,   9.32709899e-03,  -2.12375731e-03,
         5.74656534e-03,  -8.13760616e-04,   0.00000000e+00,
        -1.76711556e-03,   0.00000000e+00,  -4.09440068e-05,
        -4.77378642e-02,   1.35162611e-02,   9.78574198e-03,
        -9.79312707e-05,   2.83034271e-03,   0.00000000e+00,
        -3.17833186e-03,   0.00000000e+00,  -3.80561279e-03,
        -8.59406319e-03,  -1.46331850e-03,  -3.87243805e-03,
         0.00000000e+00,   1.72725268e-02,   0.00000000e+00,
         2.23255405e-03,  -1.74517424e-03,  -2.17233016e-02,
         1.43596430e-02,  -9.79687944e-03,  -4.52956349e-03,
        -4.72315578e-04,   0.00000000e+00,  -1.40229412e-03,
         0.00000000e+00,   1.15245744e-02,  -5.60048794e-04,
         7.23003646e-03,   5.68388213e-03,   0.00000000e+00,
         1.15560258e-03,   0.00000000e+00,  -1.34864111e-03,
         1.77956572e-03,  -1.12821603e-02,  -4.28574871e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.30769551e-03,   2.37007285e-05,
        -1.27626640e-03,  -2.35788350e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.47097131e-03,   0.00000000e+00,
         6.43224660e-04,   2.37172792e-03,   2.72837893e-03,
         2.86777549e-03,   0.00000000e+00,  -2.91835841e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.24473884e-04,
         0.00000000e+00,   9.87094114e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.15451291e-04,   0.00000000e+00,
         5.40217377e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.18935136e-04,   0.00000000e+00,
         1.56464848e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.28750520e-04,
         0.00000000e+00,  -8.58401783e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.76832997e-04,   2.59633057e-03,   3.71304850e-03,
         3.44012408e-03,   0.00000000e+00,  -7.84149441e-03,
         0.00000000e+00,   2.73273362e-03,   2.39748897e-04,
         1.52963632e-03,  -5.37598961e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.30169885e-04,   0.00000000e+00,
        -1.03658801e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.73668417e-05,
         0.00000000e+00,   1.23588296e-04,   5.97475301e-04,
         2.62938481e-03,   3.16952306e-03,   0.00000000e+00,
         8.84249209e-04,   0.00000000e+00,   5.11220424e-04,
         1.05778279e-04,  -3.09396572e-04,  -1.63856933e-03,
         0.00000000e+00,   3.59527686e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.86022659e-03,   0.00000000e+00,
         1.52519432e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.86612061e-03,
         0.00000000e+00,  -3.05261943e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.00955196e-05,   0.00000000e+00,
         1.52330706e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.79079681e-04,
         0.00000000e+00,   2.73306729e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.82914651e-04,
         0.00000000e+00,  -2.93647293e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.38792041e-03,   0.00000000e+00,   2.38943490e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.77705654e-04,   0.00000000e+00,
         1.02693784e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.59029716e-04,
         0.00000000e+00,   1.00530261e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.22691634e-02,   4.46903624e-02,   5.60857703e-02,
         1.68468995e-02,  -1.56100756e-02,   2.42404954e-02,
         3.53849192e-04,   2.15283815e-02,   2.39623841e-03,
        -1.36255430e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.13622896e-02,
         3.75442622e-03,  -1.69969614e-02,  -5.60678155e-02,
        -4.09198995e-02,   0.00000000e+00,   2.04788491e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.55967073e-02,   0.00000000e+00,
         6.92688883e-02,  -2.26747431e-02,  -1.50589640e-02,
        -2.49148669e-02,   4.11170603e-02,   0.00000000e+00,
        -2.21219205e-02,   0.00000000e+00,   4.02849941e-02,
         9.17960561e-04,  -1.88829178e-02,   2.43712339e-02,
        -1.12949542e-02,   0.00000000e+00,  -4.40331818e-03,
         0.00000000e+00,  -5.51700719e-03,   3.25660877e-02,
        -5.19233356e-03,  -6.17495525e-03,   1.37812670e-02,
         1.03610315e-02,   0.00000000e+00,  -6.88817701e-03,
         0.00000000e+00,   4.57717340e-03,   1.92972370e-02,
         3.46008088e-02,  -3.46998486e-03,  -6.33695514e-03,
        -2.02423626e-02,  -2.19934571e-02,   0.00000000e+00,
         6.09022873e-02,   0.00000000e+00,  -3.29203931e-02,
        -6.44980140e-03,  -2.00002577e-02,   7.88124973e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.06455649e-04,   0.00000000e+00,
         5.93456488e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.68833487e-02,
         1.60147565e-04,  -6.88205379e-03,   2.63587015e-02,
        -2.19663937e-02,   0.00000000e+00,  -5.96454946e-03,
         0.00000000e+00,  -3.31267687e-02,   2.91455044e-02,
         1.45183399e-02,   6.75913000e-03,   0.00000000e+00,
         7.10472569e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.21759520e-02,
         0.00000000e+00,   1.71323386e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.78936362e-02,   0.00000000e+00,  -3.73283799e-02,
        -3.33963682e-03,   7.07509918e-03,   2.64612871e-02,
         2.72624565e-02,   0.00000000e+00,   1.34830519e-02,
         0.00000000e+00,   3.00939776e-03,   2.74568978e-03,
        -3.68694386e-03,  -3.20307436e-02,   0.00000000e+00,
         1.18908292e-02,   0.00000000e+00,  -3.89784319e-02,
        -4.20308379e-03,   2.33436584e-03,   8.50504896e-03,
        -1.40426685e-02,   0.00000000e+00,   7.97662882e-03,
         0.00000000e+00,   3.24409421e-02,  -8.37942009e-03,
         2.76750200e-03,  -9.78183279e-03,   0.00000000e+00,
        -2.81867907e-02,   0.00000000e+00,  -3.41328486e-03,
        -3.50542738e-02,  -4.04627511e-03,  -4.66459953e-02,
        -6.76651974e-03,  -1.10712327e-02,   0.00000000e+00,
         1.42184722e-02,   0.00000000e+00,   2.00222970e-02,
         1.22455940e-02,   8.73892373e-03,   5.90203858e-03,
         0.00000000e+00,   8.04686006e-03,   0.00000000e+00,
        -4.49697904e-03,   1.67371905e-02,   6.50100696e-02,
         3.04871600e-02,   1.04664600e-03,  -1.12218305e-03,
         1.12703234e-03,   0.00000000e+00,  -6.34530820e-03,
         0.00000000e+00,   6.02886424e-03,  -7.84274829e-03,
         2.33956425e-03,   1.05472867e-03,   0.00000000e+00,
         5.79299052e-03,   0.00000000e+00,   1.11250821e-02,
         1.85193446e-03,  -3.99271987e-02,  -2.54355079e-02,
         3.92961382e-02,  -2.97568920e-02,  -1.18155884e-02,
        -4.71379738e-03,   1.09617126e-02,   3.71740986e-03,
         9.99070304e-03,  -1.93273369e-02,  -1.99914077e-03,
         3.93255655e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.08352640e-02,
         7.37081637e-03,   3.50125480e-03,   3.66084733e-02,
         2.72685694e-02,   0.00000000e+00,   1.38461219e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.79953183e-02,   0.00000000e+00,
        -2.20054492e-02,   1.29135590e-02,   5.64730384e-03,
         1.92494366e-02,  -2.37906191e-02,   0.00000000e+00,
         1.39816091e-02,   0.00000000e+00,   1.97395662e-03,
        -3.07211919e-03,   7.13366582e-03,  -1.23181303e-02,
         5.13698786e-03,   0.00000000e+00,   3.21490039e-04,
         0.00000000e+00,  -2.82201962e-03,  -1.31680309e-02,
         1.54877125e-03,   3.28883359e-03,  -6.87076482e-03,
        -6.58431240e-03,   0.00000000e+00,  -1.08272970e-04,
         0.00000000e+00,   2.38173401e-03,  -7.25691667e-03,
        -1.36503193e-02,  -1.42345022e-04,   5.05025918e-04,
         6.84545130e-03,  -1.17736297e-03,   0.00000000e+00,
        -2.54456148e-02,   0.00000000e+00,   4.15713782e-03,
         6.24887904e-03,   1.09035973e-02,  -2.37606847e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.52088780e-03,   0.00000000e+00,
        -2.06489804e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.75885612e-02,
         4.51584897e-03,  -3.20623691e-03,  -1.06680539e-02,
         1.03232362e-02,   0.00000000e+00,   1.30674551e-02,
         0.00000000e+00,   4.95192142e-03,  -1.06525856e-02,
        -5.86869424e-03,  -8.58714718e-04,   0.00000000e+00,
        -2.30666019e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.18936030e-02,
         0.00000000e+00,   6.08440992e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.80912193e-02,   0.00000000e+00,   4.68531760e-02,
        -5.31490157e-03,   8.47988061e-04,  -1.92389016e-02,
        -2.56217903e-02,   0.00000000e+00,  -2.13210460e-02,
         0.00000000e+00,  -1.56961471e-03,  -1.30157175e-03,
         4.85487171e-03,   2.09914484e-02,   0.00000000e+00,
        -1.13644355e-02,   0.00000000e+00,   4.79788954e-02,
         2.98903150e-03,  -5.52226219e-03,  -1.05153330e-02,
         2.10815160e-02,   0.00000000e+00,  -6.19048304e-03,
         0.00000000e+00,  -2.25729858e-02,   5.70874374e-03,
        -3.22752613e-03,   2.15161828e-03,   0.00000000e+00,
         1.71342469e-02,   0.00000000e+00,   3.34623733e-05,
         4.87534333e-02,  -7.60506477e-03,   1.86158754e-02,
         1.46278697e-03,  -2.09935611e-03,   0.00000000e+00,
        -7.81500326e-03,   0.00000000e+00,  -1.23932561e-02,
        -1.03823763e-03,  -1.21493673e-03,  -1.90120681e-03,
         0.00000000e+00,  -9.49472248e-03,   0.00000000e+00,
         6.59976422e-03,  -1.03882926e-02,  -1.64746368e-02,
        -2.74855013e-02,   7.66484413e-03,  -1.47909600e-03,
        -5.40574390e-03,   0.00000000e+00,  -2.99517131e-03,
         0.00000000e+00,  -8.92164359e-03,   4.91702901e-03,
        -1.53858833e-03,  -6.42489069e-05,   0.00000000e+00,
        -7.64641485e-03,   0.00000000e+00,   3.97272603e-03,
        -3.15564052e-03,   2.65119940e-02,   3.98085181e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.69723960e-03,  -2.33643999e-04,
        -3.86277007e-03,  -6.72396522e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.59389656e-03,   0.00000000e+00,
         4.17406247e-04,   1.46804869e-03,   2.36531666e-03,
         2.59796853e-03,   0.00000000e+00,   1.09415161e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.18195973e-04,
         0.00000000e+00,  -4.83931306e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.49388000e-05,   0.00000000e+00,
         3.31872201e-06,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.46403982e-03,   0.00000000e+00,
        -9.38250083e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.90522076e-03,
         0.00000000e+00,   6.47684912e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.54867462e-05,  -2.11963410e-04,  -3.08819817e-03,
        -3.68455218e-03,   0.00000000e+00,  -1.91691372e-03,
         0.00000000e+00,  -5.66321821e-04,  -2.40650615e-04,
         1.68552590e-04,  -7.73555710e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.12087683e-03,   0.00000000e+00,
         2.18825364e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.13815621e-04,
         0.00000000e+00,  -9.21301918e-04,   1.95777864e-04,
         7.97508941e-03,   1.18591661e-02,   0.00000000e+00,
         1.32109597e-02,   0.00000000e+00,  -5.89706297e-04,
        -2.47140960e-04,  -1.55677933e-03,  -3.25943921e-03,
         0.00000000e+00,   1.39242166e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.80683468e-02,   0.00000000e+00,
        -5.02283718e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.79368338e-03,
         0.00000000e+00,  -7.29977832e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.92132518e-04,   0.00000000e+00,
         2.23777638e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.16676574e-04,
         0.00000000e+00,   6.66609854e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.06511316e-03,
         0.00000000e+00,   6.38833314e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.22695914e-03,   0.00000000e+00,  -1.39219904e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.04000327e-03,   0.00000000e+00,
        -1.77143958e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.53033020e-05,
         0.00000000e+00,   1.39051583e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.63213237e-01,   5.38501591e-02,  -6.15845840e-02,
         7.38779894e-03,  -2.25678985e-02,  -9.47567211e-02,
         5.14011622e-03,   2.40828075e-02,  -3.46711627e-04,
        -1.53541307e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.77838066e-01,
        -4.75863873e-03,  -9.30002474e-03,  -6.99262436e-02,
        -5.16800540e-02,   0.00000000e+00,  -1.19725393e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.85622752e-02,   0.00000000e+00,
        -3.63587897e-02,  -3.80415417e-02,   3.68963435e-03,
        -3.77275276e-02,   5.14692970e-02,   0.00000000e+00,
        -2.55986900e-02,   0.00000000e+00,  -9.57595624e-02,
         1.72692222e-02,   1.89441056e-03,   5.01547936e-03,
        -1.07172865e-02,   0.00000000e+00,   9.81217510e-03,
         0.00000000e+00,   2.24273099e-02,  -1.86170352e-02,
        -8.11795165e-03,   2.18270288e-03,   5.39804045e-03,
         1.96137065e-02,   0.00000000e+00,   1.58261254e-02,
         0.00000000e+00,  -1.19491273e-02,  -5.05030901e-03,
        -2.39600872e-02,  -5.44723011e-03,   7.19453261e-03,
         3.25170879e-02,   3.52506995e-02,   0.00000000e+00,
         2.28985064e-02,   0.00000000e+00,   9.49704176e-03,
         2.21825457e-03,  -3.58276235e-03,  -4.04515288e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.58454876e-02,   0.00000000e+00,
        -4.77617359e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.98221804e-02,
        -1.96883015e-02,   1.47743823e-02,  -7.30851840e-03,
        -2.79095400e-02,   0.00000000e+00,  -1.16079932e-02,
         0.00000000e+00,   1.61420544e-02,  -8.56896443e-03,
         2.96884558e-04,   4.60751316e-03,   0.00000000e+00,
        -3.83462827e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.23231113e-01,
         0.00000000e+00,  -3.78731173e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.67764690e-02,   0.00000000e+00,  -1.67403567e-01,
        -7.91420699e-03,   2.81519838e-03,   6.46821665e-02,
         9.13375862e-02,   0.00000000e+00,   1.13487634e-01,
         0.00000000e+00,   3.21893099e-03,  -4.08132631e-03,
        -2.35514814e-02,  -4.89857934e-02,   0.00000000e+00,
         2.39276707e-02,   0.00000000e+00,  -1.67856511e-01,
        -8.21184543e-03,   3.15120931e-02,   5.68241619e-02,
        -7.97795382e-02,   0.00000000e+00,   2.74437904e-02,
         0.00000000e+00,   7.21044526e-02,  -1.71405675e-02,
         1.06948914e-02,  -3.06151908e-03,   0.00000000e+00,
        -2.27513237e-02,   0.00000000e+00,  -2.19765399e-03,
        -1.70159673e-01,   5.11125413e-02,  -1.42419232e-02,
        -1.47495845e-03,   1.44763409e-02,   0.00000000e+00,
         1.71338647e-03,   0.00000000e+00,   1.11209669e-02,
        -9.73509690e-03,   1.31327250e-03,   3.46613671e-03,
         0.00000000e+00,   1.46042153e-02,   0.00000000e+00,
        -5.71543053e-03,   4.44146398e-03,  -5.64783178e-02,
         9.99407707e-02,  -4.91366250e-02,  -1.12258145e-02,
        -1.27154413e-03,   0.00000000e+00,   4.69563306e-03,
         0.00000000e+00,   4.02077479e-02,  -1.47453830e-02,
         8.91919335e-03,   5.95281500e-03,   0.00000000e+00,
         1.80357462e-02,   0.00000000e+00,   7.72367230e-03,
        -7.07245830e-03,  -5.66686532e-02,  -1.60138645e-01,
        -7.13420607e-03,   9.34514297e-04,  -8.41563224e-03,
         5.93299145e-03,   1.14188596e-03,  -8.81295444e-03,
         3.23181034e-03,  -1.79003788e-03,  -3.18799603e-04,
         2.12551699e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.82968536e-03,
         2.24083294e-03,  -7.34298617e-03,  -1.03449343e-02,
         1.01723980e-03,   0.00000000e+00,  -1.03330018e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.53444380e-03,   0.00000000e+00,
        -3.81437012e-03,   5.84182931e-06,   1.01232686e-03,
        -5.80998993e-03,  -4.27582056e-03,   0.00000000e+00,
        -2.60217149e-03,   0.00000000e+00,  -7.89840122e-03,
         1.95064569e-03,   3.42598327e-03,   1.31616447e-03,
         1.36294617e-03,   0.00000000e+00,   4.91958118e-04,
         0.00000000e+00,  -1.16382904e-04,  -3.28052694e-03,
         4.62777859e-04,   3.44325385e-03,   2.10841075e-03,
        -1.01909806e-03,   0.00000000e+00,   4.22547637e-04,
         0.00000000e+00,  -8.93282452e-04,  -9.52216947e-04,
        -3.52606425e-03,  -2.39747619e-03,   6.26271678e-04,
         5.59498964e-03,  -1.91051765e-04,   0.00000000e+00,
         3.04002871e-03,   0.00000000e+00,   5.89489704e-03,
         6.41913778e-04,   7.12878966e-04,  -5.44257699e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.42085116e-03,   0.00000000e+00,
        -2.47442789e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.96518413e-03,
        -8.36075340e-04,   6.02560927e-04,  -1.88756973e-03,
         4.00989016e-03,   0.00000000e+00,   1.16544671e-03,
         0.00000000e+00,   4.63064697e-04,  -2.12109582e-03,
        -1.13577314e-03,  -4.03111697e-03,   0.00000000e+00,
        -2.30657889e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.51663456e-03,
         0.00000000e+00,  -2.12868557e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.95789131e-04,   0.00000000e+00,  -7.54592953e-03,
        -5.62897628e-03,   7.30529874e-03,   1.40327777e-02,
        -5.79725947e-03,   0.00000000e+00,   1.26315099e-02,
         0.00000000e+00,   9.02113871e-03,  -2.39423350e-03,
        -6.64914200e-04,  -3.32651003e-03,   0.00000000e+00,
        -3.41191996e-04,   0.00000000e+00,  -9.30747034e-03,
        -4.24812999e-04,   1.96395311e-03,   1.11522079e-02,
         9.14639680e-03,   0.00000000e+00,   1.59332524e-02,
         0.00000000e+00,   1.70996115e-03,  -8.65557354e-04,
        -2.00700076e-03,  -1.99674906e-03,   0.00000000e+00,
         1.03176160e-03,   0.00000000e+00,  -9.80555973e-03,
        -6.63489755e-03,   3.29303497e-03,   2.06756163e-03,
        -2.22696815e-03,  -2.56274980e-03,   0.00000000e+00,
        -6.99535406e-04,   0.00000000e+00,  -9.47018802e-04,
        -2.38620827e-03,  -1.10695663e-03,   5.84915065e-03,
         0.00000000e+00,  -3.36102158e-03,   0.00000000e+00,
         1.14982168e-04,  -3.14754297e-05,  -7.14736848e-03,
         5.05316991e-03,  -3.38093139e-03,  -2.50691829e-03,
        -2.65740397e-03,   0.00000000e+00,  -3.38402918e-03,
         0.00000000e+00,   1.44035024e-03,   2.42438537e-04,
         1.63338319e-03,   3.60355302e-04,   0.00000000e+00,
         6.14011315e-04,   0.00000000e+00,   3.49603677e-03,
         1.04439496e-03,  -1.04017777e-03,  -7.15866280e-03,
        -3.48124149e-03,   1.12596930e-03,  -1.40206451e-03,
        -4.80666854e-03,   9.74712625e-03,   5.23333187e-03,
        -1.00996139e-02,   1.09573273e-02,   3.60300123e-03,
        -2.59441893e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.73041978e-03,
        -1.73690142e-02,  -3.22658030e-03,  -5.79283781e-03,
        -7.70692542e-03,   0.00000000e+00,   5.64661658e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.12873375e-03,   0.00000000e+00,
         4.31502903e-03,  -6.32917626e-05,   5.24495722e-03,
        -5.81907227e-03,  -1.61581234e-03,   0.00000000e+00,
        -3.16281208e-03,   0.00000000e+00,  -4.65643682e-03,
         2.76044318e-03,   2.22956381e-03,   2.57169867e-03,
        -1.82478382e-04,   0.00000000e+00,   2.13776720e-03,
         0.00000000e+00,  -4.40496883e-03,  -1.70715408e-03,
         4.16491522e-03,   3.05674175e-03,   1.48995268e-03,
         1.43274656e-03,   0.00000000e+00,  -1.98239635e-03,
         0.00000000e+00,  -2.58448016e-03,  -2.27965902e-04,
        -1.97392634e-03,  -6.62990539e-04,  -1.63671155e-02,
        -4.01723283e-03,  -4.82797442e-03,   0.00000000e+00,
         1.05023018e-02,   0.00000000e+00,   1.25699916e-03,
         1.30745750e-03,   8.07486189e-04,   8.03338270e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.13093454e-03,   0.00000000e+00,
         5.64830825e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.46851341e-03,
        -3.99574582e-03,   8.99465251e-04,   1.69281134e-04,
        -6.89428707e-03,   0.00000000e+00,  -2.79233348e-03,
         0.00000000e+00,  -4.00030030e-03,   2.38606768e-03,
         2.86644480e-03,   2.54228959e-04,   0.00000000e+00,
         1.13628659e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.86184280e-03,
         0.00000000e+00,  -6.61199889e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.85302218e-03,   0.00000000e+00,  -4.08616737e-03,
         1.61150390e-02,  -4.36942094e-03,   2.73218035e-03,
         9.80702826e-03,   0.00000000e+00,   3.33081775e-03,
         0.00000000e+00,   2.99961051e-03,  -1.56550151e-03,
         7.13205721e-04,  -2.95134174e-03,   0.00000000e+00,
         3.26923553e-03,   0.00000000e+00,  -2.19571686e-03,
        -8.81064103e-04,   3.81943165e-03,   2.69484882e-04,
        -8.65340055e-03,   0.00000000e+00,  -5.08399494e-04,
         0.00000000e+00,   3.83152462e-03,  -2.16063262e-03,
        -5.48237408e-04,   2.89194461e-03,   0.00000000e+00,
        -3.32238153e-03,   0.00000000e+00,   1.01203389e-03,
        -4.02815561e-03,   4.83381512e-03,  -1.18798351e-03,
        -4.06645635e-03,   7.52171772e-06,   0.00000000e+00,
         1.83362173e-02,   0.00000000e+00,  -6.90953519e-03,
        -1.79351555e-03,  -5.16050456e-03,   1.07194876e-02,
         0.00000000e+00,  -5.71933689e-04,   0.00000000e+00,
        -9.49085827e-03,  -6.35237331e-04,  -1.27825394e-03,
         6.24537789e-03,  -3.35443576e-03,   8.77806967e-03,
         1.25703911e-02,   0.00000000e+00,   7.96048211e-03,
         0.00000000e+00,   4.48686344e-03,  -8.38971961e-04,
        -6.34651487e-04,  -8.79246673e-03,   0.00000000e+00,
         2.90809334e-03,   0.00000000e+00,  -1.31265723e-02,
         5.45597149e-04,  -3.90296561e-03,  -2.95302664e-03,
         5.33243590e-03,  -3.37422049e-03,  -4.89802127e-03,
        -2.87933213e-03,   9.61060583e-03,   6.20486407e-03,
        -1.06138569e-02,   3.90504783e-03,   1.00978822e-03,
        -2.22121896e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.75650474e-03,
        -1.30243730e-02,   4.31785662e-03,   4.39006521e-03,
         1.51317949e-03,   0.00000000e+00,   9.91589140e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.51326804e-03,   0.00000000e+00,
        -1.48916298e-03,   8.99756247e-04,  -1.92514709e-03,
        -2.68499185e-03,  -8.13904201e-03,   0.00000000e+00,
        -7.70832609e-04,   0.00000000e+00,   8.46416439e-04,
         4.11892850e-04,   1.50340977e-03,   4.84972639e-03,
         4.97543363e-03,   0.00000000e+00,  -8.80225089e-04,
         0.00000000e+00,  -1.92337210e-03,  -6.66632785e-03,
         6.30353872e-03,  -1.66492501e-03,   7.06318147e-04,
        -2.62625776e-03,   0.00000000e+00,  -3.43254642e-03,
         0.00000000e+00,   1.17158703e-03,   1.18518401e-03,
        -7.04846141e-03,   1.49760017e-02,   1.10863707e-03,
         6.51807241e-04,  -2.71091376e-04,   0.00000000e+00,
        -5.19387772e-03,   0.00000000e+00,   2.13442863e-03,
         2.40410185e-03,   5.11154859e-04,  -1.70482388e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.28920297e-04,   0.00000000e+00,
        -2.67659056e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.04139470e-03,
        -7.13727376e-03,   2.46467128e-03,  -6.47378157e-03,
        -4.50025334e-03,   0.00000000e+00,  -3.35401236e-03,
         0.00000000e+00,  -1.03062618e-03,  -2.12115403e-03,
        -2.08244953e-03,  -5.09945099e-03,   0.00000000e+00,
         1.43462465e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.66209136e-03,
         0.00000000e+00,   8.91198913e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.96338562e-03,   0.00000000e+00,   5.05545629e-03,
         3.73954786e-02,  -1.84573812e-02,  -8.01534673e-03,
        -1.65740626e-03,   0.00000000e+00,  -1.73638985e-03,
         0.00000000e+00,   7.96190665e-03,  -2.38775840e-03,
         1.58565766e-03,   2.41432687e-03,   0.00000000e+00,
         2.81422660e-03,   0.00000000e+00,   6.43808877e-03,
        -2.30943162e-03,  -6.23955889e-05,  -1.49505380e-03,
        -8.08022108e-04,   0.00000000e+00,  -5.02159921e-03,
         0.00000000e+00,  -3.12204737e-03,   1.79599580e-03,
         1.64967882e-03,   4.28807751e-03,   0.00000000e+00,
        -1.99777078e-03,   0.00000000e+00,   4.84048459e-04,
         5.55245767e-03,   6.51953114e-04,  -1.48847368e-03,
         1.07055984e-02,   1.53046112e-02,   0.00000000e+00,
         8.23497417e-03,   0.00000000e+00,   2.69507409e-03,
         4.08605661e-04,  -3.50193099e-04,  -4.35245722e-04,
         0.00000000e+00,  -4.10382302e-03,   0.00000000e+00,
        -8.03237809e-03,   5.87045555e-04,  -4.33524482e-03,
        -2.90634767e-03,   1.38998375e-03,   1.77969298e-02,
         2.81515320e-02,   0.00000000e+00,   3.31594150e-02,
         0.00000000e+00,  -3.22475594e-03,  -2.85573648e-05,
        -4.22979725e-03,  -6.88435642e-03,   0.00000000e+00,
         3.87706410e-03,   0.00000000e+00,  -1.06046750e-02,
         1.25604574e-03,   3.27539722e-03,   4.53698932e-03])
  elif name == "BB MO 2E INTEGRALS":
    dimens = (norbtt,nrorb,nob)
    arr = np.array([  7.79710513e-01,  -1.08355058e-01,   4.92190703e-01,
         2.30019360e-02,   7.11380945e-02,   5.82306996e-01,
        -4.69585721e-02,  -7.52628756e-02,  -7.83386067e-03,
         7.03314151e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.85863842e-01,
         2.86643152e-02,   2.20556502e-02,   1.54830710e-01,
         1.02331710e-01,   0.00000000e+00,   6.06598259e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.11090846e-02,   0.00000000e+00,
         4.45969488e-01,   7.34019893e-02,  -5.97657612e-02,
         8.25136433e-02,  -1.16543348e-01,   0.00000000e+00,
         6.10240156e-02,   0.00000000e+00,   5.89724337e-01,
        -3.57409075e-02,  -1.08057775e-02,   1.77900543e-02,
         2.49326765e-02,   0.00000000e+00,  -4.36482805e-02,
         0.00000000e+00,  -8.15949394e-02,   3.09586243e-01,
         9.24466487e-03,  -1.73498099e-02,   1.33312030e-02,
        -2.10256027e-02,   0.00000000e+00,  -4.17184749e-02,
         0.00000000e+00,   4.21595259e-02,   3.65046727e-02,
         3.29581957e-01,   6.52785529e-03,  -1.23389841e-02,
        -4.01342008e-02,  -4.77610559e-02,   0.00000000e+00,
        -1.71540450e-02,   0.00000000e+00,  -3.52470392e-02,
        -1.44031395e-02,   1.23200025e-02,   4.35846523e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.67295087e-02,   0.00000000e+00,
         3.27381570e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.44292487e-01,
         2.67247148e-02,  -2.92815251e-02,   1.58705821e-02,
         2.41312207e-02,   0.00000000e+00,   1.48344830e-02,
         0.00000000e+00,  -5.40143705e-02,   2.40091932e-02,
         5.32805264e-04,  -2.28735858e-02,   0.00000000e+00,
         4.34522742e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.69624313e-01,
         0.00000000e+00,   7.34914250e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.33907070e-02,   0.00000000e+00,   7.11694687e-01,
         8.43133808e-03,  -3.07167740e-03,  -6.18512156e-02,
        -9.39220377e-02,   0.00000000e+00,  -1.32386108e-01,
         0.00000000e+00,  -9.09181554e-03,   2.99642392e-03,
         5.28007777e-02,   9.59441159e-02,   0.00000000e+00,
        -4.34284132e-02,   0.00000000e+00,   6.85997146e-01,
         1.27353331e-02,  -3.72311833e-02,  -7.46573526e-02,
         1.03926969e-01,   0.00000000e+00,  -3.91952544e-02,
         0.00000000e+00,  -1.10445336e-01,   3.53596938e-02,
        -2.66787242e-02,   9.68283423e-04,   0.00000000e+00,
         2.84675625e-02,   0.00000000e+00,   4.78683345e-03,
         7.15477794e-01,  -6.90189800e-02,   8.56707091e-03,
         2.12244982e-03,  -2.54244130e-02,   0.00000000e+00,
         6.16857225e-03,   0.00000000e+00,  -1.52581288e-02,
         4.81757541e-02,  -6.77702186e-03,  -3.02683857e-02,
         0.00000000e+00,  -7.55252800e-02,   0.00000000e+00,
         1.34524307e-02,   1.76916718e-02,   4.88131662e-01,
        -1.11671182e-01,   6.36560822e-02,   1.96532071e-02,
        -3.75564455e-03,   0.00000000e+00,  -1.00590692e-02,
         0.00000000e+00,  -7.70649453e-02,   2.59226683e-02,
        -2.32672524e-02,  -7.09723844e-03,   0.00000000e+00,
        -3.06188666e-02,   0.00000000e+00,  -9.02138980e-03,
         3.52635906e-02,   1.18361530e-01,   7.31472869e-01,
        -1.08355058e-01,   1.13995418e-01,   8.16569505e-02,
         3.07757477e-02,  -6.01334335e-02,   2.15632391e-03,
        -2.80648746e-02,   5.89792926e-02,   6.49940646e-03,
        -9.78488681e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.62965583e-01,
         4.90266644e-03,  -1.43741579e-02,  -1.22748473e-01,
        -8.06544323e-02,   0.00000000e+00,  -2.28755239e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.74216878e-02,   0.00000000e+00,
         1.16027795e-01,  -4.07586061e-02,  -3.22557122e-02,
        -6.78164564e-02,   9.44435528e-02,   0.00000000e+00,
        -5.03055802e-02,   0.00000000e+00,   3.59053078e-02,
         4.67374140e-03,  -2.37840321e-02,   3.50780842e-02,
        -2.13042054e-02,   0.00000000e+00,   4.03615099e-03,
         0.00000000e+00,   8.41130806e-03,   6.92099795e-02,
        -8.26143802e-03,  -5.37082661e-03,   5.53002212e-03,
         1.86357937e-02,   0.00000000e+00,   8.23114357e-03,
         0.00000000e+00,   4.22470449e-03,   3.30402297e-02,
         9.28105531e-02,  -1.95495817e-03,   4.05642399e-03,
        -7.10121265e-03,  -6.41732095e-04,   0.00000000e+00,
         5.50314570e-02,   0.00000000e+00,  -2.45699233e-02,
        -8.37729893e-03,  -2.29397955e-02,   9.78673500e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.56919587e-02,   0.00000000e+00,
         6.21391261e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.19964316e-01,
        -5.38804567e-03,   3.31007953e-03,   2.60486849e-02,
        -2.79323384e-02,   0.00000000e+00,  -1.56850531e-02,
         0.00000000e+00,  -2.74932031e-02,   3.40552002e-02,
         1.49285270e-02,   1.28717393e-02,   0.00000000e+00,
         9.80782032e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.66550833e-02,
         0.00000000e+00,  -1.43256138e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.23619285e-02,   0.00000000e+00,  -1.40879762e-01,
        -1.64093018e-03,   4.31134783e-03,   3.26276129e-02,
         3.91615281e-02,   0.00000000e+00,   3.70527415e-02,
         0.00000000e+00,   2.94426058e-03,   1.88197322e-03,
        -2.03768939e-02,  -6.57064524e-02,   0.00000000e+00,
         2.97905009e-02,   0.00000000e+00,  -1.29370575e-01,
        -6.59382439e-03,   8.01015565e-03,   2.29457245e-02,
        -3.73084720e-02,   0.00000000e+00,   1.54218597e-02,
         0.00000000e+00,   5.51224168e-02,  -1.30935144e-02,
         1.05016825e-02,  -1.89104034e-02,   0.00000000e+00,
        -5.86222426e-02,   0.00000000e+00,  -8.05277212e-03,
        -1.47033204e-01,   1.28442664e-02,  -4.69794675e-02,
        -4.62150142e-03,  -4.89749492e-03,   0.00000000e+00,
         9.70342153e-03,   0.00000000e+00,   3.90642846e-02,
         1.12498541e-02,   9.89602315e-03,  -3.60765492e-03,
         0.00000000e+00,   3.19328771e-02,   0.00000000e+00,
        -1.15365089e-02,   4.25563899e-02,   8.89661388e-02,
         5.17826591e-02,  -1.59105575e-02,  -5.89981602e-03,
         6.09816482e-03,   0.00000000e+00,  -2.22239775e-03,
         0.00000000e+00,   1.82296973e-02,  -1.63722324e-02,
         7.38977696e-03,   8.87466252e-03,   0.00000000e+00,
         2.39959346e-02,   0.00000000e+00,   6.91654848e-03,
         2.03368639e-02,  -9.21301697e-02,  -1.05109948e-01,
         2.30019360e-02,   3.07757477e-02,   4.16547869e-03,
         8.64838902e-02,   1.52323287e-03,   1.99343915e-02,
        -3.73828664e-03,   6.06155623e-03,   9.85502425e-03,
        -1.84236188e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.20950706e-02,
         5.24483613e-02,  -5.13872199e-02,  -3.66506154e-02,
        -1.77074004e-02,   0.00000000e+00,   2.17620957e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.88360546e-02,   0.00000000e+00,
         4.75848305e-02,   1.74813289e-02,  -3.52946619e-02,
        -2.13756795e-02,   2.69487425e-02,   0.00000000e+00,
         7.93309101e-03,   0.00000000e+00,   4.33456575e-02,
        -1.39062426e-03,   8.40122721e-03,   2.27994503e-02,
        -2.07237905e-03,   0.00000000e+00,  -1.51900777e-02,
         0.00000000e+00,  -1.86070364e-02,   2.51398082e-03,
        -1.08324789e-05,  -4.11359766e-03,   2.55853989e-02,
         3.69167781e-03,   0.00000000e+00,  -1.24694021e-02,
         0.00000000e+00,  -4.00553163e-03,   4.53125016e-03,
        -1.42839196e-02,  -3.86327352e-03,   2.26769823e-03,
         3.78381485e-03,  -2.60884407e-03,   0.00000000e+00,
         1.82005704e-02,   0.00000000e+00,  -9.99059678e-03,
         5.62670327e-03,  -7.70650542e-03,   4.62812766e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.60710634e-03,   0.00000000e+00,
         1.80946097e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.00033593e-02,
        -2.12120444e-04,   3.85308200e-03,   2.62245515e-03,
        -4.68264054e-03,   0.00000000e+00,  -1.85779148e-03,
         0.00000000e+00,  -1.99593628e-02,   3.03481562e-03,
        -3.04063596e-03,  -1.39853147e-02,   0.00000000e+00,
         5.22902229e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.89228570e-03,
         0.00000000e+00,   3.39917294e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.06631709e-02,   0.00000000e+00,  -1.38938528e-02,
        -7.86888058e-03,   6.74356035e-03,   7.11342573e-03,
         3.61967241e-03,   0.00000000e+00,   4.21078181e-03,
         0.00000000e+00,  -9.03797046e-03,   5.23745583e-03,
        -3.80221297e-04,  -1.99166462e-02,   0.00000000e+00,
         2.89012170e-05,   0.00000000e+00,  -1.53830579e-02,
        -9.79017224e-03,   6.63723297e-03,   8.11635610e-03,
        -4.24196237e-03,   0.00000000e+00,   6.52380796e-03,
         0.00000000e+00,   9.85366113e-04,   1.90753860e-03,
        -1.49870035e-03,  -2.91337689e-03,   0.00000000e+00,
        -3.39908330e-02,   0.00000000e+00,  -1.21287741e-02,
        -2.82034223e-02,  -3.93431791e-04,  -1.10784036e-02,
        -9.28583143e-03,  -5.20302996e-03,   0.00000000e+00,
        -8.54418949e-05,   0.00000000e+00,   8.47418214e-03,
         2.46864138e-03,  -1.88052959e-03,   2.46390135e-02,
         0.00000000e+00,  -2.63486528e-02,   0.00000000e+00,
         1.14889949e-02,   3.73403619e-02,   3.52552767e-02,
         9.27846927e-03,  -2.94381925e-03,  -7.13228885e-03,
         5.34155442e-03,   0.00000000e+00,  -7.46690218e-03,
         0.00000000e+00,  -1.77924390e-02,   2.18849111e-03,
         2.19795164e-03,   8.38911809e-03,   0.00000000e+00,
         9.00892329e-03,   0.00000000e+00,   5.95181227e-02,
         4.04633355e-02,  -8.72344460e-03,   1.46117468e-02,
        -4.69585721e-02,  -2.80648746e-02,  -1.58411345e-02,
        -3.73828664e-03,   5.80827097e-03,  -1.96042271e-02,
         1.21035205e-01,  -3.47884514e-02,  -1.09380222e-02,
         1.95666130e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.35851825e-03,
         3.02798572e-02,  -3.24751733e-02,  -5.79678166e-04,
         7.00694103e-03,   0.00000000e+00,  -7.49465597e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.23225548e-03,   0.00000000e+00,
        -2.60133758e-02,  -3.02591861e-02,   4.42964485e-02,
         1.77264732e-02,   3.95006061e-03,   0.00000000e+00,
         1.48991155e-02,   0.00000000e+00,  -4.84312998e-02,
         9.25785867e-03,  -5.23490643e-03,  -2.07995255e-03,
        -6.28102017e-03,   0.00000000e+00,  -2.24025870e-03,
         0.00000000e+00,   1.88147196e-03,  -2.26642586e-02,
        -4.17527960e-03,   8.68023478e-03,   2.61161484e-03,
        -7.17631663e-03,   0.00000000e+00,   1.82646072e-03,
         0.00000000e+00,  -1.32677949e-02,   5.11006487e-04,
        -2.84762957e-02,  -3.86070225e-03,   5.21283471e-03,
         3.90975465e-03,  -7.69395228e-03,   0.00000000e+00,
         1.87753816e-04,   0.00000000e+00,   4.96362712e-03,
         9.40032988e-03,  -3.80825218e-03,  -2.51722676e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.81794901e-03,   0.00000000e+00,
        -5.00888889e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.76820608e-02,
         4.19030861e-03,  -7.45621384e-03,  -4.82424603e-03,
         1.01985379e-02,   0.00000000e+00,   9.10320471e-03,
         0.00000000e+00,   1.45788384e-02,  -4.20942130e-03,
        -4.61940118e-03,  -5.10373271e-03,   0.00000000e+00,
        -1.02832601e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.57309519e-04,
         0.00000000e+00,  -5.01956224e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.33870421e-04,   0.00000000e+00,  -4.10154480e-03,
        -1.38555022e-02,   7.27923228e-03,  -3.55042204e-04,
         1.31474326e-03,   0.00000000e+00,   4.14609581e-03,
         0.00000000e+00,  -8.47671245e-03,   4.04547107e-03,
        -5.44341284e-03,  -5.56685098e-03,   0.00000000e+00,
        -1.01688107e-02,   0.00000000e+00,  -7.71928698e-03,
         1.35760380e-02,  -9.26244904e-03,   3.46471714e-06,
         7.49754161e-03,   0.00000000e+00,   2.20481964e-03,
         0.00000000e+00,   1.07332382e-02,  -6.16060690e-03,
         3.43474668e-03,   1.30974967e-02,   0.00000000e+00,
         2.25087203e-02,   0.00000000e+00,  -6.37730710e-03,
         1.79270030e-02,  -1.95202870e-03,  -1.74593684e-04,
        -2.18425511e-03,  -4.38071896e-03,   0.00000000e+00,
        -9.32342068e-03,   0.00000000e+00,  -1.43332028e-04,
        -2.69790804e-03,   4.98233024e-03,   3.21009396e-02,
         0.00000000e+00,   1.02990271e-03,   0.00000000e+00,
         2.58185823e-02,  -4.46191485e-02,  -3.16018212e-02,
        -2.74741782e-04,   3.70728903e-03,   3.10831615e-03,
        -1.68533847e-02,   0.00000000e+00,  -3.21487185e-04,
         0.00000000e+00,   2.21469283e-02,  -5.72252875e-03,
         1.04251730e-02,   1.05085325e-02,   0.00000000e+00,
        -1.98647746e-02,   0.00000000e+00,   6.87035111e-02,
        -5.78028931e-02,   8.25550226e-03,  -3.73613907e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.45116707e-01,  -5.68519110e-02,
        -1.38806665e-02,   9.03403312e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.29026590e-04,   0.00000000e+00,
        -1.86047643e-02,   3.78827628e-02,   1.31516790e-02,
        -4.73319656e-03,   0.00000000e+00,  -3.43516953e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.65027188e-02,
         0.00000000e+00,  -1.68434960e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.11533132e-03,   0.00000000e+00,
         4.45935674e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.69532088e-03,   0.00000000e+00,
        -7.90622035e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.16432245e-03,
         0.00000000e+00,  -3.83392917e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.55838717e-03,  -7.15520123e-03,  -6.14274219e-03,
         6.88430646e-03,   0.00000000e+00,  -3.28923950e-03,
         0.00000000e+00,   6.63486622e-05,  -8.82509656e-03,
         4.66558363e-03,   1.85125729e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.33236484e-03,   0.00000000e+00,
        -7.80252209e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.26159400e-02,
         0.00000000e+00,  -2.45679292e-02,   1.44074784e-02,
         4.93598966e-03,  -3.11699371e-03,   0.00000000e+00,
        -9.34491072e-04,   0.00000000e+00,  -1.76333999e-02,
         8.53962690e-03,  -5.30296420e-03,  -6.74467099e-03,
         0.00000000e+00,  -1.98331398e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.71869624e-03,   0.00000000e+00,
         2.27685321e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.46569204e-03,
         0.00000000e+00,  -4.82496329e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.56379659e-03,   0.00000000e+00,
         1.53535467e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.81758838e-03,
         0.00000000e+00,  -1.69060063e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.42308326e-02,
         0.00000000e+00,   1.45855971e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.42892947e-02,   0.00000000e+00,   4.39681238e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.46757727e-02,   0.00000000e+00,
         2.27082999e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.83368973e-02,
         0.00000000e+00,   1.14388865e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.86643152e-02,   4.90266644e-03,   7.76127716e-03,
         5.24483613e-02,  -3.42262379e-02,  -2.07440632e-03,
         3.02798572e-02,  -2.69853672e-02,  -5.67464061e-03,
         1.76285278e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.66391384e-02,
         7.65236624e-02,  -1.49859822e-02,  -4.25181665e-04,
         1.73785692e-02,   0.00000000e+00,  -2.30887853e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.32452451e-03,   0.00000000e+00,
        -1.01021366e-04,   1.81969754e-02,  -1.91385460e-02,
         1.03384793e-02,   8.24159178e-03,   0.00000000e+00,
         1.45078203e-02,   0.00000000e+00,   1.87599453e-02,
        -7.81358132e-03,   1.85208974e-03,  -4.47464269e-03,
        -1.19370659e-03,   0.00000000e+00,  -3.93910360e-03,
         0.00000000e+00,   1.57765923e-03,   7.11824076e-03,
        -4.79374714e-03,   4.31327185e-03,  -4.04712480e-03,
         8.01388768e-05,   0.00000000e+00,   6.92886712e-03,
         0.00000000e+00,   7.65687634e-03,   4.69991159e-03,
         1.68834824e-02,  -5.99145390e-03,   1.25853024e-02,
         8.38841104e-03,   2.93366040e-03,   0.00000000e+00,
        -2.64255311e-03,   0.00000000e+00,  -5.59626201e-03,
         1.69481242e-04,   9.48221387e-04,  -6.53021722e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.53977684e-03,   0.00000000e+00,
        -5.40621845e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.25030411e-04,
         2.24500097e-03,  -4.39125432e-03,  -3.19873915e-03,
         7.86414932e-03,   0.00000000e+00,   6.16948625e-03,
         0.00000000e+00,   6.07664652e-04,  -2.38028753e-03,
        -1.35924704e-03,  -6.19022173e-03,   0.00000000e+00,
         5.76285671e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.45362129e-03,
         0.00000000e+00,   3.25356414e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.22913023e-03,   0.00000000e+00,   1.21883878e-02,
        -1.89863893e-02,   7.59231502e-03,  -2.23314873e-04,
        -3.15755765e-03,   0.00000000e+00,  -5.60249079e-03,
         0.00000000e+00,  -1.00411155e-02,   6.93892190e-03,
        -3.97388623e-03,   3.63748130e-03,   0.00000000e+00,
        -1.46346014e-02,   0.00000000e+00,   2.64281326e-03,
        -4.89012696e-03,   2.55770392e-03,   4.20536441e-03,
         5.59662849e-03,   0.00000000e+00,  -1.00843436e-03,
         0.00000000e+00,  -9.40100382e-03,   5.39574491e-03,
         3.46315096e-04,  -4.83246946e-03,   0.00000000e+00,
        -4.68304297e-03,   0.00000000e+00,  -1.52211378e-02,
         4.24078845e-03,  -1.70316628e-03,   3.05312644e-03,
        -1.54024730e-03,  -6.46724597e-03,   0.00000000e+00,
        -1.72276019e-02,   0.00000000e+00,  -3.63267464e-03,
         5.24334835e-03,   6.69858105e-03,  -8.20116422e-03,
         0.00000000e+00,  -6.42760142e-03,   0.00000000e+00,
         3.26998113e-02,   1.19363595e-02,   1.28023244e-02,
        -5.33170222e-03,  -2.28752694e-04,  -8.43466411e-03,
        -2.93241367e-03,   0.00000000e+00,  -1.35975712e-02,
         0.00000000e+00,  -1.27602397e-02,   3.94920081e-03,
         5.97415693e-03,   2.55748552e-02,   0.00000000e+00,
        -1.08209405e-02,   0.00000000e+00,   6.63286139e-02,
         2.05767061e-02,   1.06236461e-02,   2.39059242e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.86047643e-02,   2.09886005e-02,
         7.89545074e-03,  -4.26544542e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.67310969e-04,   0.00000000e+00,
         2.55647671e-02,   3.90863181e-02,   5.43762331e-03,
         8.58765713e-03,   0.00000000e+00,  -1.20641360e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.08356345e-03,
         0.00000000e+00,  -1.55068490e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.79937280e-03,   0.00000000e+00,
        -4.14159667e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.34857049e-03,   0.00000000e+00,
        -1.12364432e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.31949988e-03,
         0.00000000e+00,  -3.58328577e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         9.76552436e-04,   1.45821907e-02,   3.46805073e-03,
         2.40489940e-03,   0.00000000e+00,  -4.72826308e-03,
         0.00000000e+00,  -1.02931977e-02,  -9.03439511e-03,
         1.45818338e-04,  -4.31452873e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.45238374e-03,   0.00000000e+00,
         5.83171334e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.14432678e-03,
         0.00000000e+00,   1.14886594e-02,  -3.35819481e-03,
         1.44276434e-03,  -1.68954792e-03,   0.00000000e+00,
         9.34715990e-04,   0.00000000e+00,   1.21442389e-04,
        -2.74706048e-03,   1.58431140e-03,  -4.94673634e-04,
         0.00000000e+00,   2.28367264e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.73890621e-04,   0.00000000e+00,
         2.28429887e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.18307112e-03,
         0.00000000e+00,   2.01091415e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.75843410e-04,   0.00000000e+00,
        -4.64908536e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.75377343e-03,
         0.00000000e+00,   7.01222434e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.32804686e-03,
         0.00000000e+00,  -2.63736962e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.59159308e-02,   0.00000000e+00,  -1.58763764e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.08881578e-03,   0.00000000e+00,
        -9.07869750e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.79682515e-02,
         0.00000000e+00,  -1.35709903e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.34019893e-02,  -4.07586061e-02,  -3.27177691e-02,
         1.74813289e-02,  -3.08477181e-03,  -1.44134146e-03,
        -3.02591861e-02,   7.29458364e-03,   8.20486281e-03,
         4.56124344e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.08060339e-02,
         1.81969754e-02,  -6.57686907e-03,   4.98720444e-02,
         3.53657885e-02,   0.00000000e+00,   2.13114367e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.83915496e-02,   0.00000000e+00,
        -4.29225630e-02,   7.60643872e-02,   1.53341802e-02,
         2.92915847e-02,  -3.98588977e-02,   0.00000000e+00,
         2.06458574e-02,   0.00000000e+00,  -4.25004991e-03,
        -1.62297133e-02,   1.01438568e-02,  -1.95683843e-02,
         7.81328762e-03,   0.00000000e+00,   3.75748623e-03,
         0.00000000e+00,  -7.89618597e-03,  -1.02616312e-02,
         9.61829654e-03,   5.87777944e-03,  -8.13977196e-03,
        -1.20436062e-02,   0.00000000e+00,   5.22864254e-03,
         0.00000000e+00,  -1.96333657e-03,  -1.10266148e-02,
        -1.29979223e-02,  -2.26743908e-03,  -6.99451296e-03,
         2.85746109e-03,   2.96974687e-03,   0.00000000e+00,
        -2.78341674e-02,   0.00000000e+00,   1.59529665e-02,
         7.21599332e-03,   1.35398769e-02,  -3.24716333e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.66078631e-03,   0.00000000e+00,
        -3.52044617e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.70474733e-02,
        -3.45225109e-03,  -6.67819932e-03,  -1.96326162e-02,
         1.65371623e-02,   0.00000000e+00,   7.89634886e-03,
         0.00000000e+00,   2.41810486e-02,  -1.42702310e-02,
        -7.13665090e-03,  -3.84687347e-03,   0.00000000e+00,
        -3.73895314e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.51338719e-02,
         0.00000000e+00,   7.77825082e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.91479165e-02,   0.00000000e+00,   6.74829453e-02,
        -6.18655784e-04,  -1.35753550e-03,  -2.22172455e-02,
        -2.65354920e-02,   0.00000000e+00,  -2.67468808e-02,
         0.00000000e+00,  -7.09180540e-04,  -1.66946039e-03,
         7.12151835e-03,   2.88323906e-02,   0.00000000e+00,
        -1.69887667e-02,   0.00000000e+00,   6.15190027e-02,
        -1.56985112e-02,   7.71000971e-03,  -1.26257666e-02,
         2.37046094e-02,   0.00000000e+00,  -1.11538014e-02,
         0.00000000e+00,  -4.63296147e-02,   1.20088294e-02,
        -6.84784741e-03,   3.53879074e-03,   0.00000000e+00,
         1.30644167e-02,   0.00000000e+00,  -8.46895294e-04,
         3.88482533e-02,  -9.09244926e-03,   2.99048103e-02,
         2.27122621e-03,   1.82252251e-03,   0.00000000e+00,
        -7.15808877e-03,   0.00000000e+00,  -3.45926690e-02,
        -9.76212814e-04,  -7.90649683e-03,   1.21147322e-02,
         0.00000000e+00,   9.02214999e-03,   0.00000000e+00,
         6.58332219e-03,   4.87146857e-03,  -3.25827513e-02,
        -3.90689823e-02,   7.87253799e-03,  -1.25710664e-02,
         1.65649972e-02,   0.00000000e+00,  -9.18508361e-03,
         0.00000000e+00,  -2.78930947e-02,   1.31356974e-02,
        -6.43023563e-03,  -4.85529798e-03,   0.00000000e+00,
        -1.03345266e-02,   0.00000000e+00,  -1.03797498e-03,
         4.49481231e-02,   4.81253144e-02,   7.56864870e-02,
        -3.57409075e-02,   4.67374140e-03,  -2.19166242e-02,
        -1.39062426e-03,   8.77301453e-03,  -1.34846256e-02,
         9.25785867e-03,  -1.83252570e-03,   6.84575910e-04,
        -2.97951608e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.50321454e-02,
        -7.81358132e-03,  -2.66446665e-03,  -1.28868386e-02,
        -7.06835001e-03,   0.00000000e+00,  -2.04272464e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.67779243e-03,   0.00000000e+00,
        -1.48303603e-02,  -1.62297133e-02,   2.66544650e-03,
        -1.05686706e-02,   5.86852135e-03,   0.00000000e+00,
         1.33131751e-03,   0.00000000e+00,  -2.40031647e-02,
         9.32885670e-03,   1.11859379e-02,  -2.28203508e-03,
         6.46945760e-04,   0.00000000e+00,   1.92327579e-03,
         0.00000000e+00,   5.72883640e-03,  -3.71632900e-03,
         1.16780125e-03,   8.29866739e-03,  -1.58715872e-03,
         4.27112399e-03,   0.00000000e+00,   2.10749192e-03,
         0.00000000e+00,  -3.60036244e-03,  -1.42789490e-03,
        -9.44170002e-04,  -1.00189388e-03,  -1.37261834e-03,
         5.74308875e-03,   5.42177932e-03,   0.00000000e+00,
        -7.37190246e-05,   0.00000000e+00,   5.26428991e-03,
         1.58272133e-03,   1.55263331e-03,  -1.17863772e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.15409677e-03,   0.00000000e+00,
        -6.82373132e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.55059397e-02,
        -7.32978047e-04,   7.68839523e-03,  -3.50228473e-03,
        -1.63501269e-03,   0.00000000e+00,  -1.76966757e-03,
         0.00000000e+00,   1.34562445e-03,  -6.51527558e-03,
        -1.38245517e-03,  -3.39143528e-03,   0.00000000e+00,
        -1.11251710e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.77400486e-02,
         0.00000000e+00,  -6.41120319e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.73402764e-03,   0.00000000e+00,  -3.00770330e-02,
         3.06812486e-04,   4.89115429e-05,   7.45055727e-03,
         9.50915820e-03,   0.00000000e+00,   1.39898904e-02,
         0.00000000e+00,  -6.59607976e-04,  -6.90023337e-04,
        -4.32423534e-03,  -6.86972429e-03,   0.00000000e+00,
         4.85632457e-03,   0.00000000e+00,  -2.60483051e-02,
         4.91234026e-03,   1.15109961e-03,   6.73167807e-03,
        -1.08886353e-02,   0.00000000e+00,   5.64399370e-03,
         0.00000000e+00,   1.14952391e-02,  -3.35975304e-03,
         2.19366355e-03,   2.95541308e-03,   0.00000000e+00,
        -1.94654840e-03,   0.00000000e+00,   6.64739000e-04,
        -2.47675059e-02,   9.15304294e-03,   3.52971011e-03,
        -3.31025123e-03,   1.80016307e-03,   0.00000000e+00,
         3.46507597e-03,   0.00000000e+00,   3.19484775e-03,
        -9.26522575e-03,  -3.17280649e-03,   4.85026398e-03,
         0.00000000e+00,  -8.80146299e-03,   0.00000000e+00,
        -2.97067160e-03,  -3.23608984e-03,  -1.90906429e-02,
         1.39076516e-02,  -7.48315936e-03,   2.95468285e-03,
        -4.75647167e-03,   0.00000000e+00,   3.82284458e-03,
         0.00000000e+00,   1.02328584e-02,  -1.80596580e-03,
         3.75068680e-03,  -1.02873843e-03,   0.00000000e+00,
         5.36026224e-03,   0.00000000e+00,   8.08447249e-04,
        -1.12862195e-02,  -8.52038558e-03,  -3.36677538e-02,
         9.24466487e-03,  -8.26143802e-03,  -6.78523820e-03,
        -1.08324789e-05,   4.11265730e-03,   1.00297861e-02,
        -4.17527960e-03,   2.76934552e-03,   1.29049254e-03,
         3.49646787e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.15455311e-02,
        -4.79374714e-03,   1.31673019e-03,   3.77406589e-03,
         4.81041872e-03,   0.00000000e+00,   7.62904870e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.74339468e-03,   0.00000000e+00,
        -1.21359523e-02,   9.61829654e-03,   5.87006272e-03,
         1.35422837e-04,  -9.70446459e-03,   0.00000000e+00,
         8.10555097e-03,   0.00000000e+00,  -3.17395440e-03,
         1.16780125e-03,   9.32425546e-03,  -4.99169563e-03,
         3.78647689e-03,   0.00000000e+00,   1.45638999e-03,
         0.00000000e+00,  -4.51906077e-04,   2.72437902e-03,
         7.27349076e-03,   1.40878997e-02,  -9.63855134e-03,
        -7.27733065e-04,   0.00000000e+00,   5.25074221e-03,
         0.00000000e+00,   6.79895535e-04,   4.99548410e-03,
         1.97486357e-02,   1.94795169e-03,  -2.94162000e-03,
        -3.74450129e-04,  -5.79896944e-04,   0.00000000e+00,
        -4.96262130e-03,   0.00000000e+00,   5.26845807e-03,
         2.84222730e-03,   3.57648170e-03,  -6.87784800e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.55913292e-03,   0.00000000e+00,
        -7.32489254e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.31736322e-02,
        -6.59995753e-04,   2.62139971e-03,  -4.92439028e-03,
         2.46836320e-03,   0.00000000e+00,   3.98535044e-04,
         0.00000000e+00,   3.12201029e-03,  -4.04002472e-03,
        -2.85414756e-04,  -4.77258704e-03,   0.00000000e+00,
        -5.40625806e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.06204479e-03,
         0.00000000e+00,   1.32144682e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.35953184e-03,   0.00000000e+00,   9.85383500e-03,
         5.68715916e-03,  -3.11219853e-03,  -3.77743030e-03,
        -6.02988903e-03,   0.00000000e+00,  -5.48434561e-03,
         0.00000000e+00,   2.11645022e-04,  -1.41448832e-03,
        -1.65644186e-03,   3.79438081e-03,   0.00000000e+00,
        -3.96043428e-04,   0.00000000e+00,   1.10795509e-02,
        -2.50043168e-03,   7.11104297e-04,  -3.39664758e-03,
         4.59206378e-03,   0.00000000e+00,  -1.18480853e-03,
         0.00000000e+00,  -7.55559379e-03,   1.75961963e-03,
         3.34206437e-04,   4.66317443e-03,   0.00000000e+00,
         2.14414260e-03,   0.00000000e+00,   2.24047848e-03,
         8.70497748e-03,  -1.66277157e-03,   6.59229363e-03,
        -1.36633538e-03,   2.99053935e-03,   0.00000000e+00,
         3.07393309e-03,   0.00000000e+00,  -5.46540649e-03,
        -4.98486765e-03,  -2.66517691e-03,   6.89940326e-03,
         0.00000000e+00,  -3.94597172e-03,   0.00000000e+00,
        -2.40644435e-03,  -1.21239261e-03,  -1.06605019e-02,
        -7.94271973e-03,   1.95444676e-03,   1.12612247e-03,
         5.77277035e-03,   0.00000000e+00,   3.42442929e-03,
         0.00000000e+00,  -4.19344154e-03,   3.42251048e-03,
         3.24540323e-04,  -3.92651969e-03,   0.00000000e+00,
         6.80340617e-04,   0.00000000e+00,  -3.80621042e-03,
         3.73769314e-03,   8.37648948e-03,   9.56879434e-03,
         6.52785529e-03,  -1.95495817e-03,   4.08376856e-03,
        -3.86327352e-03,   3.20825820e-03,   7.97539410e-03,
        -3.86070225e-03,   7.13227454e-04,   1.98697806e-04,
         4.63607617e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.11355164e-03,
        -5.99145390e-03,   6.66608318e-03,   6.23830154e-03,
         2.75496056e-03,   0.00000000e+00,   4.40070652e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.22490145e-03,   0.00000000e+00,
         1.24496541e-03,  -2.26743908e-03,  -4.53546092e-03,
        -1.86898292e-04,  -1.27213298e-03,   0.00000000e+00,
        -1.17893934e-03,   0.00000000e+00,   8.27122718e-03,
        -1.00189388e-03,  -3.13517760e-03,   4.88433180e-03,
         2.04328575e-03,   0.00000000e+00,  -2.79213061e-03,
         0.00000000e+00,  -5.97290897e-04,  -2.92453455e-03,
         1.94795169e-03,  -3.58859813e-03,   1.12452216e-03,
        -2.15029406e-03,   0.00000000e+00,  -2.40443063e-03,
         0.00000000e+00,   1.79829927e-03,   2.26984566e-03,
        -3.42317273e-03,   1.11433238e-02,   9.52156325e-03,
         1.58389848e-04,  -1.61013904e-03,   0.00000000e+00,
        -4.05119275e-03,   0.00000000e+00,  -4.48904380e-03,
         1.14290611e-03,  -2.66730689e-03,   2.56647352e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.60975251e-03,   0.00000000e+00,
         1.80262843e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.71145740e-03,
        -1.10363102e-03,   1.60575315e-04,  -2.38806323e-03,
        -1.88045340e-03,   0.00000000e+00,  -5.16427217e-04,
         0.00000000e+00,  -2.33869788e-03,   3.95629630e-04,
        -2.17656402e-03,  -2.00092043e-03,   0.00000000e+00,
         8.64406511e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.45994498e-03,
         0.00000000e+00,   2.08079330e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.69709706e-04,   0.00000000e+00,   7.04337036e-03,
         1.16721362e-02,  -7.19197757e-03,  -4.77525733e-03,
        -4.69832376e-03,   0.00000000e+00,  -2.87747062e-03,
         0.00000000e+00,   2.59551475e-03,  -6.81905599e-04,
         1.38085643e-03,   1.39391482e-03,   0.00000000e+00,
         1.20984916e-03,   0.00000000e+00,   8.41974422e-03,
        -2.60598999e-04,  -3.79941928e-03,  -2.02436888e-03,
         5.40875787e-03,   0.00000000e+00,  -3.82780452e-03,
         0.00000000e+00,  -1.43417470e-03,   1.65350102e-03,
         2.11397126e-03,   1.82913720e-03,   0.00000000e+00,
        -1.82281889e-03,   0.00000000e+00,   3.79289480e-03,
         5.50490214e-03,  -5.45964253e-03,  -5.18972850e-03,
         8.30721205e-03,   8.79502625e-03,   0.00000000e+00,
        -3.65069139e-03,   0.00000000e+00,   8.71972904e-03,
         3.06692401e-03,   4.57884457e-03,  -3.95021190e-03,
         0.00000000e+00,  -1.94868265e-03,   0.00000000e+00,
        -2.04006535e-03,   4.72256307e-04,   2.71297326e-03,
        -3.33771399e-03,   4.25308491e-03,   4.84448222e-03,
         6.52842538e-03,   0.00000000e+00,   1.24074467e-02,
         0.00000000e+00,  -3.63893328e-03,  -1.55185243e-04,
        -3.13352871e-03,  -1.30260549e-03,   0.00000000e+00,
         1.50154465e-03,   0.00000000e+00,  -4.96489340e-03,
        -2.24766583e-03,   1.86213960e-03,   5.69259548e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.55838717e-03,  -3.32498617e-03,
        -2.95992678e-03,   3.41843500e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.59472158e-03,   0.00000000e+00,
         9.76552436e-04,   1.08205946e-02,   2.01959138e-03,
         1.94199540e-03,   0.00000000e+00,  -3.27319228e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.41201106e-04,
         0.00000000e+00,  -5.26842396e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.98512707e-03,   0.00000000e+00,
        -4.25288922e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.96834330e-04,   0.00000000e+00,
        -1.26759212e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.76380576e-04,
         0.00000000e+00,  -1.49616699e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.06103399e-02,   1.37967723e-02,   2.74842708e-03,
         1.97622147e-03,   0.00000000e+00,  -3.69559555e-03,
         0.00000000e+00,  -6.42411841e-03,  -1.00893575e-03,
        -4.42650768e-03,  -1.96443492e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.58260295e-03,   0.00000000e+00,
         1.64533011e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.46529231e-04,
         0.00000000e+00,  -9.87908933e-03,   7.21164578e-03,
         1.10145076e-03,   3.51911160e-04,   0.00000000e+00,
        -1.08685261e-03,   0.00000000e+00,  -3.57897142e-03,
         5.10389163e-04,  -1.02225333e-03,  -2.69783638e-04,
         0.00000000e+00,  -2.37230606e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.81122477e-04,   0.00000000e+00,
         1.38840172e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.70477897e-03,
         0.00000000e+00,  -2.59769532e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.26962010e-04,   0.00000000e+00,
        -4.31684481e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.51637152e-04,
         0.00000000e+00,  -4.40006256e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.00580083e-03,
         0.00000000e+00,  -1.46088387e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.00592269e-02,   0.00000000e+00,   4.48394120e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.08620978e-02,   0.00000000e+00,
         7.65258701e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.72182272e-04,
         0.00000000e+00,   5.08153331e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.67247148e-02,  -5.38804567e-03,   1.70213464e-02,
        -2.12120444e-04,   6.16120907e-03,   1.82197860e-02,
         4.19030861e-03,  -8.57539250e-03,  -8.51417112e-04,
         2.79815742e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.02578040e-02,
         2.24500097e-03,  -6.72001067e-04,   4.67928704e-03,
         6.78074806e-03,   0.00000000e+00,   2.22680123e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.64505773e-03,   0.00000000e+00,
         1.40878135e-02,  -3.45225109e-03,  -6.92394268e-03,
        -1.11566475e-03,  -1.37863526e-03,   0.00000000e+00,
         2.96498271e-03,   0.00000000e+00,   2.89098717e-02,
        -7.32978047e-04,   2.44366936e-03,  -4.54214307e-04,
         8.90671776e-04,   0.00000000e+00,  -2.43059363e-03,
         0.00000000e+00,  -3.67928162e-03,   6.72542029e-03,
        -6.59995753e-04,   5.46144386e-04,  -5.30419130e-04,
        -1.32776199e-03,   0.00000000e+00,  -3.16088262e-03,
         0.00000000e+00,   2.33114775e-03,   1.54027396e-03,
         1.03928495e-02,  -1.10363102e-03,   4.34456194e-04,
        -8.84559356e-03,  -7.13307449e-03,   0.00000000e+00,
         1.98205661e-03,   0.00000000e+00,  -4.62043341e-03,
        -3.02711451e-03,  -3.57394072e-03,   1.41056745e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.54879087e-03,   0.00000000e+00,
         9.37907842e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.70333006e-02,
         1.30471306e-02,   7.16654856e-03,   9.67107890e-03,
         5.61037393e-03,   0.00000000e+00,  -1.48950015e-03,
         0.00000000e+00,  -1.29056650e-02,   5.69772386e-03,
         5.65175611e-04,   4.22865073e-03,   0.00000000e+00,
         1.76849953e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.07834710e-02,
         0.00000000e+00,   7.45227741e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.51976487e-03,   0.00000000e+00,   2.65471480e-02,
        -4.61212689e-03,   3.53291985e-03,  -5.94131773e-03,
        -1.11260911e-02,   0.00000000e+00,  -1.69483991e-02,
         0.00000000e+00,  -3.49853581e-03,   2.28649208e-03,
         3.42264818e-03,   4.86332776e-03,   0.00000000e+00,
        -1.98520659e-03,   0.00000000e+00,   2.35788130e-02,
         3.08219980e-03,  -1.06118820e-02,  -1.39071121e-02,
         1.46380253e-02,   0.00000000e+00,  -3.40029120e-03,
         0.00000000e+00,  -6.38791760e-03,   7.05212192e-04,
        -1.80934734e-03,  -2.24938469e-03,   0.00000000e+00,
         5.81991413e-04,   0.00000000e+00,  -2.45629584e-03,
         2.54555147e-02,  -1.29061580e-02,  -1.05009964e-03,
        -8.61429718e-03,  -2.95048806e-03,   0.00000000e+00,
         3.91894146e-04,   0.00000000e+00,   1.14296481e-02,
        -3.88393437e-03,  -1.40022578e-03,  -2.42169636e-03,
         0.00000000e+00,  -9.50960655e-03,   0.00000000e+00,
         1.49132207e-03,   1.26942688e-03,   1.86482251e-02,
        -1.25543003e-02,   9.78879036e-03,   2.93514396e-03,
        -8.16989357e-03,   0.00000000e+00,  -6.23457533e-03,
         0.00000000e+00,  -6.94880858e-03,   3.50881813e-03,
         2.63469654e-04,   1.69242941e-03,   0.00000000e+00,
         3.88652667e-04,   0.00000000e+00,   1.44360017e-03,
        -5.93908479e-03,   4.97896891e-03,   2.41739367e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.45679292e-02,   1.41819024e-02,
         4.29767901e-03,  -2.48366585e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.22015842e-04,   0.00000000e+00,
         1.14886594e-02,   2.58638769e-03,   1.72751550e-03,
        -8.14542470e-05,   0.00000000e+00,  -8.65544152e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.03583057e-02,
         0.00000000e+00,  -2.08820870e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.80703085e-03,   0.00000000e+00,
        -4.71451438e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.03725514e-03,   0.00000000e+00,
        -1.07870482e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.87554908e-03,
         0.00000000e+00,  -2.93602783e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.87908933e-03,   6.19779945e-03,   7.84149101e-04,
         5.80206208e-04,   0.00000000e+00,  -1.18505247e-03,
         0.00000000e+00,  -3.51445487e-03,  -1.18588235e-03,
        -9.86582601e-06,   6.67287374e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.76588534e-03,   0.00000000e+00,
         6.17013657e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.17555556e-03,
         0.00000000e+00,   3.90822080e-02,  -1.66624914e-02,
        -4.60071434e-03,   2.91878186e-03,   0.00000000e+00,
         1.33804300e-04,   0.00000000e+00,   7.68016297e-03,
        -2.71819642e-03,   1.10277357e-03,   9.31448535e-04,
         0.00000000e+00,   3.43043676e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.03565115e-03,   0.00000000e+00,
         9.10975394e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.89345336e-04,
         0.00000000e+00,   9.00757494e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.46706025e-03,   0.00000000e+00,
         2.75330381e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.49398124e-03,
         0.00000000e+00,   1.17992948e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.97676491e-02,
         0.00000000e+00,  -4.72974297e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.27120216e-03,   0.00000000e+00,  -1.03400612e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.19519856e-02,   0.00000000e+00,
        -1.06218096e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.75719824e-03,
         0.00000000e+00,  -1.80358311e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.43133808e-03,  -1.64093018e-03,   4.86114485e-03,
        -7.86888058e-03,   9.69899959e-03,   1.10955619e-02,
        -1.38555022e-02,   7.59501989e-03,   1.25518749e-03,
         6.51058867e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.25067650e-03,
        -1.89863893e-02,   4.59517227e-03,   2.13402707e-03,
        -8.02568835e-04,   0.00000000e+00,   7.38216226e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.60192712e-04,   0.00000000e+00,
         7.68715002e-03,  -6.18655784e-04,  -1.48118028e-04,
        -5.06168079e-03,  -6.65905731e-03,   0.00000000e+00,
        -4.67966330e-03,   0.00000000e+00,   7.22808421e-03,
         3.06812486e-04,  -8.09120166e-04,   5.57605866e-03,
         2.99255245e-03,   0.00000000e+00,   9.66544951e-04,
         0.00000000e+00,  -3.85044763e-03,  -1.12621159e-03,
         5.68715916e-03,  -2.92879327e-03,   1.51035550e-03,
        -2.85273670e-03,   0.00000000e+00,  -4.06993851e-03,
         0.00000000e+00,   9.53333194e-05,   1.15989035e-03,
        -3.20372037e-03,   1.16721362e-02,  -5.78531919e-03,
        -4.30195816e-03,  -4.37662542e-03,   0.00000000e+00,
         8.33147428e-04,   0.00000000e+00,   7.48070411e-04,
         6.56083846e-04,  -9.60979845e-04,   6.99683612e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.11503324e-03,   0.00000000e+00,
         3.72589067e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.54875652e-03,
        -4.61212689e-03,   2.24472138e-03,  -2.05767786e-03,
        -4.70242718e-03,   0.00000000e+00,  -5.35724963e-03,
         0.00000000e+00,  -4.73117232e-03,   2.36414041e-03,
         2.07077946e-05,  -1.11498627e-03,   0.00000000e+00,
         8.68711908e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.47834513e-03,
         0.00000000e+00,   2.47303429e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.44964457e-04,   0.00000000e+00,   8.02064964e-03,
         3.58438113e-02,  -1.54621665e-02,  -7.57813312e-03,
        -9.44528206e-04,   0.00000000e+00,  -6.15372673e-03,
         0.00000000e+00,   7.15488537e-03,  -1.46739750e-03,
         2.73826153e-03,   2.01875993e-03,   0.00000000e+00,
         2.46702452e-03,   0.00000000e+00,   8.60132107e-03,
         2.31515496e-04,  -2.07713335e-03,  -5.02360006e-03,
         4.96214517e-04,   0.00000000e+00,  -5.94862089e-03,
         0.00000000e+00,  -2.81350149e-03,   7.40428509e-04,
         7.65569989e-04,   3.16257579e-03,   0.00000000e+00,
        -3.06863894e-03,   0.00000000e+00,  -5.95205203e-04,
         8.16010301e-03,  -9.23056172e-04,  -2.60789212e-03,
         6.51756759e-03,   1.05888752e-02,   0.00000000e+00,
         1.40208368e-02,   0.00000000e+00,   2.49930592e-03,
         2.96757712e-04,  -1.90534567e-03,   1.41667681e-03,
         0.00000000e+00,  -1.23840850e-03,   0.00000000e+00,
        -9.51912333e-03,   2.29327563e-04,   4.63264607e-03,
        -3.36324294e-03,   2.91070043e-03,   1.90670412e-02,
         2.46857378e-02,   0.00000000e+00,   2.72860039e-02,
         0.00000000e+00,  -8.16637952e-04,  -3.98814196e-04,
        -3.73716669e-03,  -7.75316892e-03,   0.00000000e+00,
         3.20834616e-03,   0.00000000e+00,  -1.54775405e-02,
        -6.13516018e-04,   5.20777776e-04,   7.67821837e-03,
         1.27353331e-02,  -6.59382439e-03,   1.06664819e-02,
        -9.79017224e-03,   8.17019405e-03,   1.43607870e-02,
         1.35760380e-02,  -1.14682051e-02,  -2.66414075e-03,
         1.82361328e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.00236179e-02,
        -4.89012696e-03,   4.39187486e-03,   7.22812134e-03,
         4.50237314e-03,   0.00000000e+00,   1.04625536e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.33302140e-03,   0.00000000e+00,
         4.43769603e-03,  -1.56985112e-02,   5.92528091e-03,
         2.90955872e-04,   8.60664349e-04,   0.00000000e+00,
        -1.44715030e-04,   0.00000000e+00,  -1.55124935e-03,
         4.91234026e-03,   9.63863950e-04,  -1.93378171e-04,
        -1.42878770e-03,   0.00000000e+00,   1.28774759e-03,
         0.00000000e+00,   1.98142350e-03,   4.45742753e-03,
        -2.50043168e-03,   1.56811553e-03,  -1.74902646e-03,
         8.83962238e-04,   0.00000000e+00,  -3.81355496e-04,
         0.00000000e+00,  -9.43168036e-04,   9.22757859e-05,
         6.92792047e-03,  -2.60598999e-04,  -3.00117992e-03,
         1.56307925e-03,   3.98269886e-03,   0.00000000e+00,
        -7.21477751e-03,   0.00000000e+00,   1.50093387e-03,
         1.28563656e-03,   4.67756919e-03,   5.22084560e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.64589728e-04,   0.00000000e+00,
        -9.05328419e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.14480124e-03,
         3.08219980e-03,  -6.32308189e-03,  -9.65168016e-03,
         7.94187448e-03,   0.00000000e+00,   4.03173305e-04,
         0.00000000e+00,   2.28481407e-04,  -3.12700649e-03,
        -1.76293327e-03,  -2.48980676e-03,   0.00000000e+00,
         4.03908967e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.11715464e-03,
         0.00000000e+00,   3.10433805e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.02511057e-03,   0.00000000e+00,   1.42220468e-02,
         2.31515496e-04,  -1.25097800e-03,  -5.46756543e-03,
        -4.22688616e-03,   0.00000000e+00,  -6.60988322e-03,
         0.00000000e+00,  -1.68772337e-03,   5.12345073e-05,
         1.49683889e-03,   5.20024555e-03,   0.00000000e+00,
        -3.01399119e-03,   0.00000000e+00,   1.25802163e-02,
         3.71348433e-02,  -1.64797239e-02,  -1.00954449e-02,
         1.19939992e-02,   0.00000000e+00,  -3.78807528e-03,
         0.00000000e+00,  -8.05112491e-03,   1.29002973e-03,
         8.59301241e-05,  -5.02041080e-04,   0.00000000e+00,
         1.89515768e-03,   0.00000000e+00,   6.68262905e-04,
         1.38154300e-02,   3.95264114e-03,   1.13216816e-02,
         1.03918029e-02,  -1.40169478e-02,   0.00000000e+00,
         3.87425539e-03,   0.00000000e+00,   3.87694780e-03,
        -1.50391346e-03,  -1.02185150e-03,  -1.49379975e-03,
         0.00000000e+00,  -3.05287850e-03,   0.00000000e+00,
         2.81241225e-04,  -6.34038526e-03,   5.06455207e-03,
         4.04191669e-03,   5.22140277e-03,   1.62114682e-02,
        -2.32542513e-02,   0.00000000e+00,   8.79316631e-03,
         0.00000000e+00,   2.25788077e-02,  -5.02964911e-03,
         2.47140616e-03,  -9.57617622e-04,   0.00000000e+00,
        -5.20336606e-03,   0.00000000e+00,  -1.01992828e-03,
        -2.27392180e-02,   2.94553391e-03,   8.90467736e-03,
        -6.90189800e-02,   1.28442664e-02,  -4.90744660e-02,
        -3.93431791e-04,  -8.20210438e-03,  -5.28538993e-02,
        -1.95202870e-03,   3.95905103e-03,  -8.54573231e-04,
        -6.48632197e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.42613501e-02,
        -1.70316628e-03,   2.47847630e-03,  -1.43895644e-02,
        -1.02835934e-02,   0.00000000e+00,  -6.37937657e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.25327510e-02,   0.00000000e+00,
        -4.08748526e-02,  -9.09244926e-03,   9.93226688e-03,
        -9.61300561e-03,   1.07303357e-02,   0.00000000e+00,
        -5.71515710e-03,   0.00000000e+00,  -6.34503708e-02,
         9.15304294e-03,   1.14807856e-02,  -1.03441208e-02,
        -9.78744906e-04,   0.00000000e+00,   9.94158069e-03,
         0.00000000e+00,   1.45548340e-02,  -1.64059861e-02,
        -1.66277157e-03,   7.43747819e-03,  -7.37500535e-03,
         6.89478773e-03,   0.00000000e+00,   1.25265433e-02,
         0.00000000e+00,  -6.18339336e-03,  -9.21221398e-03,
        -1.13462184e-02,  -5.45964253e-03,  -1.72556502e-03,
         2.27952699e-02,   2.45353296e-02,   0.00000000e+00,
        -1.16573807e-02,   0.00000000e+00,   1.91916554e-02,
         3.95772428e-03,   9.60986732e-03,  -4.63099471e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.26993470e-02,   0.00000000e+00,
        -3.57487209e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.35854075e-02,
        -1.29061580e-02,   9.60024824e-03,  -1.96939004e-02,
        -2.34356197e-03,   0.00000000e+00,  -9.68403364e-04,
         0.00000000e+00,   2.60285107e-02,  -1.87120618e-02,
        -6.04722957e-03,   7.50375979e-05,   0.00000000e+00,
        -4.87618348e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.29686803e-02,
         0.00000000e+00,  -2.17793208e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.34168165e-03,   0.00000000e+00,  -6.89476824e-02,
        -9.23056172e-04,  -9.66245891e-04,   1.75857958e-02,
         2.89914947e-02,   0.00000000e+00,   4.23233340e-02,
         0.00000000e+00,   2.22809424e-03,  -3.10392021e-03,
        -1.06647936e-02,  -9.31884753e-03,   0.00000000e+00,
         5.14855723e-03,   0.00000000e+00,  -6.57235461e-02,
         3.95264114e-03,   1.69957893e-02,   2.82639239e-02,
        -3.71837901e-02,   0.00000000e+00,   1.21083689e-02,
         0.00000000e+00,   2.08461415e-02,  -4.72976272e-03,
         3.86108820e-03,   8.90520656e-04,   0.00000000e+00,
        -4.52582179e-04,   0.00000000e+00,  -1.44060371e-03,
        -6.87350109e-02,   3.51701180e-02,   2.11821423e-02,
         1.57997614e-03,   5.58704283e-03,   0.00000000e+00,
         1.41120766e-05,   0.00000000e+00,  -1.10261206e-02,
        -1.09958841e-02,  -7.19392103e-03,  -8.37495214e-04,
         0.00000000e+00,   5.54878288e-03,   0.00000000e+00,
        -8.52683419e-04,  -2.86528041e-03,  -5.01594834e-02,
         3.81628688e-02,  -2.76863412e-02,  -1.53753603e-03,
        -1.27792435e-03,   0.00000000e+00,   5.78173161e-03,
         0.00000000e+00,   2.29772739e-02,  -4.72327822e-03,
         6.01678927e-03,   2.43504942e-03,   0.00000000e+00,
         5.62670064e-03,   0.00000000e+00,  -9.67878004e-04,
        -5.26440364e-04,  -1.35474635e-02,  -6.75638206e-02,
        -1.11671182e-01,   5.17826591e-02,  -2.09534512e-02,
         9.27846927e-03,  -1.88014337e-02,  -5.02331868e-02,
        -2.74741782e-04,   2.23132540e-02,   5.24577946e-03,
        -1.01970184e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.29953147e-01,
        -5.33170222e-03,  -8.38860168e-03,  -5.97767656e-02,
        -3.81147973e-02,   0.00000000e+00,  -6.83527682e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.53476401e-02,   0.00000000e+00,
        -2.30608078e-03,  -3.90689823e-02,  -5.65325531e-03,
        -4.11548244e-02,   5.30762769e-02,   0.00000000e+00,
        -2.66943347e-02,   0.00000000e+00,  -5.15611097e-02,
         1.39076516e-02,  -4.57858589e-03,   1.34253034e-02,
        -1.24042081e-02,   0.00000000e+00,   6.13187174e-03,
         0.00000000e+00,   1.42519567e-02,  -5.90312935e-04,
        -7.94271973e-03,  -4.77053461e-04,   6.17916903e-03,
         1.66610583e-02,   0.00000000e+00,   7.64002529e-03,
         0.00000000e+00,  -7.17618328e-03,   4.45027302e-03,
        -8.20757403e-04,  -3.33771399e-03,   3.90492251e-03,
         1.36280634e-02,   1.59644202e-02,   0.00000000e+00,
         3.33836600e-02,   0.00000000e+00,  -3.95790422e-03,
        -1.52786312e-03,  -8.32152824e-03,  -8.72679422e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.88743301e-02,   0.00000000e+00,
         1.94823819e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.30105314e-03,
        -1.25543003e-02,   9.73514928e-03,   6.39371008e-03,
        -2.56973527e-02,   0.00000000e+00,  -1.14791122e-02,
         0.00000000e+00,  -2.57762570e-03,   5.23689476e-03,
         5.30356088e-03,   5.36441345e-03,   0.00000000e+00,
         3.40426097e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.13717644e-01,
         0.00000000e+00,  -2.72113495e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.35702303e-02,   0.00000000e+00,  -1.24565471e-01,
        -3.36324294e-03,   3.13683036e-03,   5.08942883e-02,
         6.58587683e-02,   0.00000000e+00,   7.48992520e-02,
         0.00000000e+00,   3.65876992e-03,  -1.48674660e-03,
        -1.48581169e-02,  -3.79394250e-02,   0.00000000e+00,
         1.81880134e-02,   0.00000000e+00,  -1.14804743e-01,
         4.04191669e-03,   2.17070651e-02,   4.72684025e-02,
        -6.70745206e-02,   0.00000000e+00,   2.57475458e-02,
         0.00000000e+00,   6.88929442e-02,  -1.66172990e-02,
         8.96460182e-03,  -6.62620260e-03,   0.00000000e+00,
        -2.83950225e-02,   0.00000000e+00,  -3.72046597e-03,
        -1.32781700e-01,   3.81628688e-02,  -2.78675688e-02,
        -7.31593259e-04,   3.95863502e-03,   0.00000000e+00,
         7.81169659e-03,   0.00000000e+00,   2.06828708e-02,
        -3.99276557e-03,   4.10325579e-03,   1.22026743e-03,
         0.00000000e+00,   9.76222913e-03,   0.00000000e+00,
        -6.16996257e-03,   1.02046499e-02,  -1.38324556e-02,
         9.60640165e-02,  -3.45620052e-02,  -9.51084644e-04,
        -6.66752969e-03,   0.00000000e+00,   6.70854893e-03,
         0.00000000e+00,   3.78356477e-02,  -1.44855651e-02,
         7.18024038e-03,   4.10229588e-03,   0.00000000e+00,
         1.47250566e-02,   0.00000000e+00,   4.54552724e-03,
        -8.93741758e-03,  -5.21419042e-02,  -1.16477466e-01,
        -1.08355058e-01,   1.13995418e-01,   8.16569505e-02,
         3.07757477e-02,  -6.01334335e-02,   2.15632391e-03,
        -2.80648746e-02,   5.89792926e-02,   6.49940646e-03,
        -9.78488681e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.62965583e-01,
         4.90266644e-03,  -1.43741579e-02,  -1.22748473e-01,
        -8.06544323e-02,   0.00000000e+00,  -2.28755239e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.74216878e-02,   0.00000000e+00,
         1.16027795e-01,  -4.07586061e-02,  -3.22557122e-02,
        -6.78164564e-02,   9.44435528e-02,   0.00000000e+00,
        -5.03055802e-02,   0.00000000e+00,   3.59053078e-02,
         4.67374140e-03,  -2.37840321e-02,   3.50780842e-02,
        -2.13042054e-02,   0.00000000e+00,   4.03615099e-03,
         0.00000000e+00,   8.41130806e-03,   6.92099795e-02,
        -8.26143802e-03,  -5.37082661e-03,   5.53002212e-03,
         1.86357937e-02,   0.00000000e+00,   8.23114357e-03,
         0.00000000e+00,   4.22470449e-03,   3.30402297e-02,
         9.28105531e-02,  -1.95495817e-03,   4.05642399e-03,
        -7.10121265e-03,  -6.41732095e-04,   0.00000000e+00,
         5.50314570e-02,   0.00000000e+00,  -2.45699233e-02,
        -8.37729893e-03,  -2.29397955e-02,   9.78673500e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.56919587e-02,   0.00000000e+00,
         6.21391261e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.19964316e-01,
        -5.38804567e-03,   3.31007953e-03,   2.60486849e-02,
        -2.79323384e-02,   0.00000000e+00,  -1.56850531e-02,
         0.00000000e+00,  -2.74932031e-02,   3.40552002e-02,
         1.49285270e-02,   1.28717393e-02,   0.00000000e+00,
         9.80782032e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.66550833e-02,
         0.00000000e+00,  -1.43256138e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.23619285e-02,   0.00000000e+00,  -1.40879762e-01,
        -1.64093018e-03,   4.31134783e-03,   3.26276129e-02,
         3.91615281e-02,   0.00000000e+00,   3.70527415e-02,
         0.00000000e+00,   2.94426058e-03,   1.88197322e-03,
        -2.03768939e-02,  -6.57064524e-02,   0.00000000e+00,
         2.97905009e-02,   0.00000000e+00,  -1.29370575e-01,
        -6.59382439e-03,   8.01015565e-03,   2.29457245e-02,
        -3.73084720e-02,   0.00000000e+00,   1.54218597e-02,
         0.00000000e+00,   5.51224168e-02,  -1.30935144e-02,
         1.05016825e-02,  -1.89104034e-02,   0.00000000e+00,
        -5.86222426e-02,   0.00000000e+00,  -8.05277212e-03,
        -1.47033204e-01,   1.28442664e-02,  -4.69794675e-02,
        -4.62150142e-03,  -4.89749492e-03,   0.00000000e+00,
         9.70342153e-03,   0.00000000e+00,   3.90642846e-02,
         1.12498541e-02,   9.89602315e-03,  -3.60765492e-03,
         0.00000000e+00,   3.19328771e-02,   0.00000000e+00,
        -1.15365089e-02,   4.25563899e-02,   8.89661388e-02,
         5.17826591e-02,  -1.59105575e-02,  -5.89981602e-03,
         6.09816482e-03,   0.00000000e+00,  -2.22239775e-03,
         0.00000000e+00,   1.82296973e-02,  -1.63722324e-02,
         7.38977696e-03,   8.87466252e-03,   0.00000000e+00,
         2.39959346e-02,   0.00000000e+00,   6.91654848e-03,
         2.03368639e-02,  -9.21301697e-02,  -1.05109948e-01,
         4.92190703e-01,   8.16569505e-02,   6.55193453e-01,
         4.16547869e-03,  -6.10150291e-02,   5.57646178e-01,
        -1.58411345e-02,   3.83491509e-02,  -8.79813259e-03,
         4.98538039e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.45989121e-01,
         7.76127716e-03,   6.48078720e-03,  -7.37399657e-02,
        -5.10701384e-02,   0.00000000e+00,   5.42648512e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.58957030e-02,   0.00000000e+00,
         6.31602838e-01,  -3.27177691e-02,  -4.38742325e-02,
        -2.89186757e-02,   6.20327686e-02,   0.00000000e+00,
        -4.32890571e-02,   0.00000000e+00,   5.88412107e-01,
        -2.19166242e-02,  -7.85400304e-02,   7.01852940e-02,
        -2.62756353e-02,   0.00000000e+00,  -1.89446671e-02,
         0.00000000e+00,  -4.98339139e-02,   4.46801885e-01,
        -6.78523820e-03,  -1.54261705e-02,   8.94049719e-04,
         4.53423795e-03,   0.00000000e+00,  -7.12566291e-03,
         0.00000000e+00,   3.98476460e-02,   1.07035759e-01,
         5.30175921e-01,   4.08376856e-03,  -6.32672383e-03,
        -6.02699301e-02,  -5.75222976e-02,   0.00000000e+00,
         8.46600115e-02,   0.00000000e+00,  -7.23574853e-02,
        -2.62032916e-02,  -3.30250398e-02,   5.88328501e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.56772774e-02,   0.00000000e+00,
         1.45839602e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.35324067e-01,
         1.70213464e-02,  -3.59921223e-02,   6.46708092e-02,
        -2.23877046e-02,   0.00000000e+00,  -9.39276489e-03,
         0.00000000e+00,  -7.80122142e-02,   9.57490578e-02,
         3.25799847e-02,   1.72489837e-02,   0.00000000e+00,
         5.97468122e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.84885008e-02,
         0.00000000e+00,   3.66451323e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.98287436e-02,   0.00000000e+00,   4.25005746e-01,
         4.86114485e-03,   4.97153036e-03,  -4.52898451e-03,
        -1.91258477e-02,   0.00000000e+00,  -6.15606635e-02,
         0.00000000e+00,   8.13723851e-04,   3.91834206e-03,
         4.69335899e-03,  -3.15364802e-02,   0.00000000e+00,
         1.24886103e-02,   0.00000000e+00,   4.23923795e-01,
         1.06664819e-02,  -3.13768359e-02,  -3.92071027e-02,
         4.28501484e-02,   0.00000000e+00,  -1.39543407e-02,
         0.00000000e+00,   6.28366378e-03,   1.29388918e-03,
        -7.23616426e-04,  -2.46121912e-02,   0.00000000e+00,
        -4.90896963e-02,   0.00000000e+00,  -3.98877724e-03,
         4.38533449e-01,  -4.90744660e-02,  -8.18000244e-02,
        -3.83806741e-04,  -3.29166157e-02,   0.00000000e+00,
         2.11954255e-02,   0.00000000e+00,   5.37487139e-02,
         6.95536285e-02,   1.90245048e-02,  -2.11529170e-02,
         0.00000000e+00,   3.51004674e-02,   0.00000000e+00,
        -5.25913427e-03,   3.83197499e-02,   6.20305863e-01,
        -2.09534512e-02,   4.06659114e-02,   1.11782531e-02,
         8.53067830e-04,   0.00000000e+00,  -9.69016871e-03,
         0.00000000e+00,  -9.69513640e-03,  -1.41943318e-02,
        -3.43487201e-03,   6.21518355e-03,   0.00000000e+00,
        -4.98461605e-03,   0.00000000e+00,  -1.54053792e-03,
         6.95591495e-03,  -6.04734537e-02,   4.71271543e-01,
         7.11380945e-02,  -6.01334335e-02,  -6.10150291e-02,
         1.52323287e-03,   1.03104994e-01,   2.22415992e-02,
         5.80827097e-03,  -3.20900803e-02,   6.09126705e-03,
         6.25942788e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.15730204e-02,
        -3.42262379e-02,  -2.40714612e-02,   5.67072801e-02,
         1.78818912e-02,   0.00000000e+00,   4.47737604e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.75887564e-02,   0.00000000e+00,
        -2.68189863e-02,  -3.08477181e-03,  -3.27841621e-03,
         2.53398361e-02,  -5.04283579e-02,   0.00000000e+00,
         2.85225682e-02,   0.00000000e+00,   7.07166643e-03,
         8.77301453e-03,   2.29859373e-02,   4.97213101e-03,
         1.67599080e-02,   0.00000000e+00,  -2.08082246e-02,
         0.00000000e+00,  -2.68087538e-02,  -7.27618912e-02,
         4.11265730e-03,  -1.49419790e-02,   3.62888421e-02,
        -6.83079577e-03,   0.00000000e+00,  -3.70520489e-02,
         0.00000000e+00,  -1.23750329e-02,  -3.03731770e-02,
        -1.30034121e-01,   3.20825820e-03,  -1.12141630e-02,
        -6.56818765e-04,  -7.98857697e-03,   0.00000000e+00,
        -1.52047901e-02,   0.00000000e+00,   6.32319530e-03,
         8.39380529e-03,   3.94628577e-03,  -9.85505306e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.32827895e-03,   0.00000000e+00,
        -1.21986963e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.71038923e-02,
         6.16120907e-03,   9.22030223e-03,  -7.54446706e-03,
         5.54820313e-03,   0.00000000e+00,   4.14340703e-03,
         0.00000000e+00,  -1.11800472e-02,  -2.11648580e-02,
        -1.44562884e-02,  -1.60588416e-02,   0.00000000e+00,
        -2.81363808e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.73326360e-02,
         0.00000000e+00,   1.21088914e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.78418471e-02,   0.00000000e+00,   8.02519125e-02,
         9.69899959e-03,  -3.09963879e-03,  -1.49378010e-02,
        -1.80322410e-02,   0.00000000e+00,  -1.46963669e-02,
         0.00000000e+00,  -3.29728304e-03,  -1.83892451e-03,
         2.24877294e-02,   2.30438148e-02,   0.00000000e+00,
        -6.00848407e-03,   0.00000000e+00,   7.91962410e-02,
         8.17019405e-03,  -9.77824938e-03,  -1.45337470e-02,
         1.56494101e-02,   0.00000000e+00,  -3.94080507e-03,
         0.00000000e+00,  -2.14822371e-02,   4.42441222e-03,
        -9.90980302e-03,   1.59307476e-02,   0.00000000e+00,
         2.04677024e-02,   0.00000000e+00,   1.17639076e-02,
         1.00390219e-01,  -8.20210438e-03,   1.38452689e-02,
        -6.89949628e-03,   2.82520867e-03,   0.00000000e+00,
         1.10264907e-02,   0.00000000e+00,  -5.52753719e-03,
        -1.08660714e-02,  -1.49411745e-02,   2.81557499e-02,
         0.00000000e+00,  -6.22675358e-02,   0.00000000e+00,
        -1.38137810e-02,  -1.36896737e-02,  -3.51927863e-02,
        -1.88014337e-02,   8.85458120e-03,   1.28316188e-02,
        -7.93662959e-03,   0.00000000e+00,   9.55938810e-03,
         0.00000000e+00,  -1.20461857e-02,   7.33103574e-03,
        -8.59832070e-03,  -2.24572163e-02,   0.00000000e+00,
         3.35364613e-03,   0.00000000e+00,  -9.58999314e-03,
        -2.01240508e-02,   4.33643035e-02,   6.15467364e-02,
        -7.52628756e-02,   5.89792926e-02,   3.83491509e-02,
         6.06155623e-03,  -3.20900803e-02,  -3.37435681e-03,
        -3.47884514e-02,   7.77693511e-02,   1.60736528e-02,
        -6.95201224e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.64861731e-02,
        -2.69853672e-02,  -2.35186014e-02,  -6.84251668e-02,
        -5.82938456e-02,   0.00000000e+00,   9.02345266e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.62744464e-02,   0.00000000e+00,
         6.42265248e-02,   7.29458364e-03,   1.65502916e-02,
        -4.21798028e-02,   5.82916476e-02,   0.00000000e+00,
        -3.71050583e-02,   0.00000000e+00,   1.58104734e-03,
        -1.83252570e-03,  -2.05423229e-02,   2.08726835e-02,
        -1.82721758e-02,   0.00000000e+00,   1.03917725e-02,
         0.00000000e+00,  -2.89380473e-03,   4.30381032e-02,
         2.76934552e-03,  -3.07073203e-03,   3.75397905e-03,
         3.40553221e-03,   0.00000000e+00,   7.79692386e-03,
         0.00000000e+00,  -1.09201151e-02,   1.85758992e-02,
         4.96545526e-02,   7.13227454e-04,  -1.07367910e-02,
        -9.63076757e-03,  -4.96375890e-03,   0.00000000e+00,
         3.21777655e-02,   0.00000000e+00,  -6.33151763e-03,
         4.21305670e-03,  -1.30006027e-02,   6.48267589e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.93565705e-03,   0.00000000e+00,
         3.26745258e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.52723793e-02,
        -8.57539250e-03,  -3.04367795e-03,   9.08785749e-03,
        -1.70677633e-02,   0.00000000e+00,  -8.61909868e-03,
         0.00000000e+00,  -1.56233762e-03,   2.27993849e-02,
         6.90944487e-03,   1.64407031e-02,   0.00000000e+00,
         6.02671256e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.98592401e-02,
         0.00000000e+00,  -1.08197693e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.75034390e-02,   0.00000000e+00,  -8.39092481e-02,
         7.59501989e-03,   4.05909514e-05,   1.14338286e-02,
         1.85685159e-02,   0.00000000e+00,   1.73414812e-02,
         0.00000000e+00,   6.27170899e-03,  -3.50165774e-03,
        -1.16936564e-02,  -4.22982456e-02,   0.00000000e+00,
         2.08223990e-02,   0.00000000e+00,  -7.22347856e-02,
        -1.14682051e-02,   1.13581876e-02,   9.17256004e-03,
        -1.90762589e-02,   0.00000000e+00,   5.73904621e-03,
         0.00000000e+00,   2.58615412e-02,  -9.39465950e-03,
         5.63636260e-03,  -6.39660674e-03,   0.00000000e+00,
        -3.71200875e-02,   0.00000000e+00,   5.43491836e-03,
        -1.10246591e-01,   3.95905103e-03,  -2.35457478e-02,
        -8.65032417e-04,   2.72812234e-04,   0.00000000e+00,
         1.27601190e-02,   0.00000000e+00,   9.91891088e-03,
         6.43196175e-03,  -4.37862537e-04,   2.97540076e-02,
         0.00000000e+00,   4.79742435e-02,   0.00000000e+00,
        -2.16766613e-02,   2.12113798e-02,   3.65192301e-02,
         2.23132540e-02,  -5.20748064e-03,  -9.59595269e-03,
         1.77513868e-02,   0.00000000e+00,  -1.49934106e-04,
         0.00000000e+00,   1.04430980e-02,  -9.48892821e-03,
        -2.71019023e-04,  -1.26348115e-02,   0.00000000e+00,
         1.41068327e-02,   0.00000000e+00,  -1.97775290e-02,
         2.48097054e-02,  -5.00833537e-02,  -6.39355647e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.68519110e-02,   3.27569124e-02,
         1.35562843e-02,  -1.17175996e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.94399007e-03,   0.00000000e+00,
         2.09886005e-02,   9.38813751e-03,  -2.98221760e-03,
         7.83624103e-03,   0.00000000e+00,  -5.83805707e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.64681695e-03,
         0.00000000e+00,  -3.74848829e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.75161501e-03,   0.00000000e+00,
        -3.72910591e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.21829890e-03,   0.00000000e+00,
        -4.39961564e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.68491160e-03,
         0.00000000e+00,  -1.09127465e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.32498617e-03,   9.85354698e-03,   3.75114885e-03,
        -1.11442220e-03,   0.00000000e+00,  -1.20310805e-03,
         0.00000000e+00,  -4.15122974e-03,  -3.05489469e-03,
        -9.82750964e-04,  -2.73710679e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.40319953e-03,   0.00000000e+00,
         2.18253599e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.89958704e-03,
         0.00000000e+00,   1.41819024e-02,  -7.09320782e-03,
        -1.97721548e-03,   1.48918808e-03,   0.00000000e+00,
         1.25232678e-04,   0.00000000e+00,   3.79945887e-03,
        -3.79892451e-03,   2.20558885e-03,   2.04680496e-03,
         0.00000000e+00,   8.45201787e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.17072117e-03,   0.00000000e+00,
         1.30386836e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.54479346e-04,
         0.00000000e+00,   2.81170315e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.30455216e-03,   0.00000000e+00,
        -1.62375738e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.15221888e-03,
         0.00000000e+00,   1.71655851e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.20664318e-03,
         0.00000000e+00,  -4.47303759e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.44706265e-03,   0.00000000e+00,  -2.34784768e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.94524866e-03,   0.00000000e+00,
        -6.04570228e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.56676712e-02,
         0.00000000e+00,  -4.42233974e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.20556502e-02,  -1.43741579e-02,   6.48078720e-03,
        -5.13872199e-02,  -2.40714612e-02,   3.41241617e-03,
        -3.24751733e-02,  -2.35186014e-02,  -1.50681420e-02,
        -2.26378716e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.81766221e-02,
        -1.49859822e-02,   7.70652258e-02,   4.33623841e-02,
         3.37478382e-02,   0.00000000e+00,  -2.77281648e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.63694168e-02,   0.00000000e+00,
        -4.56841798e-02,  -6.57686907e-03,  -1.32701528e-02,
         1.79804463e-02,  -2.92858478e-02,   0.00000000e+00,
         9.68694476e-03,   0.00000000e+00,  -7.16739900e-03,
        -2.66446665e-03,   4.28166508e-03,  -2.60012209e-02,
         9.37609455e-03,   0.00000000e+00,   9.06339648e-03,
         0.00000000e+00,   2.44526009e-02,   1.51494000e-02,
         1.31673019e-03,   1.15432096e-02,  -3.61816781e-02,
         4.01312329e-03,   0.00000000e+00,   1.85819697e-02,
         0.00000000e+00,   2.10039358e-02,   2.20682976e-03,
         5.37613024e-02,   6.66608318e-03,   1.09970236e-02,
         2.72371507e-03,   1.27542661e-02,   0.00000000e+00,
        -2.49118984e-02,   0.00000000e+00,   3.33118023e-03,
        -1.36221170e-02,   1.23849464e-02,  -5.66849232e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.99493130e-04,   0.00000000e+00,
        -2.33769514e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.65361733e-02,
        -6.72001067e-04,   1.59819390e-03,  -2.60597916e-03,
         4.13611806e-03,   0.00000000e+00,  -1.38301366e-03,
         0.00000000e+00,   8.84213126e-03,  -6.01446858e-03,
         6.68124237e-03,   1.22280316e-03,   0.00000000e+00,
        -4.79300736e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.43413444e-03,
         0.00000000e+00,   1.71836898e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.68184962e-02,   0.00000000e+00,   2.43014348e-02,
         4.59517227e-03,  -7.82781158e-03,  -4.00260506e-03,
        -4.04975759e-03,   0.00000000e+00,  -7.77807518e-03,
         0.00000000e+00,   4.02946096e-03,  -9.65903295e-04,
        -1.57189575e-03,   3.08748046e-02,   0.00000000e+00,
        -2.02635884e-03,   0.00000000e+00,   2.18457718e-02,
         4.39187486e-03,  -3.73918940e-03,  -3.55593112e-03,
         1.38769445e-03,   0.00000000e+00,  -7.94606869e-03,
         0.00000000e+00,  -1.00215384e-02,   5.84358150e-03,
         2.97669846e-03,  -1.19265329e-03,   0.00000000e+00,
         2.01134095e-02,   0.00000000e+00,   1.33058572e-02,
         3.35140141e-02,   2.47847630e-03,   1.35458527e-02,
         1.13016700e-02,   6.67473756e-03,   0.00000000e+00,
        -8.60223501e-03,   0.00000000e+00,  -4.83598354e-03,
        -1.00042726e-03,   7.34148884e-03,  -6.16960288e-02,
         0.00000000e+00,   4.48244075e-03,   0.00000000e+00,
         3.54284703e-05,  -7.52888992e-03,  -1.52749206e-02,
        -8.38860168e-03,  -1.17572463e-03,   6.10225397e-03,
        -3.03557427e-03,   0.00000000e+00,   4.89551844e-03,
         0.00000000e+00,  -7.24367627e-04,   4.36823111e-03,
        -1.02853826e-03,   9.12848332e-03,   0.00000000e+00,
        -4.78531466e-03,   0.00000000e+00,  -4.94855078e-02,
        -7.32772456e-03,   1.21283747e-02,   1.79849250e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.78827628e-02,   9.38813751e-03,
         7.63191668e-04,   4.09138600e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.49779784e-03,   0.00000000e+00,
         3.90863181e-02,   1.07151653e-01,   1.06533225e-02,
         2.18230274e-02,   0.00000000e+00,  -2.85140413e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.28706668e-03,
         0.00000000e+00,  -2.87311420e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.51191249e-03,   0.00000000e+00,
        -1.37400011e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.08827432e-03,   0.00000000e+00,
        -3.06353833e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.41677662e-03,
         0.00000000e+00,  -1.07180593e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.08205946e-02,   2.90437862e-02,   3.30517647e-03,
         9.82763904e-03,   0.00000000e+00,  -1.20698785e-02,
         0.00000000e+00,  -1.91754660e-02,  -2.71956108e-02,
         1.20905091e-03,  -1.21714248e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.38310526e-03,   0.00000000e+00,
        -3.61996606e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.82032589e-03,
         0.00000000e+00,   2.58638769e-03,   1.65569444e-03,
         4.83826160e-03,  -4.57798649e-03,   0.00000000e+00,
         1.04508301e-03,   0.00000000e+00,  -8.91057725e-03,
        -2.18754132e-03,   1.14074119e-03,  -5.47143948e-03,
         0.00000000e+00,  -8.76422976e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.28445608e-03,   0.00000000e+00,
         5.51764267e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.71143369e-03,
         0.00000000e+00,   3.62762674e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.01208363e-03,   0.00000000e+00,
        -1.08182411e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.24189234e-02,
         0.00000000e+00,  -2.40669377e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.20152394e-03,
         0.00000000e+00,  -2.15008424e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.37234681e-02,   0.00000000e+00,  -1.11767030e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.67293496e-04,   0.00000000e+00,
        -1.51594938e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.83694785e-02,
         0.00000000e+00,   3.30641915e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.97657612e-02,  -3.22557122e-02,  -4.38742325e-02,
        -3.52946619e-02,  -3.27841621e-03,  -4.37553275e-02,
         4.42964485e-02,   1.65502916e-02,  -9.74137820e-03,
        -1.91817888e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.01127290e-02,
        -1.91385460e-02,  -1.32701528e-02,   1.66259172e-02,
        -2.67576172e-03,   0.00000000e+00,  -3.00510806e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.32202546e-02,   0.00000000e+00,
        -6.90028185e-02,   1.53341802e-02,   8.29102095e-02,
         1.51129615e-02,  -1.02358971e-02,   0.00000000e+00,
         8.43394888e-04,   0.00000000e+00,  -7.54069380e-02,
         2.66544650e-03,  -3.47480342e-03,  -2.20089590e-02,
        -6.73917441e-03,   0.00000000e+00,   2.07470335e-02,
         0.00000000e+00,   4.91515467e-03,  -8.41240648e-03,
         5.87006272e-03,   1.54285377e-02,  -1.67609132e-02,
        -1.20534385e-02,   0.00000000e+00,   2.02848608e-02,
         0.00000000e+00,  -2.02474169e-02,  -5.62816811e-03,
        -5.24904599e-03,  -4.53546092e-03,  -1.11489942e-02,
         6.70313744e-03,   4.30677904e-03,   0.00000000e+00,
        -1.65668966e-02,   0.00000000e+00,   2.48601224e-02,
         1.59269842e-02,   8.69829863e-03,  -5.14081837e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.24817936e-03,   0.00000000e+00,
        -3.62191258e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.51591925e-02,
        -6.92394268e-03,  -4.50809570e-03,  -2.11435907e-02,
         1.15243872e-02,   0.00000000e+00,   6.95526861e-03,
         0.00000000e+00,   4.12594624e-02,  -9.25318969e-03,
        -7.01418333e-03,   1.51051168e-02,   0.00000000e+00,
        -4.20367641e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.09534621e-03,
         0.00000000e+00,  -1.27042305e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.03863964e-03,   0.00000000e+00,  -2.35693304e-02,
        -1.48118028e-04,   3.81755890e-04,  -6.59947473e-03,
         3.32369204e-04,   0.00000000e+00,   6.14605293e-03,
         0.00000000e+00,   3.23961990e-03,  -4.73574864e-03,
        -8.28944799e-03,   1.87810151e-03,   0.00000000e+00,
        -4.58934669e-03,   0.00000000e+00,  -2.08413533e-02,
         5.92528091e-03,   6.19592144e-03,  -1.50113004e-03,
         4.20321685e-03,   0.00000000e+00,  -2.33861216e-03,
         0.00000000e+00,  -7.52310118e-03,  -4.48944141e-03,
         1.12217271e-03,   1.11942858e-02,   0.00000000e+00,
         2.58036713e-02,   0.00000000e+00,   4.80738522e-03,
        -9.94128739e-03,   9.93226688e-03,   2.35672729e-02,
         4.22934333e-03,   1.79207983e-03,   0.00000000e+00,
        -9.09054703e-04,   0.00000000e+00,  -2.54350097e-02,
        -1.07645222e-02,  -7.26272139e-03,   3.89269368e-02,
         0.00000000e+00,   4.37196147e-02,   0.00000000e+00,
        -2.05860900e-04,  -4.09535921e-02,  -6.98739985e-02,
        -5.65325531e-03,   2.54128774e-03,  -3.65860588e-03,
         1.21214411e-03,   0.00000000e+00,   1.83497463e-03,
         0.00000000e+00,   2.10834316e-02,  -2.00444199e-03,
         3.44171169e-03,  -1.12698058e-02,   0.00000000e+00,
        -1.47925889e-02,   0.00000000e+00,  -1.37448136e-03,
        -2.39373356e-02,   1.63934944e-02,  -4.65070446e-02,
        -1.08057775e-02,  -2.37840321e-02,  -7.85400304e-02,
         8.40122721e-03,   2.29859373e-02,  -3.05126616e-02,
        -5.23490643e-03,  -2.05423229e-02,   5.21914799e-03,
        -2.61914880e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.80457282e-03,
         1.85208974e-03,   4.28166508e-03,   1.55203929e-02,
         2.17644575e-02,   0.00000000e+00,  -3.38096108e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.28255854e-02,   0.00000000e+00,
        -7.22364937e-02,   1.01438568e-02,  -3.47480342e-03,
         1.57550447e-03,  -2.51579889e-02,   0.00000000e+00,
         2.48475343e-02,   0.00000000e+00,  -4.73722531e-02,
         1.11859379e-02,   4.72854592e-02,  -3.11776739e-02,
         1.54031184e-02,   0.00000000e+00,   6.79001525e-03,
         0.00000000e+00,   1.74182340e-02,  -1.37548117e-02,
         9.32425546e-03,   2.92252178e-02,  -1.89001965e-02,
         4.72557819e-03,   0.00000000e+00,   9.26465485e-03,
         0.00000000e+00,   1.02327252e-03,  -1.27275819e-02,
         1.95413895e-03,  -3.13517760e-03,  -3.06571528e-03,
         1.52117609e-02,   1.62655957e-02,   0.00000000e+00,
        -2.78940479e-02,   0.00000000e+00,   2.26172555e-02,
         4.81714805e-03,   1.55744895e-02,  -6.25047409e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.58738532e-03,   0.00000000e+00,
        -4.63926081e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.78135078e-02,
         2.44366936e-03,   2.22038073e-02,  -2.26743240e-02,
         1.30803649e-02,   0.00000000e+00,   2.57871023e-03,
         0.00000000e+00,   1.55984826e-02,  -3.31939531e-02,
        -9.65058390e-03,  -1.30213066e-02,   0.00000000e+00,
        -7.08400511e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.56699793e-03,
         0.00000000e+00,  -5.16139058e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.61723863e-02,   0.00000000e+00,  -5.75926917e-03,
        -8.09120166e-04,  -2.11023612e-03,  -2.97658913e-03,
        -4.52901127e-03,   0.00000000e+00,   4.74858386e-03,
         0.00000000e+00,  -3.87647481e-03,  -1.29331128e-03,
        -4.75475817e-03,   1.35377702e-02,   0.00000000e+00,
        -3.69127644e-03,   0.00000000e+00,  -5.38281963e-03,
         9.63863950e-04,   2.55939262e-03,   2.54379634e-03,
        -4.01966950e-03,   0.00000000e+00,   3.22663802e-03,
         0.00000000e+00,  -1.23061890e-02,   4.10800574e-03,
         6.11031055e-04,   7.62423468e-03,   0.00000000e+00,
         1.05511659e-02,   0.00000000e+00,  -8.47838847e-04,
        -1.13741112e-02,   1.14807856e-02,   3.58645990e-02,
        -9.18544242e-03,   7.09560165e-03,   0.00000000e+00,
        -5.75998597e-04,   0.00000000e+00,  -1.34227781e-02,
        -2.97683574e-02,  -1.35828346e-02,   5.50737754e-04,
         0.00000000e+00,  -3.30881907e-02,   0.00000000e+00,
         1.30661026e-03,  -8.23346628e-04,  -6.81339513e-02,
        -4.57858589e-03,  -1.09008282e-02,   1.26933661e-03,
        -3.45647484e-03,   0.00000000e+00,   2.20435284e-03,
         0.00000000e+00,  -3.20000862e-03,   1.00992274e-02,
         5.91481710e-03,   2.85207685e-04,   0.00000000e+00,
         7.03996623e-03,   0.00000000e+00,  -9.57746085e-05,
         3.55571538e-03,   2.12665930e-02,  -9.56109816e-03,
        -1.73498099e-02,  -5.37082661e-03,  -1.54261705e-02,
        -4.11359766e-03,  -1.49419790e-02,   2.98132189e-03,
         8.68023478e-03,  -3.07073203e-03,  -1.47587236e-03,
        -1.69897569e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.32958915e-02,
         4.31327185e-03,   1.15432096e-02,  -1.20112885e-02,
         8.61139754e-03,   0.00000000e+00,  -1.02989784e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.67590782e-03,   0.00000000e+00,
        -4.04723301e-02,   5.87777944e-03,   1.54285377e-02,
        -6.10496788e-03,  -8.47467975e-03,   0.00000000e+00,
         1.48852397e-02,   0.00000000e+00,  -2.90168125e-02,
         8.29866739e-03,   2.92252178e-02,  -2.55494277e-02,
         6.39769513e-03,   0.00000000e+00,   1.27934831e-02,
         0.00000000e+00,   1.65008491e-02,   2.15995943e-02,
         1.40878997e-02,   5.31034587e-02,  -4.56663499e-02,
         7.29102860e-03,   0.00000000e+00,   3.04534927e-02,
         0.00000000e+00,   9.95680919e-03,   2.23647560e-02,
         1.01060486e-01,  -3.58859813e-03,  -3.48912488e-03,
         5.17414287e-03,   7.15920169e-03,   0.00000000e+00,
        -9.34829199e-03,   0.00000000e+00,   1.40848026e-02,
         4.42817537e-03,   1.26275266e-02,  -2.93139727e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.97036019e-03,   0.00000000e+00,
        -2.28154588e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.44614681e-02,
         5.46144386e-04,   1.02314128e-02,  -1.35064815e-02,
         7.27195016e-03,   0.00000000e+00,   2.85824971e-03,
         0.00000000e+00,   1.25885915e-02,  -1.33287499e-02,
         2.71327669e-03,  -7.42652011e-03,   0.00000000e+00,
        -3.01086181e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.45430981e-03,
         0.00000000e+00,  -4.74264976e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.15486681e-03,   0.00000000e+00,  -1.23708020e-02,
        -2.92879327e-03,  -2.26427871e-03,   3.67927692e-03,
        -6.41509704e-04,   0.00000000e+00,   2.29760870e-03,
         0.00000000e+00,  -2.81871012e-03,  -3.45225788e-03,
        -1.55254504e-02,   1.80803637e-03,   0.00000000e+00,
        -9.99225011e-04,   0.00000000e+00,  -8.80843117e-03,
         1.56811553e-03,   3.24658356e-03,   5.87115967e-04,
        -1.59869965e-03,   0.00000000e+00,   3.52475902e-03,
         0.00000000e+00,  -3.58943084e-03,   1.30867064e-03,
         4.86463357e-03,   5.68997009e-03,   0.00000000e+00,
         6.67698571e-03,   0.00000000e+00,  -1.87426792e-03,
        -1.18388172e-02,   7.43747819e-03,   1.89225068e-02,
        -6.91686347e-03,   1.05605079e-03,   0.00000000e+00,
         2.56223768e-03,   0.00000000e+00,  -1.08369379e-02,
        -1.83456482e-02,  -4.96691038e-03,   4.72632705e-03,
         0.00000000e+00,  -5.13228035e-03,   0.00000000e+00,
         2.75696634e-03,  -6.13538129e-03,  -3.32117741e-02,
        -4.77053461e-04,  -4.45724485e-03,  -1.70147927e-03,
        -1.54668461e-03,   0.00000000e+00,  -1.67103997e-04,
         0.00000000e+00,   5.05759367e-03,   5.86296542e-03,
         9.97652599e-03,   1.33303161e-03,   0.00000000e+00,
         9.59094729e-04,   0.00000000e+00,   2.64541255e-03,
        -1.98532593e-03,   6.42418359e-03,  -1.43245926e-02,
        -1.23389841e-02,   4.05642399e-03,  -6.32672383e-03,
         2.26769823e-03,  -1.12141630e-02,  -1.22413943e-02,
         5.21283471e-03,  -1.07367910e-02,  -4.74680902e-03,
        -1.57992966e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.47786707e-02,
         1.25853024e-02,   1.09970236e-02,   1.14088464e-04,
         6.29365486e-03,   0.00000000e+00,  -2.19730745e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.38658608e-04,   0.00000000e+00,
        -1.47664590e-02,  -6.99451296e-03,  -1.11489942e-02,
         5.74311913e-04,   2.45675543e-03,   0.00000000e+00,
        -1.51711260e-04,   0.00000000e+00,  -2.50357502e-03,
        -1.37261834e-03,  -3.06571528e-03,   2.42777039e-03,
         3.14594596e-03,   0.00000000e+00,  -5.12172827e-03,
         0.00000000e+00,   8.32422863e-03,  -6.93249072e-03,
        -2.94162000e-03,  -3.48912488e-03,  -1.48154453e-03,
        -4.26367898e-05,   0.00000000e+00,   2.28460261e-03,
         0.00000000e+00,   3.93303716e-03,   1.96371181e-03,
        -2.06017869e-03,   9.52156325e-03,   2.84100658e-02,
         7.11697392e-03,   1.02772430e-02,   0.00000000e+00,
        -1.29907180e-02,   0.00000000e+00,  -5.09932804e-04,
        -1.93677721e-03,  -3.90852854e-03,  -1.55899726e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.02916490e-03,   0.00000000e+00,
        -6.69936740e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.45585625e-02,
         4.34456194e-04,   4.18082928e-03,  -2.34724737e-03,
         3.04498293e-03,   0.00000000e+00,  -1.47097436e-03,
         0.00000000e+00,   6.95380613e-03,  -3.55848162e-03,
        -4.31254061e-03,  -4.25059075e-03,   0.00000000e+00,
        -2.78058893e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.28747381e-03,
         0.00000000e+00,  -2.79604863e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.21031532e-03,   0.00000000e+00,  -1.32179688e-02,
        -5.78531919e-03,  -3.19452519e-03,   1.18659206e-03,
        -1.90071940e-03,   0.00000000e+00,   8.53323469e-03,
         0.00000000e+00,  -9.39386949e-04,   6.69106206e-04,
        -2.50928595e-03,  -1.62165122e-03,   0.00000000e+00,
         1.28921520e-03,   0.00000000e+00,  -1.32963683e-02,
        -3.00117992e-03,  -1.41441692e-03,   6.36120380e-03,
        -9.67944379e-04,   0.00000000e+00,   1.21994941e-03,
         0.00000000e+00,   4.72467056e-03,   1.57686588e-03,
         3.44745310e-03,  -1.49570841e-03,   0.00000000e+00,
         8.83005167e-04,   0.00000000e+00,  -1.32566246e-03,
        -1.12313550e-02,  -1.72556502e-03,  -4.37972187e-03,
         9.98179225e-03,   1.20941648e-02,   0.00000000e+00,
        -2.17622770e-02,   0.00000000e+00,   1.65226966e-02,
         2.18926844e-03,   8.88867038e-03,  -1.64111976e-02,
         0.00000000e+00,  -1.39732096e-03,   0.00000000e+00,
         7.38772858e-03,   1.86458605e-03,  -7.20399645e-03,
         3.90492251e-03,   1.46864649e-05,  -6.37851949e-03,
        -5.44284337e-03,   0.00000000e+00,   4.23083992e-03,
         0.00000000e+00,  -4.50247238e-03,   4.32397214e-05,
        -1.14745819e-03,   8.45968871e-03,   0.00000000e+00,
         2.05595701e-03,   0.00000000e+00,   8.72985910e-03,
        -2.22912409e-03,  -1.10893532e-04,  -1.46614791e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.15520123e-03,   9.85354698e-03,
         2.72999464e-03,  -2.32947164e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.28204460e-03,   0.00000000e+00,
         1.45821907e-02,   2.90437862e-02,   3.37148895e-03,
         7.65917941e-03,   0.00000000e+00,  -9.82648429e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.73524302e-03,
         0.00000000e+00,  -1.22295373e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.69011258e-03,   0.00000000e+00,
        -1.24585263e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.04714599e-03,   0.00000000e+00,
        -5.57383032e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.06186451e-03,
         0.00000000e+00,  -5.70243987e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.37967723e-02,   3.70770162e-02,   2.80240358e-03,
         7.77772094e-03,   0.00000000e+00,  -9.62794008e-03,
         0.00000000e+00,  -1.11587252e-02,  -7.34066582e-03,
        -1.08763814e-02,  -6.07661866e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.32302869e-03,   0.00000000e+00,
        -3.18721220e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.18947184e-03,
         0.00000000e+00,   6.19779945e-03,   4.91693563e-03,
        -6.99108226e-04,   2.70811579e-03,   0.00000000e+00,
        -1.90500292e-03,   0.00000000e+00,  -1.61762392e-03,
        -1.36619312e-03,  -1.81360416e-03,   9.41868604e-05,
         0.00000000e+00,   2.13302505e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.98837756e-04,   0.00000000e+00,
         3.46629389e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.97254057e-03,
         0.00000000e+00,   1.43439613e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.38559207e-03,   0.00000000e+00,
        -5.39629437e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.61695290e-03,
         0.00000000e+00,   4.44592689e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.29129794e-03,
         0.00000000e+00,  -3.44376833e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.94348001e-02,   0.00000000e+00,  -8.88189640e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.88644066e-03,   0.00000000e+00,
         8.66738880e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.52433124e-03,
         0.00000000e+00,  -6.51568125e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.92815251e-02,   3.31007953e-03,  -3.59921223e-02,
         3.85308200e-03,   9.22030223e-03,  -2.43744838e-02,
        -7.45621384e-03,  -3.04367795e-03,  -2.45705962e-04,
        -3.36832042e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.37458659e-02,
        -4.39125432e-03,   1.59819390e-03,  -4.15983491e-03,
        -2.03739739e-03,   0.00000000e+00,  -3.03485403e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.85443074e-03,   0.00000000e+00,
        -2.65163293e-02,  -6.67819932e-03,  -4.50809570e-03,
        -1.18044970e-02,   3.51108138e-03,   0.00000000e+00,
         3.57950314e-03,   0.00000000e+00,  -1.40929525e-02,
         7.68839523e-03,   2.22038073e-02,  -1.29820295e-02,
         5.96713072e-03,   0.00000000e+00,   4.32723694e-03,
         0.00000000e+00,   9.33482325e-03,  -1.31951340e-02,
         2.62139971e-03,   1.02314128e-02,  -8.37277786e-03,
         3.38282756e-03,   0.00000000e+00,   6.67193589e-03,
         0.00000000e+00,  -2.64973794e-03,  -8.25116771e-03,
         4.57150761e-04,   1.60575315e-04,   4.18082928e-03,
         6.27805041e-03,   1.16918406e-02,   0.00000000e+00,
        -9.73932552e-03,   0.00000000e+00,   1.39455602e-02,
        -2.45506754e-04,   2.48704263e-04,  -3.01988356e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.06404881e-03,   0.00000000e+00,
        -1.92492362e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.32503179e-02,
         7.16654856e-03,   3.56018559e-02,  -9.24807316e-03,
         8.50218996e-03,   0.00000000e+00,  -6.53606007e-03,
         0.00000000e+00,   1.11129927e-02,  -1.56637868e-02,
        -1.06679722e-02,   5.28573515e-03,   0.00000000e+00,
        -2.55858931e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.41519517e-02,
         0.00000000e+00,  -8.81697190e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.53937685e-03,   0.00000000e+00,  -3.03724982e-02,
         2.24472138e-03,   4.87551358e-04,   5.05433294e-03,
         7.35948132e-03,   0.00000000e+00,   1.22781142e-02,
         0.00000000e+00,  -1.30339177e-03,   2.84377723e-04,
        -5.03554395e-03,  -5.26268425e-04,   0.00000000e+00,
         4.64523316e-03,   0.00000000e+00,  -2.88181677e-02,
        -6.32308189e-03,   2.64831271e-03,   7.36468357e-03,
        -1.43611504e-02,   0.00000000e+00,   5.68243054e-03,
         0.00000000e+00,   8.65102228e-03,  -1.56914701e-03,
         2.70971540e-03,   2.29778895e-03,   0.00000000e+00,
        -4.44279865e-04,   0.00000000e+00,   2.17899814e-04,
        -2.84752181e-02,   9.60024824e-03,   1.89039320e-02,
        -1.69144718e-02,   1.53042408e-02,   0.00000000e+00,
        -1.10145256e-04,   0.00000000e+00,   1.40233513e-02,
        -2.29130264e-02,  -1.12516007e-02,  -8.51534513e-04,
         0.00000000e+00,  -1.65481528e-02,   0.00000000e+00,
        -2.63509065e-03,   4.16459820e-03,  -2.99877076e-02,
         9.73514928e-03,  -9.84213900e-03,   2.90191200e-03,
         5.14160996e-04,   0.00000000e+00,   1.49290035e-03,
         0.00000000e+00,  -2.12359208e-03,   6.20130663e-03,
         4.09676928e-03,   2.55160249e-03,   0.00000000e+00,
         1.21961791e-02,   0.00000000e+00,  -4.24821558e-03,
         1.12954299e-04,  -8.97466873e-04,  -3.13117982e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.44074784e-02,  -7.09320782e-03,
        -2.32188011e-03,   1.86326899e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.39121068e-04,   0.00000000e+00,
        -3.35819481e-03,   1.65569444e-03,   2.00435421e-03,
        -1.75521043e-03,   0.00000000e+00,   3.47089099e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.59557976e-03,
         0.00000000e+00,  -3.78166588e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.08162363e-03,   0.00000000e+00,
        -1.12778274e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.12539837e-03,   0.00000000e+00,
         8.43928839e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.20606152e-03,
         0.00000000e+00,  -1.25086440e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.21164578e-03,   4.91693563e-03,  -9.26549433e-04,
         2.74334966e-03,   0.00000000e+00,  -1.97448252e-03,
         0.00000000e+00,  -1.09726544e-03,   2.11528732e-04,
        -2.81403822e-03,   6.17747492e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.39733283e-03,   0.00000000e+00,
        -2.11730511e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.85789959e-03,
         0.00000000e+00,  -1.66624914e-02,   1.14236281e-02,
         4.66776166e-03,  -4.02244612e-03,   0.00000000e+00,
         6.48517378e-04,   0.00000000e+00,  -1.51524654e-03,
         9.90751479e-04,  -1.40240043e-03,  -4.27874041e-04,
         0.00000000e+00,  -1.52918395e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.27306781e-03,   0.00000000e+00,
         6.84215367e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.49413199e-04,
         0.00000000e+00,  -4.35878642e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.85854090e-03,   0.00000000e+00,
        -2.69377598e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.20162730e-05,
         0.00000000e+00,  -2.42666120e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.05296641e-02,
         0.00000000e+00,  -6.27330664e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.77483626e-03,   0.00000000e+00,   5.75395852e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.78493824e-02,   0.00000000e+00,
         8.41711083e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.87265530e-03,
         0.00000000e+00,   9.83883225e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.07167740e-03,   4.31134783e-03,   4.97153036e-03,
         6.74356035e-03,  -3.09963879e-03,  -1.43630262e-03,
         7.27923228e-03,   4.05909514e-05,  -1.00493342e-03,
         6.31427718e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.03457168e-03,
         7.59231502e-03,  -7.82781158e-03,  -5.33257185e-03,
        -2.89583457e-03,   0.00000000e+00,   3.02763736e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.09074418e-03,   0.00000000e+00,
         9.11352273e-03,  -1.35753550e-03,   3.81755890e-04,
        -2.79736960e-03,   6.38006635e-03,   0.00000000e+00,
         1.98568370e-05,   0.00000000e+00,   4.26452783e-03,
         4.89115429e-05,  -2.11023612e-03,   9.82130860e-04,
        -3.59239902e-03,   0.00000000e+00,   3.46538836e-05,
         0.00000000e+00,  -2.05057546e-03,   3.89122026e-03,
        -3.11219853e-03,  -2.26427871e-03,   4.51740418e-03,
        -6.39284513e-05,   0.00000000e+00,  -8.44690006e-04,
         0.00000000e+00,  -2.49887043e-03,  -1.87527433e-03,
        -3.41417988e-03,  -7.19197757e-03,  -3.19452519e-03,
        -1.35673643e-03,  -4.33347479e-03,   0.00000000e+00,
         9.13676015e-03,   0.00000000e+00,  -2.57371124e-03,
        -8.70796833e-04,  -2.28097322e-03,   4.08074390e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.42260343e-04,   0.00000000e+00,
         7.31117407e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.02493664e-02,
         3.53291985e-03,   4.87551358e-04,   5.27502756e-03,
         1.36740043e-03,   0.00000000e+00,   1.33303241e-03,
         0.00000000e+00,  -3.40488485e-03,   3.71390736e-03,
         1.11067405e-03,   3.32810598e-03,   0.00000000e+00,
         7.86095876e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.07943167e-03,
         0.00000000e+00,  -1.29562234e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.53124147e-03,   0.00000000e+00,  -4.26891143e-03,
        -1.54621665e-02,   1.13776403e-02,   7.85911287e-03,
         2.85765400e-05,   0.00000000e+00,   2.22151627e-03,
         0.00000000e+00,  -5.14048928e-04,   1.41191971e-03,
         2.11252070e-05,  -2.64040514e-03,   0.00000000e+00,
        -7.10743345e-04,   0.00000000e+00,  -5.64041745e-03,
        -1.25097800e-03,   8.22689352e-04,   4.11757299e-03,
         2.20862138e-03,   0.00000000e+00,   6.81134057e-03,
         0.00000000e+00,   4.31205617e-03,  -2.04597187e-03,
        -1.21443177e-03,  -1.99694312e-03,   0.00000000e+00,
        -1.93570105e-03,   0.00000000e+00,  -1.49570813e-03,
        -3.97187156e-03,  -9.66245891e-04,  -2.65633380e-03,
        -8.06449874e-03,  -7.42686278e-03,   0.00000000e+00,
        -6.85072190e-04,   0.00000000e+00,   4.54995046e-04,
        -2.41729663e-04,  -2.73634313e-04,   4.19001808e-03,
         0.00000000e+00,   1.00330881e-03,   0.00000000e+00,
         3.50229164e-03,   1.02602518e-03,   7.23421832e-03,
         3.13683036e-03,  -5.32165909e-04,  -6.52879087e-03,
        -9.64743227e-03,   0.00000000e+00,  -1.51899428e-02,
         0.00000000e+00,   2.72184104e-04,   2.99616382e-05,
         2.21987362e-03,   3.42467721e-03,   0.00000000e+00,
        -1.57674035e-03,   0.00000000e+00,   7.96185302e-03,
         4.64435929e-04,  -4.07474633e-03,  -3.33179804e-03,
        -3.72311833e-02,   8.01015565e-03,  -3.13768359e-02,
         6.63723297e-03,  -9.77824938e-03,  -3.39120788e-02,
        -9.26244904e-03,   1.13581876e-02,   2.46085526e-03,
        -3.97120887e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.28170338e-02,
         2.55770392e-03,  -3.73918940e-03,  -8.15534676e-03,
        -5.76303166e-03,   0.00000000e+00,  -3.54105087e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.40446268e-03,   0.00000000e+00,
        -2.94196239e-02,   7.71000971e-03,   6.19592144e-03,
        -6.32551859e-03,   7.76697083e-03,   0.00000000e+00,
        -4.00241413e-03,   0.00000000e+00,  -3.40832151e-02,
         1.15109961e-03,   2.55939262e-03,  -3.63903562e-03,
        -2.39379009e-03,   0.00000000e+00,   5.66977387e-03,
         0.00000000e+00,   3.70158051e-03,  -1.00356805e-02,
         7.11104297e-04,   3.24658356e-03,  -2.85482385e-03,
         2.90241657e-03,   0.00000000e+00,   7.12280852e-03,
         0.00000000e+00,  -3.90747761e-03,  -2.99548290e-03,
        -1.00309601e-02,  -3.79941928e-03,  -1.41441692e-03,
         1.08781452e-02,   8.63596518e-03,   0.00000000e+00,
         7.20686150e-04,   0.00000000e+00,   7.49456906e-03,
         3.19989894e-03,   3.75440353e-03,  -2.50528946e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.14218272e-02,   0.00000000e+00,
        -1.11385626e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.14046180e-02,
        -1.06118820e-02,   2.64831271e-03,  -3.24631392e-03,
        -9.02925530e-03,   0.00000000e+00,   1.23786531e-03,
         0.00000000e+00,   1.29318154e-02,  -5.54813331e-03,
        -2.38460010e-04,   2.43996968e-03,   0.00000000e+00,
        -2.39391131e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.38849880e-02,
         0.00000000e+00,  -1.14095002e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.10576090e-03,   0.00000000e+00,  -4.00744497e-02,
        -2.07713335e-03,   8.22689352e-04,   1.37511989e-02,
         1.83881093e-02,   0.00000000e+00,   2.54960577e-02,
         0.00000000e+00,   2.55370475e-03,  -2.20628933e-03,
        -5.69056465e-03,  -6.42854315e-03,   0.00000000e+00,
         2.72095198e-03,   0.00000000e+00,  -3.71487271e-02,
        -1.64797239e-02,   2.28000338e-02,   2.53989407e-02,
        -3.18718700e-02,   0.00000000e+00,   1.07118478e-02,
         0.00000000e+00,   1.97589442e-02,  -4.69944868e-03,
         1.62439818e-03,   1.72720950e-04,   0.00000000e+00,
        -2.57453934e-03,   0.00000000e+00,  -8.46398789e-04,
        -4.61030837e-02,   1.69957893e-02,   8.15980829e-04,
        -2.01098308e-03,   6.96139711e-03,   0.00000000e+00,
        -1.17992114e-03,   0.00000000e+00,  -1.31091487e-02,
        -1.70861600e-03,  -1.91600580e-03,   3.84394851e-03,
         0.00000000e+00,   8.54283398e-03,   0.00000000e+00,
        -6.56077659e-04,   1.47781478e-03,  -2.91330258e-02,
         2.17070651e-02,  -1.51080714e-02,  -1.08458664e-02,
         1.13466704e-02,   0.00000000e+00,  -2.92701954e-03,
         0.00000000e+00,   8.89707154e-04,  -5.36412695e-04,
         9.74040384e-04,  -1.26161073e-04,   0.00000000e+00,
         2.88556017e-03,   0.00000000e+00,   5.82418646e-04,
         1.35958105e-02,  -5.76262319e-03,  -3.75388648e-02,
         8.56707091e-03,  -4.69794675e-02,  -8.18000244e-02,
        -1.10784036e-02,   1.38452689e-02,  -4.35384107e-02,
        -1.74593684e-04,  -2.35457478e-02,  -1.60708283e-03,
        -1.83331204e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.01821220e-02,
         3.05312644e-03,   1.35458527e-02,   5.32931452e-02,
         3.88012067e-02,   0.00000000e+00,  -3.88300212e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.53171158e-02,   0.00000000e+00,
        -8.96280667e-02,   2.99048103e-02,   2.35672729e-02,
         2.60632470e-02,  -4.12175092e-02,   0.00000000e+00,
         2.47663130e-02,   0.00000000e+00,  -6.50841722e-02,
         3.52971011e-03,   3.58645990e-02,  -3.92272346e-02,
         1.35719749e-02,   0.00000000e+00,   1.15021930e-02,
         0.00000000e+00,   1.23298182e-02,  -3.92231270e-02,
         6.59229363e-03,   1.89225068e-02,  -2.33396127e-02,
        -6.43079128e-03,   0.00000000e+00,   1.57723420e-02,
         0.00000000e+00,  -6.16406348e-03,  -2.70026334e-02,
        -2.61273542e-02,  -5.18972850e-03,  -4.37972187e-03,
         2.91551290e-02,   3.13744744e-02,   0.00000000e+00,
        -6.61132566e-02,   0.00000000e+00,   4.42200131e-02,
         9.19678109e-03,   2.80274875e-02,  -9.88465598e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.01053799e-02,   0.00000000e+00,
        -9.76192221e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.21213493e-01,
        -1.05009964e-03,   1.89039320e-02,  -4.78224544e-02,
         3.19336649e-02,   0.00000000e+00,   9.03188136e-03,
         0.00000000e+00,   5.23110532e-02,  -4.69176898e-02,
        -2.21565355e-02,  -5.83686251e-03,   0.00000000e+00,
        -1.03245490e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.76883978e-02,
         0.00000000e+00,  -1.10787598e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.23912188e-02,   0.00000000e+00,   2.55973716e-02,
        -2.60789212e-03,  -2.65633380e-03,  -2.22226208e-02,
        -1.94547219e-02,   0.00000000e+00,  -2.98782058e-03,
         0.00000000e+00,  -2.69734595e-03,  -3.72361664e-03,
        -1.48639276e-03,   3.28458602e-02,   0.00000000e+00,
        -1.35909443e-02,   0.00000000e+00,   2.03687691e-02,
         1.13216816e-02,   8.15980829e-04,  -3.28013219e-03,
         9.65442583e-03,   0.00000000e+00,  -5.23881442e-03,
         0.00000000e+00,  -3.89100384e-02,   9.99471100e-03,
        -2.55103434e-03,   1.00757184e-02,   0.00000000e+00,
         3.13502917e-02,   0.00000000e+00,   1.76530434e-03,
         1.66357694e-02,   2.11821423e-02,   8.00808850e-02,
        -1.68134472e-03,   8.35349698e-03,   0.00000000e+00,
        -1.06034082e-02,   0.00000000e+00,  -3.33658144e-02,
        -2.57075892e-02,  -2.13584864e-02,  -1.24524297e-03,
         0.00000000e+00,  -1.11697666e-02,   0.00000000e+00,
         7.37489946e-03,  -1.73176411e-02,  -9.19559990e-02,
        -2.78675688e-02,  -1.41652972e-02,   1.62441897e-03,
        -6.85965815e-03,   0.00000000e+00,   1.75729749e-03,
         0.00000000e+00,   3.54655004e-03,   1.01473027e-02,
         4.07682541e-03,   1.07657663e-03,   0.00000000e+00,
        -4.53632556e-03,   0.00000000e+00,  -6.92425132e-03,
         2.86432993e-03,   4.28682034e-02,   1.51996234e-02,
         6.36560822e-02,  -1.59105575e-02,   4.06659114e-02,
        -2.94381925e-03,   8.85458120e-03,   4.71136316e-02,
         3.70728903e-03,  -5.20748064e-03,  -5.44155379e-03,
         6.46756969e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.74888769e-02,
        -2.28752694e-04,  -1.17572463e-03,   1.94470037e-02,
         8.64363602e-03,   0.00000000e+00,   5.36674937e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.34758826e-02,   0.00000000e+00,
         2.44483397e-02,   7.87253799e-03,   2.54128774e-03,
         1.05048900e-02,  -1.22087916e-02,   0.00000000e+00,
         5.42991586e-03,   0.00000000e+00,   5.40201285e-02,
        -7.48315936e-03,  -1.09008282e-02,   6.13921432e-03,
         2.58820599e-04,   0.00000000e+00,  -5.35872338e-03,
         0.00000000e+00,  -1.37066348e-02,   1.48677434e-02,
         1.95444676e-03,  -4.45724485e-03,   3.14038541e-03,
        -7.40454836e-03,   0.00000000e+00,  -7.81689453e-03,
         0.00000000e+00,   3.95624859e-03,   8.47189526e-03,
         1.32296336e-02,   4.25308491e-03,   1.46864649e-05,
        -1.92425991e-02,  -2.00234697e-02,   0.00000000e+00,
         6.82199335e-03,   0.00000000e+00,  -1.40526957e-02,
        -6.38159915e-04,  -5.60986437e-03,   3.54933287e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.94648040e-02,   0.00000000e+00,
         2.54955242e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.63720099e-02,
         9.78879036e-03,  -9.84213900e-03,   1.26458740e-02,
         4.56901753e-03,   0.00000000e+00,   1.64988717e-03,
         0.00000000e+00,  -1.83145833e-02,   1.55545830e-02,
         4.07268958e-03,   3.29157331e-03,   0.00000000e+00,
         4.19184514e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.06215486e-02,
         0.00000000e+00,   2.03491538e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.75793524e-03,   0.00000000e+00,   6.30015940e-02,
         2.91070043e-03,  -5.32165909e-04,  -1.81433336e-02,
        -2.73592791e-02,   0.00000000e+00,  -4.04940347e-02,
         0.00000000e+00,  -1.25192126e-03,   2.14779115e-03,
         9.10271532e-03,   1.17343951e-02,   0.00000000e+00,
        -6.46291559e-03,   0.00000000e+00,   5.92545375e-02,
         5.22140277e-03,  -1.51080714e-02,  -2.59117360e-02,
         3.41070127e-02,   0.00000000e+00,  -1.19403174e-02,
         0.00000000e+00,  -2.26293897e-02,   4.45654571e-03,
        -3.92539394e-03,  -3.45133151e-04,   0.00000000e+00,
         4.13772181e-03,   0.00000000e+00,   1.82602304e-03,
         7.18370753e-02,  -2.76863412e-02,  -1.41652972e-02,
         2.94538852e-03,  -8.11649998e-03,   0.00000000e+00,
         9.96349682e-04,   0.00000000e+00,   6.01886310e-03,
         8.79257806e-03,   5.08959538e-03,   3.25125718e-03,
         0.00000000e+00,  -3.07931049e-04,   0.00000000e+00,
         4.30965475e-04,  -1.68938989e-03,   3.88318015e-02,
        -3.45620052e-02,   2.89574874e-02,   5.39386312e-03,
        -1.64179253e-03,   0.00000000e+00,  -1.63330282e-03,
         0.00000000e+00,  -1.57150905e-02,   3.84200846e-03,
        -5.16887704e-03,  -4.16575873e-03,   0.00000000e+00,
        -8.41335290e-03,   0.00000000e+00,  -5.55776653e-04,
        -3.28024677e-03,   1.78716079e-02,   5.90206383e-02,
         2.30019360e-02,   3.07757477e-02,   4.16547869e-03,
         8.64838902e-02,   1.52323287e-03,   1.99343915e-02,
        -3.73828664e-03,   6.06155623e-03,   9.85502425e-03,
        -1.84236188e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.20950706e-02,
         5.24483613e-02,  -5.13872199e-02,  -3.66506154e-02,
        -1.77074004e-02,   0.00000000e+00,   2.17620957e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.88360546e-02,   0.00000000e+00,
         4.75848305e-02,   1.74813289e-02,  -3.52946619e-02,
        -2.13756795e-02,   2.69487425e-02,   0.00000000e+00,
         7.93309101e-03,   0.00000000e+00,   4.33456575e-02,
        -1.39062426e-03,   8.40122721e-03,   2.27994503e-02,
        -2.07237905e-03,   0.00000000e+00,  -1.51900777e-02,
         0.00000000e+00,  -1.86070364e-02,   2.51398082e-03,
        -1.08324789e-05,  -4.11359766e-03,   2.55853989e-02,
         3.69167781e-03,   0.00000000e+00,  -1.24694021e-02,
         0.00000000e+00,  -4.00553163e-03,   4.53125016e-03,
        -1.42839196e-02,  -3.86327352e-03,   2.26769823e-03,
         3.78381485e-03,  -2.60884407e-03,   0.00000000e+00,
         1.82005704e-02,   0.00000000e+00,  -9.99059678e-03,
         5.62670327e-03,  -7.70650542e-03,   4.62812766e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.60710634e-03,   0.00000000e+00,
         1.80946097e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.00033593e-02,
        -2.12120444e-04,   3.85308200e-03,   2.62245515e-03,
        -4.68264054e-03,   0.00000000e+00,  -1.85779148e-03,
         0.00000000e+00,  -1.99593628e-02,   3.03481562e-03,
        -3.04063596e-03,  -1.39853147e-02,   0.00000000e+00,
         5.22902229e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.89228570e-03,
         0.00000000e+00,   3.39917294e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.06631709e-02,   0.00000000e+00,  -1.38938528e-02,
        -7.86888058e-03,   6.74356035e-03,   7.11342573e-03,
         3.61967241e-03,   0.00000000e+00,   4.21078181e-03,
         0.00000000e+00,  -9.03797046e-03,   5.23745583e-03,
        -3.80221297e-04,  -1.99166462e-02,   0.00000000e+00,
         2.89012170e-05,   0.00000000e+00,  -1.53830579e-02,
        -9.79017224e-03,   6.63723297e-03,   8.11635610e-03,
        -4.24196237e-03,   0.00000000e+00,   6.52380796e-03,
         0.00000000e+00,   9.85366113e-04,   1.90753860e-03,
        -1.49870035e-03,  -2.91337689e-03,   0.00000000e+00,
        -3.39908330e-02,   0.00000000e+00,  -1.21287741e-02,
        -2.82034223e-02,  -3.93431791e-04,  -1.10784036e-02,
        -9.28583143e-03,  -5.20302996e-03,   0.00000000e+00,
        -8.54418949e-05,   0.00000000e+00,   8.47418214e-03,
         2.46864138e-03,  -1.88052959e-03,   2.46390135e-02,
         0.00000000e+00,  -2.63486528e-02,   0.00000000e+00,
         1.14889949e-02,   3.73403619e-02,   3.52552767e-02,
         9.27846927e-03,  -2.94381925e-03,  -7.13228885e-03,
         5.34155442e-03,   0.00000000e+00,  -7.46690218e-03,
         0.00000000e+00,  -1.77924390e-02,   2.18849111e-03,
         2.19795164e-03,   8.38911809e-03,   0.00000000e+00,
         9.00892329e-03,   0.00000000e+00,   5.95181227e-02,
         4.04633355e-02,  -8.72344460e-03,   1.46117468e-02,
         7.11380945e-02,  -6.01334335e-02,  -6.10150291e-02,
         1.52323287e-03,   1.03104994e-01,   2.22415992e-02,
         5.80827097e-03,  -3.20900803e-02,   6.09126705e-03,
         6.25942788e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.15730204e-02,
        -3.42262379e-02,  -2.40714612e-02,   5.67072801e-02,
         1.78818912e-02,   0.00000000e+00,   4.47737604e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.75887564e-02,   0.00000000e+00,
        -2.68189863e-02,  -3.08477181e-03,  -3.27841621e-03,
         2.53398361e-02,  -5.04283579e-02,   0.00000000e+00,
         2.85225682e-02,   0.00000000e+00,   7.07166643e-03,
         8.77301453e-03,   2.29859373e-02,   4.97213101e-03,
         1.67599080e-02,   0.00000000e+00,  -2.08082246e-02,
         0.00000000e+00,  -2.68087538e-02,  -7.27618912e-02,
         4.11265730e-03,  -1.49419790e-02,   3.62888421e-02,
        -6.83079577e-03,   0.00000000e+00,  -3.70520489e-02,
         0.00000000e+00,  -1.23750329e-02,  -3.03731770e-02,
        -1.30034121e-01,   3.20825820e-03,  -1.12141630e-02,
        -6.56818765e-04,  -7.98857697e-03,   0.00000000e+00,
        -1.52047901e-02,   0.00000000e+00,   6.32319530e-03,
         8.39380529e-03,   3.94628577e-03,  -9.85505306e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.32827895e-03,   0.00000000e+00,
        -1.21986963e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.71038923e-02,
         6.16120907e-03,   9.22030223e-03,  -7.54446706e-03,
         5.54820313e-03,   0.00000000e+00,   4.14340703e-03,
         0.00000000e+00,  -1.11800472e-02,  -2.11648580e-02,
        -1.44562884e-02,  -1.60588416e-02,   0.00000000e+00,
        -2.81363808e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.73326360e-02,
         0.00000000e+00,   1.21088914e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.78418471e-02,   0.00000000e+00,   8.02519125e-02,
         9.69899959e-03,  -3.09963879e-03,  -1.49378010e-02,
        -1.80322410e-02,   0.00000000e+00,  -1.46963669e-02,
         0.00000000e+00,  -3.29728304e-03,  -1.83892451e-03,
         2.24877294e-02,   2.30438148e-02,   0.00000000e+00,
        -6.00848407e-03,   0.00000000e+00,   7.91962410e-02,
         8.17019405e-03,  -9.77824938e-03,  -1.45337470e-02,
         1.56494101e-02,   0.00000000e+00,  -3.94080507e-03,
         0.00000000e+00,  -2.14822371e-02,   4.42441222e-03,
        -9.90980302e-03,   1.59307476e-02,   0.00000000e+00,
         2.04677024e-02,   0.00000000e+00,   1.17639076e-02,
         1.00390219e-01,  -8.20210438e-03,   1.38452689e-02,
        -6.89949628e-03,   2.82520867e-03,   0.00000000e+00,
         1.10264907e-02,   0.00000000e+00,  -5.52753719e-03,
        -1.08660714e-02,  -1.49411745e-02,   2.81557499e-02,
         0.00000000e+00,  -6.22675358e-02,   0.00000000e+00,
        -1.38137810e-02,  -1.36896737e-02,  -3.51927863e-02,
        -1.88014337e-02,   8.85458120e-03,   1.28316188e-02,
        -7.93662959e-03,   0.00000000e+00,   9.55938810e-03,
         0.00000000e+00,  -1.20461857e-02,   7.33103574e-03,
        -8.59832070e-03,  -2.24572163e-02,   0.00000000e+00,
         3.35364613e-03,   0.00000000e+00,  -9.58999314e-03,
        -2.01240508e-02,   4.33643035e-02,   6.15467364e-02,
         5.82306996e-01,   2.15632391e-03,   5.57646178e-01,
         1.99343915e-02,   2.22415992e-02,   5.88584393e-01,
        -1.96042271e-02,  -3.37435681e-03,  -1.71196456e-03,
         5.47671702e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.49077892e-01,
        -2.07440632e-03,   3.41241617e-03,   7.95135875e-03,
         9.47353748e-05,   0.00000000e+00,   5.77748847e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.24662430e-03,   0.00000000e+00,
         5.31536595e-01,  -1.44134146e-03,  -4.37553275e-02,
         5.65535261e-03,  -1.07788410e-02,   0.00000000e+00,
         1.95287735e-02,   0.00000000e+00,   5.67010527e-01,
        -1.34846256e-02,  -3.05126616e-02,   5.46925472e-02,
        -2.13417191e-04,   0.00000000e+00,  -3.80524068e-02,
         0.00000000e+00,  -6.50461991e-02,   3.85920018e-01,
         1.00297861e-02,   2.98132189e-03,   1.03913715e-02,
        -7.00936576e-04,   0.00000000e+00,  -2.63132477e-02,
         0.00000000e+00,   3.18046805e-02,   8.17410323e-02,
         4.46232194e-01,   7.97539410e-03,  -1.22413943e-02,
        -5.33178500e-02,  -5.18671866e-02,   0.00000000e+00,
         4.55883326e-02,   0.00000000e+00,  -5.04547907e-02,
        -1.72574653e-02,  -1.51956622e-02,   5.26588091e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.99194125e-02,   0.00000000e+00,
         9.37586445e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.36676599e-01,
         1.82197860e-02,  -2.43744838e-02,   4.18977048e-02,
        -5.91557667e-03,   0.00000000e+00,  -4.61883814e-03,
         0.00000000e+00,  -7.03306122e-02,   5.98342598e-02,
         1.95199032e-02,  -1.93855870e-02,   0.00000000e+00,
         5.33799605e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.65139290e-02,
         0.00000000e+00,   4.78489216e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.74394352e-03,   0.00000000e+00,   5.14167521e-01,
         1.10955619e-02,  -1.43630262e-03,  -2.51089927e-02,
        -4.50918087e-02,   0.00000000e+00,  -8.44454896e-02,
         0.00000000e+00,  -8.31925599e-03,   3.47708609e-03,
         2.19613366e-02,   1.24675556e-02,   0.00000000e+00,
         1.46266841e-04,   0.00000000e+00,   5.24983710e-01,
         1.43607870e-02,  -3.39120788e-02,  -5.42278142e-02,
         6.08529605e-02,   0.00000000e+00,  -2.13493084e-02,
         0.00000000e+00,  -3.66364093e-02,   1.26706144e-02,
        -9.08691466e-03,   7.72301683e-04,   0.00000000e+00,
        -2.37726727e-02,   0.00000000e+00,   1.53028954e-02,
         5.42520862e-01,  -5.28538993e-02,  -4.35384107e-02,
        -5.10173614e-03,  -2.61332410e-02,   0.00000000e+00,
         2.37037217e-02,   0.00000000e+00,   2.82408727e-02,
         4.78186054e-02,   3.59924893e-03,  -1.72003581e-03,
         0.00000000e+00,  -3.22323486e-02,   0.00000000e+00,
        -6.97495309e-03,   2.81695007e-02,   5.41020372e-01,
        -5.02331868e-02,   4.71136316e-02,   1.86604849e-02,
        -2.28419585e-03,   0.00000000e+00,  -1.64777113e-03,
         0.00000000e+00,  -3.27553008e-02,   2.75930048e-03,
        -9.08220932e-03,  -8.65962401e-03,   0.00000000e+00,
        -6.27145017e-03,   0.00000000e+00,  -2.74551905e-03,
         8.79883432e-03,   1.02305981e-02,   5.51737467e-01,
        -7.83386067e-03,   6.49940646e-03,  -8.79813259e-03,
         9.85502425e-03,   6.09126705e-03,  -1.71196456e-03,
        -1.09380222e-02,   1.60736528e-02,   2.60875949e-02,
        -1.04301010e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.31112035e-02,
        -5.67464061e-03,  -1.50681420e-02,  -1.27018310e-02,
         1.74000122e-04,   0.00000000e+00,   2.03680317e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.39457690e-03,   0.00000000e+00,
         8.85279147e-03,   8.20486281e-03,  -9.74137820e-03,
        -8.09012709e-03,   1.33989116e-02,   0.00000000e+00,
        -8.43264452e-03,   0.00000000e+00,  -1.04080255e-02,
         6.84575910e-04,   5.21914799e-03,   6.84935107e-03,
        -6.77910415e-04,   0.00000000e+00,  -3.88337923e-03,
         0.00000000e+00,   9.62578753e-05,  -4.66308337e-03,
         1.29049254e-03,  -1.47587236e-03,   8.31013719e-03,
         2.88330051e-03,   0.00000000e+00,  -9.33200349e-03,
         0.00000000e+00,  -2.65240505e-03,  -1.68912810e-03,
        -1.14361437e-02,   1.98697806e-04,  -4.74680902e-03,
        -3.19606016e-03,  -2.44994032e-03,   0.00000000e+00,
         4.93393069e-03,   0.00000000e+00,  -3.95985814e-04,
        -1.19810552e-04,  -2.76082664e-03,   2.53280553e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.66360815e-03,   0.00000000e+00,
         4.43039878e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.84504117e-03,
        -8.51417112e-04,  -2.45705962e-04,  -8.50587796e-04,
        -1.86634448e-03,   0.00000000e+00,  -1.09094991e-04,
         0.00000000e+00,   5.71636431e-05,  -3.43231473e-03,
        -1.59928506e-03,  -7.04547111e-03,   0.00000000e+00,
         5.73569639e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.77165358e-03,
         0.00000000e+00,  -1.20178971e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.69232003e-03,   0.00000000e+00,  -1.12193363e-02,
         1.25518749e-03,  -1.00493342e-03,  -7.98198740e-04,
        -1.04424935e-03,   0.00000000e+00,   2.44390793e-04,
         0.00000000e+00,   3.62315858e-05,  -1.01623707e-03,
         3.30879788e-03,  -5.94544387e-03,   0.00000000e+00,
         1.01781319e-03,   0.00000000e+00,   1.02281496e-02,
        -2.66414075e-03,   2.46085526e-03,   4.39699051e-03,
        -7.62325937e-03,   0.00000000e+00,   3.52567468e-03,
         0.00000000e+00,   6.49466775e-03,  -9.80168575e-04,
         1.99345492e-04,  -1.14907905e-03,   0.00000000e+00,
        -1.10214115e-02,   0.00000000e+00,  -1.05651704e-03,
        -3.68763443e-02,  -8.54573231e-04,  -1.60708283e-03,
        -2.69383510e-03,  -5.70298254e-04,   0.00000000e+00,
         4.63643178e-03,   0.00000000e+00,   2.87441033e-04,
        -5.48508970e-04,  -2.88477128e-03,   1.22279066e-02,
         0.00000000e+00,  -4.43967223e-03,   0.00000000e+00,
        -5.24834836e-03,   1.03026476e-02,   5.58974659e-04,
         5.24577946e-03,  -5.44155379e-03,  -2.46015166e-03,
         3.78073273e-03,   0.00000000e+00,  -1.36897458e-04,
         0.00000000e+00,  -1.12222841e-04,  -8.07167811e-04,
        -1.50817817e-03,  -5.45093095e-03,   0.00000000e+00,
         6.23558551e-03,   0.00000000e+00,  -1.18140487e-03,
         9.44628785e-03,  -5.87551992e-03,  -1.40559619e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.38806665e-02,   1.35562843e-02,
         2.25056839e-02,  -2.81837889e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.77464421e-02,   0.00000000e+00,
         7.89545074e-03,   7.63191668e-04,   6.27640470e-04,
         1.52797557e-03,   0.00000000e+00,  -8.51135033e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.50143048e-03,
         0.00000000e+00,  -5.88805725e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.12209537e-03,   0.00000000e+00,
         2.34779023e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.25221608e-04,   0.00000000e+00,
         9.10668454e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.81477789e-03,
         0.00000000e+00,   8.24982998e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.95992678e-03,   2.72999464e-03,   2.57064974e-03,
        -1.82589398e-04,   0.00000000e+00,   8.18614025e-04,
         0.00000000e+00,  -1.03121473e-05,   1.14063102e-04,
         1.24249523e-04,  -4.68696244e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.56395074e-03,   0.00000000e+00,
        -3.65685663e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.43956731e-03,
         0.00000000e+00,   4.29767901e-03,  -2.32188011e-03,
        -3.96276788e-03,   2.95022294e-04,   0.00000000e+00,
        -4.55960343e-03,   0.00000000e+00,  -3.00679485e-03,
         4.38967325e-04,   1.65426429e-03,   4.66243660e-03,
         0.00000000e+00,   2.62447358e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.42452346e-03,   0.00000000e+00,
         1.39035379e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.16205008e-03,
         0.00000000e+00,   1.63611816e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.90021674e-03,   0.00000000e+00,
         1.75778502e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.97664932e-03,
         0.00000000e+00,   1.84428715e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.19312189e-03,
         0.00000000e+00,  -1.41005339e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.74728571e-03,   0.00000000e+00,  -5.63319189e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.57509492e-03,   0.00000000e+00,
        -1.67929473e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.58795097e-03,
         0.00000000e+00,  -1.11196479e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.54830710e-01,  -1.22748473e-01,  -7.37399657e-02,
        -3.66506154e-02,   5.67072801e-02,   7.95135875e-03,
        -5.79678166e-04,  -6.84251668e-02,  -1.27018310e-02,
         1.15898687e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.94249440e-01,
        -4.25181665e-04,   4.33623841e-02,   1.77589019e-01,
         1.04433159e-01,   0.00000000e+00,   2.71332589e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.29799930e-02,   0.00000000e+00,
        -1.16924995e-01,   4.98720444e-02,   1.66259172e-02,
         8.37805910e-02,  -1.02332117e-01,   0.00000000e+00,
         5.96945551e-02,   0.00000000e+00,  -1.00737293e-02,
        -1.28868386e-02,   1.55203929e-02,  -4.30069072e-02,
         2.05371961e-02,   0.00000000e+00,  -2.26276221e-03,
         0.00000000e+00,  -1.12776953e-02,  -7.56804250e-02,
         3.77406589e-03,  -1.20112885e-02,  -9.15786373e-03,
        -2.28084121e-02,   0.00000000e+00,  -7.00148029e-03,
         0.00000000e+00,   2.07032422e-03,  -4.20758098e-02,
        -1.08651629e-01,   6.23830154e-03,   1.14088464e-04,
         1.17546399e-02,   4.81923490e-03,   0.00000000e+00,
        -7.32642240e-02,   0.00000000e+00,   1.91294614e-02,
         6.75055850e-03,   3.07287587e-02,  -1.23136770e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.65286311e-02,   0.00000000e+00,
        -6.80780608e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.23980608e-01,
         4.67928704e-03,  -4.15983491e-03,  -2.80297268e-02,
         2.84042790e-02,   0.00000000e+00,   1.91734938e-02,
         0.00000000e+00,   2.60792896e-02,  -3.52754296e-02,
        -1.73041399e-02,  -2.29082069e-03,   0.00000000e+00,
        -1.07967258e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.69037819e-02,
         0.00000000e+00,   1.94579656e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.26901489e-02,   0.00000000e+00,   1.70127403e-01,
         2.13402707e-03,  -5.33257185e-03,  -4.31122152e-02,
        -4.57572041e-02,   0.00000000e+00,  -5.15273362e-02,
         0.00000000e+00,  -4.65931375e-03,  -6.19248702e-04,
         2.75473434e-02,   9.39980836e-02,   0.00000000e+00,
        -3.76727482e-02,   0.00000000e+00,   1.71055070e-01,
         7.22812134e-03,  -8.15534676e-03,  -2.65795711e-02,
         4.05883888e-02,   0.00000000e+00,  -2.57375711e-02,
         0.00000000e+00,  -6.83892457e-02,   1.89881196e-02,
        -1.12223172e-02,   1.73303423e-02,   0.00000000e+00,
         6.24013183e-02,   0.00000000e+00,   2.43901592e-02,
         1.83149836e-01,  -1.43895644e-02,   5.32931452e-02,
         1.24409203e-02,   6.20937054e-03,   0.00000000e+00,
        -1.74675357e-02,   0.00000000e+00,  -4.23745863e-02,
        -3.88808975e-03,  -7.10023355e-03,  -2.58855437e-02,
         0.00000000e+00,  -3.16397352e-02,   0.00000000e+00,
         1.48026436e-02,  -3.62494010e-02,  -8.10267739e-02,
        -5.97767656e-02,   1.94470037e-02,   8.03662884e-03,
        -5.44886433e-03,   0.00000000e+00,   9.58668126e-04,
         0.00000000e+00,  -2.84390814e-02,   2.01161629e-02,
        -1.18655944e-02,  -2.21594342e-03,   0.00000000e+00,
        -2.93789620e-02,   0.00000000e+00,  -2.46755184e-02,
        -8.14291215e-03,   1.06553602e-01,   1.44588148e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.31516790e-02,  -2.98221760e-03,
         6.27640470e-04,   9.99842670e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.42052839e-03,   0.00000000e+00,
         5.43762331e-03,   1.06533225e-02,   2.24946263e-02,
         3.08699882e-03,   0.00000000e+00,  -1.59627024e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.06762843e-03,
         0.00000000e+00,  -1.03752906e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.94515092e-03,   0.00000000e+00,
         8.08384851e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.17455867e-03,   0.00000000e+00,
         4.08563109e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.19481109e-04,
         0.00000000e+00,  -2.80457298e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.01959138e-03,   3.37148895e-03,   4.53566746e-03,
         1.84958170e-03,   0.00000000e+00,  -6.88394026e-03,
         0.00000000e+00,  -4.43554313e-03,   3.96946536e-03,
         3.90067701e-03,  -1.35702364e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.12200322e-04,   0.00000000e+00,
         1.05573033e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.70622595e-02,
         0.00000000e+00,   1.72751550e-03,   2.00435421e-03,
         2.98317231e-03,  -5.86296446e-04,   0.00000000e+00,
         1.86081877e-03,   0.00000000e+00,  -1.13550106e-03,
         1.44526402e-03,   1.33872777e-04,  -4.58971201e-03,
         0.00000000e+00,   1.12788225e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.85807154e-03,   0.00000000e+00,
        -1.26077773e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.91304172e-03,
         0.00000000e+00,  -9.56155075e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.80600480e-03,   0.00000000e+00,
        -2.02260864e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.08448289e-03,
         0.00000000e+00,  -4.22847833e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.81729845e-04,
         0.00000000e+00,  -1.69205464e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.27102564e-02,   0.00000000e+00,   2.17471971e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.51253271e-04,   0.00000000e+00,
        -2.12077762e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.85062749e-03,
         0.00000000e+00,   1.02894862e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.25136433e-02,  -6.78164564e-02,  -2.89186757e-02,
        -2.13756795e-02,   2.53398361e-02,   5.65535261e-03,
         1.77264732e-02,  -4.21798028e-02,  -8.09012709e-03,
         7.30489710e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.08259655e-01,
         1.03384793e-02,   1.79804463e-02,   8.37805910e-02,
         4.12255502e-02,   0.00000000e+00,   2.88423920e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.07572504e-02,   0.00000000e+00,
        -5.87440977e-02,   2.92915847e-02,   1.51129615e-02,
         6.89038485e-02,  -6.01189978e-02,   0.00000000e+00,
         2.74524430e-02,   0.00000000e+00,  -7.15240282e-03,
        -1.05686706e-02,   1.57550447e-03,  -2.39606110e-02,
         1.36423507e-02,   0.00000000e+00,  -5.93145040e-03,
         0.00000000e+00,  -3.70096527e-03,  -4.56605354e-02,
         1.35422837e-04,  -6.10496788e-03,  -2.50003107e-03,
        -1.04218875e-02,   0.00000000e+00,  -6.67055153e-03,
         0.00000000e+00,   5.60587201e-03,  -1.97599982e-02,
        -5.85655569e-02,  -1.86898292e-04,   5.74311913e-04,
         1.86884557e-03,  -3.39501403e-04,   0.00000000e+00,
        -3.21486664e-02,   0.00000000e+00,   7.41952167e-03,
         8.99251141e-05,   1.08517290e-02,  -4.29304023e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.12336397e-02,   0.00000000e+00,
        -3.42060809e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.25529617e-02,
        -1.11566475e-03,  -1.18044970e-02,  -1.65384538e-02,
         1.76086479e-02,   0.00000000e+00,   1.25667557e-02,
         0.00000000e+00,   2.18155878e-02,  -2.02859849e-02,
        -8.96162687e-03,  -4.75370570e-03,   0.00000000e+00,
        -6.81577579e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.64657366e-02,
         0.00000000e+00,   1.04839987e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.86022423e-02,   0.00000000e+00,   9.63733281e-02,
        -5.06168079e-03,  -2.79736960e-03,  -2.47711344e-02,
        -2.46722580e-02,   0.00000000e+00,  -2.78799503e-02,
         0.00000000e+00,  -3.82512091e-03,   2.75341537e-04,
         1.42098521e-02,   4.05347619e-02,   0.00000000e+00,
        -2.19296098e-02,   0.00000000e+00,   8.86185242e-02,
         2.90955872e-04,  -6.32551859e-03,  -1.75803661e-02,
         2.78978761e-02,   0.00000000e+00,  -1.75829229e-02,
         0.00000000e+00,  -4.27466825e-02,   1.24888231e-02,
        -6.66112789e-03,   9.86984664e-03,   0.00000000e+00,
         4.35338234e-02,   0.00000000e+00,   1.23854843e-02,
         1.16762760e-01,  -9.61300561e-03,   2.60632470e-02,
         7.32174690e-03,  -3.13479360e-04,   0.00000000e+00,
        -1.25067985e-02,   0.00000000e+00,  -2.88932404e-02,
         5.47086094e-03,  -7.63217962e-04,  -1.00202679e-02,
         0.00000000e+00,  -1.05346102e-02,   0.00000000e+00,
         1.20195656e-02,  -2.66071206e-02,  -3.83947289e-02,
        -4.11548244e-02,   1.05048900e-02,   9.16150585e-04,
        -2.82870366e-03,   0.00000000e+00,  -4.28206122e-03,
         0.00000000e+00,  -1.49514990e-02,   8.72779692e-03,
        -6.12824266e-03,   6.09583901e-04,   0.00000000e+00,
        -2.18791503e-02,   0.00000000e+00,   1.64015034e-04,
        -6.95912632e-03,   5.73283493e-02,   7.97830880e-02,
         1.77900543e-02,   3.50780842e-02,   7.01852940e-02,
         2.27994503e-02,   4.97213101e-03,   5.46925472e-02,
        -2.07995255e-03,   2.08726835e-02,   6.84935107e-03,
         2.17116259e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.47815144e-04,
        -4.47464269e-03,  -2.60012209e-02,  -4.30069072e-02,
        -3.07890683e-02,   0.00000000e+00,   5.19805159e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.10214585e-02,   0.00000000e+00,
         9.28445119e-02,  -1.95683843e-02,  -2.20089590e-02,
        -2.39606110e-02,   3.05494908e-02,   0.00000000e+00,
        -1.78053422e-02,   0.00000000e+00,   6.18550664e-02,
        -2.28203508e-03,  -3.11776739e-02,   5.19727708e-02,
        -1.00714273e-02,   0.00000000e+00,  -2.29576104e-02,
         0.00000000e+00,  -2.92479169e-02,   2.41886506e-03,
        -4.99169563e-03,  -2.55494277e-02,   3.78912662e-02,
         1.13204935e-03,   0.00000000e+00,  -2.53976318e-02,
         0.00000000e+00,  -5.12017415e-03,   1.48984076e-02,
        -1.98479845e-02,   4.88433180e-03,   2.42777039e-03,
        -1.48096209e-02,  -1.62535825e-02,   0.00000000e+00,
         3.55693584e-02,   0.00000000e+00,  -2.30034789e-02,
        -4.42948190e-03,  -1.96765653e-02,   9.28165878e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.37888840e-03,   0.00000000e+00,
         5.22135219e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.00783019e-01,
        -4.54214307e-04,  -1.29820295e-02,   2.52527290e-02,
        -1.75114374e-02,   0.00000000e+00,  -7.97151161e-03,
         0.00000000e+00,  -3.17243810e-02,   3.15792254e-02,
         8.05389333e-03,  -7.95410355e-03,   0.00000000e+00,
         1.00027303e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.06106935e-02,
         0.00000000e+00,   6.40082179e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.08564480e-02,   0.00000000e+00,   1.12453483e-03,
         5.57605866e-03,   9.82130860e-04,   8.06306451e-03,
         5.86626180e-03,   0.00000000e+00,   1.55015729e-03,
         0.00000000e+00,   1.03288756e-03,   1.88893602e-03,
         7.53472143e-03,  -2.64334345e-02,   0.00000000e+00,
         1.22456964e-02,   0.00000000e+00,   4.48519544e-03,
        -1.93378171e-04,  -3.63903562e-03,   4.75812533e-04,
        -2.03013057e-03,   0.00000000e+00,   4.53238565e-03,
         0.00000000e+00,   1.94617574e-02,  -5.19868177e-03,
        -1.96697900e-03,  -4.22269186e-03,   0.00000000e+00,
        -2.87543328e-02,   0.00000000e+00,  -3.40836281e-03,
         3.90575913e-05,  -1.03441208e-02,  -3.92272346e-02,
         8.29786141e-04,  -5.63787738e-03,   0.00000000e+00,
         9.42326579e-03,   0.00000000e+00,   2.54192925e-02,
         2.56405608e-02,   8.15168624e-03,   1.45284120e-02,
         0.00000000e+00,  -2.26162800e-03,   0.00000000e+00,
        -7.71481005e-03,   1.76505443e-02,   7.94739328e-02,
         1.34253034e-02,   6.13921432e-03,   2.30998781e-03,
         2.64645452e-03,   0.00000000e+00,   3.64669968e-03,
         0.00000000e+00,  -1.09646106e-03,  -1.01523369e-02,
        -6.09250655e-03,  -5.86578910e-03,   0.00000000e+00,
         7.65501059e-03,   0.00000000e+00,   1.19427049e-02,
         2.09163382e-03,  -2.90277778e-02,   1.29482345e-02,
         1.33312030e-02,   5.53002212e-03,   8.94049719e-04,
         2.55853989e-02,   3.62888421e-02,   1.03913715e-02,
         2.61161484e-03,   3.75397905e-03,   8.31013719e-03,
         1.50917711e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.49407111e-03,
        -4.04712480e-03,  -3.61816781e-02,  -9.15786373e-03,
        -1.87644047e-02,   0.00000000e+00,   2.45921230e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.51581481e-03,   0.00000000e+00,
         3.86495255e-02,  -8.13977196e-03,  -1.67609132e-02,
        -2.50003107e-03,   7.86318855e-03,   0.00000000e+00,
        -6.60922163e-03,   0.00000000e+00,   2.54652882e-02,
        -1.58715872e-03,  -1.89001965e-02,   3.78912662e-02,
        -3.45442072e-03,   0.00000000e+00,  -2.35575327e-02,
         0.00000000e+00,  -2.52444780e-02,  -2.95748935e-02,
        -9.63855134e-03,  -4.56663499e-02,   6.06259351e-02,
        -4.35542008e-03,   0.00000000e+00,  -4.15779537e-02,
         0.00000000e+00,  -1.74092782e-02,  -2.30481682e-02,
        -1.20390237e-01,   1.12452216e-03,  -1.48154453e-03,
        -7.31605518e-03,  -1.11352928e-02,   0.00000000e+00,
         2.10597224e-02,   0.00000000e+00,  -1.34808474e-02,
        -1.78890823e-03,  -1.67725137e-02,   4.74138756e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.19367765e-03,   0.00000000e+00,
         2.88445637e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.66123389e-02,
        -5.30419130e-04,  -8.37277786e-03,   1.47568135e-02,
        -9.40500244e-03,   0.00000000e+00,  -4.97686653e-03,
         0.00000000e+00,  -2.03092354e-02,   1.18933940e-02,
        -2.33190190e-03,  -8.49706690e-03,   0.00000000e+00,
         4.32456075e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.59737586e-03,
         0.00000000e+00,   5.39939688e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.60470919e-03,   0.00000000e+00,   5.85750119e-03,
         1.51035550e-03,   4.51740418e-03,   2.34498819e-03,
         3.90218080e-03,   0.00000000e+00,   3.83646663e-03,
         0.00000000e+00,   2.32596146e-04,   4.08303749e-03,
         1.69955620e-02,  -1.30803294e-02,   0.00000000e+00,
         5.24163348e-03,   0.00000000e+00,   5.18274855e-03,
        -1.74902646e-03,  -2.85482385e-03,   4.11383661e-04,
         5.35912281e-04,   0.00000000e+00,   2.24967536e-03,
         0.00000000e+00,   6.55704346e-03,  -3.14401038e-03,
        -6.73911249e-03,  -9.68515927e-05,   0.00000000e+00,
        -1.36564392e-02,   0.00000000e+00,  -1.03289819e-03,
         8.92087768e-03,  -7.37500535e-03,  -2.33396127e-02,
        -8.92498550e-04,  -3.70393770e-03,   0.00000000e+00,
         5.42803933e-03,   0.00000000e+00,   1.22979741e-02,
         1.35743990e-02,   2.43756041e-03,   1.92640354e-02,
         0.00000000e+00,  -1.42072103e-02,   0.00000000e+00,
        -5.42519097e-03,   9.46119071e-03,   2.82425646e-02,
         6.17916903e-03,   3.14038541e-03,   1.50128326e-03,
        -4.24829421e-04,   0.00000000e+00,  -2.45891978e-04,
         0.00000000e+00,  -5.65607792e-03,  -6.01098488e-03,
        -9.70037684e-03,  -7.64231372e-03,   0.00000000e+00,
         4.53037605e-03,   0.00000000e+00,   1.39687505e-02,
         1.40999558e-03,  -6.96019909e-03,   9.55537044e-03,
        -4.01342008e-02,  -7.10121265e-03,  -6.02699301e-02,
         3.78381485e-03,  -6.56818765e-04,  -5.33178500e-02,
         3.90975465e-03,  -9.63076757e-03,  -3.19606016e-03,
        -4.26588274e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.67520358e-02,
         8.38841104e-03,   2.72371507e-03,   1.17546399e-02,
         9.18244870e-03,   0.00000000e+00,  -6.11558130e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.51283433e-03,   0.00000000e+00,
        -5.69201867e-02,   2.85746109e-03,   6.70313744e-03,
         1.86884557e-03,  -5.71725790e-03,   0.00000000e+00,
         5.00704955e-03,   0.00000000e+00,  -5.56060211e-02,
         5.74308875e-03,   1.52117609e-02,  -1.48096209e-02,
         2.36819972e-03,   0.00000000e+00,   8.24501848e-03,
         0.00000000e+00,   9.09298207e-03,  -2.82030659e-02,
        -3.74450129e-04,   5.17414287e-03,  -7.31605518e-03,
         1.14892814e-04,   0.00000000e+00,   1.17186211e-02,
         0.00000000e+00,  -5.77781669e-03,  -1.52005524e-02,
        -3.32418043e-02,   1.58389848e-04,   7.11697392e-03,
         3.66916112e-02,   2.74789552e-02,   0.00000000e+00,
        -3.73039357e-02,   0.00000000e+00,   2.03350147e-02,
         1.07286488e-02,   1.71582865e-02,  -6.52502504e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.44641720e-02,   0.00000000e+00,
        -4.51968637e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.10699259e-02,
        -8.84559356e-03,   6.27805041e-03,  -2.73361038e-02,
         1.97018063e-03,   0.00000000e+00,   8.64856851e-03,
         0.00000000e+00,   2.32135651e-02,  -2.67059991e-02,
        -1.26563960e-02,  -2.43118852e-03,   0.00000000e+00,
        -5.68082851e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.11353201e-02,
         0.00000000e+00,  -1.43929690e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.11430994e-03,   0.00000000e+00,  -3.50466271e-02,
        -4.30195816e-03,  -1.35673643e-03,   4.07309082e-03,
         9.29719176e-03,   0.00000000e+00,   3.26857386e-02,
         0.00000000e+00,   3.88691658e-04,  -4.38686482e-03,
        -7.10272327e-03,   3.52122227e-03,   0.00000000e+00,
        -2.43971954e-03,   0.00000000e+00,  -3.57791868e-02,
         1.56307925e-03,   1.08781452e-02,   1.90715919e-02,
        -1.46811377e-02,   0.00000000e+00,   6.32279845e-03,
         0.00000000e+00,   2.87811198e-03,   9.26268322e-04,
         1.90056942e-03,   2.51703657e-03,   0.00000000e+00,
         7.28531645e-03,   0.00000000e+00,  -2.06430748e-03,
        -3.77195818e-02,   2.27952699e-02,   2.91551290e-02,
         5.67639895e-03,   9.65671356e-03,   0.00000000e+00,
        -1.19591597e-02,   0.00000000e+00,  -1.25949480e-02,
        -8.71386077e-03,  -3.24947668e-03,  -3.25968994e-03,
         0.00000000e+00,  -5.32423573e-03,   0.00000000e+00,
         5.02188253e-03,  -5.91489817e-03,  -6.16032026e-02,
         1.36280634e-02,  -1.92425991e-02,  -4.59773020e-03,
        -3.19949399e-03,   0.00000000e+00,   4.80801252e-03,
         0.00000000e+00,   9.09650101e-03,  -1.11608806e-03,
         2.04624842e-03,   4.51051444e-03,   0.00000000e+00,
         2.08476187e-03,   0.00000000e+00,   7.06467361e-03,
         1.88336984e-03,   5.95293846e-03,  -3.68427902e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.14274219e-03,   3.75114885e-03,
         2.57064974e-03,  -4.30538162e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.54461851e-04,   0.00000000e+00,
         3.46805073e-03,   3.30517647e-03,   4.53566746e-03,
         1.81794886e-03,   0.00000000e+00,  -5.99502195e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.82086744e-04,
         0.00000000e+00,  -3.09041835e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.37377391e-04,   0.00000000e+00,
         3.80921935e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.27869614e-05,   0.00000000e+00,
         2.21378002e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.64977960e-03,
         0.00000000e+00,  -7.90718314e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.74842708e-03,   2.80240358e-03,   1.20138700e-02,
         1.25380168e-03,   0.00000000e+00,  -7.87146666e-03,
         0.00000000e+00,  -5.00683087e-03,   4.23204348e-03,
         4.13605257e-03,  -5.16300324e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.08126872e-03,   0.00000000e+00,
         1.00260754e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.90843247e-03,
         0.00000000e+00,   7.84149101e-04,  -9.26549433e-04,
        -3.42700502e-04,   2.19315651e-04,   0.00000000e+00,
        -4.12817988e-03,   0.00000000e+00,  -1.92860624e-03,
         5.00310297e-04,   1.12386159e-03,  -2.14310229e-04,
         0.00000000e+00,   2.44172302e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.05662472e-03,   0.00000000e+00,
         4.01946260e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.40919053e-03,
         0.00000000e+00,   9.88167440e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.63442866e-03,   0.00000000e+00,
        -2.70374201e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.11730346e-03,
         0.00000000e+00,   1.36843048e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.96707667e-04,
         0.00000000e+00,  -4.33177832e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.99549923e-03,   0.00000000e+00,  -3.71724299e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.09288274e-04,   0.00000000e+00,
         9.06527956e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.87136262e-03,
         0.00000000e+00,  -4.76410912e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.58705821e-02,   2.60486849e-02,   6.46708092e-02,
         2.62245515e-03,  -7.54446706e-03,   4.18977048e-02,
        -4.82424603e-03,   9.08785749e-03,  -8.50587796e-04,
         2.06384278e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.77288377e-03,
        -3.19873915e-03,  -2.60597916e-03,  -2.80297268e-02,
        -1.72473353e-02,   0.00000000e+00,   3.85682022e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.20050348e-02,   0.00000000e+00,
         6.53121423e-02,  -1.96326162e-02,  -2.11435907e-02,
        -1.65384538e-02,   2.13342035e-02,   0.00000000e+00,
        -1.11801525e-02,   0.00000000e+00,   5.96876398e-02,
        -3.50228473e-03,  -2.26743240e-02,   2.52527290e-02,
        -9.21352762e-03,   0.00000000e+00,  -9.31678109e-03,
         0.00000000e+00,  -1.34243980e-02,   3.15914410e-02,
        -4.92439028e-03,  -1.35064815e-02,   1.47568135e-02,
         2.60376905e-03,   0.00000000e+00,  -1.24275327e-02,
         0.00000000e+00,   4.13487425e-03,   1.66220592e-02,
         2.24553530e-02,  -2.38806323e-03,  -2.34724737e-03,
        -2.73361038e-02,  -2.25205624e-02,   0.00000000e+00,
         4.12007578e-02,   0.00000000e+00,  -2.43234754e-02,
        -1.41816861e-02,  -1.91783428e-02,   6.70886275e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.08940954e-02,   0.00000000e+00,
         6.27157126e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.56879821e-02,
         9.67107890e-03,  -9.24807316e-03,   5.02916189e-02,
        -1.73080030e-02,   0.00000000e+00,  -1.23813307e-02,
         0.00000000e+00,  -4.57884673e-02,   3.95370105e-02,
         2.06870054e-02,   6.53240335e-03,   0.00000000e+00,
         7.59875816e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.91446234e-03,
         0.00000000e+00,   1.08302234e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.79061711e-02,   0.00000000e+00,   4.23080955e-03,
        -2.05767786e-03,   5.27502756e-03,   1.11626071e-02,
         3.05058986e-03,   0.00000000e+00,  -1.25341773e-02,
         0.00000000e+00,  -1.68971667e-03,   5.26426730e-03,
         5.37506867e-03,  -1.41123371e-02,   0.00000000e+00,
         8.21897237e-03,   0.00000000e+00,   5.83237857e-03,
        -9.65168016e-03,  -3.24631392e-03,  -6.96286058e-03,
        -1.27649520e-03,   0.00000000e+00,   3.77866797e-03,
         0.00000000e+00,   2.19386768e-02,  -7.87240648e-03,
        -2.19634718e-03,  -7.61388400e-03,   0.00000000e+00,
        -1.81871017e-02,   0.00000000e+00,  -2.05668473e-03,
         1.14941106e-02,  -1.96939004e-02,  -4.78224544e-02,
        -8.64333934e-03,  -8.96977204e-03,   0.00000000e+00,
         9.40704989e-03,   0.00000000e+00,   2.17548323e-02,
         1.37618590e-02,   9.28651270e-03,  -7.21195444e-03,
         0.00000000e+00,   2.33678841e-03,   0.00000000e+00,
        -5.32481792e-03,   1.12964246e-02,   7.30549672e-02,
         6.39371008e-03,   1.26458740e-02,   1.20742247e-03,
         1.50166343e-03,   0.00000000e+00,  -9.88038006e-03,
         0.00000000e+00,  -9.33088890e-03,  -3.21027455e-03,
        -1.97910152e-03,   1.54872774e-03,   0.00000000e+00,
         2.24481652e-03,   0.00000000e+00,  -2.87731541e-03,
        -2.46588565e-03,  -2.49248702e-02,   9.91662825e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.93598966e-03,  -1.97721548e-03,
        -3.96276788e-03,   4.17179277e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.61134224e-03,   0.00000000e+00,
         1.44276434e-03,   4.83826160e-03,   2.98317231e-03,
         9.40268818e-05,   0.00000000e+00,   2.67609143e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.86902903e-03,
         0.00000000e+00,  -1.62866038e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.45374959e-04,   0.00000000e+00,
         8.42223632e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.59295594e-04,   0.00000000e+00,
        -6.19491322e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.93201182e-03,
         0.00000000e+00,  -2.57081085e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.10145076e-03,  -6.99108226e-04,  -3.42700502e-04,
         5.90659059e-04,   0.00000000e+00,  -3.99834517e-03,
         0.00000000e+00,  -2.45346045e-03,   2.08523303e-05,
         1.04071803e-03,  -3.33623188e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.05394385e-03,   0.00000000e+00,
         1.09721955e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.39419539e-03,
         0.00000000e+00,  -4.60071434e-03,   4.66776166e-03,
         1.00960424e-02,  -9.50623573e-04,   0.00000000e+00,
         8.14508513e-03,   0.00000000e+00,   3.76515618e-03,
        -9.44603539e-04,  -1.58029038e-04,  -1.62516876e-03,
         0.00000000e+00,  -7.77738128e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.54191016e-03,   0.00000000e+00,
        -1.24034736e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.39251041e-03,
         0.00000000e+00,  -3.35233815e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.05511574e-02,   0.00000000e+00,
        -3.01029237e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.99545225e-04,
         0.00000000e+00,  -3.76904059e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.85509208e-03,
         0.00000000e+00,   1.24531915e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.60674902e-03,   0.00000000e+00,   5.88747862e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.68333839e-03,   0.00000000e+00,
         1.05507098e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.29512971e-05,
         0.00000000e+00,   3.05566657e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.18512156e-02,   3.26276129e-02,  -4.52898451e-03,
         7.11342573e-03,  -1.49378010e-02,  -2.51089927e-02,
        -3.55042204e-04,   1.14338286e-02,  -7.98198740e-04,
        -5.53208015e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.42819757e-02,
        -2.23314873e-04,  -4.00260506e-03,  -4.31122152e-02,
        -2.51699608e-02,   0.00000000e+00,  -4.05298982e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.07499870e-02,   0.00000000e+00,
         4.45748555e-03,  -2.22172455e-02,  -6.59947473e-03,
        -2.47711344e-02,   2.69341086e-02,   0.00000000e+00,
        -1.49536918e-02,   0.00000000e+00,  -2.13245648e-02,
         7.45055727e-03,  -2.97658913e-03,   8.06306451e-03,
        -6.46587748e-03,   0.00000000e+00,   3.14518096e-03,
         0.00000000e+00,   7.47801795e-03,   5.98868815e-03,
        -3.77743030e-03,   3.67927692e-03,   2.34498819e-03,
         1.06798522e-02,   0.00000000e+00,   6.58602650e-03,
         0.00000000e+00,  -4.71944231e-04,   7.26050518e-03,
         1.39003050e-02,  -4.77525733e-03,   1.18659206e-03,
         4.07309082e-03,   4.54363395e-03,   0.00000000e+00,
         3.24891110e-02,   0.00000000e+00,  -4.37980245e-03,
        -4.93329770e-03,  -7.74768367e-03,   3.84374564e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.32166557e-02,   0.00000000e+00,
         2.01673231e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.13600098e-02,
        -5.94131773e-03,   5.05433294e-03,   1.11626071e-02,
        -1.50873398e-02,   0.00000000e+00,  -9.12986962e-03,
         0.00000000e+00,  -7.63338837e-03,   8.16303244e-03,
         7.42303949e-03,   2.45056943e-03,   0.00000000e+00,
         8.28273292e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.96074096e-02,
         0.00000000e+00,  -1.26062759e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.09683082e-02,   0.00000000e+00,  -7.03779705e-02,
        -7.57813312e-03,   7.85911287e-03,   4.30463070e-02,
         4.00155542e-02,   0.00000000e+00,   4.96133021e-02,
         0.00000000e+00,   6.31432118e-03,  -9.62349154e-04,
        -9.48678435e-03,  -2.45362898e-02,   0.00000000e+00,
         1.13621909e-02,   0.00000000e+00,  -7.08840439e-02,
        -5.46756543e-03,   1.37511989e-02,   2.95944945e-02,
        -3.07118358e-02,   0.00000000e+00,   2.19944575e-02,
         0.00000000e+00,   3.97673979e-02,  -9.63522870e-03,
         3.88602102e-03,  -5.19572182e-03,   0.00000000e+00,
        -1.61574795e-02,   0.00000000e+00,  -5.43804554e-03,
        -6.95721511e-02,   1.75857958e-02,  -2.22226208e-02,
        -5.47443148e-03,   2.16002712e-04,   0.00000000e+00,
         5.55497996e-03,   0.00000000e+00,   1.14392059e-02,
        -1.69954040e-03,   2.97429818e-03,  -8.04870163e-04,
         0.00000000e+00,   4.47018298e-03,   0.00000000e+00,
        -2.94003868e-03,   7.46559524e-03,   2.33070937e-05,
         5.08942883e-02,  -1.81433336e-02,  -4.74086677e-03,
        -2.15090765e-03,   0.00000000e+00,  -4.44170984e-03,
         0.00000000e+00,   1.56394398e-02,  -5.92114224e-03,
         5.52574170e-03,   4.77859315e-03,   0.00000000e+00,
         7.75292201e-03,   0.00000000e+00,   2.74993043e-03,
        -1.92090745e-03,  -3.21132641e-02,  -6.39704103e-02,
        -7.46573526e-02,   2.29457245e-02,  -3.92071027e-02,
         8.11635610e-03,  -1.45337470e-02,  -5.42278142e-02,
         3.46471714e-06,   9.17256004e-03,   4.39699051e-03,
        -7.21220645e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.27784582e-02,
         4.20536441e-03,  -3.55593112e-03,  -2.65795711e-02,
        -1.24701109e-02,   0.00000000e+00,  -6.22042332e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.65099395e-02,   0.00000000e+00,
        -2.80833340e-02,  -1.26257666e-02,  -1.50113004e-03,
        -1.75803661e-02,   2.29931364e-02,   0.00000000e+00,
        -1.38617891e-02,   0.00000000e+00,  -5.51366779e-02,
         6.73167807e-03,   2.54379634e-03,   4.75812533e-04,
        -4.01619796e-03,   0.00000000e+00,   6.09844761e-03,
         0.00000000e+00,   1.30523749e-02,  -1.58062676e-02,
        -3.39664758e-03,   5.87115967e-04,   4.11383661e-04,
         7.08111345e-03,   0.00000000e+00,   7.15908542e-03,
         0.00000000e+00,  -4.53671598e-03,  -4.78278510e-03,
        -1.86014914e-02,  -2.02436888e-03,   6.36120380e-03,
         1.90715919e-02,   1.31101409e-02,   0.00000000e+00,
         6.22487954e-03,   0.00000000e+00,   7.15170709e-03,
         1.83211137e-03,   5.43643652e-04,  -3.12202687e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.96222307e-02,   0.00000000e+00,
        -1.01119214e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.20832402e-02,
        -1.39071121e-02,   7.36468357e-03,  -6.96286058e-03,
        -1.16919142e-02,   0.00000000e+00,   5.11129626e-04,
         0.00000000e+00,   1.68914179e-02,  -1.00743059e-02,
        -2.74760450e-03,   4.51787931e-04,   0.00000000e+00,
        -3.03087945e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.23430007e-02,
         0.00000000e+00,  -1.95046881e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.40720808e-02,   0.00000000e+00,  -7.88487324e-02,
        -5.02360006e-03,   4.11757299e-03,   2.95944945e-02,
         2.86230695e-02,   0.00000000e+00,   4.83892923e-02,
         0.00000000e+00,   7.78449084e-03,  -2.76343134e-03,
        -9.67961911e-03,  -1.71022503e-02,   0.00000000e+00,
         6.70047547e-03,   0.00000000e+00,  -7.42049116e-02,
        -1.00954449e-02,   2.53989407e-02,   4.71372982e-02,
        -4.74838453e-02,   0.00000000e+00,   2.51018883e-02,
         0.00000000e+00,   4.37283307e-02,  -9.31203996e-03,
         5.71194712e-03,  -1.93053290e-03,   0.00000000e+00,
        -7.77993876e-03,   0.00000000e+00,  -4.51252732e-03,
        -8.86922318e-02,   2.82639239e-02,  -3.28013219e-03,
         1.24446845e-04,   9.02961020e-03,   0.00000000e+00,
        -4.25250190e-03,   0.00000000e+00,  -2.39847206e-03,
        -3.20445036e-03,   1.41971299e-03,  -9.18721592e-04,
         0.00000000e+00,   5.71785967e-03,   0.00000000e+00,
         5.51465891e-04,   1.49113744e-03,  -3.53441109e-02,
         4.72684025e-02,  -2.59117360e-02,  -8.00991233e-03,
         3.16766656e-03,   0.00000000e+00,   1.26133326e-03,
         0.00000000e+00,   1.50311913e-02,  -5.67091257e-03,
         4.32933585e-03,   4.86549084e-03,   0.00000000e+00,
         6.09495984e-03,   0.00000000e+00,   6.03362061e-03,
         2.53895736e-03,  -2.21617586e-02,  -7.79508613e-02,
         2.12244982e-03,  -4.62150142e-03,  -3.83806741e-04,
        -9.28583143e-03,  -6.89949628e-03,  -5.10173614e-03,
        -2.18425511e-03,  -8.65032417e-04,  -2.69383510e-03,
        -1.84942201e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.01783564e-03,
        -1.54024730e-03,   1.13016700e-02,   1.24409203e-02,
         6.48853688e-03,   0.00000000e+00,  -8.85628002e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.83527467e-03,   0.00000000e+00,
        -9.41550158e-03,   2.27122621e-03,   4.22934333e-03,
         7.32174690e-03,  -4.63561554e-03,   0.00000000e+00,
        -3.51530889e-03,   0.00000000e+00,  -1.13047556e-02,
        -3.31025123e-03,  -9.18544242e-03,   8.29786141e-04,
        -3.15324028e-04,   0.00000000e+00,   1.58982474e-03,
         0.00000000e+00,   4.72245488e-03,   1.90209908e-03,
        -1.36633538e-03,  -6.91686347e-03,  -8.92498550e-04,
        -2.68069149e-03,   0.00000000e+00,   1.32944558e-03,
         0.00000000e+00,   2.03466758e-03,   6.53364946e-04,
        -5.03352073e-03,   8.30721205e-03,   9.98179225e-03,
         5.67639895e-03,   5.34136675e-03,   0.00000000e+00,
        -1.13218216e-02,   0.00000000e+00,  -1.40566131e-03,
         2.54486052e-03,   3.62229239e-03,  -1.07875220e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.11792764e-03,   0.00000000e+00,
        -8.75343457e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.05108637e-02,
        -8.61429718e-03,  -1.69144718e-02,  -8.64333934e-03,
        -1.13189608e-03,   0.00000000e+00,   3.03598100e-03,
         0.00000000e+00,   7.58691806e-03,  -1.70961286e-03,
        -1.43821401e-04,  -2.95246293e-03,   0.00000000e+00,
        -7.62173589e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.15623311e-03,
         0.00000000e+00,   5.30084059e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.78918339e-03,   0.00000000e+00,   4.20426556e-03,
         6.51756759e-03,  -8.06449874e-03,  -5.47443148e-03,
        -2.82979628e-03,   0.00000000e+00,   1.05670094e-03,
         0.00000000e+00,   3.26357055e-03,  -1.82305648e-03,
         3.41421400e-04,   4.54822696e-03,   0.00000000e+00,
        -2.61325511e-03,   0.00000000e+00,   3.44580511e-03,
         1.03918029e-02,  -2.01098308e-03,   1.24446845e-04,
         5.19802016e-03,   0.00000000e+00,  -5.33611256e-03,
         0.00000000e+00,  -7.26227165e-03,   3.03549295e-03,
         1.54258537e-03,  -6.13766815e-04,   0.00000000e+00,
         3.40430663e-03,   0.00000000e+00,   2.22396051e-03,
         1.25551845e-03,   1.57997614e-03,  -1.68134472e-03,
         2.31401813e-02,   3.52792005e-04,   0.00000000e+00,
        -9.12278625e-03,   0.00000000e+00,  -5.26092497e-03,
         9.26296120e-03,   7.71772806e-03,  -9.46088937e-03,
         0.00000000e+00,   1.30089802e-02,   0.00000000e+00,
         1.30787809e-03,  -4.00850628e-03,  -5.93470040e-03,
        -7.31593259e-04,   2.94538852e-03,   1.69451652e-03,
         2.41873358e-04,   0.00000000e+00,   1.28841979e-02,
         0.00000000e+00,   6.48840968e-03,  -3.93302889e-03,
        -3.08174511e-03,  -4.18937099e-04,   0.00000000e+00,
        -5.89221122e-03,   0.00000000e+00,  -5.61167048e-03,
        -2.51224015e-03,   4.22237975e-03,   2.39770539e-03,
         1.96532071e-02,  -5.89981602e-03,   1.11782531e-02,
        -7.13228885e-03,   1.28316188e-02,   1.86604849e-02,
         3.10831615e-03,  -9.59595269e-03,  -2.46015166e-03,
         1.95429014e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.23350123e-02,
        -8.43466411e-03,   6.10225397e-03,   8.03662884e-03,
         3.30616122e-03,   0.00000000e+00,   1.46685037e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.21974464e-03,   0.00000000e+00,
         8.17682481e-03,  -1.25710664e-02,  -3.65860588e-03,
         9.16150585e-04,  -4.83623242e-03,   0.00000000e+00,
         3.60707221e-04,   0.00000000e+00,   1.29642455e-02,
         2.95468285e-03,   1.26933661e-03,   2.30998781e-03,
         1.79167092e-03,   0.00000000e+00,  -9.05343347e-04,
         0.00000000e+00,  -2.82900414e-03,  -1.52875588e-03,
         1.12612247e-03,  -1.70147927e-03,   1.50128326e-03,
        -6.84275341e-04,   0.00000000e+00,  -4.94350868e-03,
         0.00000000e+00,   1.10672187e-03,  -9.88214803e-04,
        -2.94374125e-03,   4.84448222e-03,  -6.37851949e-03,
        -4.59773020e-03,  -4.45648980e-03,   0.00000000e+00,
         1.64994513e-03,   0.00000000e+00,  -1.46820029e-03,
        -2.63874141e-03,  -9.19084232e-04,   9.26825286e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.34723507e-03,   0.00000000e+00,
         4.07977402e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.04509831e-02,
         2.93514396e-03,   2.90191200e-03,   1.20742247e-03,
         1.37077661e-03,   0.00000000e+00,  -4.46013306e-03,
         0.00000000e+00,  -1.00735940e-02,   1.79636403e-03,
         2.99008044e-04,  -4.53682726e-04,   0.00000000e+00,
         8.32646998e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.46810769e-03,
         0.00000000e+00,   5.23412656e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.80572173e-03,   0.00000000e+00,   1.84343997e-02,
         1.90670412e-02,  -6.52879087e-03,  -4.74086677e-03,
        -3.52813523e-03,   0.00000000e+00,  -9.90688674e-03,
         0.00000000e+00,   2.15682939e-03,   1.07585361e-03,
         4.39219255e-03,   5.96320935e-03,   0.00000000e+00,
        -1.14407770e-03,   0.00000000e+00,   1.70874455e-02,
         1.62114682e-02,  -1.08458664e-02,  -8.00991233e-03,
         6.76703560e-03,   0.00000000e+00,  -3.67822376e-03,
         0.00000000e+00,  -2.64640080e-03,   3.54675645e-04,
        -1.86469540e-04,   2.01179378e-03,   0.00000000e+00,
         6.64006697e-04,   0.00000000e+00,   1.00920935e-03,
         2.48427502e-02,  -1.53753603e-03,   1.62441897e-03,
         1.69451652e-03,  -1.35847620e-03,   0.00000000e+00,
         1.21873959e-02,   0.00000000e+00,   7.39196760e-03,
        -2.08123989e-03,  -1.75297107e-03,  -3.55705486e-03,
         0.00000000e+00,  -1.06880423e-02,   0.00000000e+00,
        -3.58566320e-03,  -3.46492455e-03,   1.07426448e-02,
        -9.51084644e-04,   5.39386312e-03,   2.26702508e-02,
         1.46056207e-03,   0.00000000e+00,   1.64261265e-02,
         0.00000000e+00,   7.02043130e-03,  -1.07161837e-03,
        -2.25271618e-04,  -1.70133840e-03,   0.00000000e+00,
        -1.48670051e-03,   0.00000000e+00,  -6.25657155e-03,
        -1.46813424e-02,   2.90276377e-03,   1.44222427e-02,
        -4.69585721e-02,  -2.80648746e-02,  -1.58411345e-02,
        -3.73828664e-03,   5.80827097e-03,  -1.96042271e-02,
         1.21035205e-01,  -3.47884514e-02,  -1.09380222e-02,
         1.95666130e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.35851825e-03,
         3.02798572e-02,  -3.24751733e-02,  -5.79678166e-04,
         7.00694103e-03,   0.00000000e+00,  -7.49465597e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.23225548e-03,   0.00000000e+00,
        -2.60133758e-02,  -3.02591861e-02,   4.42964485e-02,
         1.77264732e-02,   3.95006061e-03,   0.00000000e+00,
         1.48991155e-02,   0.00000000e+00,  -4.84312998e-02,
         9.25785867e-03,  -5.23490643e-03,  -2.07995255e-03,
        -6.28102017e-03,   0.00000000e+00,  -2.24025870e-03,
         0.00000000e+00,   1.88147196e-03,  -2.26642586e-02,
        -4.17527960e-03,   8.68023478e-03,   2.61161484e-03,
        -7.17631663e-03,   0.00000000e+00,   1.82646072e-03,
         0.00000000e+00,  -1.32677949e-02,   5.11006487e-04,
        -2.84762957e-02,  -3.86070225e-03,   5.21283471e-03,
         3.90975465e-03,  -7.69395228e-03,   0.00000000e+00,
         1.87753816e-04,   0.00000000e+00,   4.96362712e-03,
         9.40032988e-03,  -3.80825218e-03,  -2.51722676e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.81794901e-03,   0.00000000e+00,
        -5.00888889e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.76820608e-02,
         4.19030861e-03,  -7.45621384e-03,  -4.82424603e-03,
         1.01985379e-02,   0.00000000e+00,   9.10320471e-03,
         0.00000000e+00,   1.45788384e-02,  -4.20942130e-03,
        -4.61940118e-03,  -5.10373271e-03,   0.00000000e+00,
        -1.02832601e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.57309519e-04,
         0.00000000e+00,  -5.01956224e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.33870421e-04,   0.00000000e+00,  -4.10154480e-03,
        -1.38555022e-02,   7.27923228e-03,  -3.55042204e-04,
         1.31474326e-03,   0.00000000e+00,   4.14609581e-03,
         0.00000000e+00,  -8.47671245e-03,   4.04547107e-03,
        -5.44341284e-03,  -5.56685098e-03,   0.00000000e+00,
        -1.01688107e-02,   0.00000000e+00,  -7.71928698e-03,
         1.35760380e-02,  -9.26244904e-03,   3.46471714e-06,
         7.49754161e-03,   0.00000000e+00,   2.20481964e-03,
         0.00000000e+00,   1.07332382e-02,  -6.16060690e-03,
         3.43474668e-03,   1.30974967e-02,   0.00000000e+00,
         2.25087203e-02,   0.00000000e+00,  -6.37730710e-03,
         1.79270030e-02,  -1.95202870e-03,  -1.74593684e-04,
        -2.18425511e-03,  -4.38071896e-03,   0.00000000e+00,
        -9.32342068e-03,   0.00000000e+00,  -1.43332028e-04,
        -2.69790804e-03,   4.98233024e-03,   3.21009396e-02,
         0.00000000e+00,   1.02990271e-03,   0.00000000e+00,
         2.58185823e-02,  -4.46191485e-02,  -3.16018212e-02,
        -2.74741782e-04,   3.70728903e-03,   3.10831615e-03,
        -1.68533847e-02,   0.00000000e+00,  -3.21487185e-04,
         0.00000000e+00,   2.21469283e-02,  -5.72252875e-03,
         1.04251730e-02,   1.05085325e-02,   0.00000000e+00,
        -1.98647746e-02,   0.00000000e+00,   6.87035111e-02,
        -5.78028931e-02,   8.25550226e-03,  -3.73613907e-02,
        -7.52628756e-02,   5.89792926e-02,   3.83491509e-02,
         6.06155623e-03,  -3.20900803e-02,  -3.37435681e-03,
        -3.47884514e-02,   7.77693511e-02,   1.60736528e-02,
        -6.95201224e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.64861731e-02,
        -2.69853672e-02,  -2.35186014e-02,  -6.84251668e-02,
        -5.82938456e-02,   0.00000000e+00,   9.02345266e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.62744464e-02,   0.00000000e+00,
         6.42265248e-02,   7.29458364e-03,   1.65502916e-02,
        -4.21798028e-02,   5.82916476e-02,   0.00000000e+00,
        -3.71050583e-02,   0.00000000e+00,   1.58104734e-03,
        -1.83252570e-03,  -2.05423229e-02,   2.08726835e-02,
        -1.82721758e-02,   0.00000000e+00,   1.03917725e-02,
         0.00000000e+00,  -2.89380473e-03,   4.30381032e-02,
         2.76934552e-03,  -3.07073203e-03,   3.75397905e-03,
         3.40553221e-03,   0.00000000e+00,   7.79692386e-03,
         0.00000000e+00,  -1.09201151e-02,   1.85758992e-02,
         4.96545526e-02,   7.13227454e-04,  -1.07367910e-02,
        -9.63076757e-03,  -4.96375890e-03,   0.00000000e+00,
         3.21777655e-02,   0.00000000e+00,  -6.33151763e-03,
         4.21305670e-03,  -1.30006027e-02,   6.48267589e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.93565705e-03,   0.00000000e+00,
         3.26745258e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.52723793e-02,
        -8.57539250e-03,  -3.04367795e-03,   9.08785749e-03,
        -1.70677633e-02,   0.00000000e+00,  -8.61909868e-03,
         0.00000000e+00,  -1.56233762e-03,   2.27993849e-02,
         6.90944487e-03,   1.64407031e-02,   0.00000000e+00,
         6.02671256e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.98592401e-02,
         0.00000000e+00,  -1.08197693e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.75034390e-02,   0.00000000e+00,  -8.39092481e-02,
         7.59501989e-03,   4.05909514e-05,   1.14338286e-02,
         1.85685159e-02,   0.00000000e+00,   1.73414812e-02,
         0.00000000e+00,   6.27170899e-03,  -3.50165774e-03,
        -1.16936564e-02,  -4.22982456e-02,   0.00000000e+00,
         2.08223990e-02,   0.00000000e+00,  -7.22347856e-02,
        -1.14682051e-02,   1.13581876e-02,   9.17256004e-03,
        -1.90762589e-02,   0.00000000e+00,   5.73904621e-03,
         0.00000000e+00,   2.58615412e-02,  -9.39465950e-03,
         5.63636260e-03,  -6.39660674e-03,   0.00000000e+00,
        -3.71200875e-02,   0.00000000e+00,   5.43491836e-03,
        -1.10246591e-01,   3.95905103e-03,  -2.35457478e-02,
        -8.65032417e-04,   2.72812234e-04,   0.00000000e+00,
         1.27601190e-02,   0.00000000e+00,   9.91891088e-03,
         6.43196175e-03,  -4.37862537e-04,   2.97540076e-02,
         0.00000000e+00,   4.79742435e-02,   0.00000000e+00,
        -2.16766613e-02,   2.12113798e-02,   3.65192301e-02,
         2.23132540e-02,  -5.20748064e-03,  -9.59595269e-03,
         1.77513868e-02,   0.00000000e+00,  -1.49934106e-04,
         0.00000000e+00,   1.04430980e-02,  -9.48892821e-03,
        -2.71019023e-04,  -1.26348115e-02,   0.00000000e+00,
         1.41068327e-02,   0.00000000e+00,  -1.97775290e-02,
         2.48097054e-02,  -5.00833537e-02,  -6.39355647e-02,
        -7.83386067e-03,   6.49940646e-03,  -8.79813259e-03,
         9.85502425e-03,   6.09126705e-03,  -1.71196456e-03,
        -1.09380222e-02,   1.60736528e-02,   2.60875949e-02,
        -1.04301010e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.31112035e-02,
        -5.67464061e-03,  -1.50681420e-02,  -1.27018310e-02,
         1.74000122e-04,   0.00000000e+00,   2.03680317e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.39457690e-03,   0.00000000e+00,
         8.85279147e-03,   8.20486281e-03,  -9.74137820e-03,
        -8.09012709e-03,   1.33989116e-02,   0.00000000e+00,
        -8.43264452e-03,   0.00000000e+00,  -1.04080255e-02,
         6.84575910e-04,   5.21914799e-03,   6.84935107e-03,
        -6.77910415e-04,   0.00000000e+00,  -3.88337923e-03,
         0.00000000e+00,   9.62578753e-05,  -4.66308337e-03,
         1.29049254e-03,  -1.47587236e-03,   8.31013719e-03,
         2.88330051e-03,   0.00000000e+00,  -9.33200349e-03,
         0.00000000e+00,  -2.65240505e-03,  -1.68912810e-03,
        -1.14361437e-02,   1.98697806e-04,  -4.74680902e-03,
        -3.19606016e-03,  -2.44994032e-03,   0.00000000e+00,
         4.93393069e-03,   0.00000000e+00,  -3.95985814e-04,
        -1.19810552e-04,  -2.76082664e-03,   2.53280553e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.66360815e-03,   0.00000000e+00,
         4.43039878e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.84504117e-03,
        -8.51417112e-04,  -2.45705962e-04,  -8.50587796e-04,
        -1.86634448e-03,   0.00000000e+00,  -1.09094991e-04,
         0.00000000e+00,   5.71636431e-05,  -3.43231473e-03,
        -1.59928506e-03,  -7.04547111e-03,   0.00000000e+00,
         5.73569639e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.77165358e-03,
         0.00000000e+00,  -1.20178971e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.69232003e-03,   0.00000000e+00,  -1.12193363e-02,
         1.25518749e-03,  -1.00493342e-03,  -7.98198740e-04,
        -1.04424935e-03,   0.00000000e+00,   2.44390793e-04,
         0.00000000e+00,   3.62315858e-05,  -1.01623707e-03,
         3.30879788e-03,  -5.94544387e-03,   0.00000000e+00,
         1.01781319e-03,   0.00000000e+00,   1.02281496e-02,
        -2.66414075e-03,   2.46085526e-03,   4.39699051e-03,
        -7.62325937e-03,   0.00000000e+00,   3.52567468e-03,
         0.00000000e+00,   6.49466775e-03,  -9.80168575e-04,
         1.99345492e-04,  -1.14907905e-03,   0.00000000e+00,
        -1.10214115e-02,   0.00000000e+00,  -1.05651704e-03,
        -3.68763443e-02,  -8.54573231e-04,  -1.60708283e-03,
        -2.69383510e-03,  -5.70298254e-04,   0.00000000e+00,
         4.63643178e-03,   0.00000000e+00,   2.87441033e-04,
        -5.48508970e-04,  -2.88477128e-03,   1.22279066e-02,
         0.00000000e+00,  -4.43967223e-03,   0.00000000e+00,
        -5.24834836e-03,   1.03026476e-02,   5.58974659e-04,
         5.24577946e-03,  -5.44155379e-03,  -2.46015166e-03,
         3.78073273e-03,   0.00000000e+00,  -1.36897458e-04,
         0.00000000e+00,  -1.12222841e-04,  -8.07167811e-04,
        -1.50817817e-03,  -5.45093095e-03,   0.00000000e+00,
         6.23558551e-03,   0.00000000e+00,  -1.18140487e-03,
         9.44628785e-03,  -5.87551992e-03,  -1.40559619e-03,
         7.03314151e-01,  -9.78488681e-02,   4.98538039e-01,
        -1.84236188e-04,   6.25942788e-02,   5.47671702e-01,
         1.95666130e-03,  -6.95201224e-02,  -1.04301010e-02,
         7.10964673e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.04543948e-01,
         1.76285278e-02,  -2.26378716e-03,   1.15898687e-01,
         8.59409889e-02,   0.00000000e+00,   5.90825046e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.61492684e-02,   0.00000000e+00,
         4.46691160e-01,   4.56124344e-02,  -1.91817888e-02,
         7.30489710e-02,  -1.03515388e-01,   0.00000000e+00,
         2.94235776e-02,   0.00000000e+00,   5.62125594e-01,
        -2.97951608e-02,  -2.61914880e-02,   2.17116259e-02,
         1.60291616e-02,   0.00000000e+00,  -3.31288755e-02,
         0.00000000e+00,  -7.84774050e-02,   3.12633912e-01,
         3.49646787e-03,  -1.69897569e-02,   1.50917711e-02,
        -2.53086700e-02,   0.00000000e+00,  -3.90170127e-02,
         0.00000000e+00,   3.33192965e-02,   4.04674284e-02,
         3.31116661e-01,   4.63607617e-04,  -1.57992966e-02,
        -4.26588274e-02,  -5.72311553e-02,   0.00000000e+00,
        -2.81210845e-03,   0.00000000e+00,  -3.36001253e-02,
        -1.04668698e-02,   5.06431430e-03,   4.54671482e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.52553715e-02,   0.00000000e+00,
         4.44987980e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.46479828e-01,
         2.79815742e-02,  -3.36832042e-02,   2.06384278e-02,
         2.46011079e-02,   0.00000000e+00,   1.77641036e-02,
         0.00000000e+00,  -4.94855514e-02,   3.28213987e-02,
        -2.95239794e-05,  -8.72575753e-03,   0.00000000e+00,
         4.45606997e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.51498455e-01,
         0.00000000e+00,   6.33037762e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.34109335e-02,   0.00000000e+00,   6.51317729e-01,
         6.51058867e-03,   6.31427718e-04,  -5.53208015e-02,
        -9.07933912e-02,   0.00000000e+00,  -1.22009323e-01,
         0.00000000e+00,  -1.68261415e-03,   2.95804252e-04,
         4.83679378e-02,   7.57613997e-02,   0.00000000e+00,
        -4.41976985e-02,   0.00000000e+00,   6.53950554e-01,
         1.82361328e-02,  -3.97120887e-02,  -7.21220645e-02,
         1.07338500e-01,   0.00000000e+00,  -3.12362666e-02,
         0.00000000e+00,  -9.32878539e-02,   2.65508420e-02,
        -2.70409756e-02,  -5.28289891e-03,   0.00000000e+00,
         3.89513429e-02,   0.00000000e+00,  -2.05864893e-02,
         6.95219454e-01,  -6.48632197e-02,  -1.83331204e-03,
        -1.84942201e-04,  -2.90354232e-02,   0.00000000e+00,
         9.79074680e-03,   0.00000000e+00,  -9.43253396e-03,
         4.77208917e-02,  -5.65699229e-03,  -6.78045332e-03,
         0.00000000e+00,  -4.87725045e-02,   0.00000000e+00,
         1.47123048e-02,  -8.28222580e-03,   4.82958474e-01,
        -1.01970184e-01,   6.46756969e-02,   1.95429014e-02,
        -8.66038848e-03,   0.00000000e+00,  -9.88420818e-03,
         0.00000000e+00,  -5.45585394e-02,   1.66221237e-02,
        -1.94071303e-02,  -1.14106987e-02,   0.00000000e+00,
        -3.39827178e-02,   0.00000000e+00,   2.66881094e-03,
         2.21160864e-03,   9.74382486e-02,   6.67554842e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.03403312e-03,  -1.17175996e-02,
        -2.81837889e-03,   3.60872394e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.09358559e-02,   0.00000000e+00,
        -4.26544542e-03,   4.09138600e-03,   9.99842670e-04,
        -5.36362423e-03,   0.00000000e+00,  -5.73888138e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.14459621e-02,
         0.00000000e+00,   6.06043513e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.79325236e-03,   0.00000000e+00,
        -1.52697332e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.34209482e-03,   0.00000000e+00,
         1.27369659e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.84042998e-03,
         0.00000000e+00,   1.33997454e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.41843500e-03,  -2.32947164e-04,  -4.30538162e-04,
         3.60190056e-03,   0.00000000e+00,   8.41883800e-04,
         0.00000000e+00,  -1.25483181e-03,  -2.29613628e-05,
        -1.37626513e-03,  -5.46059114e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.43112611e-03,   0.00000000e+00,
        -1.36761252e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.56552056e-04,
         0.00000000e+00,  -2.48366585e-03,   1.86326899e-03,
         4.17179277e-04,  -8.27506446e-03,   0.00000000e+00,
        -3.38173719e-03,   0.00000000e+00,   4.20064398e-03,
        -9.54627509e-04,   3.43344863e-03,   4.16068592e-03,
         0.00000000e+00,  -8.07988236e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.49109850e-03,   0.00000000e+00,
         1.97964370e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.81721867e-03,
         0.00000000e+00,   1.93285553e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.54154842e-03,   0.00000000e+00,
        -3.02987842e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.25347826e-03,
         0.00000000e+00,  -2.34083421e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.58372743e-03,
         0.00000000e+00,  -1.34713670e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.11592231e-03,   0.00000000e+00,   5.50475861e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.51328633e-03,   0.00000000e+00,
         6.37767123e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.75325603e-04,
         0.00000000e+00,   7.37862243e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.02331710e-01,  -8.06544323e-02,  -5.10701384e-02,
        -1.77074004e-02,   1.78818912e-02,   9.47353748e-05,
         7.00694103e-03,  -5.82938456e-02,   1.74000122e-04,
         8.59409889e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.27093586e-01,
         1.73785692e-02,   3.37478382e-02,   1.04433159e-01,
         1.00545533e-01,   0.00000000e+00,   7.95360739e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.98746935e-02,   0.00000000e+00,
        -8.83175738e-02,   3.53657885e-02,  -2.67576172e-03,
         4.12255502e-02,  -7.53762647e-02,   0.00000000e+00,
         4.32217216e-02,   0.00000000e+00,  -2.16610891e-02,
        -7.06835001e-03,   2.17644575e-02,  -3.07890683e-02,
         1.76716993e-02,   0.00000000e+00,  -1.40483774e-03,
         0.00000000e+00,   3.35251418e-03,  -3.81041450e-02,
         4.81041872e-03,   8.61139754e-03,  -1.87644047e-02,
        -1.33817268e-02,   0.00000000e+00,   1.20928469e-03,
         0.00000000e+00,   7.86500871e-03,  -2.09241931e-02,
        -3.73660227e-02,   2.75496056e-03,   6.29365486e-03,
         9.18244870e-03,   5.25894122e-03,   0.00000000e+00,
        -5.36576211e-02,   0.00000000e+00,   1.88833563e-02,
        -5.69728465e-04,   2.46714895e-02,  -9.89631322e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.88285087e-03,   0.00000000e+00,
        -5.04187908e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.25446979e-02,
         6.78074806e-03,  -2.03739739e-03,  -1.72473353e-02,
         2.50226583e-02,   0.00000000e+00,   1.22109836e-02,
         0.00000000e+00,   1.80387570e-02,  -2.54820011e-02,
        -7.12369408e-03,  -1.70664751e-02,   0.00000000e+00,
        -7.85414947e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.08618783e-02,
         0.00000000e+00,   1.27544383e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.04256934e-02,   0.00000000e+00,   1.11254495e-01,
        -8.02568835e-04,  -2.89583457e-03,  -2.51699608e-02,
        -3.76036597e-02,   0.00000000e+00,  -3.63941904e-02,
         0.00000000e+00,  -1.83408174e-03,   2.56798912e-04,
         1.61952825e-02,   6.86825178e-02,   0.00000000e+00,
        -3.02898283e-02,   0.00000000e+00,   1.23547814e-01,
         4.50237314e-03,  -5.76303166e-03,  -1.24701109e-02,
         2.70249915e-02,   0.00000000e+00,  -8.52333193e-03,
         0.00000000e+00,  -4.25478947e-02,   1.30114594e-02,
        -7.20378889e-03,   7.56643627e-03,   0.00000000e+00,
         4.11916907e-02,   0.00000000e+00,  -6.40512588e-03,
         1.03907482e-01,  -1.02835934e-02,   3.88012067e-02,
         6.48853688e-03,   4.23251991e-03,   0.00000000e+00,
        -1.46880965e-02,   0.00000000e+00,  -2.74674749e-02,
        -6.82938407e-03,  -2.17771389e-03,  -2.83395009e-02,
         0.00000000e+00,  -2.90840490e-02,   0.00000000e+00,
         2.12431842e-02,  -2.13031942e-02,  -5.81895787e-02,
        -3.81147973e-02,   8.64363602e-03,   3.30616122e-03,
        -5.61920644e-03,   0.00000000e+00,   1.05674222e-04,
         0.00000000e+00,  -2.00951341e-02,   1.57003780e-02,
        -4.21604423e-03,   6.35035505e-03,   0.00000000e+00,
        -1.90929841e-02,   0.00000000e+00,  -4.12395851e-03,
        -3.99424153e-03,   7.23523961e-02,   9.90672444e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.73319656e-03,   7.83624103e-03,
         1.52797557e-03,  -5.36362423e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.63584651e-03,   0.00000000e+00,
         8.58765713e-03,   2.18230274e-02,   3.08699882e-03,
         1.57014474e-02,   0.00000000e+00,  -1.50724484e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.14582238e-03,
         0.00000000e+00,   5.30113380e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.06123254e-03,   0.00000000e+00,
        -5.18142684e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.34625704e-06,   0.00000000e+00,
        -5.16408782e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.94445133e-04,
         0.00000000e+00,  -4.54521895e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.94199540e-03,   7.65917941e-03,   1.81794886e-03,
         2.63794108e-03,   0.00000000e+00,  -5.73371946e-03,
         0.00000000e+00,   3.65726222e-04,  -6.05479468e-03,
         1.59726980e-03,  -1.47628987e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.70095711e-03,   0.00000000e+00,
        -1.36439422e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.26467212e-03,
         0.00000000e+00,  -8.14542470e-05,  -1.75521043e-03,
         9.40268818e-05,   2.53506388e-03,   0.00000000e+00,
         1.32055687e-03,   0.00000000e+00,  -1.56151385e-03,
        -9.01588771e-04,   7.75243260e-04,  -4.20207260e-03,
         0.00000000e+00,  -2.00880588e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.07225934e-03,   0.00000000e+00,
         4.43222234e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.78576172e-03,
         0.00000000e+00,  -3.05961320e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.90325668e-03,   0.00000000e+00,
        -1.36630182e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.72379177e-04,
         0.00000000e+00,   5.62124985e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.52571877e-04,
         0.00000000e+00,  -1.27033465e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.81827645e-02,   0.00000000e+00,  -8.11319464e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.85928691e-04,   0.00000000e+00,
        -2.26613209e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.81463830e-03,
         0.00000000e+00,  -2.28270208e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.16543348e-01,   9.44435528e-02,   6.20327686e-02,
         2.69487425e-02,  -5.04283579e-02,  -1.07788410e-02,
         3.95006061e-03,   5.82916476e-02,   1.33989116e-02,
        -1.03515388e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.47751350e-01,
         8.24159178e-03,  -2.92858478e-02,  -1.02332117e-01,
        -7.53762647e-02,   0.00000000e+00,  -1.45697925e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.58909333e-02,   0.00000000e+00,
         8.95552175e-02,  -3.98588977e-02,  -1.02358971e-02,
        -6.01189978e-02,   1.09050672e-01,   0.00000000e+00,
        -4.92455004e-02,   0.00000000e+00,   1.65982213e-02,
         5.86852135e-03,  -2.51579889e-02,   3.05494908e-02,
        -2.79762587e-02,   0.00000000e+00,   7.27240015e-03,
         0.00000000e+00,   5.81467155e-03,   5.33510642e-02,
        -9.70446459e-03,  -8.47467975e-03,   7.86318855e-03,
         1.41532860e-02,   0.00000000e+00,   7.22087143e-03,
         0.00000000e+00,  -5.98384213e-03,   2.64665537e-02,
         6.44847515e-02,  -1.27213298e-03,   2.45675543e-03,
        -5.71725790e-03,  -3.58981083e-03,   0.00000000e+00,
         5.01536225e-02,   0.00000000e+00,  -2.38247690e-02,
        -3.22449599e-04,  -2.36065453e-02,   9.10285134e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.32417753e-02,   0.00000000e+00,
         5.17807669e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.52445161e-02,
        -1.37863526e-03,   3.51108138e-03,   2.13342035e-02,
        -2.45406157e-02,   0.00000000e+00,  -1.00560276e-02,
         0.00000000e+00,  -1.94391656e-02,   3.00993144e-02,
         8.36296700e-03,   2.30815702e-02,   0.00000000e+00,
         9.12854486e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.11740537e-02,
         0.00000000e+00,  -1.52061404e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.56146732e-02,   0.00000000e+00,  -1.30212006e-01,
        -6.65905731e-03,   6.38006635e-03,   2.69341086e-02,
         3.89522672e-02,   0.00000000e+00,   3.42667686e-02,
         0.00000000e+00,  -1.43476808e-03,   2.67960164e-03,
        -1.91710798e-02,  -6.20937192e-02,   0.00000000e+00,
         2.41825176e-02,   0.00000000e+00,  -1.18420835e-01,
         8.60664349e-04,   7.76697083e-03,   2.29931364e-02,
        -3.91045808e-02,   0.00000000e+00,   1.25664199e-02,
         0.00000000e+00,   5.97526369e-02,  -1.63253913e-02,
         1.21636618e-02,  -1.46350180e-02,   0.00000000e+00,
        -5.52547488e-02,   0.00000000e+00,   1.37667519e-03,
        -1.56763395e-01,   1.07303357e-02,  -4.12175092e-02,
        -4.63561554e-03,  -6.03641679e-03,   0.00000000e+00,
         6.11909589e-03,   0.00000000e+00,   3.70513763e-02,
         7.79454393e-03,   7.94810174e-03,   1.47091689e-02,
         0.00000000e+00,   3.76069320e-02,   0.00000000e+00,
        -6.81479351e-03,   2.90491191e-02,   6.70549128e-02,
         5.30762769e-02,  -1.22087916e-02,  -4.83623242e-03,
         5.82522322e-04,   0.00000000e+00,  -3.72396618e-03,
         0.00000000e+00,   2.57153369e-02,  -1.70891895e-02,
         8.40974082e-03,   8.48023192e-03,   0.00000000e+00,
         1.67188747e-02,   0.00000000e+00,   2.21549084e-02,
         3.40894585e-03,  -8.07351623e-02,  -1.10237189e-01,
         2.49326765e-02,  -2.13042054e-02,  -2.62756353e-02,
        -2.07237905e-03,   1.67599080e-02,  -2.13417191e-04,
        -6.28102017e-03,  -1.82721758e-02,  -6.77910415e-04,
         1.60291616e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.96415172e-02,
        -1.19370659e-03,   9.37609455e-03,   2.05371961e-02,
         1.76716993e-02,   0.00000000e+00,  -7.55632335e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.30518183e-02,   0.00000000e+00,
        -2.93412612e-02,   7.81328762e-03,  -6.73917441e-03,
         1.36423507e-02,  -2.79762587e-02,   0.00000000e+00,
         1.41317878e-02,   0.00000000e+00,  -6.85713841e-03,
         6.46945760e-04,   1.54031184e-02,  -1.00714273e-02,
         1.20244401e-02,   0.00000000e+00,  -4.01705094e-03,
         0.00000000e+00,   4.00963492e-03,  -1.64582390e-02,
         3.78647689e-03,   6.39769513e-03,  -3.45442072e-03,
        -3.67286718e-04,   0.00000000e+00,  -2.86664452e-03,
         0.00000000e+00,   4.41562125e-03,  -7.15381191e-03,
        -1.38319430e-02,   2.04328575e-03,   3.14594596e-03,
         2.36819972e-03,   4.01479051e-03,   0.00000000e+00,
        -1.45791082e-02,   0.00000000e+00,   7.63514257e-03,
        -2.62933967e-04,   5.22825671e-03,  -2.45933384e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.47441079e-03,   0.00000000e+00,
        -1.80567241e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.12395583e-02,
         8.90671776e-04,   5.96713072e-03,  -9.21352762e-03,
         7.64748776e-03,   0.00000000e+00,   1.55527246e-03,
         0.00000000e+00,   6.40473890e-03,  -1.32477255e-02,
        -4.50962144e-03,  -1.06541478e-02,   0.00000000e+00,
        -3.15306635e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.34830165e-02,
         0.00000000e+00,   2.74553791e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.37774198e-02,   0.00000000e+00,   2.54052976e-02,
         2.99255245e-03,  -3.59239902e-03,  -6.46587748e-03,
        -9.80921584e-03,   0.00000000e+00,  -6.17479859e-03,
         0.00000000e+00,   7.60059404e-06,  -5.16363982e-04,
         3.44671998e-03,   1.32336454e-02,   0.00000000e+00,
        -4.04013182e-03,   0.00000000e+00,   2.28638128e-02,
        -1.42878770e-03,  -2.39379009e-03,  -4.01619796e-03,
         7.25502437e-03,   0.00000000e+00,  -2.10072838e-03,
         0.00000000e+00,  -1.47968154e-02,   5.08552077e-03,
        -1.92762708e-03,   4.29504122e-03,   0.00000000e+00,
         1.25148271e-02,   0.00000000e+00,  -1.87744463e-04,
         3.15029443e-02,  -9.78744906e-04,   1.35719749e-02,
        -3.15324028e-04,   4.92784025e-03,   0.00000000e+00,
        -2.57515733e-03,   0.00000000e+00,  -6.08636454e-03,
        -7.01735823e-03,  -3.39877670e-03,  -6.34371259e-03,
         0.00000000e+00,  -1.89316765e-02,   0.00000000e+00,
         8.36961649e-04,  -2.90007506e-03,  -2.33396074e-02,
        -1.24042081e-02,   2.58820599e-04,   1.79167092e-03,
         1.98324035e-04,   0.00000000e+00,   3.57537193e-03,
         0.00000000e+00,  -8.41617105e-03,   6.09423969e-03,
        -1.24665649e-03,  -1.43765668e-03,   0.00000000e+00,
         2.97896833e-04,   0.00000000e+00,  -4.78996396e-03,
         1.28957905e-03,   1.96489847e-02,   2.20885476e-02,
        -2.10256027e-02,   1.86357937e-02,   4.53423795e-03,
         3.69167781e-03,  -6.83079577e-03,  -7.00936576e-04,
        -7.17631663e-03,   3.40553221e-03,   2.88330051e-03,
        -2.53086700e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.91088291e-02,
         8.01388768e-05,   4.01312329e-03,  -2.28084121e-02,
        -1.33817268e-02,   0.00000000e+00,  -8.04949742e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.01322384e-02,   0.00000000e+00,
         7.34081466e-03,  -1.20436062e-02,  -1.20534385e-02,
        -1.04218875e-02,   1.41532860e-02,   0.00000000e+00,
        -4.87871940e-03,   0.00000000e+00,  -2.27950521e-03,
         4.27112399e-03,   4.72557819e-03,   1.13204935e-03,
        -3.67286718e-04,   0.00000000e+00,  -7.46472761e-05,
         0.00000000e+00,   7.16283767e-03,   9.94383999e-03,
        -7.27733065e-04,   7.29102860e-03,  -4.35542008e-03,
         9.52584258e-03,   0.00000000e+00,   2.66564818e-03,
         0.00000000e+00,   5.81032080e-03,   6.56933128e-03,
         2.50724809e-02,  -2.15029406e-03,  -4.26367898e-05,
         1.14892814e-04,   3.49322428e-03,   0.00000000e+00,
         1.11380912e-02,   0.00000000e+00,  -4.59180303e-03,
        -3.45995896e-03,  -1.05878962e-03,   1.26808270e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.42146984e-03,   0.00000000e+00,
         6.99165744e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.33740454e-03,
        -1.32776199e-03,   3.38282756e-03,   2.60376905e-03,
        -6.81135842e-03,   0.00000000e+00,  -2.47813288e-03,
         0.00000000e+00,  -5.42825458e-03,   4.86161458e-04,
         4.48663442e-03,  -2.64256562e-03,   0.00000000e+00,
         1.97049388e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.98359290e-02,
         0.00000000e+00,  -3.55812684e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.23898735e-03,   0.00000000e+00,  -2.69199493e-02,
        -2.85273670e-03,  -6.39284513e-05,   1.06798522e-02,
         1.45657848e-02,   0.00000000e+00,   1.32322350e-02,
         0.00000000e+00,  -1.24831564e-03,  -1.13029914e-04,
        -5.15507837e-03,  -1.12777028e-02,   0.00000000e+00,
         6.33034978e-03,   0.00000000e+00,  -2.59089858e-02,
         8.83962238e-04,   2.90241657e-03,   7.08111345e-03,
        -1.49273579e-02,   0.00000000e+00,   3.99557804e-03,
         0.00000000e+00,   1.39341807e-02,  -2.27427475e-03,
         2.63757347e-03,  -2.82163351e-03,   0.00000000e+00,
        -8.99935119e-03,   0.00000000e+00,   6.91085785e-04,
        -2.87162940e-02,   6.89478773e-03,  -6.43079128e-03,
        -2.68069149e-03,  -1.72272382e-03,   0.00000000e+00,
         3.39949589e-03,   0.00000000e+00,   5.31482468e-03,
        -1.86249477e-03,   8.26483505e-04,  -6.79270191e-03,
         0.00000000e+00,  -4.55702452e-03,   0.00000000e+00,
        -2.80234997e-03,   8.37417316e-03,   7.01713740e-03,
         1.66610583e-02,  -7.40454836e-03,  -6.84275341e-04,
        -3.01275685e-03,   0.00000000e+00,  -4.83404998e-04,
         0.00000000e+00,   5.95533964e-03,  -2.22946548e-03,
         3.24838267e-03,   2.05258474e-03,   0.00000000e+00,
         6.23624286e-03,   0.00000000e+00,  -1.35730254e-03,
         1.13840900e-03,  -1.59027525e-02,  -2.18510159e-02,
        -4.77610559e-02,  -6.41732095e-04,  -5.75222976e-02,
        -2.60884407e-03,  -7.98857697e-03,  -5.18671866e-02,
        -7.69395228e-03,  -4.96375890e-03,  -2.44994032e-03,
        -5.72311553e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.64284255e-02,
         2.93366040e-03,   1.27542661e-02,   4.81923490e-03,
         5.25894122e-03,   0.00000000e+00,  -6.50413082e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.03509181e-03,   0.00000000e+00,
        -5.72985043e-02,   2.96974687e-03,   4.30677904e-03,
        -3.39501403e-04,  -3.58981083e-03,   0.00000000e+00,
         6.06715448e-03,   0.00000000e+00,  -6.01660245e-02,
         5.42177932e-03,   1.62655957e-02,  -1.62535825e-02,
         4.01479051e-03,   0.00000000e+00,   6.88102810e-03,
         0.00000000e+00,   1.65828286e-02,  -1.96129678e-02,
        -5.79896944e-04,   7.15920169e-03,  -1.11352928e-02,
         3.49322428e-03,   0.00000000e+00,   1.41631160e-02,
         0.00000000e+00,  -4.96428405e-03,  -1.28296999e-02,
        -1.43057130e-02,  -1.61013904e-03,   1.02772430e-02,
         2.74789552e-02,   3.63865973e-02,   0.00000000e+00,
        -3.75913989e-02,   0.00000000e+00,   2.88966764e-02,
         2.70688381e-03,   1.40367421e-02,  -6.55921552e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.59574720e-02,   0.00000000e+00,
        -4.68169922e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.14314603e-02,
        -7.13307449e-03,   1.16918406e-02,  -2.25205624e-02,
         7.91241840e-03,   0.00000000e+00,  -2.88410221e-03,
         0.00000000e+00,   3.14810514e-02,  -2.43347378e-02,
        -9.49444097e-03,  -4.95939386e-03,   0.00000000e+00,
        -6.09180501e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.30245040e-02,
         0.00000000e+00,  -1.55812204e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.00307817e-03,   0.00000000e+00,  -4.42500225e-02,
        -4.37662542e-03,  -4.33347479e-03,   4.54363395e-03,
         1.50833857e-02,   0.00000000e+00,   3.17861266e-02,
         0.00000000e+00,  -3.23150641e-03,  -2.53777078e-03,
        -8.55254426e-03,   1.95485963e-03,   0.00000000e+00,
         2.59349765e-03,   0.00000000e+00,  -4.61111226e-02,
         3.98269886e-03,   8.63596518e-03,   1.31101409e-02,
        -2.06450209e-02,   0.00000000e+00,   3.48083884e-03,
         0.00000000e+00,   7.03987856e-04,   1.18303184e-03,
         2.34598417e-03,   2.55828077e-03,   0.00000000e+00,
         5.98950124e-03,   0.00000000e+00,   1.18253033e-03,
        -5.05344898e-02,   2.45353296e-02,   3.13744744e-02,
         5.34136675e-03,   1.01882707e-02,   0.00000000e+00,
        -1.24526932e-02,   0.00000000e+00,  -7.42119844e-03,
        -1.29494058e-02,  -6.31735243e-03,  -1.09433261e-02,
         0.00000000e+00,   1.36802123e-03,   0.00000000e+00,
         1.83107047e-03,  -9.58891718e-04,  -5.96306136e-02,
         1.59644202e-02,  -2.00234697e-02,  -4.45648980e-03,
        -4.96409183e-03,   0.00000000e+00,   4.83484278e-03,
         0.00000000e+00,   1.14277213e-02,  -3.32400761e-05,
         2.97326372e-03,   5.11860613e-03,   0.00000000e+00,
         5.13992966e-03,   0.00000000e+00,  -3.67496019e-03,
         3.91949400e-03,   2.35177060e-03,  -4.44739121e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.88430646e-03,  -1.11442220e-03,
        -1.82589398e-04,   3.60190056e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.12766828e-04,   0.00000000e+00,
         2.40489940e-03,   9.82763904e-03,   1.84958170e-03,
         2.63794108e-03,   0.00000000e+00,  -5.42618536e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.41094317e-04,
         0.00000000e+00,   2.26232390e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.18877156e-04,   0.00000000e+00,
        -3.12967520e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.01026981e-03,   0.00000000e+00,
        -9.58076552e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.80956787e-03,
         0.00000000e+00,  -8.89732562e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.97622147e-03,   7.77772094e-03,   1.25380168e-03,
         7.89988400e-03,   0.00000000e+00,  -7.06225553e-03,
         0.00000000e+00,   3.34618402e-03,  -3.38877614e-03,
        -6.82957746e-04,  -5.47165762e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.79645129e-04,   0.00000000e+00,
        -5.24218485e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.52812408e-03,
         0.00000000e+00,   5.80206208e-04,   2.74334966e-03,
         5.90659059e-04,  -3.20241259e-03,   0.00000000e+00,
        -2.84032338e-03,   0.00000000e+00,   1.84717915e-03,
        -2.99691170e-04,  -2.47523034e-04,  -8.78175365e-04,
         0.00000000e+00,  -2.09738146e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.61077157e-03,   0.00000000e+00,
         2.81715256e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.26329151e-03,
         0.00000000e+00,   1.56098860e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.99543148e-03,   0.00000000e+00,
        -2.41806342e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.66498968e-04,
         0.00000000e+00,  -2.20475308e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.11736401e-03,
         0.00000000e+00,  -5.99161462e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.60236938e-03,   0.00000000e+00,   1.25323942e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.58712927e-04,   0.00000000e+00,
         1.65988511e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.51677898e-03,
         0.00000000e+00,   5.14233866e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.41312207e-02,  -2.79323384e-02,  -2.23877046e-02,
        -4.68264054e-03,   5.54820313e-03,  -5.91557667e-03,
         1.01985379e-02,  -1.70677633e-02,  -1.86634448e-03,
         2.46011079e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.69624988e-02,
         7.86414932e-03,   4.13611806e-03,   2.84042790e-02,
         2.50226583e-02,   0.00000000e+00,   1.16272989e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.65128687e-02,   0.00000000e+00,
        -3.18835490e-02,   1.65371623e-02,   1.15243872e-02,
         1.76086479e-02,  -2.45406157e-02,   0.00000000e+00,
         1.42270938e-02,   0.00000000e+00,  -1.35876221e-02,
        -1.63501269e-03,   1.30803649e-02,  -1.75114374e-02,
         7.64748776e-03,   0.00000000e+00,   2.11373880e-03,
         0.00000000e+00,   5.58203260e-03,  -1.09038537e-02,
         2.46836320e-03,   7.27195016e-03,  -9.40500244e-03,
        -6.81135842e-03,   0.00000000e+00,   4.43177690e-03,
         0.00000000e+00,  -1.67653936e-03,  -9.75435714e-03,
        -3.85295765e-03,  -1.88045340e-03,   3.04498293e-03,
         1.97018063e-03,   7.91241840e-03,   0.00000000e+00,
        -2.74264228e-02,   0.00000000e+00,   1.96851784e-02,
        -1.29965746e-04,   7.00638297e-03,  -3.53312140e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.94427588e-03,   0.00000000e+00,
        -3.37524050e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.19849097e-02,
         5.61037393e-03,   8.50218996e-03,  -1.73080030e-02,
         2.54202063e-02,   0.00000000e+00,   9.27981169e-04,
         0.00000000e+00,   2.46620030e-02,  -1.73447190e-02,
        -1.02721815e-02,  -3.63929144e-03,   0.00000000e+00,
        -3.65096950e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.05874974e-02,
         0.00000000e+00,   2.11468505e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.77729232e-02,   0.00000000e+00,   3.38245283e-02,
        -4.70242718e-03,   1.36740043e-03,  -1.50873398e-02,
        -2.29496066e-02,   0.00000000e+00,  -1.81022453e-02,
         0.00000000e+00,  -1.49025364e-03,   5.50613202e-04,
         2.71593897e-03,   1.98556041e-02,   0.00000000e+00,
        -1.01803695e-02,   0.00000000e+00,   3.07435903e-02,
         7.94187448e-03,  -9.02925530e-03,  -1.16919142e-02,
         2.26829837e-02,   0.00000000e+00,  -4.12596162e-03,
         0.00000000e+00,  -2.91578729e-02,   7.20459024e-03,
        -2.55154384e-03,   4.25113880e-03,   0.00000000e+00,
         1.87938700e-02,   0.00000000e+00,  -2.46325486e-03,
         3.18997214e-02,  -2.34356197e-03,   3.19336649e-02,
        -1.13189608e-03,   6.20589955e-04,   0.00000000e+00,
        -8.67356224e-03,   0.00000000e+00,  -7.59944650e-03,
        -1.11556463e-02,  -7.85889518e-03,   2.90712005e-04,
         0.00000000e+00,  -3.38527551e-03,   0.00000000e+00,
         7.78075717e-03,  -8.89782305e-03,  -2.83120007e-02,
        -2.56973527e-02,   4.56901753e-03,   1.37077661e-03,
        -6.97945299e-03,   0.00000000e+00,  -2.82167563e-03,
         0.00000000e+00,  -3.69162418e-03,   7.00621004e-03,
         1.29541938e-03,   2.90811895e-03,   0.00000000e+00,
        -6.26892157e-03,   0.00000000e+00,   2.85455288e-03,
        -2.34449496e-03,   2.75047166e-02,   2.63685578e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.11699371e-03,   1.48918808e-03,
         2.95022294e-04,  -8.27506446e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.22354874e-03,   0.00000000e+00,
        -1.68954792e-03,  -4.57798649e-03,  -5.86296446e-04,
         2.53506388e-03,   0.00000000e+00,   1.42159376e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.15557078e-03,
         0.00000000e+00,   5.73574507e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.81420828e-04,   0.00000000e+00,
        -2.85787924e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.67410622e-03,   0.00000000e+00,
         1.35882182e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.11603184e-03,
         0.00000000e+00,  -1.57686008e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.51911160e-04,   2.70811579e-03,   2.19315651e-04,
        -3.20241259e-03,   0.00000000e+00,  -2.38576435e-03,
         0.00000000e+00,   2.76398069e-03,   6.01874239e-04,
        -8.58179249e-04,  -7.53757505e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.56483140e-03,   0.00000000e+00,
         3.01890456e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.55863058e-03,
         0.00000000e+00,   2.91878186e-03,  -4.02244612e-03,
        -9.50623573e-04,   1.68707755e-02,   0.00000000e+00,
         5.15491549e-03,   0.00000000e+00,  -5.48540303e-03,
         1.08879092e-03,  -1.71370113e-03,  -1.30531204e-03,
         0.00000000e+00,   2.65084707e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.17096934e-02,   0.00000000e+00,
        -2.51068762e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.37878152e-03,
         0.00000000e+00,  -4.47992237e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.38399272e-02,   0.00000000e+00,
         3.48700258e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.11368311e-03,
         0.00000000e+00,   5.16554480e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.96988410e-03,
         0.00000000e+00,  -4.32585901e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.14826995e-03,   0.00000000e+00,  -1.94776619e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.76547559e-03,   0.00000000e+00,
         7.22337958e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.25242516e-04,
         0.00000000e+00,  -1.73739541e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.39220377e-02,   3.91615281e-02,  -1.91258477e-02,
         3.61967241e-03,  -1.80322410e-02,  -4.50918087e-02,
         1.31474326e-03,   1.85685159e-02,  -1.04424935e-03,
        -9.07933912e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.05920185e-01,
        -3.15755765e-03,  -4.04975759e-03,  -4.57572041e-02,
        -3.76036597e-02,   0.00000000e+00,  -6.16515060e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.64566694e-02,   0.00000000e+00,
        -5.92522569e-03,  -2.65354920e-02,   3.32369204e-04,
        -2.46722580e-02,   3.89522672e-02,   0.00000000e+00,
        -1.70727431e-02,   0.00000000e+00,  -4.42607674e-02,
         9.50915820e-03,  -4.52901127e-03,   5.86626180e-03,
        -9.80921584e-03,   0.00000000e+00,   6.06741997e-03,
         0.00000000e+00,   1.20024807e-02,  -5.10685327e-04,
        -6.02988903e-03,  -6.41509704e-04,   3.90218080e-03,
         1.45657848e-02,   0.00000000e+00,   9.03031884e-03,
         0.00000000e+00,  -5.76991073e-03,   1.59549710e-03,
        -1.36146119e-03,  -4.69832376e-03,  -1.90071940e-03,
         9.29719176e-03,   1.50833857e-02,   0.00000000e+00,
         2.99827532e-02,   0.00000000e+00,  -4.26382491e-03,
        -1.79040954e-03,  -6.55564157e-03,  -7.61016629e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.99913831e-02,   0.00000000e+00,
         1.28425733e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.46279926e-03,
        -1.11260911e-02,   7.35948132e-03,   3.05058986e-03,
        -2.29496066e-02,   0.00000000e+00,  -1.07885295e-02,
         0.00000000e+00,   2.05727411e-03,   3.54041648e-03,
         5.20465281e-03,   7.03282256e-03,   0.00000000e+00,
        -7.25303980e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.84211075e-02,
         0.00000000e+00,  -2.04425613e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.61225040e-02,   0.00000000e+00,  -9.99210051e-02,
        -9.44528206e-04,   2.85765400e-05,   4.00155542e-02,
         6.80288013e-02,   0.00000000e+00,   6.41027337e-02,
         0.00000000e+00,  -1.79608934e-03,  -9.83082082e-05,
        -1.40370246e-02,  -3.12373214e-02,   0.00000000e+00,
         1.58007251e-02,   0.00000000e+00,  -1.00847796e-01,
        -4.22688616e-03,   1.83881093e-02,   2.86230695e-02,
        -5.58962922e-02,   0.00000000e+00,   9.30891270e-03,
         0.00000000e+00,   4.77712750e-02,  -1.15617849e-02,
         7.37908816e-03,  -2.83355914e-03,   0.00000000e+00,
        -1.92867700e-02,   0.00000000e+00,   1.79841839e-03,
        -1.00483222e-01,   2.89914947e-02,  -1.94547219e-02,
        -2.82979628e-03,   5.63989402e-03,   0.00000000e+00,
         8.77021585e-03,   0.00000000e+00,   9.28319765e-03,
        -2.98095745e-03,   1.78856366e-03,   6.08618781e-05,
         0.00000000e+00,   1.31683653e-02,   0.00000000e+00,
        -3.75078243e-03,   5.51099119e-03,  -1.54937050e-02,
         6.58587683e-02,  -2.73592791e-02,  -3.52813523e-03,
         1.78867421e-03,   0.00000000e+00,   2.61092217e-03,
         0.00000000e+00,   2.59580927e-02,  -9.95357483e-03,
         5.48646984e-03,   3.69158205e-03,   0.00000000e+00,
         1.01946434e-02,   0.00000000e+00,   3.81922751e-03,
        -4.61119058e-03,  -3.99454830e-02,  -9.31080525e-02,
         1.03926969e-01,  -3.73084720e-02,   4.28501484e-02,
        -4.24196237e-03,   1.56494101e-02,   6.08529605e-02,
         7.49754161e-03,  -1.90762589e-02,  -7.62325937e-03,
         1.07338500e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.16625540e-01,
         5.59662849e-03,   1.38769445e-03,   4.05883888e-02,
         2.70249915e-02,   0.00000000e+00,   7.29996486e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.59319771e-02,   0.00000000e+00,
         2.46695154e-02,   2.37046094e-02,   4.20321685e-03,
         2.78978761e-02,  -3.91045808e-02,   0.00000000e+00,
         1.54171806e-02,   0.00000000e+00,   6.72164236e-02,
        -1.08886353e-02,  -4.01966950e-03,  -2.03013057e-03,
         7.25502437e-03,   0.00000000e+00,  -6.56054189e-03,
         0.00000000e+00,  -1.68061365e-02,   1.30738057e-02,
         4.59206378e-03,  -1.59869965e-03,   5.35912281e-04,
        -1.49273579e-02,   0.00000000e+00,  -8.58668435e-03,
         0.00000000e+00,   7.14106932e-03,   2.81537656e-03,
         1.21021921e-02,   5.40875787e-03,  -9.67944379e-04,
        -1.46811377e-02,  -2.06450209e-02,   0.00000000e+00,
        -1.28916375e-02,   0.00000000e+00,  -7.25528888e-03,
         1.14821107e-03,   1.31696395e-03,   2.84014297e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.50978667e-02,   0.00000000e+00,
         2.83493255e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.72636267e-02,
         1.46380253e-02,  -1.43611504e-02,  -1.27649520e-03,
         2.26829837e-02,   0.00000000e+00,   7.60544907e-03,
         0.00000000e+00,  -1.56609786e-02,   6.48959072e-03,
        -2.03478189e-03,  -3.09867041e-03,   0.00000000e+00,
         3.16730475e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.63658156e-02,
         0.00000000e+00,   2.53803714e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.37825093e-02,   0.00000000e+00,   1.10642121e-01,
         4.96214517e-04,   2.20862138e-03,  -3.07118358e-02,
        -5.58962922e-02,   0.00000000e+00,  -5.78268268e-02,
         0.00000000e+00,   2.27287972e-03,   8.74527153e-04,
         1.38313719e-02,   2.63813619e-02,   0.00000000e+00,
        -1.55224247e-02,   0.00000000e+00,   1.02609581e-01,
         1.19939992e-02,  -3.18718700e-02,  -4.74838453e-02,
         8.22951156e-02,   0.00000000e+00,  -1.82231244e-02,
         0.00000000e+00,  -6.30983507e-02,   1.47388468e-02,
        -8.71694906e-03,   5.98879391e-04,   0.00000000e+00,
         1.62251594e-02,   0.00000000e+00,  -2.38111708e-03,
         1.23259572e-01,  -3.71837901e-02,   9.65442583e-03,
         5.19802016e-03,  -1.23052707e-02,   0.00000000e+00,
        -3.88887380e-03,   0.00000000e+00,  -1.57322218e-03,
         7.03991422e-03,   1.83323437e-03,   2.96593605e-03,
         0.00000000e+00,  -7.41790952e-03,   0.00000000e+00,
         5.32076241e-03,  -5.06915557e-03,   3.55918028e-02,
        -6.70745206e-02,   3.41070127e-02,   6.76703560e-03,
        -4.87684841e-03,   0.00000000e+00,  -4.15026941e-03,
         0.00000000e+00,  -2.27765377e-02,   8.42871417e-03,
        -5.72416948e-03,  -2.35883212e-03,   0.00000000e+00,
        -1.31481586e-02,   0.00000000e+00,   5.71497531e-04,
         1.04875151e-04,   3.71304552e-02,   1.08147144e-01,
        -2.54244130e-02,  -4.89749492e-03,  -3.29166157e-02,
        -5.20302996e-03,   2.82520867e-03,  -2.61332410e-02,
        -4.38071896e-03,   2.72812234e-04,  -5.70298254e-04,
        -2.90354232e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.24256935e-02,
        -6.46724597e-03,   6.67473756e-03,   6.20937054e-03,
         4.23251991e-03,   0.00000000e+00,  -3.03768339e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.17719681e-03,   0.00000000e+00,
        -3.13401612e-02,   1.82252251e-03,   1.79207983e-03,
        -3.13479360e-04,  -6.03641679e-03,   0.00000000e+00,
         1.44581590e-03,   0.00000000e+00,  -2.32910465e-02,
         1.80016307e-03,   7.09560165e-03,  -5.63787738e-03,
         4.92784025e-03,   0.00000000e+00,   1.54815043e-03,
         0.00000000e+00,   5.93966018e-03,  -1.90395818e-02,
         2.99053935e-03,   1.05605079e-03,  -3.70393770e-03,
        -1.72272382e-03,   0.00000000e+00,   4.09204390e-03,
         0.00000000e+00,  -2.48542902e-03,  -6.44685675e-03,
        -1.78322799e-02,   8.79502625e-03,   1.20941648e-02,
         9.65671356e-03,   1.01882707e-02,   0.00000000e+00,
        -1.53290610e-02,   0.00000000e+00,   9.64679700e-03,
         1.47568135e-03,   5.96252834e-04,  -3.46646837e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.88412247e-03,   0.00000000e+00,
        -1.93011643e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.71587730e-02,
        -2.95048806e-03,   1.53042408e-02,  -8.96977204e-03,
         6.20589955e-04,   0.00000000e+00,  -2.61437695e-03,
         0.00000000e+00,   1.41777730e-02,  -1.19051662e-02,
        -7.74621626e-03,  -1.20805761e-04,   0.00000000e+00,
        -2.67543662e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.03290725e-02,
         0.00000000e+00,  -8.40618649e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -4.16844612e-04,   0.00000000e+00,  -1.97083034e-02,
         1.05888752e-02,  -7.42686278e-03,   2.16002712e-04,
         5.63989402e-03,   0.00000000e+00,   1.39549067e-02,
         0.00000000e+00,   1.96086194e-03,  -1.61425006e-03,
        -2.76005480e-03,   1.21939903e-03,   0.00000000e+00,
         2.81502599e-03,   0.00000000e+00,  -1.79431615e-02,
        -1.40169478e-02,   6.96139711e-03,   9.02961020e-03,
        -1.23052707e-02,   0.00000000e+00,   6.12752701e-04,
         0.00000000e+00,   6.25889001e-03,  -1.06517023e-04,
         3.06808831e-03,   4.48224053e-03,   0.00000000e+00,
         4.50544007e-03,   0.00000000e+00,   1.71442018e-03,
        -1.91191151e-02,   5.58704283e-03,   8.35349698e-03,
         3.52792005e-04,   2.16761358e-02,   0.00000000e+00,
        -7.97871945e-03,   0.00000000e+00,   5.08629630e-03,
        -7.74195432e-03,  -1.57803163e-03,  -3.75602029e-03,
         0.00000000e+00,  -3.20578235e-03,   0.00000000e+00,
        -1.28527740e-03,  -3.46256963e-03,  -3.33720562e-02,
         3.95863502e-03,  -8.11649998e-03,  -1.35847620e-03,
         1.26933276e-02,   0.00000000e+00,   1.08411586e-02,
         0.00000000e+00,  -5.68027252e-03,   2.77640081e-03,
        -1.46377174e-03,   1.24678898e-04,   0.00000000e+00,
         6.08841020e-03,   0.00000000e+00,  -6.35992949e-03,
         1.74666184e-03,   3.37839521e-03,  -2.33033854e-02,
        -3.75564455e-03,   6.09816482e-03,   8.53067830e-04,
         5.34155442e-03,  -7.93662959e-03,  -2.28419585e-03,
        -1.68533847e-02,   1.77513868e-02,   3.78073273e-03,
        -8.66038848e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -8.77761169e-03,
        -2.93241367e-03,  -3.03557427e-03,  -5.44886433e-03,
        -5.61920644e-03,   0.00000000e+00,   3.54377368e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.19352941e-03,   0.00000000e+00,
         3.24439813e-03,   1.65649972e-02,   1.21214411e-03,
        -2.82870366e-03,   5.82522322e-04,   0.00000000e+00,
        -5.14325377e-03,   0.00000000e+00,   4.46301687e-03,
        -4.75647167e-03,  -3.45647484e-03,   2.64645452e-03,
         1.98324035e-04,   0.00000000e+00,   2.81519077e-03,
         0.00000000e+00,  -3.68936163e-03,   3.50782248e-03,
         5.77277035e-03,  -1.54668461e-03,  -4.24829421e-04,
        -3.01275685e-03,   0.00000000e+00,   9.43480196e-04,
         0.00000000e+00,   3.66698532e-04,   2.93203078e-03,
         3.94113579e-03,   6.52842538e-03,  -5.44284337e-03,
        -3.19949399e-03,  -4.96409183e-03,   0.00000000e+00,
         5.79633996e-03,   0.00000000e+00,   9.78557184e-04,
         1.14154379e-03,  -2.09619337e-03,   5.87266083e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.93279786e-04,   0.00000000e+00,
         6.08741823e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.80548414e-03,
        -8.16989357e-03,   5.14160996e-04,   1.50166343e-03,
        -6.97945299e-03,   0.00000000e+00,  -2.59375118e-03,
         0.00000000e+00,   1.02726223e-03,   4.26282319e-03,
         1.56951724e-03,   2.71767028e-03,   0.00000000e+00,
         5.32725255e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.19510680e-03,
         0.00000000e+00,  -4.77204325e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.34377656e-03,   0.00000000e+00,  -5.57187235e-03,
         2.46857378e-02,  -9.64743227e-03,  -2.15090765e-03,
         1.78867421e-03,   0.00000000e+00,  -7.23450523e-04,
         0.00000000e+00,   6.86520933e-03,  -1.33321646e-03,
        -6.92900234e-04,  -3.02283547e-03,   0.00000000e+00,
         2.03964869e-03,   0.00000000e+00,  -3.94909516e-03,
        -2.32542513e-02,   1.13466704e-02,   3.16766656e-03,
        -4.87684841e-03,   0.00000000e+00,  -2.41290524e-03,
         0.00000000e+00,  -1.43075553e-03,   6.64340918e-04,
         4.65905311e-04,   1.41376024e-03,   0.00000000e+00,
        -5.75461520e-03,   0.00000000e+00,  -9.53606342e-04,
        -1.10294861e-02,  -1.27792435e-03,  -6.85965815e-03,
         2.41873358e-04,   1.26933276e-02,   0.00000000e+00,
         7.99221891e-03,   0.00000000e+00,  -7.56210757e-03,
         3.47508122e-03,  -9.17587183e-04,   5.44382651e-03,
         0.00000000e+00,   1.05471643e-02,   0.00000000e+00,
        -5.06293968e-03,   6.46823352e-03,   1.85125614e-03,
        -6.66752969e-03,  -1.64179253e-03,   1.46056207e-03,
         3.69868223e-02,   0.00000000e+00,   1.24441025e-02,
         0.00000000e+00,  -1.37905356e-02,   2.39884977e-03,
        -3.57188600e-03,  -3.56704124e-03,   0.00000000e+00,
         3.09798287e-03,   0.00000000e+00,  -5.60979259e-03,
         2.05636150e-02,  -1.87035788e-03,   6.89046506e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.45116707e-01,  -5.68519110e-02,
        -1.38806665e-02,   9.03403312e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.29026590e-04,   0.00000000e+00,
        -1.86047643e-02,   3.78827628e-02,   1.31516790e-02,
        -4.73319656e-03,   0.00000000e+00,  -3.43516953e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.65027188e-02,
         0.00000000e+00,  -1.68434960e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.11533132e-03,   0.00000000e+00,
         4.45935674e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.69532088e-03,   0.00000000e+00,
        -7.90622035e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.16432245e-03,
         0.00000000e+00,  -3.83392917e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.55838717e-03,  -7.15520123e-03,  -6.14274219e-03,
         6.88430646e-03,   0.00000000e+00,  -3.28923950e-03,
         0.00000000e+00,   6.63486622e-05,  -8.82509656e-03,
         4.66558363e-03,   1.85125729e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.33236484e-03,   0.00000000e+00,
        -7.80252209e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.26159400e-02,
         0.00000000e+00,  -2.45679292e-02,   1.44074784e-02,
         4.93598966e-03,  -3.11699371e-03,   0.00000000e+00,
        -9.34491072e-04,   0.00000000e+00,  -1.76333999e-02,
         8.53962690e-03,  -5.30296420e-03,  -6.74467099e-03,
         0.00000000e+00,  -1.98331398e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.71869624e-03,   0.00000000e+00,
         2.27685321e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.46569204e-03,
         0.00000000e+00,  -4.82496329e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.56379659e-03,   0.00000000e+00,
         1.53535467e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.81758838e-03,
         0.00000000e+00,  -1.69060063e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.42308326e-02,
         0.00000000e+00,   1.45855971e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.42892947e-02,   0.00000000e+00,   4.39681238e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.46757727e-02,   0.00000000e+00,
         2.27082999e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.83368973e-02,
         0.00000000e+00,   1.14388865e-01,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.68519110e-02,   3.27569124e-02,
         1.35562843e-02,  -1.17175996e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.94399007e-03,   0.00000000e+00,
         2.09886005e-02,   9.38813751e-03,  -2.98221760e-03,
         7.83624103e-03,   0.00000000e+00,  -5.83805707e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.64681695e-03,
         0.00000000e+00,  -3.74848829e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.75161501e-03,   0.00000000e+00,
        -3.72910591e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.21829890e-03,   0.00000000e+00,
        -4.39961564e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.68491160e-03,
         0.00000000e+00,  -1.09127465e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.32498617e-03,   9.85354698e-03,   3.75114885e-03,
        -1.11442220e-03,   0.00000000e+00,  -1.20310805e-03,
         0.00000000e+00,  -4.15122974e-03,  -3.05489469e-03,
        -9.82750964e-04,  -2.73710679e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.40319953e-03,   0.00000000e+00,
         2.18253599e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.89958704e-03,
         0.00000000e+00,   1.41819024e-02,  -7.09320782e-03,
        -1.97721548e-03,   1.48918808e-03,   0.00000000e+00,
         1.25232678e-04,   0.00000000e+00,   3.79945887e-03,
        -3.79892451e-03,   2.20558885e-03,   2.04680496e-03,
         0.00000000e+00,   8.45201787e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.17072117e-03,   0.00000000e+00,
         1.30386836e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.54479346e-04,
         0.00000000e+00,   2.81170315e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.30455216e-03,   0.00000000e+00,
        -1.62375738e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.15221888e-03,
         0.00000000e+00,   1.71655851e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.20664318e-03,
         0.00000000e+00,  -4.47303759e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.44706265e-03,   0.00000000e+00,  -2.34784768e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.94524866e-03,   0.00000000e+00,
        -6.04570228e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.56676712e-02,
         0.00000000e+00,  -4.42233974e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.38806665e-02,   1.35562843e-02,
         2.25056839e-02,  -2.81837889e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.77464421e-02,   0.00000000e+00,
         7.89545074e-03,   7.63191668e-04,   6.27640470e-04,
         1.52797557e-03,   0.00000000e+00,  -8.51135033e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.50143048e-03,
         0.00000000e+00,  -5.88805725e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.12209537e-03,   0.00000000e+00,
         2.34779023e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.25221608e-04,   0.00000000e+00,
         9.10668454e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.81477789e-03,
         0.00000000e+00,   8.24982998e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.95992678e-03,   2.72999464e-03,   2.57064974e-03,
        -1.82589398e-04,   0.00000000e+00,   8.18614025e-04,
         0.00000000e+00,  -1.03121473e-05,   1.14063102e-04,
         1.24249523e-04,  -4.68696244e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.56395074e-03,   0.00000000e+00,
        -3.65685663e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.43956731e-03,
         0.00000000e+00,   4.29767901e-03,  -2.32188011e-03,
        -3.96276788e-03,   2.95022294e-04,   0.00000000e+00,
        -4.55960343e-03,   0.00000000e+00,  -3.00679485e-03,
         4.38967325e-04,   1.65426429e-03,   4.66243660e-03,
         0.00000000e+00,   2.62447358e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.42452346e-03,   0.00000000e+00,
         1.39035379e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.16205008e-03,
         0.00000000e+00,   1.63611816e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.90021674e-03,   0.00000000e+00,
         1.75778502e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.97664932e-03,
         0.00000000e+00,   1.84428715e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.19312189e-03,
         0.00000000e+00,  -1.41005339e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.74728571e-03,   0.00000000e+00,  -5.63319189e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.57509492e-03,   0.00000000e+00,
        -1.67929473e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.58795097e-03,
         0.00000000e+00,  -1.11196479e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.03403312e-03,  -1.17175996e-02,
        -2.81837889e-03,   3.60872394e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.09358559e-02,   0.00000000e+00,
        -4.26544542e-03,   4.09138600e-03,   9.99842670e-04,
        -5.36362423e-03,   0.00000000e+00,  -5.73888138e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.14459621e-02,
         0.00000000e+00,   6.06043513e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.79325236e-03,   0.00000000e+00,
        -1.52697332e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.34209482e-03,   0.00000000e+00,
         1.27369659e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.84042998e-03,
         0.00000000e+00,   1.33997454e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.41843500e-03,  -2.32947164e-04,  -4.30538162e-04,
         3.60190056e-03,   0.00000000e+00,   8.41883800e-04,
         0.00000000e+00,  -1.25483181e-03,  -2.29613628e-05,
        -1.37626513e-03,  -5.46059114e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.43112611e-03,   0.00000000e+00,
        -1.36761252e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.56552056e-04,
         0.00000000e+00,  -2.48366585e-03,   1.86326899e-03,
         4.17179277e-04,  -8.27506446e-03,   0.00000000e+00,
        -3.38173719e-03,   0.00000000e+00,   4.20064398e-03,
        -9.54627509e-04,   3.43344863e-03,   4.16068592e-03,
         0.00000000e+00,  -8.07988236e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.49109850e-03,   0.00000000e+00,
         1.97964370e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.81721867e-03,
         0.00000000e+00,   1.93285553e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.54154842e-03,   0.00000000e+00,
        -3.02987842e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.25347826e-03,
         0.00000000e+00,  -2.34083421e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.58372743e-03,
         0.00000000e+00,  -1.34713670e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.11592231e-03,   0.00000000e+00,   5.50475861e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.51328633e-03,   0.00000000e+00,
         6.37767123e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.75325603e-04,
         0.00000000e+00,   7.37862243e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.85863842e-01,  -1.62965583e-01,   4.45989121e-01,
        -1.20950706e-02,   9.15730204e-02,   5.49077892e-01,
        -9.35851825e-03,  -9.64861731e-02,  -1.31112035e-02,
         7.04543948e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.91096009e-01,
         1.66391384e-02,   2.81766221e-02,   1.94249440e-01,
         1.27093586e-01,   0.00000000e+00,   5.84053877e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.23869937e-01,   0.00000000e+00,
         3.87138522e-01,   8.08060339e-02,  -3.01127290e-02,
         1.08259655e-01,  -1.47751350e-01,   0.00000000e+00,
         7.58644906e-02,   0.00000000e+00,   5.34848628e-01,
        -3.50321454e-02,  -3.80457282e-03,   1.47815144e-04,
         2.96415172e-02,   0.00000000e+00,  -3.96589438e-02,
         0.00000000e+00,  -7.68224141e-02,   2.72972840e-01,
         1.15455311e-02,  -1.32958915e-02,   6.49407111e-03,
        -2.91088291e-02,   0.00000000e+00,  -3.99900700e-02,
         0.00000000e+00,   3.59930992e-02,   2.11910137e-02,
         2.84605854e-01,   8.11355164e-03,  -1.47786707e-02,
        -3.67520358e-02,  -4.64284255e-02,   0.00000000e+00,
        -4.00470358e-02,   0.00000000e+00,  -2.04002793e-02,
        -9.91105229e-03,   2.09981820e-02,   3.75031852e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.97010374e-02,   0.00000000e+00,
        -5.63640373e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.82864669e-01,
         3.02578040e-02,  -3.37458659e-02,   2.77288377e-03,
         3.69624988e-02,   0.00000000e+00,   2.17732090e-02,
         0.00000000e+00,  -3.24127760e-02,   8.59227344e-03,
        -4.87551801e-03,  -2.40897685e-02,   0.00000000e+00,
         3.74733865e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.11765719e-01,
         0.00000000e+00,   8.09016126e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.18974136e-01,   0.00000000e+00,   8.06124887e-01,
         9.25067650e-03,  -5.03457168e-03,  -7.42819757e-02,
        -1.05920185e-01,   0.00000000e+00,  -1.41009547e-01,
         0.00000000e+00,  -8.90875460e-03,   1.37284047e-03,
         5.67770166e-02,   1.17088303e-01,   0.00000000e+00,
        -5.32282847e-02,   0.00000000e+00,   7.10143735e-01,
         2.00236179e-02,  -4.28170338e-02,  -8.27784582e-02,
         1.16625540e-01,   0.00000000e+00,  -4.44142066e-02,
         0.00000000e+00,  -1.24353869e-01,   3.69250157e-02,
        -2.84232026e-02,   1.13438976e-02,   0.00000000e+00,
         5.95205564e-02,   0.00000000e+00,   9.56327607e-03,
         7.53152611e-01,  -7.42613501e-02,   3.01821220e-02,
         6.01783564e-03,  -2.24256935e-02,   0.00000000e+00,
         1.22547693e-03,   0.00000000e+00,  -3.23393922e-02,
         4.17273147e-02,  -1.02898646e-02,  -2.41540323e-02,
         0.00000000e+00,  -7.76577082e-02,   0.00000000e+00,
         1.77516157e-02,  -1.56921305e-02,   4.30842239e-01,
        -1.29953147e-01,   6.74888769e-02,   2.23350123e-02,
        -8.77761169e-03,   0.00000000e+00,  -6.84811725e-03,
         0.00000000e+00,  -7.22477965e-02,   2.93343615e-02,
        -2.39789566e-02,  -1.16792260e-02,   0.00000000e+00,
        -4.43845290e-02,   0.00000000e+00,  -1.29799760e-02,
         6.17271481e-03,   1.54339041e-01,   7.51826300e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.29026590e-04,   1.94399007e-03,
         1.77464421e-02,   1.09358559e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.36438308e-02,   0.00000000e+00,
        -6.67310969e-04,  -4.49779784e-03,  -6.42052839e-03,
        -5.63584651e-03,   0.00000000e+00,  -1.14875640e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.55039226e-03,
         0.00000000e+00,  -2.27038457e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.92547901e-03,   0.00000000e+00,
         6.77572862e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.73295657e-03,   0.00000000e+00,
         7.57691562e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.53860795e-03,
         0.00000000e+00,   2.53868513e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.59472158e-03,  -1.28204460e-03,   3.54461851e-04,
         5.12766828e-04,   0.00000000e+00,   4.33512223e-03,
         0.00000000e+00,   1.20587540e-03,  -6.96230448e-05,
        -1.41436652e-03,   2.10309767e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.15919076e-03,   0.00000000e+00,
        -1.05643870e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.18421734e-03,
         0.00000000e+00,  -7.22015842e-04,  -1.39121068e-04,
        -4.61134224e-03,  -3.22354874e-03,   0.00000000e+00,
        -6.92213548e-03,   0.00000000e+00,  -2.60302241e-03,
         7.80668027e-04,   1.82364331e-03,   7.45552875e-03,
         0.00000000e+00,  -2.21776230e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.31780185e-03,   0.00000000e+00,
         2.34642177e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.39392335e-03,
         0.00000000e+00,   2.19462395e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.21971377e-03,   0.00000000e+00,
         1.72272557e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.87849723e-03,
         0.00000000e+00,   7.92332901e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.71837840e-04,
         0.00000000e+00,   1.35177414e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.74403519e-03,   0.00000000e+00,   2.23893998e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.91101418e-06,   0.00000000e+00,
         7.22771170e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.93796957e-03,
         0.00000000e+00,   1.21261982e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.11090846e-02,   6.74216878e-02,   3.58957030e-02,
         1.88360546e-02,  -2.75887564e-02,  -8.24662430e-03,
        -9.23225548e-03,   3.62744464e-02,   5.39457690e-03,
        -6.61492684e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.23869937e-01,
        -1.32452451e-03,  -1.63694168e-02,  -7.29799930e-02,
        -4.98746935e-02,   0.00000000e+00,  -1.97433627e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.76525283e-02,   0.00000000e+00,
         7.20390281e-02,  -2.83915496e-02,  -1.32202546e-02,
        -4.07572504e-02,   5.58909333e-02,   0.00000000e+00,
        -2.89188493e-02,   0.00000000e+00,   7.22957172e-03,
         5.67779243e-03,  -1.28255854e-02,   2.10214585e-02,
        -1.30518183e-02,   0.00000000e+00,   2.57597550e-03,
         0.00000000e+00,   4.72406341e-03,   3.20867426e-02,
        -5.74339468e-03,  -5.67590782e-03,   7.51581481e-03,
         1.01322384e-02,   0.00000000e+00,   3.13246907e-03,
         0.00000000e+00,  -1.91207246e-03,   1.53201914e-02,
         3.84807771e-02,  -2.22490145e-03,   3.38658608e-04,
        -1.51283433e-03,   1.03509181e-03,   0.00000000e+00,
         3.15284375e-02,   0.00000000e+00,  -1.09356532e-02,
        -2.31148185e-03,  -1.29512936e-02,   5.24216902e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.41114606e-02,   0.00000000e+00,
         3.54050047e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.25676073e-02,
        -5.64505773e-03,   2.85443074e-03,   1.20050348e-02,
        -1.65128687e-02,   0.00000000e+00,  -8.80737259e-03,
         0.00000000e+00,  -1.23777561e-02,   1.68378098e-02,
         6.59398452e-03,   6.73611260e-03,   0.00000000e+00,
         5.18359410e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.28181159e-02,
         0.00000000e+00,  -1.36357658e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.35251817e-02,   0.00000000e+00,  -1.07017029e-01,
        -6.60192712e-04,   3.09074418e-03,   2.07499870e-02,
         2.64566694e-02,   0.00000000e+00,   2.78805219e-02,
         0.00000000e+00,   1.71117427e-03,   5.79236689e-04,
        -1.24418126e-02,  -4.17803872e-02,   0.00000000e+00,
         1.85650783e-02,   0.00000000e+00,  -8.50412218e-02,
        -2.33302140e-03,   5.40446268e-03,   1.65099395e-02,
        -2.59319771e-02,   0.00000000e+00,   1.11965062e-02,
         0.00000000e+00,   3.60522380e-02,  -9.07971720e-03,
         6.54732847e-03,  -9.06915634e-03,   0.00000000e+00,
        -3.43285812e-02,   0.00000000e+00,  -4.46642784e-03,
        -9.63506097e-02,   1.25327510e-02,  -2.53171158e-02,
        -2.83527467e-03,  -2.17719681e-03,   0.00000000e+00,
         6.76761948e-03,   0.00000000e+00,   2.17767525e-02,
         4.72616349e-03,   3.21311947e-03,   5.75261016e-03,
         0.00000000e+00,   1.76235072e-02,   0.00000000e+00,
        -8.00696535e-03,   2.17963888e-02,   4.36133005e-02,
         3.53476401e-02,  -1.34758826e-02,  -3.21974464e-03,
         2.19352941e-03,   0.00000000e+00,   8.45164444e-04,
         0.00000000e+00,   1.63844330e-02,  -1.12927349e-02,
         5.78239458e-03,   3.22733434e-03,   0.00000000e+00,
         1.53316229e-02,   0.00000000e+00,   6.87856419e-03,
         7.60078426e-03,  -5.85236629e-02,  -7.75908923e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.65027188e-02,  -7.64681695e-03,
         7.50143048e-03,  -1.14459621e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.55039226e-03,   0.00000000e+00,
        -8.08356345e-03,  -3.28706668e-03,  -3.06762843e-03,
         3.14582238e-03,   0.00000000e+00,  -1.07679412e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.03392085e-02,
         0.00000000e+00,   1.17460871e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.32736039e-03,   0.00000000e+00,
         1.14824773e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.06620896e-03,   0.00000000e+00,
         4.95968022e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.36372741e-04,
         0.00000000e+00,  -3.81803498e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.41201106e-04,  -3.73524302e-03,  -5.82086744e-04,
        -5.41094317e-04,   0.00000000e+00,   8.30094537e-04,
         0.00000000e+00,   5.32864385e-03,  -7.40938369e-04,
         1.26764066e-03,  -1.21239220e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.67254124e-03,   0.00000000e+00,
        -1.61624095e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.08001742e-03,
         0.00000000e+00,  -1.03583057e-02,   2.59557976e-03,
        -2.86902903e-03,   4.15557078e-03,   0.00000000e+00,
        -2.61632082e-03,   0.00000000e+00,  -8.46333909e-03,
         3.28031755e-03,  -1.87079468e-03,  -4.84934368e-04,
         0.00000000e+00,  -1.28931007e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.71275064e-05,   0.00000000e+00,
        -2.57684130e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.33438052e-04,
         0.00000000e+00,   3.06171110e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.25575308e-03,   0.00000000e+00,
         3.62508302e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.36768319e-03,
         0.00000000e+00,   1.44584028e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.58997401e-03,
         0.00000000e+00,   3.96810316e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.97284283e-03,   0.00000000e+00,   8.49723751e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.65099944e-03,   0.00000000e+00,
         3.66343365e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.49793222e-03,
         0.00000000e+00,   2.09467904e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.11533132e-03,   2.75161501e-03,
        -1.12209537e-03,   1.79325236e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.92547901e-03,   0.00000000e+00,
         1.79937280e-03,  -2.51191249e-03,   1.94515092e-03,
        -1.06123254e-03,   0.00000000e+00,   7.46540360e-05,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.32736039e-03,
         0.00000000e+00,   4.38581295e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.10679579e-03,   0.00000000e+00,
         1.90930279e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.24338999e-04,   0.00000000e+00,
         1.20397015e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.73030796e-04,
         0.00000000e+00,   2.00114206e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.98512707e-03,  -1.69011258e-03,   6.37377391e-04,
        -4.18877156e-04,   0.00000000e+00,  -1.94071352e-04,
         0.00000000e+00,  -6.83226338e-04,   9.56737857e-04,
         9.96840141e-04,  -2.64050508e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.14055626e-03,   0.00000000e+00,
         8.15389848e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.19224975e-03,
         0.00000000e+00,   4.80703085e-03,  -2.08162363e-03,
         6.45374959e-04,  -9.81420828e-04,   0.00000000e+00,
         7.78210174e-04,   0.00000000e+00,   2.82364160e-03,
        -8.62378762e-04,   6.64570745e-04,  -7.10056221e-05,
         0.00000000e+00,   8.88506678e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.32731728e-04,   0.00000000e+00,
        -2.02914872e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.54253531e-04,
         0.00000000e+00,  -4.14012191e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.27188634e-03,   0.00000000e+00,
        -2.71533293e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.11328753e-04,
         0.00000000e+00,  -2.66127075e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.02492467e-03,
         0.00000000e+00,   9.54673513e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.75641431e-03,   0.00000000e+00,  -2.40586949e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.97177519e-03,   0.00000000e+00,
        -2.06903287e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.78882522e-03,
         0.00000000e+00,  -6.62816627e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.69532088e-03,  -2.21829890e-03,
        -8.25221608e-04,  -2.34209482e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.73295657e-03,   0.00000000e+00,
        -3.34857049e-03,  -6.08827432e-03,   1.17455867e-03,
        -1.34625704e-06,   0.00000000e+00,   7.48839414e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.06620896e-03,
         0.00000000e+00,   1.33202355e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.24338999e-04,   0.00000000e+00,
         1.29925522e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.51852986e-03,   0.00000000e+00,
         3.04544529e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.44580286e-03,
         0.00000000e+00,   2.88323516e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.96834330e-04,  -1.04714599e-03,  -2.27869614e-05,
        -1.01026981e-03,   0.00000000e+00,  -5.29035013e-04,
         0.00000000e+00,   1.31199511e-03,   2.14757067e-03,
        -5.26263334e-04,  -1.05904363e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.35309579e-05,   0.00000000e+00,
         1.93794867e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.05644883e-03,
         0.00000000e+00,  -3.03725514e-03,   1.12539837e-03,
         7.59295594e-04,   2.67410622e-03,   0.00000000e+00,
         1.25513031e-03,   0.00000000e+00,  -9.23907230e-04,
         6.43989676e-04,  -6.78477029e-04,  -5.92748886e-04,
         0.00000000e+00,   7.85260529e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.56972354e-03,   0.00000000e+00,
        -1.01568889e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.32507397e-04,
         0.00000000e+00,  -1.90723214e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.09627776e-03,   0.00000000e+00,
         6.71969693e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.65220814e-04,
         0.00000000e+00,   6.34934816e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.85158970e-03,
         0.00000000e+00,  -1.09205753e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.61777917e-03,   0.00000000e+00,   1.85188026e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.72258063e-03,   0.00000000e+00,
         2.23721856e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.64930662e-03,
         0.00000000e+00,   8.36760593e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.16432245e-03,  -2.68491160e-03,
        -2.81477789e-03,  -1.84042998e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.53860795e-03,   0.00000000e+00,
        -2.31949988e-03,  -2.41677662e-03,   8.19481109e-04,
         2.94445133e-04,   0.00000000e+00,   1.80014434e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.36372741e-04,
         0.00000000e+00,   5.16648554e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.73030796e-04,   0.00000000e+00,
         2.26972736e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.44580286e-03,   0.00000000e+00,
         6.50119366e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.37937878e-03,
         0.00000000e+00,   3.48334913e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         8.76380576e-04,  -1.06186451e-03,  -2.64977960e-03,
        -2.80956787e-03,   0.00000000e+00,   1.48945382e-03,
         0.00000000e+00,  -9.33342261e-04,   5.72030342e-04,
        -1.07194311e-03,   4.22917673e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.58505904e-04,   0.00000000e+00,
        -3.15660170e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.92986877e-04,
         0.00000000e+00,  -2.87554908e-03,   1.20606152e-03,
         2.93201182e-03,   3.11603184e-03,   0.00000000e+00,
         4.80507147e-03,   0.00000000e+00,  -1.86113089e-04,
         7.29958076e-05,  -6.65040314e-04,  -9.25696732e-04,
         0.00000000e+00,   2.40204204e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.83900101e-03,   0.00000000e+00,
        -2.48564091e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.65620004e-04,
         0.00000000e+00,  -3.22260773e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.03117081e-04,   0.00000000e+00,
        -3.27310230e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.68038122e-04,
         0.00000000e+00,  -1.13926116e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.55737378e-03,
         0.00000000e+00,   9.77612474e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.58326696e-03,   0.00000000e+00,   1.18727349e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.35337346e-03,   0.00000000e+00,
         1.16580875e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.74330843e-03,
         0.00000000e+00,   2.29246751e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         5.67295087e-02,  -1.56919587e-02,   3.56772774e-02,
        -5.60710634e-03,   9.32827895e-03,   3.99194125e-02,
         4.81794901e-03,  -6.93565705e-03,  -1.66360815e-03,
         5.52553715e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.97010374e-02,
        -1.53977684e-03,   4.99493130e-04,   1.65286311e-02,
         9.88285087e-03,   0.00000000e+00,   4.76114368e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.41114606e-02,   0.00000000e+00,
         2.81848304e-02,   5.66078631e-03,  -2.24817936e-03,
         1.12336397e-02,  -1.32417753e-02,   0.00000000e+00,
         5.64053165e-03,   0.00000000e+00,   4.29785861e-02,
        -6.15409677e-03,  -7.58738532e-03,   4.37888840e-03,
         1.47441079e-03,   0.00000000e+00,  -5.74121769e-03,
         0.00000000e+00,  -1.04976218e-02,   9.52849883e-03,
         1.55913292e-03,  -3.97036019e-03,   3.19367765e-03,
        -5.42146984e-03,   0.00000000e+00,  -7.77624026e-03,
         0.00000000e+00,   4.25958489e-03,   5.76804445e-03,
         7.49434129e-03,   2.60975251e-03,  -2.02916490e-03,
        -1.44641720e-02,  -1.59574720e-02,   0.00000000e+00,
         4.80608019e-03,   0.00000000e+00,  -1.00094875e-02,
        -2.05010594e-03,  -4.16585726e-03,   2.85770622e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.00053539e-02,   0.00000000e+00,
         2.55018032e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.48356372e-02,
         8.54879087e-03,  -7.06404881e-03,   1.08940954e-02,
         2.94427588e-03,   0.00000000e+00,   1.75905833e-03,
         0.00000000e+00,  -1.42737843e-02,   1.07393396e-02,
         3.36236070e-03,   2.53967002e-04,   0.00000000e+00,
         2.86085259e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.76408846e-02,
         0.00000000e+00,   1.82668504e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -8.74442223e-03,   0.00000000e+00,   6.36542511e-02,
         2.11503324e-03,   1.42260343e-04,  -1.32166557e-02,
        -1.99913831e-02,   0.00000000e+00,  -2.95259635e-02,
         0.00000000e+00,  -1.11656524e-03,   1.47240348e-03,
         8.05731138e-03,   1.04422152e-02,   0.00000000e+00,
        -5.26654596e-03,   0.00000000e+00,   5.48654554e-02,
        -4.64589728e-04,  -1.14218272e-02,  -1.96222307e-02,
         2.50978667e-02,   0.00000000e+00,  -8.71857131e-03,
         0.00000000e+00,  -1.63348484e-02,   3.49672838e-03,
        -3.31003149e-03,   8.39963615e-04,   0.00000000e+00,
         6.21147712e-03,   0.00000000e+00,   1.37493331e-03,
         6.23696302e-02,  -2.26993470e-02,  -1.01053799e-02,
        -1.11792764e-03,  -4.88412247e-03,   0.00000000e+00,
         2.05798946e-03,   0.00000000e+00,   3.03031494e-03,
         7.09102643e-03,   3.84510408e-03,   9.10326692e-04,
         0.00000000e+00,  -3.50499109e-03,   0.00000000e+00,
         4.51974237e-04,  -3.37939514e-03,   3.24152256e-02,
        -2.88743301e-02,   1.94648040e-02,   3.34723507e-03,
         6.93279786e-04,   0.00000000e+00,  -3.03285070e-03,
         0.00000000e+00,  -1.41404539e-02,   3.65547406e-03,
        -4.36570778e-03,  -2.92763063e-03,   0.00000000e+00,
        -6.56774713e-03,   0.00000000e+00,  -1.65075799e-03,
        -4.26141589e-03,   1.47489166e-02,   5.37591431e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.33236484e-03,  -6.40319953e-03,
        -2.56395074e-03,   4.43112611e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.15919076e-03,   0.00000000e+00,
        -4.45238374e-03,  -1.38310526e-03,  -6.12200322e-04,
        -1.70095711e-03,   0.00000000e+00,   5.90498544e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.67254124e-03,
         0.00000000e+00,   6.58846330e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.14055626e-03,   0.00000000e+00,
         3.01968233e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.35309579e-05,   0.00000000e+00,
         7.13737013e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.58505904e-04,
         0.00000000e+00,   3.03686427e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.58260295e-03,  -1.32302869e-03,   2.08126872e-03,
         2.79645129e-04,   0.00000000e+00,   1.96827851e-04,
         0.00000000e+00,  -1.91957839e-03,   2.08162805e-03,
         4.12979200e-04,   8.20531116e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.79762263e-03,   0.00000000e+00,
         3.12271581e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.07439520e-04,
         0.00000000e+00,  -8.76588534e-03,   4.39733283e-03,
         1.05394385e-03,  -4.56483140e-03,   0.00000000e+00,
        -1.84046338e-03,   0.00000000e+00,  -4.64404412e-04,
         5.85291570e-04,   1.82514582e-04,   3.59628206e-04,
         0.00000000e+00,  -1.30415060e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.48533930e-03,   0.00000000e+00,
         1.05127664e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.66405744e-04,
         0.00000000e+00,   1.02335888e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.85727633e-03,   0.00000000e+00,
        -2.33032728e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.82898412e-03,
         0.00000000e+00,  -3.90643351e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.82315840e-03,
         0.00000000e+00,  -3.54869751e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.10635323e-03,   0.00000000e+00,   3.35046815e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.93705734e-03,   0.00000000e+00,
         3.47639490e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.14695108e-03,
         0.00000000e+00,   6.48628812e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.69624313e-01,   6.66550833e-02,  -4.84885008e-02,
         9.89228570e-03,  -2.73326360e-02,  -8.65139290e-02,
        -3.57309519e-04,   2.98592401e-02,   4.77165358e-03,
        -1.51498455e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.11765719e-01,
        -6.45362129e-03,  -9.43413444e-03,  -7.69037819e-02,
        -5.08618783e-02,   0.00000000e+00,  -1.08791011e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.28181159e-02,   0.00000000e+00,
        -2.13499910e-02,  -4.51338719e-02,  -2.09534621e-03,
        -4.64657366e-02,   6.11740537e-02,   0.00000000e+00,
        -3.12574071e-02,   0.00000000e+00,  -8.71389099e-02,
         1.77400486e-02,  -2.56699793e-03,   1.06106935e-02,
        -1.34830165e-02,   0.00000000e+00,   9.80667385e-03,
         0.00000000e+00,   2.16990931e-02,  -1.10506913e-02,
        -9.06204479e-03,   1.45430981e-03,   4.59737586e-03,
         1.98359290e-02,   0.00000000e+00,   1.24976121e-02,
         0.00000000e+00,  -9.73500047e-03,   1.04067305e-03,
        -1.13909494e-02,  -6.45994498e-03,   4.28747381e-03,
         2.11353201e-02,   2.30245040e-02,   0.00000000e+00,
         3.38060786e-02,   0.00000000e+00,   2.01969966e-03,
        -9.02539155e-04,  -7.68943239e-03,  -2.40341139e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.76408846e-02,   0.00000000e+00,
         1.43766536e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.77386767e-02,
        -2.07834710e-02,   1.41519517e-02,   3.91446234e-03,
        -3.05874974e-02,   0.00000000e+00,  -1.17097284e-02,
         0.00000000e+00,   7.09731884e-03,   1.35640790e-04,
         5.15675148e-03,   6.38524721e-03,   0.00000000e+00,
        -2.20432941e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.78636893e-01,
         0.00000000e+00,  -4.72881928e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         4.90894044e-02,   0.00000000e+00,  -1.95732504e-01,
        -5.47834513e-03,   4.07943167e-03,   5.96074096e-02,
         7.84211075e-02,   0.00000000e+00,   9.43221418e-02,
         0.00000000e+00,   5.16145389e-03,  -2.56352079e-03,
        -2.15853417e-02,  -4.96913914e-02,   0.00000000e+00,
         2.40894085e-02,   0.00000000e+00,  -1.66600630e-01,
        -9.11715464e-03,   3.38849880e-02,   6.23430007e-02,
        -8.63658156e-02,   0.00000000e+00,   3.24718108e-02,
         0.00000000e+00,   8.31025577e-02,  -1.99745703e-02,
         1.13377724e-02,  -6.27037119e-03,   0.00000000e+00,
        -3.07164250e-02,   0.00000000e+00,  -3.99718682e-03,
        -1.81611318e-01,   5.29686803e-02,  -2.76883978e-02,
        -4.15623311e-03,   1.03290725e-02,   0.00000000e+00,
         6.34795987e-03,   0.00000000e+00,   1.62050013e-02,
        -7.17321465e-03,   3.07638995e-03,   1.92456668e-03,
         0.00000000e+00,   1.59815691e-02,   0.00000000e+00,
        -7.47716370e-03,   1.02001373e-02,  -4.03687070e-02,
         1.13717644e-01,  -5.06215486e-02,  -9.46810769e-03,
         1.19510680e-03,   0.00000000e+00,   4.99289413e-03,
         0.00000000e+00,   4.31335413e-02,  -1.69413995e-02,
         9.90405982e-03,   6.14458637e-03,   0.00000000e+00,
         2.04197388e-02,   0.00000000e+00,   5.63311218e-03,
        -5.63694084e-03,  -6.76382005e-02,  -1.68352884e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.71869624e-03,  -1.17072117e-03,
        -4.42452346e-03,  -5.49109850e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.31780185e-03,   0.00000000e+00,
        -1.73890621e-04,   1.28445608e-03,   1.85807154e-03,
         2.07225934e-03,   0.00000000e+00,   1.70642788e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.71275064e-05,
         0.00000000e+00,  -3.03462428e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.32731728e-04,   0.00000000e+00,
        -9.54013143e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.56972354e-03,   0.00000000e+00,
        -5.48424017e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.83900101e-03,
         0.00000000e+00,  -1.72509337e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         7.81122477e-04,   3.98837756e-04,  -2.05662472e-03,
        -2.61077157e-03,   0.00000000e+00,  -3.88844224e-03,
         0.00000000e+00,  -2.97388299e-04,   1.55767779e-05,
         2.46939766e-04,  -5.37322474e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.48533930e-03,   0.00000000e+00,
         5.55503781e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.83687992e-05,
         0.00000000e+00,  -2.03565115e-03,   1.27306781e-03,
         9.54191016e-03,   1.17096934e-02,   0.00000000e+00,
         1.35147021e-02,   0.00000000e+00,   2.43026950e-04,
        -3.68793399e-04,  -1.49107685e-03,  -2.90234495e-03,
         0.00000000e+00,   1.05939108e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.91929216e-02,   0.00000000e+00,
        -4.26547832e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.44498387e-03,
         0.00000000e+00,  -6.92310203e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.86520930e-04,   0.00000000e+00,
        -3.37460558e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.01950137e-05,
         0.00000000e+00,  -4.58553081e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.31743648e-04,
         0.00000000e+00,  -5.63989225e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.04835253e-03,   0.00000000e+00,   3.80176543e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.95592315e-03,   0.00000000e+00,
         8.03083936e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.05123517e-04,
         0.00000000e+00,   1.93791513e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.56379659e-03,  -5.30455216e-03,
        -4.90021674e-03,   6.54154842e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.21971377e-03,   0.00000000e+00,
        -1.75843410e-04,   3.01208363e-03,   2.80600480e-03,
        -2.90325668e-03,   0.00000000e+00,   8.07417959e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.25575308e-03,
         0.00000000e+00,   1.47228084e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.27188634e-03,   0.00000000e+00,
         5.33393297e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.09627776e-03,   0.00000000e+00,
        -3.60353940e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.03117081e-04,
         0.00000000e+00,  -8.41459300e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.26962010e-04,  -3.38559207e-03,  -3.63442866e-03,
         3.99543148e-03,   0.00000000e+00,  -1.18311162e-03,
         0.00000000e+00,  -1.11853190e-03,  -4.91664544e-04,
         5.55884045e-04,   7.89213319e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.85727633e-03,   0.00000000e+00,
        -3.07674326e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.55985277e-03,
         0.00000000e+00,  -5.46706025e-03,   7.85854090e-03,
         1.05511574e-02,  -1.38399272e-02,   0.00000000e+00,
         4.90310484e-03,   0.00000000e+00,   9.68913717e-03,
        -1.79626043e-03,   5.33839336e-04,  -8.01955069e-04,
         0.00000000e+00,  -3.07298780e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.86520930e-04,   0.00000000e+00,
        -3.81772161e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.22338452e-04,
         0.00000000e+00,  -3.81076274e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.25539321e-02,   0.00000000e+00,
        -4.16725707e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.97574686e-03,
         0.00000000e+00,  -8.29341255e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.87902322e-03,
         0.00000000e+00,   4.23949998e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.24803223e-03,   0.00000000e+00,   2.93130664e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.42214929e-03,   0.00000000e+00,
         9.50677602e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.91877753e-03,
         0.00000000e+00,   5.83528952e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.42308326e-02,   9.20664318e-03,
         3.19312189e-03,  -2.58372743e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.71837840e-04,   0.00000000e+00,
         7.32804686e-03,   2.20152394e-03,   4.81729845e-04,
         1.52571877e-04,   0.00000000e+00,  -2.55938178e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.58997401e-03,
         0.00000000e+00,  -3.30619636e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.02492467e-03,   0.00000000e+00,
         1.54595278e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.85158970e-03,   0.00000000e+00,
        -2.05713916e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.55737378e-03,
         0.00000000e+00,   2.21289262e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.00580083e-03,  -4.29129794e-03,  -6.96707667e-04,
        -1.11736401e-03,   0.00000000e+00,   1.07742218e-03,
         0.00000000e+00,   6.83598727e-04,  -1.14064775e-03,
         3.01121924e-03,   8.15443021e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.82315840e-03,   0.00000000e+00,
         3.42410206e-06,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.30948030e-03,
         0.00000000e+00,   1.97676491e-02,  -1.05296641e-02,
        -1.85509208e-03,   1.96988410e-03,   0.00000000e+00,
         1.53829677e-03,   0.00000000e+00,   3.71652320e-03,
        -1.50844561e-03,   1.28544579e-03,   9.65623984e-05,
         0.00000000e+00,   1.38818725e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.31743648e-04,   0.00000000e+00,
        -4.28913590e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.06859643e-04,
         0.00000000e+00,   3.81231697e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.87902322e-03,   0.00000000e+00,
         2.68446261e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.01677399e-03,
         0.00000000e+00,   2.65459279e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.31539699e-02,
         0.00000000e+00,   7.59958327e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.98953545e-03,   0.00000000e+00,  -6.05466368e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.02611318e-02,   0.00000000e+00,
        -1.00394831e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.39591127e-03,
         0.00000000e+00,  -1.06529013e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.46757727e-02,   8.94524866e-03,
         3.57509492e-03,  -2.51328633e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.91101418e-06,   0.00000000e+00,
         7.08881578e-03,  -9.67293496e-04,   8.51253271e-04,
        -4.85928691e-04,   0.00000000e+00,   1.36241240e-04,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.65099944e-03,
         0.00000000e+00,   5.02782381e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.97177519e-03,   0.00000000e+00,
        -2.91272904e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.72258063e-03,   0.00000000e+00,
         1.19891075e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.35337346e-03,
         0.00000000e+00,   5.42194831e-05,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.08620978e-02,   4.88644066e-03,   1.09288274e-04,
         7.58712927e-04,   0.00000000e+00,  -1.01060029e-03,
         0.00000000e+00,  -2.68899069e-03,  -4.59582133e-04,
        -4.69989723e-06,  -1.04114715e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.93705734e-03,   0.00000000e+00,
         5.38586065e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.16599124e-03,
         0.00000000e+00,   4.19519856e-02,  -1.78493824e-02,
        -4.68333839e-03,   2.76547559e-03,   0.00000000e+00,
         2.83712440e-04,   0.00000000e+00,   8.74957435e-03,
        -2.51432670e-03,   8.18232812e-04,   9.26473609e-04,
         0.00000000e+00,   2.76285958e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.95592315e-03,   0.00000000e+00,
         7.77873539e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.20673209e-04,
         0.00000000e+00,   7.77244406e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.42214929e-03,   0.00000000e+00,
         3.47190953e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.97029671e-03,
         0.00000000e+00,   1.03258781e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.02611318e-02,
         0.00000000e+00,  -4.90719237e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.06924944e-04,   0.00000000e+00,  -7.65588921e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.87439103e-02,   0.00000000e+00,
        -1.03950991e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.60762627e-03,
         0.00000000e+00,  -1.22284897e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.86643152e-02,   4.90266644e-03,   7.76127716e-03,
         5.24483613e-02,  -3.42262379e-02,  -2.07440632e-03,
         3.02798572e-02,  -2.69853672e-02,  -5.67464061e-03,
         1.76285278e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.66391384e-02,
         7.65236624e-02,  -1.49859822e-02,  -4.25181665e-04,
         1.73785692e-02,   0.00000000e+00,  -2.30887853e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.32452451e-03,   0.00000000e+00,
        -1.01021366e-04,   1.81969754e-02,  -1.91385460e-02,
         1.03384793e-02,   8.24159178e-03,   0.00000000e+00,
         1.45078203e-02,   0.00000000e+00,   1.87599453e-02,
        -7.81358132e-03,   1.85208974e-03,  -4.47464269e-03,
        -1.19370659e-03,   0.00000000e+00,  -3.93910360e-03,
         0.00000000e+00,   1.57765923e-03,   7.11824076e-03,
        -4.79374714e-03,   4.31327185e-03,  -4.04712480e-03,
         8.01388768e-05,   0.00000000e+00,   6.92886712e-03,
         0.00000000e+00,   7.65687634e-03,   4.69991159e-03,
         1.68834824e-02,  -5.99145390e-03,   1.25853024e-02,
         8.38841104e-03,   2.93366040e-03,   0.00000000e+00,
        -2.64255311e-03,   0.00000000e+00,  -5.59626201e-03,
         1.69481242e-04,   9.48221387e-04,  -6.53021722e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.53977684e-03,   0.00000000e+00,
        -5.40621845e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.25030411e-04,
         2.24500097e-03,  -4.39125432e-03,  -3.19873915e-03,
         7.86414932e-03,   0.00000000e+00,   6.16948625e-03,
         0.00000000e+00,   6.07664652e-04,  -2.38028753e-03,
        -1.35924704e-03,  -6.19022173e-03,   0.00000000e+00,
         5.76285671e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.45362129e-03,
         0.00000000e+00,   3.25356414e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.22913023e-03,   0.00000000e+00,   1.21883878e-02,
        -1.89863893e-02,   7.59231502e-03,  -2.23314873e-04,
        -3.15755765e-03,   0.00000000e+00,  -5.60249079e-03,
         0.00000000e+00,  -1.00411155e-02,   6.93892190e-03,
        -3.97388623e-03,   3.63748130e-03,   0.00000000e+00,
        -1.46346014e-02,   0.00000000e+00,   2.64281326e-03,
        -4.89012696e-03,   2.55770392e-03,   4.20536441e-03,
         5.59662849e-03,   0.00000000e+00,  -1.00843436e-03,
         0.00000000e+00,  -9.40100382e-03,   5.39574491e-03,
         3.46315096e-04,  -4.83246946e-03,   0.00000000e+00,
        -4.68304297e-03,   0.00000000e+00,  -1.52211378e-02,
         4.24078845e-03,  -1.70316628e-03,   3.05312644e-03,
        -1.54024730e-03,  -6.46724597e-03,   0.00000000e+00,
        -1.72276019e-02,   0.00000000e+00,  -3.63267464e-03,
         5.24334835e-03,   6.69858105e-03,  -8.20116422e-03,
         0.00000000e+00,  -6.42760142e-03,   0.00000000e+00,
         3.26998113e-02,   1.19363595e-02,   1.28023244e-02,
        -5.33170222e-03,  -2.28752694e-04,  -8.43466411e-03,
        -2.93241367e-03,   0.00000000e+00,  -1.35975712e-02,
         0.00000000e+00,  -1.27602397e-02,   3.94920081e-03,
         5.97415693e-03,   2.55748552e-02,   0.00000000e+00,
        -1.08209405e-02,   0.00000000e+00,   6.63286139e-02,
         2.05767061e-02,   1.06236461e-02,   2.39059242e-02,
         2.20556502e-02,  -1.43741579e-02,   6.48078720e-03,
        -5.13872199e-02,  -2.40714612e-02,   3.41241617e-03,
        -3.24751733e-02,  -2.35186014e-02,  -1.50681420e-02,
        -2.26378716e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.81766221e-02,
        -1.49859822e-02,   7.70652258e-02,   4.33623841e-02,
         3.37478382e-02,   0.00000000e+00,  -2.77281648e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.63694168e-02,   0.00000000e+00,
        -4.56841798e-02,  -6.57686907e-03,  -1.32701528e-02,
         1.79804463e-02,  -2.92858478e-02,   0.00000000e+00,
         9.68694476e-03,   0.00000000e+00,  -7.16739900e-03,
        -2.66446665e-03,   4.28166508e-03,  -2.60012209e-02,
         9.37609455e-03,   0.00000000e+00,   9.06339648e-03,
         0.00000000e+00,   2.44526009e-02,   1.51494000e-02,
         1.31673019e-03,   1.15432096e-02,  -3.61816781e-02,
         4.01312329e-03,   0.00000000e+00,   1.85819697e-02,
         0.00000000e+00,   2.10039358e-02,   2.20682976e-03,
         5.37613024e-02,   6.66608318e-03,   1.09970236e-02,
         2.72371507e-03,   1.27542661e-02,   0.00000000e+00,
        -2.49118984e-02,   0.00000000e+00,   3.33118023e-03,
        -1.36221170e-02,   1.23849464e-02,  -5.66849232e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.99493130e-04,   0.00000000e+00,
        -2.33769514e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.65361733e-02,
        -6.72001067e-04,   1.59819390e-03,  -2.60597916e-03,
         4.13611806e-03,   0.00000000e+00,  -1.38301366e-03,
         0.00000000e+00,   8.84213126e-03,  -6.01446858e-03,
         6.68124237e-03,   1.22280316e-03,   0.00000000e+00,
        -4.79300736e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.43413444e-03,
         0.00000000e+00,   1.71836898e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.68184962e-02,   0.00000000e+00,   2.43014348e-02,
         4.59517227e-03,  -7.82781158e-03,  -4.00260506e-03,
        -4.04975759e-03,   0.00000000e+00,  -7.77807518e-03,
         0.00000000e+00,   4.02946096e-03,  -9.65903295e-04,
        -1.57189575e-03,   3.08748046e-02,   0.00000000e+00,
        -2.02635884e-03,   0.00000000e+00,   2.18457718e-02,
         4.39187486e-03,  -3.73918940e-03,  -3.55593112e-03,
         1.38769445e-03,   0.00000000e+00,  -7.94606869e-03,
         0.00000000e+00,  -1.00215384e-02,   5.84358150e-03,
         2.97669846e-03,  -1.19265329e-03,   0.00000000e+00,
         2.01134095e-02,   0.00000000e+00,   1.33058572e-02,
         3.35140141e-02,   2.47847630e-03,   1.35458527e-02,
         1.13016700e-02,   6.67473756e-03,   0.00000000e+00,
        -8.60223501e-03,   0.00000000e+00,  -4.83598354e-03,
        -1.00042726e-03,   7.34148884e-03,  -6.16960288e-02,
         0.00000000e+00,   4.48244075e-03,   0.00000000e+00,
         3.54284703e-05,  -7.52888992e-03,  -1.52749206e-02,
        -8.38860168e-03,  -1.17572463e-03,   6.10225397e-03,
        -3.03557427e-03,   0.00000000e+00,   4.89551844e-03,
         0.00000000e+00,  -7.24367627e-04,   4.36823111e-03,
        -1.02853826e-03,   9.12848332e-03,   0.00000000e+00,
        -4.78531466e-03,   0.00000000e+00,  -4.94855078e-02,
        -7.32772456e-03,   1.21283747e-02,   1.79849250e-02,
         1.54830710e-01,  -1.22748473e-01,  -7.37399657e-02,
        -3.66506154e-02,   5.67072801e-02,   7.95135875e-03,
        -5.79678166e-04,  -6.84251668e-02,  -1.27018310e-02,
         1.15898687e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.94249440e-01,
        -4.25181665e-04,   4.33623841e-02,   1.77589019e-01,
         1.04433159e-01,   0.00000000e+00,   2.71332589e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.29799930e-02,   0.00000000e+00,
        -1.16924995e-01,   4.98720444e-02,   1.66259172e-02,
         8.37805910e-02,  -1.02332117e-01,   0.00000000e+00,
         5.96945551e-02,   0.00000000e+00,  -1.00737293e-02,
        -1.28868386e-02,   1.55203929e-02,  -4.30069072e-02,
         2.05371961e-02,   0.00000000e+00,  -2.26276221e-03,
         0.00000000e+00,  -1.12776953e-02,  -7.56804250e-02,
         3.77406589e-03,  -1.20112885e-02,  -9.15786373e-03,
        -2.28084121e-02,   0.00000000e+00,  -7.00148029e-03,
         0.00000000e+00,   2.07032422e-03,  -4.20758098e-02,
        -1.08651629e-01,   6.23830154e-03,   1.14088464e-04,
         1.17546399e-02,   4.81923490e-03,   0.00000000e+00,
        -7.32642240e-02,   0.00000000e+00,   1.91294614e-02,
         6.75055850e-03,   3.07287587e-02,  -1.23136770e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.65286311e-02,   0.00000000e+00,
        -6.80780608e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.23980608e-01,
         4.67928704e-03,  -4.15983491e-03,  -2.80297268e-02,
         2.84042790e-02,   0.00000000e+00,   1.91734938e-02,
         0.00000000e+00,   2.60792896e-02,  -3.52754296e-02,
        -1.73041399e-02,  -2.29082069e-03,   0.00000000e+00,
        -1.07967258e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -7.69037819e-02,
         0.00000000e+00,   1.94579656e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -7.26901489e-02,   0.00000000e+00,   1.70127403e-01,
         2.13402707e-03,  -5.33257185e-03,  -4.31122152e-02,
        -4.57572041e-02,   0.00000000e+00,  -5.15273362e-02,
         0.00000000e+00,  -4.65931375e-03,  -6.19248702e-04,
         2.75473434e-02,   9.39980836e-02,   0.00000000e+00,
        -3.76727482e-02,   0.00000000e+00,   1.71055070e-01,
         7.22812134e-03,  -8.15534676e-03,  -2.65795711e-02,
         4.05883888e-02,   0.00000000e+00,  -2.57375711e-02,
         0.00000000e+00,  -6.83892457e-02,   1.89881196e-02,
        -1.12223172e-02,   1.73303423e-02,   0.00000000e+00,
         6.24013183e-02,   0.00000000e+00,   2.43901592e-02,
         1.83149836e-01,  -1.43895644e-02,   5.32931452e-02,
         1.24409203e-02,   6.20937054e-03,   0.00000000e+00,
        -1.74675357e-02,   0.00000000e+00,  -4.23745863e-02,
        -3.88808975e-03,  -7.10023355e-03,  -2.58855437e-02,
         0.00000000e+00,  -3.16397352e-02,   0.00000000e+00,
         1.48026436e-02,  -3.62494010e-02,  -8.10267739e-02,
        -5.97767656e-02,   1.94470037e-02,   8.03662884e-03,
        -5.44886433e-03,   0.00000000e+00,   9.58668126e-04,
         0.00000000e+00,  -2.84390814e-02,   2.01161629e-02,
        -1.18655944e-02,  -2.21594342e-03,   0.00000000e+00,
        -2.93789620e-02,   0.00000000e+00,  -2.46755184e-02,
        -8.14291215e-03,   1.06553602e-01,   1.44588148e-01,
         1.02331710e-01,  -8.06544323e-02,  -5.10701384e-02,
        -1.77074004e-02,   1.78818912e-02,   9.47353748e-05,
         7.00694103e-03,  -5.82938456e-02,   1.74000122e-04,
         8.59409889e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.27093586e-01,
         1.73785692e-02,   3.37478382e-02,   1.04433159e-01,
         1.00545533e-01,   0.00000000e+00,   7.95360739e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.98746935e-02,   0.00000000e+00,
        -8.83175738e-02,   3.53657885e-02,  -2.67576172e-03,
         4.12255502e-02,  -7.53762647e-02,   0.00000000e+00,
         4.32217216e-02,   0.00000000e+00,  -2.16610891e-02,
        -7.06835001e-03,   2.17644575e-02,  -3.07890683e-02,
         1.76716993e-02,   0.00000000e+00,  -1.40483774e-03,
         0.00000000e+00,   3.35251418e-03,  -3.81041450e-02,
         4.81041872e-03,   8.61139754e-03,  -1.87644047e-02,
        -1.33817268e-02,   0.00000000e+00,   1.20928469e-03,
         0.00000000e+00,   7.86500871e-03,  -2.09241931e-02,
        -3.73660227e-02,   2.75496056e-03,   6.29365486e-03,
         9.18244870e-03,   5.25894122e-03,   0.00000000e+00,
        -5.36576211e-02,   0.00000000e+00,   1.88833563e-02,
        -5.69728465e-04,   2.46714895e-02,  -9.89631322e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   9.88285087e-03,   0.00000000e+00,
        -5.04187908e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.25446979e-02,
         6.78074806e-03,  -2.03739739e-03,  -1.72473353e-02,
         2.50226583e-02,   0.00000000e+00,   1.22109836e-02,
         0.00000000e+00,   1.80387570e-02,  -2.54820011e-02,
        -7.12369408e-03,  -1.70664751e-02,   0.00000000e+00,
        -7.85414947e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.08618783e-02,
         0.00000000e+00,   1.27544383e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -5.04256934e-02,   0.00000000e+00,   1.11254495e-01,
        -8.02568835e-04,  -2.89583457e-03,  -2.51699608e-02,
        -3.76036597e-02,   0.00000000e+00,  -3.63941904e-02,
         0.00000000e+00,  -1.83408174e-03,   2.56798912e-04,
         1.61952825e-02,   6.86825178e-02,   0.00000000e+00,
        -3.02898283e-02,   0.00000000e+00,   1.23547814e-01,
         4.50237314e-03,  -5.76303166e-03,  -1.24701109e-02,
         2.70249915e-02,   0.00000000e+00,  -8.52333193e-03,
         0.00000000e+00,  -4.25478947e-02,   1.30114594e-02,
        -7.20378889e-03,   7.56643627e-03,   0.00000000e+00,
         4.11916907e-02,   0.00000000e+00,  -6.40512588e-03,
         1.03907482e-01,  -1.02835934e-02,   3.88012067e-02,
         6.48853688e-03,   4.23251991e-03,   0.00000000e+00,
        -1.46880965e-02,   0.00000000e+00,  -2.74674749e-02,
        -6.82938407e-03,  -2.17771389e-03,  -2.83395009e-02,
         0.00000000e+00,  -2.90840490e-02,   0.00000000e+00,
         2.12431842e-02,  -2.13031942e-02,  -5.81895787e-02,
        -3.81147973e-02,   8.64363602e-03,   3.30616122e-03,
        -5.61920644e-03,   0.00000000e+00,   1.05674222e-04,
         0.00000000e+00,  -2.00951341e-02,   1.57003780e-02,
        -4.21604423e-03,   6.35035505e-03,   0.00000000e+00,
        -1.90929841e-02,   0.00000000e+00,  -4.12395851e-03,
        -3.99424153e-03,   7.23523961e-02,   9.90672444e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.29026590e-04,   1.94399007e-03,
         1.77464421e-02,   1.09358559e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.36438308e-02,   0.00000000e+00,
        -6.67310969e-04,  -4.49779784e-03,  -6.42052839e-03,
        -5.63584651e-03,   0.00000000e+00,  -1.14875640e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.55039226e-03,
         0.00000000e+00,  -2.27038457e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.92547901e-03,   0.00000000e+00,
         6.77572862e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.73295657e-03,   0.00000000e+00,
         7.57691562e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.53860795e-03,
         0.00000000e+00,   2.53868513e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.59472158e-03,  -1.28204460e-03,   3.54461851e-04,
         5.12766828e-04,   0.00000000e+00,   4.33512223e-03,
         0.00000000e+00,   1.20587540e-03,  -6.96230448e-05,
        -1.41436652e-03,   2.10309767e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.15919076e-03,   0.00000000e+00,
        -1.05643870e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.18421734e-03,
         0.00000000e+00,  -7.22015842e-04,  -1.39121068e-04,
        -4.61134224e-03,  -3.22354874e-03,   0.00000000e+00,
        -6.92213548e-03,   0.00000000e+00,  -2.60302241e-03,
         7.80668027e-04,   1.82364331e-03,   7.45552875e-03,
         0.00000000e+00,  -2.21776230e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.31780185e-03,   0.00000000e+00,
         2.34642177e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.39392335e-03,
         0.00000000e+00,   2.19462395e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.21971377e-03,   0.00000000e+00,
         1.72272557e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.87849723e-03,
         0.00000000e+00,   7.92332901e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.71837840e-04,
         0.00000000e+00,   1.35177414e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.74403519e-03,   0.00000000e+00,   2.23893998e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -4.91101418e-06,   0.00000000e+00,
         7.22771170e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.93796957e-03,
         0.00000000e+00,   1.21261982e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.06598259e-01,  -2.28755239e-02,   5.42648512e-01,
         2.17620957e-02,   4.47737604e-02,   5.77748847e-01,
        -7.49465597e-03,   9.02345266e-04,   2.03680317e-02,
         5.90825046e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.84053877e-01,
        -2.30887853e-03,  -2.77281648e-02,   2.71332589e-02,
         7.95360739e-03,   0.00000000e+00,   6.21779769e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.97433627e-02,   0.00000000e+00,
         5.29175083e-01,   2.13114367e-02,  -3.00510806e-02,
         2.88423920e-02,  -1.45697925e-02,   0.00000000e+00,
         8.73944436e-03,   0.00000000e+00,   5.64787702e-01,
        -2.04272464e-02,  -3.38096108e-02,   5.19805159e-02,
        -7.55632335e-04,   0.00000000e+00,  -3.97556625e-02,
         0.00000000e+00,  -7.43162914e-02,   3.58088359e-01,
         7.62904870e-03,  -1.02989784e-02,   2.45921230e-02,
        -8.04949742e-03,   0.00000000e+00,  -4.18638549e-02,
         0.00000000e+00,   2.59822187e-02,   6.87905495e-02,
         3.92745055e-01,   4.40070652e-03,  -2.19730745e-02,
        -6.11558130e-02,  -6.50413082e-02,   0.00000000e+00,
         4.49689588e-02,   0.00000000e+00,  -5.17461862e-02,
        -1.19899307e-02,  -1.88332800e-02,   5.53541892e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.76114368e-02,   0.00000000e+00,
         9.34390156e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   5.34826090e-01,
         2.22680123e-02,  -3.03485403e-02,   3.85682022e-02,
         1.16272989e-03,   0.00000000e+00,   4.52449275e-03,
         0.00000000e+00,  -6.41810674e-02,   5.37980630e-02,
         1.07315450e-02,  -1.14509062e-02,   0.00000000e+00,
         5.18471885e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.08791011e-01,
         0.00000000e+00,   5.25242776e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.56485130e-02,   0.00000000e+00,   5.47090978e-01,
         7.38216226e-03,   3.02763736e-04,  -4.05298982e-02,
        -6.16515060e-02,   0.00000000e+00,  -1.02575307e-01,
         0.00000000e+00,  -8.86359287e-03,   2.29890178e-03,
         3.31129665e-02,   1.73725859e-02,   0.00000000e+00,
        -1.21287986e-02,   0.00000000e+00,   5.73402776e-01,
         1.04625536e-02,  -3.54105087e-02,  -6.22042332e-02,
         7.29996486e-02,   0.00000000e+00,  -2.63334516e-02,
         0.00000000e+00,  -4.84476302e-02,   1.43717094e-02,
        -1.40173265e-02,  -6.96885411e-04,   0.00000000e+00,
        -1.35798420e-02,   0.00000000e+00,   1.13761351e-02,
         5.60791067e-01,  -6.37937657e-02,  -3.88300212e-02,
        -8.85628002e-03,  -3.03768339e-02,   0.00000000e+00,
         2.42772295e-02,   0.00000000e+00,   1.76315715e-02,
         5.02810343e-02,  -2.34600449e-03,   2.49757656e-02,
         0.00000000e+00,  -3.02242822e-02,   0.00000000e+00,
        -6.83166010e-03,   2.06678355e-02,   5.33379726e-01,
        -6.83527682e-02,   5.36674937e-02,   1.46685037e-02,
         3.54377368e-04,   0.00000000e+00,  -8.95715785e-03,
         0.00000000e+00,  -3.94573134e-02,   4.75500277e-03,
        -1.36768933e-02,  -1.75206052e-02,   0.00000000e+00,
        -1.26156674e-02,   0.00000000e+00,   5.77204404e-03,
         1.02247084e-02,   2.89734029e-02,   5.82635895e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.43516953e-03,  -5.83805707e-03,
        -8.51135033e-03,  -5.73888138e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.14875640e-03,   0.00000000e+00,
        -1.20641360e-02,  -2.85140413e-02,  -1.59627024e-02,
        -1.50724484e-02,   0.00000000e+00,   2.82990349e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.07679412e-03,
         0.00000000e+00,   1.23775114e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.46540360e-05,   0.00000000e+00,
        -2.10488751e-05,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.48839414e-04,   0.00000000e+00,
         2.24640479e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.80014434e-03,
         0.00000000e+00,   6.26266963e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.27319228e-03,  -9.82648429e-03,  -5.99502195e-03,
        -5.42618536e-03,   0.00000000e+00,   9.01902719e-03,
         0.00000000e+00,   2.34142380e-03,   3.21143614e-03,
        -4.05306247e-03,   2.44875363e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.90498544e-04,   0.00000000e+00,
         7.74180593e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.14006116e-03,
         0.00000000e+00,  -8.65544152e-04,   3.47089099e-04,
         2.67609143e-04,   1.42159376e-03,   0.00000000e+00,
         1.47940693e-03,   0.00000000e+00,   2.29231472e-03,
        -6.44495324e-05,  -2.30583290e-03,   3.98276316e-03,
         0.00000000e+00,   1.07149805e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.70642788e-03,   0.00000000e+00,
        -1.21308872e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.62180198e-03,
         0.00000000e+00,  -8.27673161e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.07417959e-04,   0.00000000e+00,
         2.81162244e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.60041058e-03,
         0.00000000e+00,  -2.05557289e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.55938178e-04,
         0.00000000e+00,   2.29835341e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.64552058e-02,   0.00000000e+00,   5.83583559e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.36241240e-04,   0.00000000e+00,
         3.56878536e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.67391945e-03,
         0.00000000e+00,  -4.02754807e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.10240156e-02,  -5.03055802e-02,  -4.32890571e-02,
         7.93309101e-03,   2.85225682e-02,   1.95287735e-02,
         1.48991155e-02,  -3.71050583e-02,  -8.43264452e-03,
         2.94235776e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   7.58644906e-02,
         1.45078203e-02,   9.68694476e-03,   5.96945551e-02,
         4.32217216e-02,   0.00000000e+00,   8.73944436e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.89188493e-02,   0.00000000e+00,
        -5.14024762e-02,   2.06458574e-02,   8.43394888e-04,
         2.74524430e-02,  -4.92455004e-02,   0.00000000e+00,
         5.29925250e-02,   0.00000000e+00,  -1.26551439e-02,
         1.33131751e-03,   2.48475343e-02,  -1.78053422e-02,
         1.41317878e-02,   0.00000000e+00,  -8.85132493e-03,
         0.00000000e+00,  -3.32433981e-03,  -2.30725369e-02,
         8.10555097e-03,   1.48852397e-02,  -6.60922163e-03,
        -4.87871940e-03,   0.00000000e+00,  -5.86420954e-04,
         0.00000000e+00,  -2.64950909e-04,  -1.09700322e-02,
        -2.49352883e-02,  -1.17893934e-03,  -1.51711260e-04,
         5.00704955e-03,   6.06715448e-03,   0.00000000e+00,
        -2.96580993e-02,   0.00000000e+00,   1.47544273e-02,
         3.42747919e-03,   1.52133546e-02,  -6.50185387e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   5.64053165e-03,   0.00000000e+00,
        -3.03344826e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -5.49447254e-02,
         2.96498271e-03,   3.57950314e-03,  -1.11801525e-02,
         1.42270938e-02,   0.00000000e+00,   4.79796558e-03,
         0.00000000e+00,   8.42848106e-03,  -1.85284559e-02,
        -3.11255693e-03,  -2.24258176e-02,   0.00000000e+00,
        -4.36810515e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.12574071e-02,
         0.00000000e+00,   8.21683586e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.02620367e-02,   0.00000000e+00,   6.60786574e-02,
        -4.67966330e-03,   1.98568370e-05,  -1.49536918e-02,
        -1.70727431e-02,   0.00000000e+00,  -2.01034099e-02,
         0.00000000e+00,  -9.88930475e-03,   2.47691870e-03,
         5.85690800e-03,   3.52818927e-02,   0.00000000e+00,
        -1.07798425e-02,   0.00000000e+00,   6.05799843e-02,
        -1.44715030e-04,  -4.00241413e-03,  -1.38617891e-02,
         1.54171806e-02,   0.00000000e+00,  -7.84964527e-03,
         0.00000000e+00,  -3.12836833e-02,   8.33516456e-03,
        -3.82076674e-03,   1.65832320e-02,   0.00000000e+00,
         2.19076696e-02,   0.00000000e+00,   1.26736687e-02,
         7.66177506e-02,  -5.71515710e-03,   2.47663130e-02,
        -3.51530889e-03,   1.44581590e-03,   0.00000000e+00,
        -6.01735575e-03,   0.00000000e+00,  -1.90768947e-02,
        -1.10475122e-02,  -5.22589137e-03,  -1.94970500e-03,
         0.00000000e+00,  -3.34765295e-02,   0.00000000e+00,
         1.11105460e-02,  -1.11764714e-02,  -4.18640779e-02,
        -2.66943347e-02,   5.42991586e-03,   3.60707221e-04,
        -5.14325377e-03,   0.00000000e+00,  -1.55744359e-03,
         0.00000000e+00,  -1.61289286e-02,   1.18529645e-02,
         6.59482185e-04,   2.03751742e-03,   0.00000000e+00,
        -8.81901491e-03,   0.00000000e+00,   1.29941904e-02,
        -9.42549067e-04,   4.54903937e-02,   5.64281902e-02,
        -4.36482805e-02,   4.03615099e-03,  -1.89446671e-02,
        -1.51900777e-02,  -2.08082246e-02,  -3.80524068e-02,
        -2.24025870e-03,   1.03917725e-02,  -3.88337923e-03,
        -3.31288755e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.96589438e-02,
        -3.93910360e-03,   9.06339648e-03,  -2.26276221e-03,
        -1.40483774e-03,   0.00000000e+00,  -3.97556625e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.57597550e-03,   0.00000000e+00,
        -2.85604862e-02,   3.75748623e-03,   2.07470335e-02,
        -5.93145040e-03,   7.27240015e-03,   0.00000000e+00,
        -8.85132493e-03,   0.00000000e+00,  -3.36715715e-02,
         1.92327579e-03,   6.79001525e-03,  -2.29576104e-02,
        -4.01705094e-03,   0.00000000e+00,   2.18801323e-02,
         0.00000000e+00,   1.68541305e-02,   2.02891702e-02,
         1.45638999e-03,   1.27934831e-02,  -2.35575327e-02,
        -7.46472761e-05,   0.00000000e+00,   2.12585252e-02,
         0.00000000e+00,  -1.01445299e-04,   2.50881313e-04,
         3.65972748e-02,  -2.79213061e-03,  -5.12172827e-03,
         8.24501848e-03,   6.88102810e-03,   0.00000000e+00,
        -7.44368350e-03,   0.00000000e+00,   8.80763341e-03,
         4.13039040e-03,   7.70404140e-03,  -3.37439293e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.74121769e-03,   0.00000000e+00,
        -1.58254318e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.23676923e-02,
        -2.43059363e-03,   4.32723694e-03,  -9.31678109e-03,
         2.11373880e-03,   0.00000000e+00,   2.12689455e-03,
         0.00000000e+00,   1.38041088e-02,  -7.53101662e-03,
        -9.41252075e-04,   1.56453539e-02,   0.00000000e+00,
        -3.06383001e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.80667385e-03,
         0.00000000e+00,  -8.19849966e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.97431991e-03,   0.00000000e+00,  -3.54017358e-02,
         9.66544951e-04,   3.46538836e-05,   3.14518096e-03,
         6.06741997e-03,   0.00000000e+00,   8.50697786e-03,
         0.00000000e+00,   3.57523754e-03,  -2.24662604e-03,
        -1.01068577e-02,   1.76481417e-04,   0.00000000e+00,
        -1.60462411e-03,   0.00000000e+00,  -3.60587988e-02,
         1.28774759e-03,   5.66977387e-03,   6.09844761e-03,
        -6.56054189e-03,   0.00000000e+00,   1.45288950e-03,
         0.00000000e+00,   3.84914367e-03,  -2.07744450e-03,
         3.74025942e-03,  -2.93511000e-03,   0.00000000e+00,
         3.65032201e-03,   0.00000000e+00,  -2.34207918e-03,
        -4.04803882e-02,   9.94158069e-03,   1.15021930e-02,
         1.58982474e-03,   1.54815043e-03,   0.00000000e+00,
        -3.90379237e-04,   0.00000000e+00,  -9.13947816e-03,
        -1.15740105e-02,  -2.76889153e-03,  -2.90733967e-03,
         0.00000000e+00,   2.17467590e-02,   0.00000000e+00,
        -5.04999645e-05,  -6.35473735e-03,  -2.79549142e-02,
         6.13187174e-03,  -5.35872338e-03,  -9.05343347e-04,
         2.81519077e-03,   0.00000000e+00,  -2.29965425e-04,
         0.00000000e+00,   1.04586840e-02,   1.29521090e-04,
         5.01024342e-03,   2.48300304e-03,   0.00000000e+00,
        -1.82930321e-03,   0.00000000e+00,  -1.05517621e-02,
        -3.87135978e-04,  -5.31583210e-03,  -3.79322817e-02,
        -4.17184749e-02,   8.23114357e-03,  -7.12566291e-03,
        -1.24694021e-02,  -3.70520489e-02,  -2.63132477e-02,
         1.82646072e-03,   7.79692386e-03,  -9.33200349e-03,
        -3.90170127e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.99900700e-02,
         6.92886712e-03,   1.85819697e-02,  -7.00148029e-03,
         1.20928469e-03,   0.00000000e+00,  -4.18638549e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.13246907e-03,   0.00000000e+00,
        -2.82869570e-02,   5.22864254e-03,   2.02848608e-02,
        -6.67055153e-03,   7.22087143e-03,   0.00000000e+00,
        -5.86420954e-04,   0.00000000e+00,  -3.24045625e-02,
         2.10749192e-03,   9.26465485e-03,  -2.53976318e-02,
        -2.86664452e-03,   0.00000000e+00,   2.12585252e-02,
         0.00000000e+00,   1.91735039e-02,   2.37871421e-02,
         5.25074221e-03,   3.04534927e-02,  -4.15779537e-02,
         2.66564818e-03,   0.00000000e+00,   3.57592466e-02,
         0.00000000e+00,   5.89112531e-03,   1.62195391e-02,
         8.47383114e-02,  -2.40443063e-03,   2.28460261e-03,
         1.17186211e-02,   1.41631160e-02,   0.00000000e+00,
        -1.31133947e-02,   0.00000000e+00,   1.32304435e-02,
         3.88690926e-03,   1.08470055e-02,  -4.16547104e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -7.77624026e-03,   0.00000000e+00,
        -2.21185726e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.58351859e-02,
        -3.16088262e-03,   6.67193589e-03,  -1.24275327e-02,
         4.43177690e-03,   0.00000000e+00,   1.16272438e-03,
         0.00000000e+00,   2.04781095e-02,  -7.18460471e-03,
         1.22809949e-04,   1.10966595e-02,   0.00000000e+00,
        -2.78588789e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.24976121e-02,
         0.00000000e+00,  -1.05651062e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.91790041e-03,   0.00000000e+00,  -3.60502727e-02,
        -4.06993851e-03,  -8.44690006e-04,   6.58602650e-03,
         9.03031884e-03,   0.00000000e+00,   1.28036541e-02,
         0.00000000e+00,   4.63954190e-05,  -3.07183226e-03,
        -1.73844807e-02,  -1.74830838e-04,   0.00000000e+00,
        -3.74768022e-04,   0.00000000e+00,  -3.88640577e-02,
        -3.81355496e-04,   7.12280852e-03,   7.15908542e-03,
        -8.58668435e-03,   0.00000000e+00,   1.85615376e-03,
         0.00000000e+00,   3.37834261e-03,  -4.42400945e-04,
         6.52674840e-03,  -7.27922242e-04,   0.00000000e+00,
         3.76442441e-03,   0.00000000e+00,  -5.75922034e-04,
        -3.95532303e-02,   1.25265433e-02,   1.57723420e-02,
         1.32944558e-03,   4.09204390e-03,   0.00000000e+00,
        -5.94538892e-03,   0.00000000e+00,  -7.70346386e-03,
        -1.01475497e-02,  -1.81042811e-03,  -7.65439992e-03,
         0.00000000e+00,   2.27168113e-02,   0.00000000e+00,
         4.89063316e-03,  -5.68879899e-03,  -2.69433051e-02,
         7.64002529e-03,  -7.81689453e-03,  -4.94350868e-03,
         9.43480196e-04,   0.00000000e+00,  -1.53610787e-03,
         0.00000000e+00,   1.02770748e-02,   1.53522051e-03,
         8.50538394e-03,   7.57168938e-03,   0.00000000e+00,
        -2.09694762e-03,   0.00000000e+00,  -3.74025004e-03,
         2.15369378e-03,  -5.41359135e-03,  -3.66106445e-02,
        -1.71540450e-02,   5.50314570e-02,   8.46600115e-02,
         1.82005704e-02,  -1.52047901e-02,   4.55883326e-02,
         1.87753816e-04,   3.21777655e-02,   4.93393069e-03,
        -2.81210845e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.00470358e-02,
        -2.64255311e-03,  -2.49118984e-02,  -7.32642240e-02,
        -5.36576211e-02,   0.00000000e+00,   4.49689588e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   3.15284375e-02,   0.00000000e+00,
         1.01902551e-01,  -2.78341674e-02,  -1.65668966e-02,
        -3.21486664e-02,   5.01536225e-02,   0.00000000e+00,
        -2.96580993e-02,   0.00000000e+00,   6.31089364e-02,
        -7.37190246e-05,  -2.78940479e-02,   3.55693584e-02,
        -1.45791082e-02,   0.00000000e+00,  -7.44368350e-03,
         0.00000000e+00,  -1.13303330e-02,   4.63432639e-02,
        -4.96262130e-03,  -9.34829199e-03,   2.10597224e-02,
         1.11380912e-02,   0.00000000e+00,  -1.31133947e-02,
         0.00000000e+00,   4.96983339e-03,   2.74524271e-02,
         4.71549481e-02,  -4.05119275e-03,  -1.29907180e-02,
        -3.73039357e-02,  -3.75913989e-02,   0.00000000e+00,
         8.80892639e-02,   0.00000000e+00,  -4.40112359e-02,
        -1.09496632e-02,  -3.06627004e-02,   1.15489554e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.80608019e-03,   0.00000000e+00,
         8.72427273e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.27134637e-01,
         1.98205661e-03,  -9.73932552e-03,   4.12007578e-02,
        -2.74264228e-02,   0.00000000e+00,  -1.14276076e-02,
         0.00000000e+00,  -4.66449255e-02,   4.41154258e-02,
         2.14298224e-02,   8.69778752e-03,   0.00000000e+00,
         1.04173343e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.38060786e-02,
         0.00000000e+00,   6.03610950e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         3.62652680e-02,   0.00000000e+00,  -3.55665480e-02,
         8.33147428e-04,   9.13676015e-03,   3.24891110e-02,
         2.99827532e-02,   0.00000000e+00,   7.09386086e-03,
         0.00000000e+00,   5.36209237e-03,   4.39757658e-03,
        -1.62820987e-03,  -4.07150017e-02,   0.00000000e+00,
         1.53340402e-02,   0.00000000e+00,  -3.68012283e-02,
        -7.21477751e-03,   7.20686150e-04,   6.22487954e-03,
        -1.28916375e-02,   0.00000000e+00,   9.92996903e-03,
         0.00000000e+00,   3.99738322e-02,  -1.14203193e-02,
         2.45434718e-03,  -1.09844659e-02,   0.00000000e+00,
        -3.59835715e-02,   0.00000000e+00,  -4.49197216e-03,
        -3.14609121e-02,  -1.16573807e-02,  -6.61132566e-02,
        -1.13218216e-02,  -1.53290610e-02,   0.00000000e+00,
         2.43697346e-02,   0.00000000e+00,   2.67874936e-02,
         1.66293914e-02,   1.01844249e-02,   1.38251334e-02,
         0.00000000e+00,   1.21404583e-02,   0.00000000e+00,
        -8.75841993e-03,   2.00351671e-02,   9.56225986e-02,
         3.33836600e-02,   6.82199335e-03,   1.64994513e-03,
         5.79633996e-03,   0.00000000e+00,  -8.00426360e-03,
         0.00000000e+00,   5.08149824e-03,  -9.12986869e-03,
         2.07039291e-03,  -2.18221902e-03,   0.00000000e+00,
         6.34384803e-03,   0.00000000e+00,   9.48659576e-03,
         7.76990141e-04,  -5.03513762e-02,  -2.16576193e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.28923950e-03,  -1.20310805e-03,
         8.18614025e-04,   8.41883800e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.33512223e-03,   0.00000000e+00,
        -4.72826308e-03,  -1.20698785e-02,  -6.88394026e-03,
        -5.73371946e-03,   0.00000000e+00,   9.01902719e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   8.30094537e-04,
         0.00000000e+00,   1.64516167e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.94071352e-04,   0.00000000e+00,
         1.92434258e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -5.29035013e-04,   0.00000000e+00,
        -9.47829252e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.48945382e-03,
         0.00000000e+00,   1.41900647e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -3.69559555e-03,  -9.62794008e-03,  -7.87146666e-03,
        -7.06225553e-03,   0.00000000e+00,   1.39142847e-02,
         0.00000000e+00,  -1.79996062e-04,   5.10138541e-04,
        -1.96534249e-03,   1.03938717e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.96827851e-04,   0.00000000e+00,
        -1.17863073e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.48512328e-03,
         0.00000000e+00,  -1.18505247e-03,  -1.97448252e-03,
        -3.99834517e-03,  -2.38576435e-03,   0.00000000e+00,
         3.04598316e-06,   0.00000000e+00,  -5.62794586e-04,
         3.92489723e-05,   1.68800857e-04,   2.65419854e-03,
         0.00000000e+00,  -2.67042934e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.88844224e-03,   0.00000000e+00,
        -3.50700911e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.78832577e-03,
         0.00000000e+00,   2.44643310e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.18311162e-03,   0.00000000e+00,
         1.78950893e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.98231168e-03,
         0.00000000e+00,   1.02781422e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.07742218e-03,
         0.00000000e+00,   8.97662409e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.21916203e-02,   0.00000000e+00,   1.42289546e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.01060029e-03,   0.00000000e+00,
        -2.23801617e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.32501008e-03,
         0.00000000e+00,  -2.40693830e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.48344830e-02,  -1.56850531e-02,  -9.39276489e-03,
        -1.85779148e-03,   4.14340703e-03,  -4.61883814e-03,
         9.10320471e-03,  -8.61909868e-03,  -1.09094991e-04,
         1.77641036e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.17732090e-02,
         6.16948625e-03,  -1.38301366e-03,   1.91734938e-02,
         1.22109836e-02,   0.00000000e+00,   4.52449275e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.80737259e-03,   0.00000000e+00,
        -1.45498959e-02,   7.89634886e-03,   6.95526861e-03,
         1.25667557e-02,  -1.00560276e-02,   0.00000000e+00,
         4.79796558e-03,   0.00000000e+00,  -5.75202823e-03,
        -1.76966757e-03,   2.57871023e-03,  -7.97151161e-03,
         1.55527246e-03,   0.00000000e+00,   2.12689455e-03,
         0.00000000e+00,  -9.35539590e-04,  -1.02432164e-02,
         3.98535044e-04,   2.85824971e-03,  -4.97686653e-03,
        -2.47813288e-03,   0.00000000e+00,   1.16272438e-03,
         0.00000000e+00,   2.49347285e-03,  -3.65775517e-03,
        -9.73816145e-03,  -5.16427217e-04,  -1.47097436e-03,
         8.64856851e-03,  -2.88410221e-03,   0.00000000e+00,
        -1.14276076e-02,   0.00000000e+00,  -2.95695159e-03,
         8.34155171e-03,   8.55702933e-03,  -1.26040940e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.75905833e-03,   0.00000000e+00,
        -1.25116641e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.85705950e-02,
        -1.48950015e-03,  -6.53606007e-03,  -1.23813307e-02,
         9.27981169e-04,   0.00000000e+00,   1.50258033e-02,
         0.00000000e+00,   4.82775772e-03,  -8.59307314e-03,
        -4.29360410e-03,   9.52753547e-04,   0.00000000e+00,
        -1.79488671e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.17097284e-02,
         0.00000000e+00,   1.38350027e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -9.21906175e-03,   0.00000000e+00,   2.00281007e-02,
        -5.35724963e-03,   1.33303241e-03,  -9.12986962e-03,
        -1.07885295e-02,   0.00000000e+00,  -6.17991847e-03,
         0.00000000e+00,   1.11488811e-03,  -2.58448897e-03,
         8.13510334e-04,   9.04461706e-03,   0.00000000e+00,
        -7.09422343e-03,   0.00000000e+00,   2.17065664e-02,
         4.03173305e-04,   1.23786531e-03,   5.11129626e-04,
         7.60544907e-03,   0.00000000e+00,  -2.32215851e-03,
         0.00000000e+00,  -8.45168502e-03,   2.69098625e-03,
        -7.98106561e-04,   2.80986659e-04,   0.00000000e+00,
         1.01633997e-02,   0.00000000e+00,   5.09801930e-04,
         2.05417740e-02,  -9.68403364e-04,   9.03188136e-03,
         3.03598100e-03,  -2.61437695e-03,   0.00000000e+00,
        -4.79822101e-03,   0.00000000e+00,  -1.30412408e-02,
         2.78569023e-03,   1.37630075e-03,   2.08150297e-03,
         0.00000000e+00,  -2.43112094e-03,   0.00000000e+00,
         4.44181587e-03,  -8.04626972e-03,  -1.37606303e-02,
        -1.14791122e-02,   1.64988717e-03,  -4.46013306e-03,
        -2.59375118e-03,   0.00000000e+00,  -2.07124827e-03,
         0.00000000e+00,  -2.22588830e-03,   8.90868468e-04,
        -6.81007181e-04,  -1.22980273e-03,   0.00000000e+00,
        -5.54986836e-03,   0.00000000e+00,   6.05935918e-03,
        -1.21548744e-03,   1.30048190e-02,   1.61597275e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -9.34491072e-04,   1.25232678e-04,
        -4.55960343e-03,  -3.38173719e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -6.92213548e-03,   0.00000000e+00,
         9.34715990e-04,   1.04508301e-03,   1.86081877e-03,
         1.32055687e-03,   0.00000000e+00,   1.47940693e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -2.61632082e-03,
         0.00000000e+00,   5.60923273e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   7.78210174e-04,   0.00000000e+00,
        -1.76582098e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.25513031e-03,   0.00000000e+00,
        -1.27189179e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.80507147e-03,
         0.00000000e+00,   2.21940409e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.08685261e-03,  -1.90500292e-03,  -4.12817988e-03,
        -2.84032338e-03,   0.00000000e+00,   3.04598316e-06,
         0.00000000e+00,  -1.17456070e-03,  -3.06968359e-04,
         2.33648955e-04,   8.18952309e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -1.84046338e-03,   0.00000000e+00,
        -4.31248217e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.35189830e-04,
         0.00000000e+00,   1.33804300e-04,   6.48517378e-04,
         8.14508513e-03,   5.15491549e-03,   0.00000000e+00,
         1.17983138e-02,   0.00000000e+00,   3.02534833e-03,
        -1.11884573e-03,  -7.83038306e-04,  -2.67388969e-03,
         0.00000000e+00,   8.07643965e-04,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.35147021e-02,   0.00000000e+00,
        -4.54066007e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   2.11065132e-03,
         0.00000000e+00,  -5.94601498e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   4.90310484e-03,   0.00000000e+00,
        -9.42940965e-04,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.19416255e-04,
         0.00000000e+00,  -1.97094501e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.53829677e-03,
         0.00000000e+00,   2.66790190e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -6.04674516e-04,   0.00000000e+00,  -1.06846286e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.83712440e-04,   0.00000000e+00,
        -1.26567952e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.26824617e-04,
         0.00000000e+00,  -1.01239109e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -1.32386108e-01,   3.70527415e-02,  -6.15606635e-02,
         4.21078181e-03,  -1.46963669e-02,  -8.44454896e-02,
         4.14609581e-03,   1.73414812e-02,   2.44390793e-04,
        -1.22009323e-01,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -1.41009547e-01,
        -5.60249079e-03,  -7.77807518e-03,  -5.15273362e-02,
        -3.63941904e-02,   0.00000000e+00,  -1.02575307e-01,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.78805219e-02,   0.00000000e+00,
        -4.07565497e-02,  -2.67468808e-02,   6.14605293e-03,
        -2.78799503e-02,   3.42667686e-02,   0.00000000e+00,
        -2.01034099e-02,   0.00000000e+00,  -8.65391251e-02,
         1.39898904e-02,   4.74858386e-03,   1.55015729e-03,
        -6.17479859e-03,   0.00000000e+00,   8.50697786e-03,
         0.00000000e+00,   1.88909100e-02,  -2.24889095e-02,
        -5.48434561e-03,   2.29760870e-03,   3.83646663e-03,
         1.32322350e-02,   0.00000000e+00,   1.28036541e-02,
         0.00000000e+00,  -1.07598522e-02,  -8.09777630e-03,
        -2.95920612e-02,  -2.87747062e-03,   8.53323469e-03,
         3.26857386e-02,   3.17861266e-02,   0.00000000e+00,
         7.09386086e-03,   0.00000000e+00,   1.43656776e-02,
         4.32154544e-03,   5.55283015e-04,  -4.43683614e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -2.95259635e-02,   0.00000000e+00,
        -1.55612058e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.76107532e-02,
        -1.69483991e-02,   1.22781142e-02,  -1.25341773e-02,
        -1.81022453e-02,   0.00000000e+00,  -6.17991847e-03,
         0.00000000e+00,   1.93290368e-02,  -1.31465114e-02,
        -3.60868393e-03,   1.48752059e-03,   0.00000000e+00,
        -4.28971871e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   9.43221418e-02,
         0.00000000e+00,  -3.17775348e-02,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         2.59828714e-02,   0.00000000e+00,  -1.32699652e-01,
        -6.15372673e-03,   2.22151627e-03,   4.96133021e-02,
         6.41027337e-02,   0.00000000e+00,   9.26369234e-02,
         0.00000000e+00,   6.20231158e-03,  -5.22173775e-03,
        -1.85297483e-02,  -3.69546149e-02,   0.00000000e+00,
         1.79262873e-02,   0.00000000e+00,  -1.32755920e-01,
        -6.60988322e-03,   2.54960577e-02,   4.83892923e-02,
        -5.78268268e-02,   0.00000000e+00,   2.57078112e-02,
         0.00000000e+00,   5.31682451e-02,  -1.25877271e-02,
         7.74771048e-03,  -1.82128268e-03,   0.00000000e+00,
        -1.34239799e-02,   0.00000000e+00,  -4.05159199e-03,
        -1.35680721e-01,   4.23233340e-02,  -2.98782058e-03,
         1.05670094e-03,   1.39549067e-02,   0.00000000e+00,
        -2.55050221e-03,   0.00000000e+00,   5.65520675e-03,
        -9.43504328e-03,   6.62512078e-05,   4.34761066e-03,
         0.00000000e+00,   1.04679862e-02,   0.00000000e+00,
        -5.12340380e-03,   6.69118252e-04,  -5.86883572e-02,
         7.48992520e-02,  -4.04940347e-02,  -9.90688674e-03,
        -7.23450523e-04,   0.00000000e+00,   5.91512113e-03,
         0.00000000e+00,   3.14522752e-02,  -1.12360067e-02,
         6.45266770e-03,   3.54157773e-03,   0.00000000e+00,
         1.44812923e-02,   0.00000000e+00,   4.45617943e-03,
        -5.49256638e-03,  -4.03602563e-02,  -1.28869680e-01,
        -3.91952544e-02,   1.54218597e-02,  -1.39543407e-02,
         6.52380796e-03,  -3.94080507e-03,  -2.13493084e-02,
         2.20481964e-03,   5.73904621e-03,   3.52567468e-03,
        -3.12362666e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -4.44142066e-02,
        -1.00843436e-03,  -7.94606869e-03,  -2.57375711e-02,
        -8.52333193e-03,   0.00000000e+00,  -2.63334516e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   1.11965062e-02,   0.00000000e+00,
        -2.85831735e-03,  -1.11538014e-02,  -2.33861216e-03,
        -1.75829229e-02,   1.25664199e-02,   0.00000000e+00,
        -7.84964527e-03,   0.00000000e+00,  -2.30465899e-02,
         5.64399370e-03,   3.22663802e-03,   4.53238565e-03,
        -2.10072838e-03,   0.00000000e+00,   1.45288950e-03,
         0.00000000e+00,   4.44206942e-03,  -3.11674368e-03,
        -1.18480853e-03,   3.52475902e-03,   2.24967536e-03,
         3.99557804e-03,   0.00000000e+00,   1.85615376e-03,
         0.00000000e+00,  -3.01124810e-03,   9.20290638e-04,
        -1.53241421e-03,  -3.82780452e-03,   1.21994941e-03,
         6.32279845e-03,   3.48083884e-03,   0.00000000e+00,
         9.92996903e-03,   0.00000000e+00,   5.93515053e-03,
        -1.00530799e-03,  -1.82921301e-03,  -6.13306333e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -8.71857131e-03,   0.00000000e+00,
         3.20281835e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -3.00047763e-03,
        -3.40029120e-03,   5.68243054e-03,   3.77866797e-03,
        -4.12596162e-03,   0.00000000e+00,  -2.32215851e-03,
         0.00000000e+00,   1.40754415e-03,  -4.26962837e-04,
         1.18285380e-03,  -2.56591744e-03,   0.00000000e+00,
        -2.42910574e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.24718108e-02,
         0.00000000e+00,  -8.85860238e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         1.06790708e-02,   0.00000000e+00,  -4.21191192e-02,
        -5.94862089e-03,   6.81134057e-03,   2.19944575e-02,
         9.30891270e-03,   0.00000000e+00,   2.57078112e-02,
         0.00000000e+00,   7.25128489e-03,  -1.89689157e-03,
        -4.62648802e-03,  -1.27500597e-02,   0.00000000e+00,
         5.79718837e-03,   0.00000000e+00,  -3.91108114e-02,
        -3.78807528e-03,   1.07118478e-02,   2.51018883e-02,
        -1.82231244e-02,   0.00000000e+00,   2.19632581e-02,
         0.00000000e+00,   2.57476633e-02,  -6.85414543e-03,
         1.23304861e-03,  -2.30088786e-03,   0.00000000e+00,
        -6.55377602e-03,   0.00000000e+00,  -7.78073540e-03,
        -4.65296533e-02,   1.21083689e-02,  -5.23881442e-03,
        -5.33611256e-03,   6.12752701e-04,   0.00000000e+00,
         1.10447539e-03,   0.00000000e+00,   3.60105302e-03,
        -4.12282072e-03,  -1.07655604e-03,   4.64395495e-03,
         0.00000000e+00,  -1.62155256e-03,   0.00000000e+00,
        -2.41499819e-03,   2.26988474e-03,  -9.77048914e-03,
         2.57475458e-02,  -1.19403174e-02,  -3.67822376e-03,
        -2.41290524e-03,   0.00000000e+00,  -2.35462866e-03,
         0.00000000e+00,   8.51128516e-03,  -2.82551823e-03,
         3.69783818e-03,   1.08738947e-03,   0.00000000e+00,
         5.40791381e-03,   0.00000000e+00,   3.11771009e-03,
        -1.66303826e-03,  -1.58871316e-02,  -4.14481158e-02,
         6.16857225e-03,   9.70342153e-03,   2.11954255e-02,
        -8.54418949e-05,   1.10264907e-02,   2.37037217e-02,
        -9.32342068e-03,   1.27601190e-02,   4.63643178e-03,
         9.79074680e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   1.22547693e-03,
        -1.72276019e-02,  -8.60223501e-03,  -1.74675357e-02,
        -1.46880965e-02,   0.00000000e+00,   2.42772295e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   6.76761948e-03,   0.00000000e+00,
         3.04580845e-02,  -7.15808877e-03,  -9.09054703e-04,
        -1.25067985e-02,   6.11909589e-03,   0.00000000e+00,
        -6.01735575e-03,   0.00000000e+00,   1.64795655e-02,
         3.46507597e-03,  -5.75998597e-04,   9.42326579e-03,
        -2.57515733e-03,   0.00000000e+00,  -3.90379237e-04,
         0.00000000e+00,  -8.91176111e-03,   9.19073488e-03,
         3.07393309e-03,   2.56223768e-03,   5.42803933e-03,
         3.39949589e-03,   0.00000000e+00,  -5.94538892e-03,
         0.00000000e+00,  -1.24228814e-03,   5.09029872e-03,
         1.04987096e-02,  -3.65069139e-03,  -2.17622770e-02,
        -1.19591597e-02,  -1.24526932e-02,   0.00000000e+00,
         2.43697346e-02,   0.00000000e+00,  -5.95366210e-03,
        -1.29736824e-03,  -3.50360759e-03,   3.55615423e-02,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   2.05798946e-03,   0.00000000e+00,
         2.43229695e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   3.68117150e-02,
         3.91894146e-04,  -1.10145256e-04,   9.40704989e-03,
        -8.67356224e-03,   0.00000000e+00,  -4.79822101e-03,
         0.00000000e+00,  -1.75220791e-02,   1.14723234e-02,
         7.07443930e-03,   9.71573615e-04,   0.00000000e+00,
         2.65634724e-02,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   6.34795987e-03,
         0.00000000e+00,   3.82049891e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         6.67318192e-03,   0.00000000e+00,   5.43572832e-04,
         1.40208368e-02,  -6.85072190e-04,   5.55497996e-03,
         8.77021585e-03,   0.00000000e+00,  -2.55050221e-03,
         0.00000000e+00,   2.57677249e-03,  -2.60303560e-04,
         2.09071384e-03,  -7.72863945e-03,   0.00000000e+00,
         5.00090443e-03,   0.00000000e+00,   2.66037085e-03,
         3.87425539e-03,  -1.17992114e-03,  -4.25250190e-03,
        -3.88887380e-03,   0.00000000e+00,   1.10447539e-03,
         0.00000000e+00,   6.39373505e-03,  -3.52295563e-03,
        -1.58595137e-03,   2.14584602e-04,   0.00000000e+00,
        -1.01378593e-02,   0.00000000e+00,  -8.23152668e-04,
         1.93305315e-03,   1.41120766e-05,  -1.06034082e-02,
        -9.12278625e-03,  -7.97871945e-03,   0.00000000e+00,
         2.53683453e-02,   0.00000000e+00,  -3.03761694e-05,
         1.83469212e-04,  -4.82396860e-03,   1.32859144e-02,
         0.00000000e+00,  -4.09394357e-03,   0.00000000e+00,
        -1.12659760e-02,   4.45304243e-03,   2.41942491e-02,
         7.81169659e-03,   9.96349682e-04,   1.21873959e-02,
         7.99221891e-03,   0.00000000e+00,   4.20453494e-03,
         0.00000000e+00,   5.68317848e-03,  -2.07346838e-03,
         2.06717949e-04,  -9.10395169e-03,   0.00000000e+00,
         3.95665681e-03,   0.00000000e+00,  -1.07566548e-02,
        -1.81277425e-03,  -1.11971163e-02,   4.54974880e-03,
        -1.00590692e-02,  -2.22239775e-03,  -9.69016871e-03,
        -7.46690218e-03,   9.55938810e-03,  -1.64777113e-03,
        -3.21487185e-04,  -1.49934106e-04,  -1.36897458e-04,
        -9.88420818e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -6.84811725e-03,
        -1.35975712e-02,   4.89551844e-03,   9.58668126e-04,
         1.05674222e-04,   0.00000000e+00,  -8.95715785e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   8.45164444e-04,   0.00000000e+00,
        -6.08095371e-03,  -9.18508361e-03,   1.83497463e-03,
        -4.28206122e-03,  -3.72396618e-03,   0.00000000e+00,
        -1.55744359e-03,   0.00000000e+00,  -1.29244602e-02,
         3.82284458e-03,   2.20435284e-03,   3.64669968e-03,
         3.57537193e-03,   0.00000000e+00,  -2.29965425e-04,
         0.00000000e+00,   2.61668987e-03,  -8.22286720e-03,
         3.42442929e-03,  -1.67103997e-04,  -2.45891978e-04,
        -4.83404998e-04,   0.00000000e+00,  -1.53610787e-03,
         0.00000000e+00,  -3.94136204e-04,   4.79424842e-04,
        -7.54453271e-03,   1.24074467e-02,   4.23083992e-03,
         4.80801252e-03,   4.83484278e-03,   0.00000000e+00,
        -8.00426360e-03,   0.00000000e+00,   3.66193343e-03,
         3.20719350e-03,   1.91860094e-03,  -8.41118527e-03,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,  -3.03285070e-03,   0.00000000e+00,
        -8.19640727e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,  -9.06428144e-03,
        -6.23457533e-03,   1.49290035e-03,  -9.88038006e-03,
        -2.82167563e-03,   0.00000000e+00,  -2.07124827e-03,
         0.00000000e+00,   3.11762333e-03,  -5.21277023e-03,
        -3.14177905e-03,  -5.90970579e-03,   0.00000000e+00,
        -4.93151786e-03,   0.00000000e+00,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   4.99289413e-03,
         0.00000000e+00,  -2.79754491e-03,   0.00000000e+00,
         0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
        -2.38103216e-04,   0.00000000e+00,  -7.56754677e-03,
         2.72860039e-02,  -1.51899428e-02,  -4.44170984e-03,
         2.61092217e-03,   0.00000000e+00,   5.91512113e-03,
         0.00000000e+00,   5.90973000e-03,  -2.66516360e-03,
        -6.87645209e-04,  -3.09285400e-04,   0.00000000e+00,
         3.73672819e-03,   0.00000000e+00,  -5.50487289e-03,
         8.79316631e-03,  -2.92701954e-03,   1.26133326e-03,
        -4.15026941e-03,   0.00000000e+00,  -2.35462866e-03,
         0.00000000e+00,   2.54783875e-03,   1.11098355e-04,
         2.78286414e-03,   3.78456134e-03,   0.00000000e+00,
        -2.37842340e-04,   0.00000000e+00,   7.90044457e-04,
        -5.65493705e-03,   5.78173161e-03,   1.75729749e-03,
         1.28841979e-02,   1.08411586e-02,   0.00000000e+00,
         4.20453494e-03,   0.00000000e+00,   5.31543062e-03,
        -1.42580257e-03,   2.79563216e-04,  -1.17475292e-03,
         0.00000000e+00,  -3.71694107e-03,   0.00000000e+00,
        -6.46618709e-03,  -4.14164103e-03,  -1.14943365e-02,
         6.70854893e-03,  -1.63330282e-03,   1.64261265e-02,
         1.24441025e-02,   0.00000000e+00,   3.02754523e-02,
         0.00000000e+00,   8.53890772e-03,  -3.10521460e-03,
        -1.74509126e-03,  -5.63663103e-03,   0.00000000e+00,
         3.24619907e-03,   0.00000000e+00,  -8.00252757e-03,
        -1.01854864e-02,  -8.72568227e-04,  -1.12479409e-02])
  else:
    arr = None
  return (asym,n,dimens,arr)

if __name__ == '__main__': main()
